# (akien) Partially synced with Fedora (patches, license checks, manpage).

# "fix" underlinking:
%define _disable_ld_no_undefined 1


# http://trac.wildfiregames.com/wiki/BuildInstructions#Linux

%bcond_without	system_mozjs115

# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{_libdir}/0ad/
%global __requires_exclude ^(libAtlasUI.*\.so|libCollada.*\.so|libmozjs115.*\.so)

Name:		0ad
Epoch:		1
Version:	0.27.0
Release:	%mkrel 2
License:	GPLv2+ and BSD and MIT and IBM and MPLv2.0
Group:		Games/Strategy
Summary:	Cross-Platform RTS Game of Ancient Warfare
Url:		https://play0ad.com/
Source0:	https://releases.wildfiregames.com/%{name}-%{version}-unix-build.tar.xz
Source1:	https://releases.wildfiregames.com/%{name}-%{version}-unix-build.tar.xz.sha1sum
# adapted from binaries/system/readme.txt
# It is advisable to review this file at on newer versions, to update the
# version field and check for extra options. Note that windows specific,
# and disabled options were not added to the manual page.
Source2:	%{name}.6
Source3:	premake-disable-rpath.patch

BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	cxxtest
BuildRequires:	icu-devel
BuildRequires:	miniupnpc-devel
BuildRequires:	pkgconfig(gloox)
BuildRequires:	pkgconfig(fmt)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libenet)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libsodium)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(valgrind)
BuildRequires:	pkgconfig(vorbisfile)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	wxgtk-devel

%if %{without system_mozjs115}
# bundled mozjs
BuildRequires:	pkgconfig(nspr)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(readline)
BuildRequires:	rustc
BuildRequires:	cargo
BuildRequires:	zip
# for patching bundled mozjs
BuildRequires:	git-core
%else
BuildRequires:	pkgconfig(mozjs-115)
%endif

# bundled mozjs: For build time tests only
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
BuildRequires:	perl-devel

ExclusiveArch:	%{ix86} x86_64 %{arm} aarch64 ppc64le

%if %{without system_mozjs115}
Provides:	bundled(mozjs) = 115
%endif

Requires:	%{name}-data = %{epoch}:%{version}

# Fedora patches

# Mageia patches

%description
0 A.D. (pronounced "zero ey-dee") is a free, open-source, cross-platform
real-time strategy (RTS) game of ancient warfare. In short, it is a
historically-based war/economy game that allows players to relive or rewrite
the history of Western civilizations, focusing on the years between 500 B.C.
and 500 A.D. The project is highly ambitious, involving state-of-the-art 3D
graphics, detailed artwork, sound, and a flexible and powerful custom-built
game engine.

The game has been in development by Wildfire Games (WFG), a group of volunteer,
hobbyist game developers, since 2001.

%prep
%setup -q

rm -fr libraries/source/nvtt
rm -fr libraries/source/valgrind
# (tv) prevent underlinking
sed -i 's!-Wl,--no-undefined!!' build/premake/premake5.lua
cp %SOURCE3 libraries/source/premake-core/patches/
sed -i -e 's_# patch_# patch\npatch -d "premake-core-${PV}" -p1 <patches/premake-disable-rpath.patch_' libraries/source/premake-core/build.sh

%build
%set_build_flags

libraries/source/fcollada/build.sh
libraries/source/premake-core/build.sh
build/workspaces/update-workspaces.sh \
    --bindir=%{_bindir} \
    --datadir=%{_gamesdatadir}/%{name} \
    --libdir=%{_libdir}/%{name} \
    --without-tests \
%if %{with system_mozjs115}
    --with-system-mozjs \
%endif
    --without-nvtt

%make_build -C build/workspaces/gcc config=release verbose=1

%install
install -d %{buildroot}%{_bindir}
install -m755 binaries/system/ActorEditor %{buildroot}%{_bindir}/ActorEditor
install -m755 binaries/system/pyrogenesis %{buildroot}%{_bindir}/pyrogenesis
install -m755 build/resources/0ad.sh      %{buildroot}%{_bindir}/%{name}

install -d %{buildroot}%{_libdir}/%{name}
for name in AtlasUI Collada; do
    install -p -m 755 binaries/system/lib${name}.so %{buildroot}%{_libdir}/%{name}/lib${name}.so
done

%if %{without system_mozjs115}
name=mozjs115-ps-release
install -p -m 755 binaries/system/lib${name}.so %{buildroot}%{_libdir}/%{name}/lib${name}.so
%endif

install -D -m644 build/resources/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m644 build/resources/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -D -m644 build/resources/%{name}.png %{buildroot}%{_iconsdir}/hicolor/128x128/apps/%{name}.png

install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -a binaries/data/* %{buildroot}%{_gamesdatadir}/%{name}

install -D -m644 %{_sourcedir}/%{name}.6 %{buildroot}%{_mandir}/man6/%{name}.6
ln -sf %{name}.6 %{buildroot}%{_mandir}/man6/pyrogenesis.6

%files
%doc README.md
%license LICENSE.md license_gpl-2.0.txt license_lgpl-2.1.txt license_mit.txt
%{_bindir}/%{name}
%{_bindir}/pyrogenesis
%{_bindir}/ActorEditor
%{_gamesdatadir}/%{name}/
%{_libdir}/%{name}/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/128x128/apps/%{name}.png
%{_mandir}/man6/*.6*
