%global __requires_exclude ^/usr/bin/repl-monitor.pl


%global pkgname   dirsrv

# systemd support
%global groupname %{pkgname}.target

Summary:          389 Administration Server (admin)
Name:             389-admin
Version:          1.1.46
Release:          %mkrel 1
License:          GPLv2 and ASL 2.0
URL:              https://port389.org/
Group:            System/Servers

BuildRequires:    pkgconfig(nspr)
BuildRequires:    pkgconfig(nss)
BuildRequires:    openldap-devel
BuildRequires:    pkgconfig(libsasl2)
BuildRequires:    icu
BuildRequires:    libicu-devel
BuildRequires:    apache-devel
BuildRequires:    pkgconfig(apr-1)
BuildRequires:    apache-mod_nss
BuildRequires:    pkgconfig(389-adminutil) >= 1.1.21

Requires:         389-ds-base
Requires:         apache-mod_nss
Requires:         389-adminutil >= 1.1.21

# this is needed for using semanage from our setup scripts
Requires:         policycoreutils-python-utils

# the following are needed for some of our scripts
Requires:         perl-Mozilla-LDAP
Requires:         nss

# for systemd
Requires(post):  systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

Source0:          https://port389.org/sources/%{name}-%{version}%{?prerel}.tar.bz2
# 389-admin-git.sh should be used to generate the source tarball from git
Source1:          %{name}-git.sh
Patch0:           mageia-group.patch
Patch1:           389-admin-1.1.35-link.patch
Patch2:           mod_nss.patch
Patch3:           389-admin-fix-build-with-gcc14.patch

%description
389 Administration Server is an HTTP agent that provides management features
for 389 Directory Server.  It provides some management web apps that can
be used through a web browser.  It provides the authentication, access control,
and CGI utilities used by the console.

%prep
%setup -q -n %{name}-%{version}%{?prerel}
%autopatch -p1

%build
autoreconf -fi
%configure \
           --disable-rpath \
           --disable-static \
           --with-openldap \
           --with-systemdsystemunitdir=%{_unitdir} \
           --with-systemddirsrvgroupname=%{groupname} \
           --with-modnss-bin=%{_libexecdir}


# Generate symbolic info for debuggers
export XCFLAGS=$RPM_OPT_FLAGS

%ifarch x86_64
export USE_64=1
%endif

%make_build

%install
%make_install

# make console jars directory
mkdir -p %{buildroot}%{_datadir}/%{pkgname}/html/java

#remove libtool and static libs
rm -f %{buildroot}%{_libdir}/*.so
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/%{pkgname}/modules/*.la

%pre -p <lua>
-- save ownership/permissions on the dirs/files that rpm changes
-- if these don't exist, the vars will be nil
%{pkgname}admin_adminserv = posix.stat('%{_sysconfdir}/%{pkgname}/admin-serv')
%{pkgname}admin_consoleconf = posix.stat('%{_sysconfdir}/%{pkgname}/admin-serv/console.conf')

%post -p <lua>
-- do the usual daemon post setup stuff
os.execute('/bin/systemctl preset %{pkgname}-admin.service >/dev/null 2>&1 || :')
os.execute('/sbin/ldconfig')
-- restore permissions if upgrading
if %{pkgname}admin_adminserv then
    posix.chmod('%{_sysconfdir}/%{pkgname}/admin-serv', %{pkgname}admin_adminserv.mode)
    posix.chown('%{_sysconfdir}/%{pkgname}/admin-serv', %{pkgname}admin_adminserv.uid, %{pkgname}admin_adminserv.gid)
end
if %{pkgname}admin_consoleconf then
    posix.chmod('%{_sysconfdir}/%{pkgname}/admin-serv/console.conf', %{pkgname}admin_consoleconf.mode)
    posix.chown('%{_sysconfdir}/%{pkgname}/admin-serv/console.conf', %{pkgname}admin_consoleconf.uid, %{pkgname}admin_consoleconf.gid)
end

%preun
%_preun_service %{pkgname}-admin


%files
%doc LICENSE
%dir %{_sysconfdir}/%{pkgname}/admin-serv
%config(noreplace)%{_sysconfdir}/%{pkgname}/admin-serv/*.conf
%{_datadir}/%{pkgname}
%config(noreplace)%{_sysconfdir}/sysconfig/%{pkgname}-admin
%{_unitdir}/%{pkgname}-admin.service
%{_sbindir}/*
%{_libdir}/*.so.*
%{_libdir}/%{pkgname}
%{_mandir}/man8/*
