%define rel 6

%bcond_without qt5
%bcond_without qt6

Name:           accounts-qt
Version:        1.16
Release:        %mkrel %{rel}
Summary:        Accounts framework Qt bindings
Group:          System/Libraries
License:        LGPLv2
URL:            https://gitlab.com/groups/accounts-sso
Source0:        https://gitlab.com/accounts-sso/libaccounts-qt/-/archive/VERSION_%{version}/lib%{name}-VERSION_%{version}.tar.bz2
Patch0:         0001-Support-for-provider-tags.patch
# Qt6 branch of Nicolas Fella's fork https://gitlab.com/nicolasfella/libaccounts-qt
Patch1:         0001-Fix-libaccounts-glib-includes.patch
Patch2:         0002-Port-away-from-deprecated-QList::toSet.patch
Patch3:         0003-Use-undeprecated-Account::value.patch
Patch4:         0004-Do-not-access-a-QString_out-of-bounds.patch
Patch5:         0005-Adjust-buildsystem-to-include-correct-Qt-Major-version-number.patch

BuildRequires:  pkgconfig(libaccounts-glib)
BuildRequires:  doxygen

%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5Test)
%endif
%if %{with qt6}
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6Test)
%endif

%description
Framework to provide accounts for Qt.

#------------------------------------------------------------------------------
%if %{with qt5}

%define libaccounts_major 1
%define libaccounts_qt5 %mklibname accounts-qt5_ %{libaccounts_major}

%package -n     %{libaccounts_qt5}
Summary:        Runtime library for %{name}
Group:          System/Libraries

%description -n %{libaccounts_qt5}
Runtime libraries for %{name}.

%files -n %{libaccounts_qt5}
%{_libdir}/libaccounts-qt5.so.%{libaccounts_major}{,.*}

#---------------------------------------------------------------------------------

%define libaccounts_devel %mklibname accounts-qt5 -d

%package -n     %{libaccounts_devel}
Summary:        Headers files for %{name}
Group:          Development/KDE and Qt
Requires:       %{libaccounts_qt5} = %{version}-%{release}
Provides:       accounts-qt5-devel = %{version}-%{release}

%description -n %{libaccounts_devel}
Headers files for %{name}.

%files -n %{libaccounts_devel}
%{_includedir}/%{name}5/
%{_libdir}/libaccounts-qt5.so
%{_libdir}/cmake/AccountsQt5/
%{_libdir}/pkgconfig/accounts-qt5.pc
%{_bindir}/accountstest
%endif

#------------------------------------------------------------------------------
%if %{with qt6}

%define libaccountsqt6_major 1
%define libaccounts_qt6 %mklibname accounts-qt6_ %{libaccountsqt6_major}

%package -n     %{libaccounts_qt6}
Summary:        Runtime library for %{name}
Group:          System/Libraries

%description -n %{libaccounts_qt6}
Runtime libraries for %{name}.

%files -n %{libaccounts_qt6}
%{_libdir}/libaccounts-qt6.so.%{libaccountsqt6_major}{,.*}

#---------------------------------------------------------------------------------

%define libaccountsqt6_devel %mklibname accounts-qt6 -d

%package -n     %{libaccountsqt6_devel}
Summary:        Headers files for %{name}
Group:          Development/KDE and Qt
Requires:       %{libaccounts_qt6} = %{version}-%{release}
Provides:       accounts-qt6-devel = %{version}-%{release}

%description -n %{libaccountsqt6_devel}
Headers files for %{name}.

%files -n %{libaccountsqt6_devel}
%{_includedir}/%{name}6/
%{_libdir}/libaccounts-qt6.so
%{_libdir}/cmake/AccountsQt6/
%{_libdir}/pkgconfig/accounts-qt6.pc
%endif

#------------------------------------------------------------------------------

%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
Documentation for %{name}.

%files doc
%{_datadir}/doc/%{name}

#---------------------------------------------------------------------------------

%prep
%autosetup -p1 -n lib%{name}-VERSION_%{version}

sed -i 's|$${TOP_BUILD_DIR}/Accounts|../Accounts|' tests/tst_libaccounts.pro

mkdir -p qt5
mv $(ls |grep -v qt5) qt5/
cp -a qt5 qt6

%build
%if %{with qt5}
pushd qt5
%qmake_qt5 \
	QMF_INSTALL_ROOT=%{_prefix} \
	CONFIG+=release accounts-qt.pro \
	LIBDIR=%{_libdir} \
	TOP_SRC_DIR=..

%make_build
popd
%endif

%if %{with qt6}
pushd qt6
%qmake_qt6 \
	QMF_INSTALL_ROOT=%{_prefix} \
	CONFIG+=release accounts-qt.pro \
	LIBDIR=%{_libdir} \
	TOP_SRC_DIR=..

%make_build
popd
%endif

%install
%if %{with qt5}
%make_install -C qt5 INSTALL_ROOT=%{buildroot}
%endif

%if %{with qt6}
%make_install -C qt6 INSTALL_ROOT=%{buildroot}
%endif
