# The major and minor releases contain a full tarball.  Patch releases, however,
# contain only the parts that have changed, typically just the sources
# directory.  Use this to set up everything appropriately.
%global minorver 2.3
%global patchrel 3

%global debug_package %{nil}

Summary:        Automated theorem prover including linear arithmetic
Name:           alt-ergo
Version:        %{minorver}.%{patchrel}
Release:        %mkrel 1
Group:          Sciences/Computer science
# The project as a whole is Apache-2.0.
# The AB-Why3 plugin is LGPL-2.1-only WITH OCaml-LGPL-linking-exception
License:       Apache-2.0 AND LGPL-2.1-only WITH OCaml-LGPL-linking-exception
URL:           https://alt-ergo.ocamlpro.com/
# The patch releases contain only the sources directory.  The other files come
# from the minor releases.
Source0:       https://alt-ergo.ocamlpro.com/http/%{name}-free-%{minorver}.0/%{name}-free-%{minorver}.0.tar.gz
%if 0%{?patchrel} > 0
Source1:       https://alt-ergo.ocamlpro.com/http/%{name}-free-%{version}/%{name}-free-%{version}.tar.gz
%endif
Source4:        %{name}.metainfo.xml
# Do not use the deprecated Pervasives interface
Patch0:         %{name}-pervasives.patch
# Adapt to recent changes in psmt2-frontend
Patch1:         %{name}-psmt2-frontend.patch
# Temporarily use the menhir table backend instead of the code backend for the
# AB plugin.  Menhir is unable to infer types with the current code and layout.
# Check each new release to see if this is still necessary.
Patch2:         %{name}-menhir.patch
# Fedora does not need the forward compatibility seq and stdlib-shims packages
Patch3:         %{name}-forward-compat.patch
# Dune 3 eliminated the external-lib-deps command
Patch4:         %{name}-dune3.patch

BuildRequires:	make
BuildRequires:	ocaml >= 4.04.0
BuildRequires:	ocaml-dune
BuildRequires:	ocaml-menhir
BuildRequires:	ocaml-num-devel
BuildRequires:	ocaml-ocplib-simplex-devel >= 0.4
BuildRequires:	ocaml-psmt2-frontend-devel >= 0.2
BuildRequires:	ocaml-zarith-devel
BuildRequires:	ocaml-zip-devel

%global _desc %{expand:
Alt-Ergo is an automated theorem prover implemented in OCaml. It is
based on CC(X) - a congruence closure algorithm parameterized by an
equational theory X. This algorithm is reminiscent of the Shostak
algorithm. Currently CC(X) is instantiated by the theory of linear
arithmetics. Alt-Ergo also contains a home made SAT-solver and an
instantiation mechanism by which it fully supports quantifiers.}

%description %_desc

%package -n ocaml-alt-ergo-parsers
Summary:	Parser library used by the Alt-Ergo SMT solver
License:	Apache-2.0
Requires:	ocaml-alt-ergo-lib%{?_isa} = %{version}-%{release}

%description -n ocaml-alt-ergo-parsers %_desc

This package contains the parser library used by the Alt-Ergo SMT solver.

%package -n ocaml-alt-ergo-parsers-devel
Summary:	Development files for ocaml-alt-ergo-parsers
License:	Apache-2.0
Requires:	ocaml-alt-ergo-parsers%{?_isa} = %{version}-%{release}
Requires:	ocaml-alt-ergo-lib-devel%{?_isa} = %{version}-%{release}
Requires:	ocaml-psmt2-frontend-devel%{?_isa}
Requires:	ocaml-zip-devel%{?_isa}

%description -n ocaml-alt-ergo-parsers-devel %_desc

This package contains development files needed to build applications
that use the Alt-Ergo parser library.

%package -n ocaml-alt-ergo-lib
Summary:	Automated theorem prover library
License:	Apache-2.0

%description -n ocaml-alt-ergo-lib %_desc

This package is the core of Alt-Ergo as an OCaml library.

%package -n ocaml-alt-ergo-lib-devel
Summary:	Development files for ocaml-alt-ergo-lib
License:	Apache-2.0
Requires:	ocaml-alt-ergo-lib%{?_isa} = %{version}-%{release}
Requires:	ocaml-num-devel%{?_isa}
Requires:	ocaml-ocplib-simplex-devel%{?_isa}
Requires:	ocaml-zarith-devel%{?_isa}

%description -n ocaml-alt-ergo-lib-devel %_desc

This package contains development files needed to build applications
that use the Alt-Ergo library.

%prep
%autosetup -n %{name}-%{minorver}.0-free -N 

%if 0%{?patchrel} > 0
# See above.  Replace the minor release sources with the patch release sources.
rm -rf sources
tar xf %{SOURCE1}
%endif

%autopatch -p1
cd sources

# Unzip an example
cd examples/AB-Why3-plugin
unzip p4_34.why.zip
rm p4_34.why.zip
cd -

# This requires gtksourceview2 we don't have anymore
rm -f altgr-ergo*
rm -rf tools/gui/

%build
cd sources
# This is not an autoconf-generated script.  Do NOT use %%configure.
./configure --prefix=%{_prefix} --libdir=%{ocamldir} --sharedir=%{ocamldir}
make lib
make bin
make plugins

%install
cd sources
#make_install DUNE_FLAGS="-p alt-ergo,alt-ergo-lib,alt-ergo-parsers,alt-ergo-lib-free,alt-ergo-free,alt-ergo-parsers-free"
%make_install DUNE_FLAGS="-p alt-ergo,alt-ergo-lib,alt-ergo-parsers,alt-ergo-lib-free,alt-ergo-free,alt-ergo-parsers-free"

# We do not want the ml files
find %{buildroot}%{ocamldir} -name \*.ml -delete

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

# Install the man page
mkdir -p %{buildroot}%{_mandir}/man1
cp -p doc/alt-ergo.1 %{buildroot}%{_mandir}/man1

# The install target in the Makefile puts these in the wrong place
mv %{buildroot}%{_datadir}/alt-ergo/{plugins,preludes} \
   %{buildroot}%{ocamldir}/alt-ergo
rmdir %{buildroot}%{_datadir}/alt-ergo

%check
cd sources
%dune_check

%files
%doc README.md sources/CHANGES sources/examples publications/*.pdf
%{_bindir}/%{name}
%{_mandir}/man1/alt-ergo.1.*
%{ocamldir}/%{name}/
%{ocamldir}/%{name}-free/

%files -n ocaml-%{name}-parsers
%dir %{ocamldir}/%{name}-parsers/
%{ocamldir}/%{name}-parsers/META
%{ocamldir}/%{name}-parsers/*.cma
%{ocamldir}/%{name}-parsers/*.cmi
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-parsers/*.cmxs
%endif
%{ocamldir}/%{name}-parsers-free/

%files -n ocaml-%{name}-parsers-devel
%{ocamldir}/%{name}-parsers/dune-package
%{ocamldir}/%{name}-parsers/opam
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-parsers/*.a
%{ocamldir}/%{name}-parsers/*.cmx
%{ocamldir}/%{name}-parsers/*.cmxa
%endif
%{ocamldir}/%{name}-parsers/*.mli
%{ocamldir}/%{name}-parsers/*.cmt
%{ocamldir}/%{name}-parsers/*.cmti

%files -n ocaml-%{name}-lib
%dir %{ocamldir}/%{name}-lib/
%license LGPL-License.txt LICENSE.md License.OCamlPro
%{ocamldir}/%{name}-lib/META
%{ocamldir}/%{name}-lib/*.cma
%{ocamldir}/%{name}-lib/*.cmi
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-lib/*.cmxs
%endif
%{ocamldir}/%{name}-lib-free/

%files -n ocaml-%{name}-lib-devel
%{ocamldir}/%{name}-lib/dune-package
%{ocamldir}/%{name}-lib/opam
%ifarch %{ocaml_native_compiler}
%{ocamldir}/%{name}-lib/*.a
%{ocamldir}/%{name}-lib/*.cmx
%{ocamldir}/%{name}-lib/*.cmxa
%endif
%{ocamldir}/%{name}-lib/*.mli
%{ocamldir}/%{name}-lib/*.cmt
%{ocamldir}/%{name}-lib/*.cmti

