%define oname		aMule

%define date		20250117

%if %{date}
%define release		%mkrel -c git%{date} %{rel}
%define tarballver	%{commit}
%define tarballdir	%{commit}
%define tarballgit	+git%{date}
%define commit		4a1b78a2a20095fd7312eaf99f42e439cac41f72
%else
%define release		%mkrel %{rel}
%define tarballver	%{version}
%define tarballdir	%{version}
%endif

%define rel	1

Name:		amule
Version:	2.4.0
Release:	%{release}
Summary:	File sharing client compatible with eDonkey
License:	GPLv2
Group:		Networking/File transfer
URL:		https://amule.org
Source:		https://github.com/amule-project/amule/archive/%{tarballdir}/%{name}-%{version}%{?tarballgit}.tar.gz
Patch0:		amule-2.4.0-version_check.patch

BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	flex
BuildRequires:	imagemagick
BuildRequires:	desktop-file-utils
BuildRequires:	binutils-devel
BuildRequires:	boost-devel
BuildRequires:	gettext-devel
BuildRequires:	wxgtk-devel
BuildRequires:	pkgconfig(cryptopp)
BuildRequires:	pkgconfig(gdlib) >= 2.0
BuildRequires:	pkgconfig(geoip)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libupnp)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(readline)

%description
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

#------------------------------------------------------------------------------

%package	commandline
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name} = %{version}-%{release}

%description	commandline
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the command line tool to control aMule remotely (or locally:).

#------------------------------------------------------------------------------

%package	webserver
Summary:	File sharing client compatible with eDonkey
Group:		Networking/File transfer
Requires:	%{name}

%description	webserver
aMule is an easy to use multi-platform client for ED2K Peer-to-Peer Network. It
is a fork of xMule, whis was based on emule for Windows. aMule currently
supports (but is not limited to) the following platforms: Linux, *BSD and
MacOSX.

This is the webserver to control aMule remotely (or locally:).

#------------------------------------------------------------------------------
%prep
%autosetup -p1 -n %{name}-%{tarballver}

# fix GIT version tag name
sed -i -e 's|VERSION "GIT"|VERSION "%{version} GIT"|' CMakeLists.txt

sed -i 's|unset (\${CMAKE_REQUIRED_LIBRARIES})|#unset (\${CMAKE_REQUIRED_LIBRARIES})|' cmake/bfd.cmake

%build
%cmake \
	-DENABLE_BOOST=ON      \
	-DBUILD_AMULECMD=ON    \
	-DBUILD_REMOTEGUI=ON   \
	-DBUILD_WEBSERVER=ON   \
	-DBUILD_CAS=ON         \
	-DBUILD_WXCAS=ON       \
	-DBUILD_ALC=ON         \
	-DBUILD_ALCC=ON        \
	-DBUILD_DAEMON=ON      \
	-DENABLE_IP2COUNTRY=ON \
	-DBUILD_FILEVIEW=ON    \
	-DBUILD_XAS=ON         \
	-DSVNDATE="rev. %{date}"
%cmake_build

%install
%cmake_install

for png in 128x128 48x48 32x32 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png amule.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_menudir}

# Fix wrong-script-end-of-line-encoding
perl -pi -e 's/\015$//' %{buildroot}%{_datadir}/doc/%{name}-%{version}/%{name}-win32.HOWTO.txt

mv %{buildroot}%{_bindir}/ed2k %{buildroot}%{_bindir}/ed2k-%{name}
rm -f %{buildroot}%{_datadir}/doc/%{name}-%{version}/man/.cvsignore
rm -rf %{buildroot}%{_datadir}/doc/%{oname}-%{version}
rm -f %{buildroot}%{_libdir}/xchat/plugins/xas.pl

desktop-file-install --vendor="" \
	--add-category="GTK" \
	--add-category="FileTransfer" \
	--dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*.desktop

%find_lang %{name} --with-man
%find_lang alc --with-man
%find_lang amulegui --with-man
%find_lang cas --with-man
%find_lang ed2k --with-man
%find_lang wxcas --with-man
%find_lang xas --with-man
cat alc.lang amulegui.lang cas.lang ed2k.lang wxcas.lang xas.lang  >> %{name}.lang

%find_lang alcc --with-man
%find_lang amulecmd --with-man
%find_lang amuled --with-man
cat alcc.lang amulecmd.lang amuled.lang  > %{name}-commandline.lang

%find_lang amuleweb --with-man
cat amuleweb.lang  > %{name}-webserver.lang

%post
update-alternatives --install %{_bindir}/ed2k ed2k %{_bindir}/ed2k-%{name} 5

%postun
update-alternatives --remove ed2k %{_bindir}/ed2k-%{name}

%files -f %{name}.lang
%doc docs/{ABOUT-NLS,AUTHORS,Changelog,README,README.Asio.txt,TODO}
%doc docs/{amulesig.txt,EC_Protocol.txt,license.txt,Releases.dia}
%license docs/COPYING
%exclude %{_docdir}/%{name}/INSTALL
%dir %{_datadir}/%{name}
%{_bindir}/%{name}*
%{_bindir}/autostart-xas
%{_bindir}/wxcas
%{_bindir}/cas
%{_bindir}/ed2k-%{name}
%{_bindir}/alc
%{_bindir}/fileview
%{_datadir}/%{name}/skins
%{_datadir}/cas
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/applications/alc.desktop
%{_datadir}/applications/wxcas.desktop
%{_datadir}/pixmaps/%{name}*.xpm
%{_datadir}/pixmaps/alc.xpm
%{_datadir}/pixmaps/wxcas.xpm
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/alc.1*
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man1/cas.1*
%{_mandir}/man1/ed2k.1*
%{_mandir}/man1/wxcas.1*
%{_mandir}/man1/xas.1*

%files commandline -f %{name}-commandline.lang
%{_bindir}/%{name}cmd
%{_bindir}/alcc
%{_bindir}/%{name}d
%{_mandir}/man1/alcc.1*
%{_mandir}/man1/%{name}cmd.1*
%{_mandir}/man1/%{name}d.1*

%files webserver -f %{name}-webserver.lang
%{_bindir}/%{name}web
%{_datadir}/%{name}/webserver/*
%{_mandir}/man1/amuleweb.1*
