# This is for Source5, 51-android.rules
%define rules_date 20230303

Name:		android-tools
Version:	35.0.2
Release:	%mkrel 2
Summary:	Android platform tools (adb, fastboot, mkbootimg)
# The entire source code is Apache Software License except fastboot/ which is BSD
# 51-android.rules is licensed under GPLv3
License:	ASL 2.0 and (ASL 2.0 and BSD) and GPLv3
Group:		Development/Tools
# https://developer.android.com/tools/
URL:		https://github.com/nmeum/android-tools
# https://developer.android.com/guide/developing/tools/
Source0:	https://github.com/nmeum/android-tools/releases/download/%{version}/%{name}-%{version}.tar.xz
Source5:	https://github.com/M0Rf30/android-udev-rules/raw/main/51-android.rules#/51-android-%{rules_date}.rules
Source6:	adb.service
Patch0:		android-tools-35.0.2-system-golang-x-crypto.patch
# https://github.com/nmeum/android-tools/issues/153
Patch10:	0001-Fix-libusb-enumeration.patch
# https://github.com/libusb/libusb/pull/1428, https://github.com/libusb/libusb/pull/1477
Patch11:	0001-Disable-libusb-SuperSpeed-support.patch
Patch12:	android-tools-35.0.2-fix-protobuf-30.0-compilation.patch
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(gtest)
BuildRequires:	pkgconfig(libbrotlidec)
BuildRequires:	pkgconfig(libbrotlienc)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(libunwind-generic)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	cmake
BuildRequires:	cmake(fmt)
BuildRequires:	go
BuildRequires:	golang-x-crypto-devel
BuildRequires:	golang-net-devel

Provides:	adb = %{version}-%{release}
Provides:	fastboot = %{version}-%{release}
Provides:	mkbootimg = %{version}-%{release}

# From Fedora
Provides: bundled(boringssl)

%description
The Android Debug Bridge (ADB) is used to:

- keep track of all Android devices and emulators instances
  connected to or running on a given host developer machine

- implement various control commands (e.g. "adb shell", "adb pull", etc.)
  for the benefit of clients (command-line users, or helper programs like
  DDMS). These commands are what is called a 'service' in ADB.

Fastboot is used to manipulate the flash partitions of the Android phone.
It can also boot the phone using a kernel image or root filesystem image
which reside on the host machine rather than in the phone flash.
In order to use it, it is important to understand the flash partition
layout for the phone.
The fastboot program works in conjunction with firmware on the phone
to read and write the flash partitions. It needs the same USB device
setup between the host and the target phone as adb.

For Mageia you must use the following commands:

- adb
- fastboot
- mkbootimg

%prep
%autosetup -p1

sed -i -e '1s/python$/python3/' vendor/mkbootimg/mkbootimg.py

%build
export GO111MODULE=off
%cmake -DBUILD_SHARED_LIBS:BOOL=OFF \
       -DBUILD_STATIC_LIBS:BOOL=ON \
       -DCMAKE_FIND_PACKAGE_PREFER_CONFIG:BOOL=ON \
       -Dprotobuf_MODULE_COMPATIBLE:BOOL=ON
%cmake_build

%install
%cmake_install

install -d -m 0775 %{buildroot}%{_sharedstatedir}/adb
install -m 0755 vendor/mkbootimg/mkbootimg.py %{buildroot}%{_bindir}/mkbootimg

# for 51-android.rules
mkdir -p %{buildroot}%{_udevrulesdir}
install -m 0644 %{S:5} %{buildroot}%{_udevrulesdir}/51-android.rules
# for adb.service
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 %{S:6} %{buildroot}%{_unitdir}/adb.service

%post
%_post_service adb

%preun
%_preun_service adb

%files
%doc README.md
%{_udevrulesdir}/51-android.rules
%{_unitdir}/adb.service
%attr(0755,root,root) %dir %{_sharedstatedir}/adb
#Apache Software License
%{_bindir}/adb
%{_bindir}/append2simg
%{_bindir}/simg2img
%{_bindir}/img2simg
%{_bindir}/make_f2fs
%{_bindir}/sload_f2fs
%{_bindir}/mkbootimg
%{_bindir}/mke2fs.android
%{_bindir}/e2fsdroid
%{_bindir}/ext2simg
%{_bindir}/lpadd
%{_bindir}/lpdump
%{_bindir}/lpflash
%{_bindir}/lpmake
%{_bindir}/lpunpack
%{_bindir}/repack_bootimg
%{_bindir}/unpack_bootimg
%{_bindir}/avbtool
%{_bindir}/mkdtboimg
%{_datadir}/%{name}/
%{_datadir}/bash-completion/completions/adb
#Apache Software License and BSD.
%{_bindir}/fastboot
%{_datadir}/bash-completion/completions/fastboot
%{_mandir}/man1/adb.1.*
