# (akien) bear-engine is built in the bear SRPM (same for bear-factory)
# We build against the same version but drop the conflicting files (libs and translations)
# TODO: Work with upstream to make bear-engine a real library and prevent building it
# in each game based upon the engine (so far two, but there's a third one we might package)
%define bear_version 20200220

Name:           andy-super-great-park
Version:        1.0.21
Release:        %mkrel 13
Summary:        A 2D shooter on rails
Group:          Games/Arcade
License:        GPLv3+ and CC-BY-SA 3.0
Url:            https://github.com/j-jorge/asgp
Source0:        https://github.com/j-jorge/asgp/archive/%{version}/asgp-%{version}.tar.gz
# Should be synced with the bear SRPM
Source1:        bear-%{bear_version}.tar.xz
# From asgp 1.0.13
Source10:       CMakeLists.txt
Patch0:         asgp-mga-boost-mutex.patch
Patch1:         asgp-boost-placeholders.patch
Patch2:         bear-boost-placeholders.patch
Patch3:         asgp-cstdint.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  docbook-to-man
BuildRequires:  gettext
BuildRequires:  libclaw-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)

Requires:       %{name}-data >= %{version}
Requires:       bear-engine >= 1:0.7.0-1.%{bear_version}

%description
Andy's Super Great Park is an original game with an inventive and easy to
learn gameplay, where every action can be simply done with a mouse.
Challenge your reflexes and your dexterity in this adventure of 25 to 43
levels, punctuated by amazing boss fights.

Through 25 main levels, you will have to retrieve a minimum number of
balloons using your plunger gun while avoiding collisions with the obstacles
dropped on the path (explosive zeppelins, crates, TNT…). Try to get the best
scores and unlock up to 18 extra levels!

Grabbing balloons with a plunger gun, shooting birds with a cannon and
exploding everything else, all while riding a roller coaster: this is Andy's
Super Great Park!

%files -f straining-coasters.lang
%doc asgp/README.md asgp/LICENSE
%{_gamesbindir}/straining-coasters
%{_libdir}/bear/librp.so
%{_datadir}/applications/straining-coasters.desktop
%{_iconsdir}/hicolor/*/apps/asgp.png
%{_mandir}/man6/straining-coasters.6*

#----------------------------------------------------------------------

%package        data
Summary:        Data files for Andy's Super Great Park
License:        CC-BY-SA-3.0
BuildArch:      noarch

%description    data
These are the data files for Andy's Super Great Park arcade game.

%files          data
%{_gamesdatadir}/straining-coasters/
%{_datadir}/bear-factory/straining-coasters/

#----------------------------------------------------------------------

%prep
%setup -q -T -c %{name}-%{version} -a0 -a1
%autopatch -p1

install -pm644 %{SOURCE10} .

mv bear-%{bear_version} bear
mv asgp-%{version} asgp

# convenience.hpp was removed in boost 1.85.0
sed -i -e 's,filesystem/convenience.hpp,filesystem.hpp,g' $(grep -rl convenience.hpp)

# Boost.Math requires C++14
sed -i -e 's,c++11,c++14,g' $(grep -rl c++11)

%build
%cmake -GNinja -DBEAR_ENGINE_INSTALL_LIBRARY_DIR=%{_lib}/bear \
       -DBEAR_EDITORS_ENABLED=OFF \
       -DRP_INSTALL_CUSTOM_LIBRARY_DIR=%{_lib}/bear \
       -DRP_INSTALL_DATA_DIR=share/games/straining-coasters \
       -DRP_INSTALL_EXECUTABLE_DIR=games \
       -DRP_BEAR_FACTORY_ENABLED=ON
%cmake_build

%install
%cmake_install

%find_lang straining-coasters

# Remove the content already provided in the bear-engine package
rm -rf %{buildroot}%{_datadir}/cmake \
       %{buildroot}%{_datadir}/locale/*/LC_MESSAGES/bear-engine.mo \
       %{buildroot}%{_datadir}/pixmaps \
       %{buildroot}%{_libdir}/bear/libbear*.so \
       %{buildroot}%{_mandir}/man6/running-bear.6
