%define major     3
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%bcond_with jpegxl
%bcond_without vmaf

Name:       aom
Version:    3.11.0
Release:    %mkrel 1
Summary:    Royalty-free next-generation video format
Group:      System/Libraries
License:    BSD
URL:        https://aomedia.org/
Source0:    https://aomedia.googlesource.com/%{name}/+archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  gcc
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  git-core
BuildRequires:  graphviz
BuildRequires:  perl(Getopt::Long)
BuildRequires:  wxgtk-devel
BuildRequires:  yasm
BuildRequires:  ccache
%if %{with jpegxl}
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libhwy)
%endif
%if %{with vmaf}
BuildRequires:  pkgconfig(libvmaf)
%endif
Provides:       av1 = %{version}-%{release}

%description
The Alliance for Open Media’s focus is to deliver a next-generation
video format that is:

 - Interoperable and open;
 - Optimized for the Internet;
 - Scalable to any modern device at any bandwidth;
 - Designed with a low computational footprint and optimized for hardware;
 - Capable of consistent, highest-quality, real-time video delivery; and
 - Flexible for both commercial and non-commercial content, including
   user-generated content.

This package contains the reference encoder and decoder.


%package -n %{libname}
Summary:        Library files for aom
Group:          System/Libraries

%description -n %{libname}
Library files for aom, the royalty-free next-generation video format.


%package -n %{develname}
Summary:        Development files for aom
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for aom, the royalty-free next-generation video format.


%prep
%autosetup -p1 -c %{name}-%{version}

# use our _FORTIFY_SOURCE level
sed -i -e 's/_FORTIFY_SOURCE=[0-9]\+/_FORTIFY_SOURCE=%{_fortify_level}/' build/cmake/aom_configure.cmake

%build
%define _vpath_builddir build-%{_target_cpu}
%cmake      -DENABLE_CCACHE=1 \
            -DCMAKE_SKIP_RPATH=1 \
%ifarch %{arm32}
            -DAOM_TARGET_CPU=armv7 \
            -DENABLE_NEON=0 \
%endif
%ifarch aarch64
            -DAOM_TARGET_CPU=arm64 \
%endif
%ifarch %{ix86}
            -DAOM_TARGET_CPU=x86 \
            -DENABLE_SSE3=0 \
%endif
%ifarch x86_64
            -DAOM_TARGET_CPU=x86_64 \
%endif
            -DCONFIG_WEBM_IO=1 \
            -DENABLE_DOCS=1 \
            -DENABLE_TESTS=0 \
            -DCONFIG_INSPECTION=1 \
            -DCONFIG_ANALYZER=0 \
            -DFORCE_HIGHBITDEPTH_DECODING=0 \
            -DBUILD_SHARED_LIBS=1 \
%if %{with jpegxl}
            -DCONFIG_TUNE_BUTTERAUGLI=1 \
%endif
%if %{with vmaf}
            -DCONFIG_TUNE_VMAF=1 \
%endif
            -DLIB_INSTALL_DIR=%{_lib} \
            -DCMAKE_INSTALL_LIBDIR=%{_lib}
%cmake_build

%install
%cmake_install

# Delete static library
find %{buildroot} -name libaom.a -delete

%files
%doc AUTHORS CHANGELOG README.md
%license LICENSE PATENTS
%{_bindir}/aomdec
%{_bindir}/aomenc


%files -n %{libname}
%license LICENSE PATENTS
%{_libdir}/libaom.so.%{major}{,.*}


%files -n %{develname}
%doc %{_vpath_builddir}/docs/html/
%{_includedir}/%{name}/
%{_libdir}/libaom.so
%{_libdir}/pkgconfig/%{name}.pc
