# https://gcc.gnu.org/gcc-10/porting_to.html#common
%define _legacy_common_support 1

%define nss_version %(rpm -q nss --queryformat="%{VERSION}")
%define nssdir %{_sysconfdir}/pki/nss/apache-mod_nss


Summary:	Provides SSL support using the NSS crypto libraries
Name:		apache-mod_nss
Version:	1.0.18
Release:	%mkrel 2
License:	Apache License
Group:		System/Servers
URL:		https://fedorahosted.org/mod_nss/
Source0:	https://releases.pagure.org/mod_nss/mod_nss-%{version}.tar.gz
# Change configuration to not conflict with mod_ssl
Patch1:		mod_nss-conf.patch
# Generate a password-less NSS database
Patch2:		mod_nss-gencert.patch

Requires(pre): 	rpm-helper
Requires(postun): rpm-helper
Requires(pre):	apache >= 2.2.0

Requires:	openssl
Requires:	apache >= 2.2.0
Requires:	p11-kit-trust
BuildRequires:	apache-devel >= 2.2.0
BuildRequires:	automake
BuildRequires:	pkgconfig(nspr)
BuildRequires:	pkgconfig(nss)
BuildRequires:	flex
# Needed for make check
BuildRequires:	openssl

%description
An Apache 2.0 module for implementing crypto using the Mozilla NSS crypto
libraries. This supports SSLv3/TLSv1 including support for client certificate
authentication. NSS provides web applications with a FIPS 140 certified crypto
provider and support for a full range of PKCS11 devices.

mod_nss is an SSL provider derived from the mod_ssl module for the Apache web
server that uses the Network Security Services (NSS) libraries. We started with
mod_ssl and replaced the OpenSSL calls with NSS calls. 

The mod_ssl package was created in April 1998 by Ralf S. Engelschall and was
originally derived from the Apache-SSL package developed by Ben Laurie. It is
licensed under the Apache 2.0 license.

%prep

%setup -q -n mod_nss-%{version}
%autopatch -p1

# Touch expression parser sources to prevent regenerating it
touch nss_expr_*.[chyl]

%build
CFLAGS="%{optflags}"

APXS=%{_httpd_apxs}

export CFLAGS APXS

NSPR_INCLUDE_DIR=`%{_bindir}/pkg-config --variable=includedir nspr`
NSPR_LIB_DIR=`%{_bindir}/pkg-config --variable=libdir nspr`

NSS_INCLUDE_DIR=`%{_bindir}/pkg-config --variable=includedir nss`
NSS_LIB_DIR=`%{_bindir}/pkg-config --variable=libdir nss`

NSS_BIN=`%{_bindir}/pkg-config --variable=exec_prefix nss`


autoreconf -ivf

%configure \
      --localstatedir=/var/lib \
      --with-apr-config=%{_bindir}/apr-1-config \
      --with-apxs=%{_bindir}/apxs \
      --with-nspr-inc=`pkg-config --cflags nspr | sed 's/^\-I//'` \
      --with-nspr-lib=%{_libdir} \
      --with-nss-inc=`pkg-config --cflags nss | awk '{ print $1}' | sed 's/^\-I//'` \
      --with-nss-lib=%{_libdir}


%make_build

%install
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_libdir}/httpd/modules
install -d %{buildroot}%{_httpd_modconfdir}
install -d %{buildroot}%{_httpd_confdir}/conf.d
install -d %{buildroot}%{nssdir}
install -d %{buildroot}%{_libexecdir}

sed -n /^LoadModule/p nss.conf > 10_mod_nss.conf
sed -i /^LoadModule/d nss.conf
install -m0644 *_mod_nss.conf %{buildroot}%{_httpd_modconfdir}
install -m0644 nss.conf %{buildroot}%{_httpd_confdir}/conf.d

install -m0755 .libs/libmodnss.so %{buildroot}%{_libdir}/httpd/modules/mod_nss.so
install -m0755 nss_pcache %{buildroot}%{_libexecdir}/
install -m0755 gencert %{buildroot}%{_sbindir}/gencert
ln -s ../../../%{_libdir}/pkcs11/p11-kit-trust.so %{buildroot}%{nssdir}/libnssckbi.so
touch %{buildroot}%{nssdir}/secmod.db
touch %{buildroot}%{nssdir}/cert8.db
touch %{buildroot}%{nssdir}/key3.db
touch %{buildroot}%{nssdir}/install.log

cat  > README.urpmi << EOF

NOTE: You may need to convert your existing ssl certs
These links provide a good how-to:

http://www.mozilla.org/projects/security/pki/nss/tools/certutil.html
http://www.mozilla.org/projects/security/pki/nss/tools/pk12util.html
http://directory.fedora.redhat.com/wiki/Mod_nss
EOF

%check
#  This needs some love, not working right now.
# make check



%post
# Create an NSS database.
# This will create the 3 files that make up your database: cert8.db, key3.db and secmod.db. and the install.log
umask 077

if [ "$1" -eq 1 ] ; then
    if [ ! -e %{nssdir}/key3.db ]; then
        %{_sbindir}/gencert %{nssdir} > %{nssdir}/install.log 2>&1
        echo ""
        echo "%{name} certificate database generated."
        echo ""
    fi

    # Make sure that the database ownership is setup properly.
    /bin/find %{nssdir} -user root -name "*.db" -exec /bin/chgrp apache {} \;
    /bin/find %{nssdir} -user root -name "*.db" -exec /bin/chmod g+r {} \;
fi
%_post_service httpd

%preun
%_preun_service httpd


%files
%doc LICENSE NOTICE README TODO migrate.pl docs/*.html README.urpmi
%dir %attr(0755,root,root)%{nssdir}
%config(noreplace) %{_httpd_confdir}/conf.d/nss.conf
%attr(0644,root,root) %config(noreplace)%{_httpd_modconfdir}/*_mod_nss.conf
%ghost %attr(0644,root,apache) %config(noreplace)%{nssdir}/secmod.db
%ghost %attr(0644,root,apache) %config(noreplace)%{nssdir}/cert8.db
%ghost %attr(0644,root,apache) %config(noreplace)%{nssdir}/key3.db
%ghost %config(noreplace) %{nssdir}/install.log
%{nssdir}/libnssckbi.so
%attr(0755,root,root) %{_libexecdir}/nss_pcache
%attr(0755,root,root) %{_sbindir}/gencert
%attr(0755,root,root) %{_libdir}//httpd/modules/mod_nss.so
