#global commit 311849653c0e3e6c2c9c22f430ea37a59e5f1592
#global shortcommit %%(c=%%{commit}; echo ${c:0:7})

# Update to submodule revision as in https://github.com/apitrace/apitrace/tree/master/thirdparty when updating
%global libbacktrace_commit 8602fda64e78f1f46563220f2ee9f7e70819c51d
%global libbacktrace_shortcommit %(c=%{libbacktrace_commit}; echo ${c:0:7})

Name:           apitrace
Epoch:          1
Version:        12.0
Release:        %mkrel %{?commit:0.git%{shortcommit}.}3
Group:          Graphics/Utilities
Summary:        Tools for tracing OpenGL
License:        MIT
URL:            https://apitrace.github.io/
%if 0%{?commit:1}
# git clone --recursive https://github.com/apitrace/apitrace.git
# cd apitrace
# git archive --prefix=apitrace-$commit/ -o ../apitrace-${commit:0:7}.tar $commit
# git submodule foreach --recursive "git archive --prefix=apitrace-$commit/\$path/ --output=\$sha1.tar HEAD && tar --concatenate --file=$(pwd)/../apitrace-${commit:0:7}.tar \$sha1.tar && rm \$sha1.tar"
# cd ..
# gzip apitrace-${commit:0:7}.tar
Source0:        apitrace-%{shortcommit}.tar.gz
%else
Source0:        https://github.com/apitrace/apitrace/archive/%{version}/apitrace-%{version}.tar.gz
%endif
Source1:        https://github.com/ianlancetaylor/libbacktrace/archive/%{libbacktrace_commit}/libbacktrace-%{libbacktrace_shortcommit}.tar.gz
Source2:        qapitrace.desktop
Source3:        qapitrace.appdata.xml

# Don't require third-party submodules
Patch0:         apitrace_nosubmodules-3118496.patch
# From https://gcc.gnu.org/git/gitweb.cgi?p=gcc.git;h=690180eb4b35df3f4b5def690878ecaeb5492e41
Patch1:         apitrace-3118496-fix-libbacktrace-8602fda-btest.patch

BuildRequires:  cmake
BuildRequires:  appstream-util
BuildRequires:  brotli-devel
BuildRequires:  desktop-file-utils
BuildRequires:  git-core
BuildRequires:  libstdc++-static-devel
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libdwarf)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(python3)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(snappy)
BuildRequires:  pkgconfig(xext)

# scripts/snapdiff.py
Requires:       python3-pillow

# See http://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Packages_granted_exceptions
Provides:       bundled(md5-plumb)
# See https://fedorahosted.org/fpc/ticket/429
Provides:       bundled(libbacktrace)
# Modified http://create.stephan-brumme.com/crc32/, see thirdparty/crc32c/README.md
Provides:       bundled(crc32c)
#
Provides:       %{name}%{_isa} = %{epoch}:%{version}-%{release}


%description
apitrace consists of a set of tools to:
 * trace OpenGL and OpenGL ES  APIs calls to a file;
 * replay OpenGL and OpenGL ES calls from a file
 * inspect OpenGL state at any call while retracing
 * visualize and edit trace files


%package gui
Summary:        Graphical frontend for apitrace
Requires:       %{name}%{_isa} = %{epoch}:%{version}-%{release}

%description gui
This package contains qapitrace, the Graphical frontend for apitrace.


%prep
%if 0%{?commit:1}
%autosetup -p1 -n %{name}-%{commit} -a1
%else
%autosetup -p1 -n %{name}-%{version} -a1
%endif

# Remove bundled libraries, except khronos headers
rm -rf `ls -1d thirdparty/* | grep -Ev "(khronos|md5|crc32c|libbacktrace.cmake|support|CMakeLists.txt)"`

# Add bundled libbacktrace
mv libbacktrace-%{libbacktrace_commit} thirdparty/libbacktrace


%build
%cmake -DENABLE_STATIC_SNAPPY=OFF \
       -DENABLE_QT6=ON
%cmake_build


%install
%cmake_install

# Install doc through %%doc
rm -rf %{buildroot}%{_docdir}/

# Install desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications/ %{SOURCE2}

# Install appdata file
install -Dpm 0644 %{SOURCE3} %{buildroot}%{_datadir}/appdata/qapitrace.appdata.xml
%{_bindir}/appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/qapitrace.appdata.xml

# highlight.py is not a script
chmod 0644 %{buildroot}%{_libdir}/%{name}/scripts/highlight.py


%check
# If run through ctest, libbacktrace_btest will fail with
#     ERROR: descriptor 3 still open after tests complete
# This is due to https://gitlab.kitware.com/cmake/cmake/-/issues/18863
# So, run the test outside of ctest
pushd %{_vpath_builddir}
ctest --output-on-failure --force-new-ctest-process -j 1 -E libbacktrace_btest
./btest
popd


%files
%license LICENSE
%doc README.markdown docs/*
%{_bindir}/%{name}
%{_bindir}/eglretrace
%{_bindir}/glretrace
%{_bindir}/gltrim
%{_libdir}/%{name}/

%files gui
%{_bindir}/qapitrace
%{_datadir}/applications/qapitrace.desktop
%{_datadir}/appdata/qapitrace.appdata.xml

