%define aprver    1
%define major     0
%define libname   %mklibname apr %{aprver} %{major}
%define develname %mklibname apr -d

Summary:	Apache Portable Runtime library
Name:		apr
Epoch:		1
Version:	1.7.5
Release:	%mkrel 1
License:	Apache License
Group:		System/Libraries
URL:		https://apr.apache.org/
Source0:	https://www.apache.org/dist/apr/apr-%{version}.tar.bz2
Source1:	https://www.apache.org/dist/apr/apr-%{version}.tar.bz2.asc
Patch0:		apr-1.5.0-deplibs.patch
Patch1:		apr-1.4.6-config.diff
Patch2:		apr-1.0.0-mutextype_reorder.diff
Patch3:		apr-1.2.2-deepbind.diff
Patch4:		apr-1.2.2-locktimeout.patch
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	doxygen
BuildRequires:	python3
BuildRequires:	pkgconfig(uuid)

%description
The mission of the Apache Portable Runtime (APR) is to provide a free library
of C data structures and routines, forming a system portability layer to as
many operating systems as possible, including Unices, MS Win32, BeOS and OS/2.

%package -n	%{libname}
Summary:	Apache Portable Runtime library
Group: 		System/Libraries
Provides:	lib%{name} = %{epoch}:%{version}-%{release}
Obsoletes:	%{_lib}apr1 < %{epoch}:%{version}-%{release}

%description -n	%{libname}
The mission of the Apache Portable Runtime (APR) is to provide a free library
of C data structures and routines, forming a system portability layer to as
many operating systems as possible, including Unices, MS Win32, BeOS and OS/2.

%package -n	%{develname}
Summary:	APR library development kit
Group:		Development/C
Requires:	%{libname} = %{epoch}:%{version}
Provides:	%{mklibname apr -d 1} = %{epoch}:%{version}-%{release}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Requires:	libtool

%description -n	%{develname}
This package provides the support files which can be used to build applications
using the APR library. The mission of the Apache Portable Runtime (APR) is to
provide a free library of C data structures and routines.

%prep

%setup -q
#patch -P 0 -p1 -b .deplibs
#patch -P 1 -p1 -b .config
#patch -P 2 -p0 -b .mutextype_reorder
# We're not applying this patch because RTLD_DEEPBIND breaks the mod_dav_svn.so
# of subversion-1.7.1 due to pointer mismatches in loaded shared libraries.
# See: http://subversion.tigris.org/issues/show_bug.cgi?id=4068
# ( -- Shlomi Fish )
# %patch3 -p0 -b .deepbind
#patch -P 4 -p0 -b .locktimeout

cat >> config.layout << EOF
<Layout NUX>
    prefix:        %{_prefix}
    exec_prefix:   %{_prefix}
    bindir:        %{_bindir}
    sbindir:       %{_sbindir}
    libdir:        %{_libdir}
    libexecdir:    %{_libexecdir}
    mandir:        %{_mandir}
    infodir:       %{_infodir}
    includedir:    %{_includedir}/apr-%{aprver}
    sysconfdir:    %{_sysconfdir}
    datadir:       %{_datadir}
    installbuilddir: %{_libdir}/apr-%{aprver}/build
    localstatedir: /var
    runtimedir:    /run
    libsuffix:     -\${APR_MAJOR_VERSION}
</Layout>
EOF

perl -i -lpe 's/^(\s*)testsock\.lo(\s)/$1$2/' test/Makefile.in
perl -i -lnE 'say unless /^\s*\{testsock\},\s*$/' test/abts_tests.h

# python shebangs
%py3_shebang_fix build/gen-build.py

%build
%serverbuild

# We need to re-run ./buildconf because of any applied patch(es)
#rm -f configure; sh ./buildconf
#./buildconf

# Forcibly prevent detection of shm_open (which then picks up but
# does not use -lrt).
# disable robust process-shared mutex support on arm because it makes the
# test hang
cat >> config.cache << EOF
ac_cv_search_shm_open=no
%ifarch %arm
apr_cv_mutex_robust_shared=no
%endif
EOF

%configure \
    --disable-static \
    --cache-file=config.cache \
    --includedir=%{_includedir}/apr-%{aprver} \
    --with-installbuilddir=%{_libdir}/apr-%{aprver}/build \
    --enable-layout=NUX \
%ifarch %ix86
%ifnarch i386 i486
    --enable-nonportable-atomics=yes \
%endif
%endif
    --enable-lfs \
    --enable-threads \
    --with-sendfile  \
    --with-devrandom=/dev/urandom

%make_build
make dox

%check
%ifnarch %ix86
make check
%endif

%install
%make_install

# These are referenced by apr_rules.mk
for f in make_exports.awk make_var_export.awk; do
    install -m0644 build/${f} %{buildroot}%{_libdir}/apr-%{aprver}/build/${f}
done

install -m0755 build/mkdir.sh %{buildroot}%{_libdir}/apr-%{aprver}/build/mkdir.sh

# these are needed if apr-util is ./buildconf'ed
for f in apr_common.m4 apr_hints.m4 apr_network.m4 apr_threads.m4 find_apr.m4; do
    install -m0644 build/${f} %{buildroot}%{_libdir}/apr-%{aprver}/build/${f}
done
install -m0755 build/gen-build.py %{buildroot}%{_libdir}/apr-%{aprver}/build/

# enforce system libtool
ln -snf %{_bindir}/libtool %{buildroot}%{_libdir}/apr-%{aprver}/build/libtool

# Sanitize apr_rules.mk
sed -e "/^apr_build/d" \
    -e 's|$(apr_builders)|%{_libdir}/apr-%{aprver}/build|g' \
    -e 's|$(apr_builddir)|%{_libdir}/apr-%{aprver}/build|g' \
    -e 's|$(top_builddir)|%{_libdir}/apr-%{aprver}/build|g' \
    < build/apr_rules.mk > %{buildroot}%{_libdir}/apr-%{aprver}/build/apr_rules.mk

# Move docs to more convenient location
rm -rf html
cp -r docs/dox/html html


# here too
perl -pi -e "s|-luuid -lcrypt||g" \
    %{buildroot}%{_bindir}/apr-%{aprver}-config \
    %{buildroot}%{_libdir}/pkgconfig/*.pc

# Unpackaged files:
rm -f %{buildroot}%{_libdir}/apr.exp
find %{buildroot} -name '*.la' -delete

# extra headers
install -d %{buildroot}%{_includedir}/apr-%{aprver}/arch/unix
install -m0644 include/arch/apr_private_common.h %{buildroot}%{_includedir}/apr-%{aprver}/arch/
install -m0644 include/arch/unix/*.h %{buildroot}%{_includedir}/apr-%{aprver}/arch/unix/

%files -n %{libname}
%doc CHANGES README*
%{_libdir}/libapr-%{aprver}.so.%{major}{,.*}

%files -n %{develname}
%doc docs/APRDesign.html docs/canonical_filenames.html
%doc docs/incomplete_types docs/non_apr_programs
%doc html
%{_bindir}/apr-%{aprver}-config
%{_libdir}/libapr-%{aprver}.so
%dir %{_libdir}/apr-%{aprver}
%dir %{_libdir}/apr-%{aprver}/build
%{_libdir}/apr-%{aprver}/build/*
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/apr-%{aprver}
%dir %{_includedir}/apr-%{aprver}/arch
%dir %{_includedir}/apr-%{aprver}/arch/unix
%{_includedir}/apr-%{aprver}/*.h
%{_includedir}/apr-%{aprver}/arch/*.h
%{_includedir}/apr-%{aprver}/arch/unix/*.h
