%define _disable_ld_no_undefined 1

%define oname Ardour
%define maj %{expand:%(echo "%{version}" | cut -d. -f1)}

# Needs waf 2.0
%bcond_with system_waf

%if ! %{with system_waf}
%global __waf ./waf
%endif

Name:          ardour
Epoch:         1
Version:       8.12.0
Release:       %mkrel 2
Summary:       Professional multi-track audio recording application
Group:         Sound/Editors and Converters
License:       GPLv2+
URL:           https://ardour.org/

Source0:       https://community.ardour.org/download?architecture=x86_64&type=source#/%{oname}-%{version}.tar.bz2
Patch1:        ardour-7.0-re-vendor_qm-dsp.patch

BuildRequires: waf
BuildRequires: boost-devel
BuildRequires: desktop-file-utils
BuildRequires: dmalloc
BuildRequires: doxygen
BuildRequires: gettext
BuildRequires: graphviz
BuildRequires: help2man
BuildRequires: itstool
BuildRequires: shared-mime-info
BuildRequires: xdg-utils
BuildRequires: pkgconfig(gtk+-2.0) >= 2.12.1
BuildRequires: pkgconfig(gtkmm-2.4) >= 2.8
BuildRequires: pkgconfig(glibmm-2.4)
BuildRequires: pkgconfig(jack)
BuildRequires: pkgconfig(readline)
BuildRequires: pkgconfig(alsa)
BuildRequires: pkgconfig(aubio) >= 0.3.2
BuildRequires: pkgconfig(cairo)
BuildRequires: pkgconfig(cairomm-1.0)
BuildRequires: pkgconfig(cppunit) >= 1.12.0
BuildRequires: pkgconfig(dbus-1)
BuildRequires: pkgconfig(cwiid)
BuildRequires: pkgconfig(fftw3)
BuildRequires: pkgconfig(flac) >= 1.2.1
BuildRequires: pkgconfig(fluidsynth) >= 2.0.2
BuildRequires: pkgconfig(glib-2.0) >= 2.2
BuildRequires: pkgconfig(hidapi-hidraw)
BuildRequires: pkgconfig(libarchive) >= 3.0.0
BuildRequires: pkgconfig(libart-2.0)
BuildRequires: pkgconfig(libcurl) >= 7.0.0
BuildRequires: pkgconfig(libgnomecanvas-2.0) >= 2.30
BuildRequires: pkgconfig(liblo) >= 0.24
BuildRequires: pkgconfig(libpulse)
BuildRequires: pkgconfig(libusb)
BuildRequires: pkgconfig(libusb-1.0)
BuildRequires: pkgconfig(libwebsockets) >= 2.0.0
BuildRequires: pkgconfig(libxslt)
BuildRequires: pkgconfig(lilv-0) >= 0.14
BuildRequires: pkgconfig(lrdf) >= 0.4.0
BuildRequires: pkgconfig(ltc) >= 1.1.0
BuildRequires: pkgconfig(lv2)
BuildRequires: pkgconfig(ogg) >= 1.1.2
BuildRequires: pkgconfig(python3)
BuildRequires: pkgconfig(raptor2)
BuildRequires: pkgconfig(redland)
BuildRequires: pkgconfig(rubberband)
BuildRequires: pkgconfig(samplerate)
BuildRequires: pkgconfig(serd-0) >= 0.14.0
BuildRequires: pkgconfig(sndfile) >= 1.0.18
BuildRequires: pkgconfig(sord-0) >= 0.8.0
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(sratom-0) >= 0.4.0
BuildRequires: pkgconfig(suil-0) >= 0.6.0
BuildRequires: pkgconfig(taglib)
BuildRequires: pkgconfig(uuid)
BuildRequires: pkgconfig(vamp-sdk)

Requires:      jackit
Requires:      gtk2-clearlooks-engine

#to ensure that all LV2 plugins will work properly:
Requires:      suil-x11-in-gtk2

Provides:      %{name}3 = %{version}-%{release}

%description
Ardour is a digital audio workstation. You can use it to record, edit and mix
multi-track audio and MIDI. You can produce your own CDs, mix video sound
tracks, or just experiment with new ideas about music and sound.

Ardour capabilities include: multi channel recording, non-destructive editing
with unlimited undo/redo, full automation support, LV2 and Linux VST plugins 
support, a powerful mixer, unlimited tracks/buses/plugins, time-code
synchronization, and hardware control from surfaces like the
Mackie Control Universal.

%prep
%autosetup -p1 -n %{oname}-%{version}

# Fixes to use system waf:
# making sure, that subdirectories can be picked up with local includes
 touch __init__.py
# making ancient 'misc.py' include available to system installed waf
 sed -e "s/('misc')/('misc', tooldir='tools')/" \
     -i {gtk2_ardour,headless,luasession,session_utils,libs/fst}/wscript
# make custom 'autowaf' include compatible with system installed waf
 find . -type f \
        -iname "*wscript*" \
        -exec sed -e 's/from waflib.extras import autowaf/from tools import autowaf/g' \
                  -e 's/import waflib.extras.autowaf/from tools import autowaf/g' \
                  -i {} \;

%build
%waf \
    --configdir=%{_sysconfdir} \
    --program-name=Ardour \
    --docs \
    --cxx17 \
    --freedesktop \
    --optimize \
    --ptformat \
    --use-external-libs \
    --with-backends="jack,alsa,dummy,pulseaudio" \
    --noconfirm \
    --no-ytk \
    --no-phone-home

%waf_build

%{python3} ./waf i18n_mo

%install
%waf_install

cat>%{name}.desktop<<EOF
[Desktop Entry]
Comment=Digital Audio Workstation
Comment[en_GB]=Digital Audio Workstation
Comment[fr]=Station de travail audio numérique
Comment[ru_RU]=Программа звукозаписи
Exec=ardour%{maj}
GenericName=%{oname}
GenericName[en_GB]=%{oname}
GenericName[fr]=%{oname}
Icon=%{name}%{maj}
MimeType=application/x-%{name};
Name=%{oname}
Name[en_GB]=%{oname}
StartupNotify=true
Terminal=false
Type=Application
Categories=AudioVideo;Audio;X-Recorders;X-Multitrack;

EOF

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}.desktop

rm -rf %{buildroot}%{_datadir}/applications/%{name}%{maj}.desktop
install -D -m0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}%{maj}.1

cat > README.urpmi <<EOF
You will need to add yourself to the 'audio' and 'realtime' groups before using Ardour.
This may be done in a terminal by using the following commands:

su

gpasswd -a <yourusername> audio

gpasswd -a <yourusername> realtime

exit

You can alternatively do this by using the Mageia Control Center GUI:
System -> Manage Users on System -> Right click on your user, twice -> Edit -> Groups tab ->
Check boxes for audio and realtime groups -> Click on OK

You will need to log out and log back in before using Ardour for the first time.

EOF

cp -a README.urpmi README.Mageia

%files
%doc README README.urpmi README.Mageia
%{_bindir}/%{name}%{maj}
%{_bindir}/%{name}%{maj}-lua
%{_bindir}/%{name}%{maj}-copy-mixer
%{_bindir}/%{name}%{maj}-export
%{_bindir}/%{name}%{maj}-new_empty_session
%{_bindir}/%{name}%{maj}-new_session
%{_libdir}/%{name}%{maj}/
%{_datadir}/%{name}%{maj}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}%{maj}.appdata.xml
%{_datadir}/mime/packages/%{name}*.xml
%{_iconsdir}/hicolor/*/*/*%{name}%{maj}.png
%dir %{_sysconfdir}/%{name}%{maj}
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/%{name}.menus
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/clearlooks.rc
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/clearlooks.ardoursans.rc
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/default_ui_config
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/system_config
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/ardour.keys
%{_mandir}/man1/%{name}%{maj}.1.*
