Name:           aseprite
Version:        1.3.9.1
Release:        %mkrel 1
Summary:        Animated sprite editor & pixel art tool
Group:          Graphics/Editors and Converters
License:        GPLv2+
URL:            https://www.aseprite.org/
# Git repo: https://github.com/aseprite/aseprite
# Upstream zip archive repacked without unused third party libs
# rm -rf third_party/{cmark,curl,fmt,freetype2,giflib,harfbuzz,jpeg,libarchive,libpng,libwebp,pixman,pixman-cmake,tinyxml2,zlib}
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}.1
# From third_party/pixman/pixman/pixman-combine32.h
Source2:        pixman-combine32.h
Patch1:         aseprite-shared-fmt.patch
# Based on https://patch-diff.githubusercontent.com/raw/aseprite/aseprite/pull/2535.patch
Patch2:         aseprite-shared-libarchive.patch
# Based on https://patch-diff.githubusercontent.com/raw/aseprite/aseprite/pull/2523.patch
Patch3:         aseprite-shared-libwebp.patch

BuildRequires:  cmake
BuildRequires:  allegro4-devel
BuildRequires:  giflib-devel
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libcmark)
BuildRequires:  pkgconfig(harfbuzz)

%description
Aseprite (aka ASE, Allegro Sprite Editor) is an open source program to
create animated sprites & pixel art. Sprites are little images that can
be used in your website or in a video game. You can draw characters with
movement, intros, textures, patterns, backgrounds, logos, color palettes,
isometric levels, etc.

%prep
%autosetup -p1

# Needed to build doc-lib
mkdir -p third_party/pixman/pixman
cp %{_sourcedir}/pixman-combine32.h third_party/pixman/pixman/

# Stable version
sed -i data/gui.xml src/config.h -e 's/-dev//'

%build
# The window can't be resized/maximize when linked against the system allegro 4
# We build against the embedded version for now - patching allegro could be investigated too
# allegro is still needed as a BR for libloadpng
%cmake -DENABLE_UPDATER=OFF \
       -DUSE_SHARED_CMARK=ON \
       -DUSE_SHARED_CURL=ON \
       -DUSE_SHARED_FMT=ON \
       -DUSE_SHARED_FREETYPE=ON \
       -DUSE_SHARED_GIFLIB=ON \
       -DUSE_SHARED_HARFBUZZ=ON \
       -DUSE_SHARED_LIBARCHIVE=ON \
       -DUSE_SHARED_JPEGLIB=ON \
       -DUSE_SHARED_LIBPNG=ON \
       -DUSE_SHARED_PIXMAN=ON \
       -DUSE_SHARED_TINYXML=ON \
       -DUSE_SHARED_WEBP=ON \
       -DUSE_SHARED_ZLIB=ON \
       -DENABLE_WEBP=ON
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_includedir}
find %{buildroot} -name '*.a' -delete
find %{buildroot} -name '*.pc' -delete

install -D -m644 %{_sourcedir}/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

for size in 16 32 48 64 128 256; do
  install -D -m644 data/icons/ase${size}.png \
          %{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps/%{name}.png
done

install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=Aseprite
GenericName=Sprite editor
Comment=Animated sprite editor & pixel art tool
Exec=%{name}
Icon=%{name}
Type=Application
Categories=Graphics;2DGraphics;RasterGraphics;
EOF

%files
%doc CONTRIBUTING.md README.md
%license EULA.txt
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*
