%define major   5
%define minor   4
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           assimp
Version:        5.4.3
Release:        %mkrel 1
Summary:        Library to import various 3D model formats into applications
Group:          Graphics/3D
# Assimp is BSD
# Bundled contrib/clipper is Boost
# Bundled contrib/Open3DGC is MIT
# Bundled contrib/openddlparser is MIT
# Bundled contrib/stb_image is MIT
# Bundled contrib/unzip is zlib
# Bundled contrib/zip is unlicense
# Bundled contrib/zlib is zlib
License:        BSD and MIT and Boost and unlicense and zlib
URL:            https://github.com/assimp/assimp

# Github releases include nonfree models, source tarball must be re-generated
# using assimp_generate_tarball.sh
Source0:        %{name}-%{version}-free.tar.xz
Source1:        assimp_generate_tarball.sh

# Un-bundle libraries that are provided by the distribution.
# Also fixes FTBFS: https://github.com/assimp/assimp/issues/4334
Patch0:         assimp-5.4.3-mga-unbundle.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  cmake(RapidJSON)
BuildRequires:  cmake(utf8cpp)
BuildRequires:  pkgconfig(draco)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(poly2tri)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(stb)
BuildRequires:  pkgconfig(polyclipping)

#Provides: bundled(polyclipping) = 6.4.2
Provides: bundled(open3dgc)
Provides: bundled(openddl-parser)
# https://github.com/kuba--/zip
Provides: bundled(zip)

%description
Assimp, the Open Asset Import Library, is a free library to import various
well-known 3D model formats into applications. Assimp aims to provide a full
asset conversion pipeline for use in game engines and real-time rendering
systems, but is not limited to these applications.

This package contains the assimp binary, a tool to work with various formats.

%files
%doc Readme.md CREDITS CHANGES
%{_bindir}/%{name}

#----------------------------------------------------------------------------

%package -n     %{libname}
Summary:        Library to import various 3D model formats into applications
Group:          System/Libraries

%description -n %{libname}
Assimp, the Open Asset Import Library, is a free library to import various
well-known 3D model formats into applications. Assimp aims to provide a full
asset conversion pipeline for use in game engines and real-time rendering
systems, but is not limited to these applications.

%files -n       %{libname}
%doc Readme.md CREDITS CHANGES
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{version}

#----------------------------------------------------------------------------

%package -n     %{devname}
Summary:        Header files and development libraries for assimp
Group:          Development/C++
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Requires:       pkgconfig(stb)

%description -n %{devname}
This package contains the header files and development libraries for assimp.
You need to install it if you want to develop programs using assimp.

%files -n       %{devname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/cmake/%{name}-%{major}.%{minor}/
%{_libdir}/pkgconfig/%{name}.pc

#----------------------------------------------------------------------------

%prep
%autosetup -p1

# Get rid of bundled libs so we can't accidentally build against them
rm -rf contrib/android-cmake
rm -rf contrib/clipper
rm -rf contrib/draco
rm -rf contrib/gtest
rm -rf contrib/poly2tri
rm -rf contrib/pugixml
rm -rf contrib/rapidjson
rm -rf contrib/stb
rm -rf contrib/unzip
rm -rf contrib/utf8cpp
#rm -rf contrib/zip
rm -rf contrib/zlib

%build
%cmake \
  -DASSIMP_BUILD_TESTS=OFF \
  -DASSIMP_BUILD_ZLIB=OFF \
  -DASSIMP_WARNINGS_AS_ERRORS=OFF \
  -DASSIMP_BUILD_ASSIMP_TOOLS=ON \
  -DCLIPPER_INCLUDE_PATH=%{_includedir}/polyclipping

%cmake_build

%install
%cmake_install

# HACK hackaround missing imported target "draco::draco"
# The link interface of target "assimp::assimp" contains:
#     draco::draco
# but the target was not found.  Possible reasons include:
#     * There is a typo in the target name.
#     * A find_package call is missing for an IMPORTED target.
#     * An ALIAS target is missing.
sed -i 's|draco::draco;|draco;|' %{buildroot}%{_libdir}/cmake/assimp-%{major}.%{minor}/assimpTargets.cmake
