%global libatfc_somajor 1
%global libatfcxx_somajor 2
%global libatfc %mklibname %{name}-c %{libatfc_somajor}
%global devatfc %mklibname %{name}-c -d
%global libatfcxx %mklibname %{name}-c++ %{libatfcxx_somajor}
%global devatfcxx %mklibname %{name}-c++ -d

Summary: Automated Testing Framework
Name: atf
Version: 0.21
Release: %mkrel 1
License: BSD
Group: Development/Tools
URL: https://code.google.com/p/kyua/wiki/ATF
Source0: https://github.com/jmmv/atf/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1: README.Fedora

%define _testsdir %{_libexecdir}/atf/tests

%define common_description The Automated Testing Framework (ATF) is a collection of libraries to \
implement test programs in a variety of languages.  At the moment, ATF \
offers C, C++ and POSIX shell bindings with which to implement tests. \
These bindings all offer a similar set of functionality and any test \
program written with them exposes a consistent user interface. \
\
ATF-based test programs rely on a separate runtime engine to execute them. \
The runtime engine is in charge of isolating the test programs from the \
rest of the system to ensure that their results are deterministic and that \
they cannot affect the running system.  The runtime engine is also \
responsible for gathering the results of all tests and composing reports. \
The current runtime of choice is Kyua.

%description
There is no main package being built here.  This is unused.

# Ideally, we would ship one tests package for every component, namely
# libatf-c-tests, libatf-c++-tests and atf-sh-tests.  However, the test
# suite of ATF has not been written with this in mind, and the tests of one
# component often have dependencies on the rest of the components.  It is
# much easier to ship a single package with the whole test suite rather
# than attempting to fight this fact.
%package tests
Summary: Automated Testing Framework - Test suite
Requires: %{libatfc} = %{version}-%{release}
Requires: %{libatfcxx} = %{version}-%{release}
Requires: atf-sh = %{version}-%{release}
Requires: %{devatfc} = %{version}-%{release}
Requires: %{devatfcxx} = %{version}-%{release}
Requires: atf-sh-devel = %{version}-%{release}

%description tests
%{common_description}

This package installs the run-time tests for all the components of ATF, which
include tests for the C, C++ and POSIX shell libraries and the run-time tools.
Please see the README.Fedora file in the documentation directory for further
details on how to run the installed tests.

%files tests
%doc README.Fedora
%{_testsdir}


%package -n %{libatfc}
Summary: Automated Testing Framework - C bindings
Group: System/Libraries

%description -n %{libatfc}
%{common_description}

This package provides the run-time libraries to run tests that use the
ATF C bindings.

%files -n %{libatfc}
%{_libdir}/libatf-c.so.%{libatfc_somajor}
%{_libdir}/libatf-c.so.%{libatfc_somajor}.*
%{_datadir}/man/man1/atf-test-program.1*
%{_datadir}/man/man4/atf-test-case.4*
%{_mandir}/man3/atf-sh.3.*
%{_mandir}/man7/atf.7.*

%package -n %{devatfc}
Summary: Automated Testing Framework - C bindings (headers)
Group: Development/C
Provides: libatf-c-devel = %{version}-%{release}
Provides: libatf-c-devel%{?_isa} = %{version}-%{release}
Requires: %{libatfc} = %{version}-%{release}

%description -n %{devatfc}
%{common_description}

This package provides the libraries, header files and documentation to
develop tests that use the ATF C bindings.

%files -n %{devatfc}
%{_datadir}/aclocal/atf-c.m4
%{_datadir}/aclocal/atf-common.m4
%{_includedir}/atf-c.h
%{_includedir}/atf-c
%{_libdir}/libatf-c.so
%{_libdir}/pkgconfig/atf-c.pc
%{_mandir}/man3/atf-c-api.3*
%{_mandir}/man3/atf-c.3.*

%package -n %{libatfcxx}
Summary: Automated Testing Framework - C++ bindings
Group: System/Libraries
Requires: %{libatfc} = %{version}-%{release}

%description -n %{libatfcxx}
%{common_description}

This package provides the run-time libraries to run tests that use the
ATF C++ bindings.

%files -n %{libatfcxx}
%{_libdir}/libatf-c++.so.%{libatfcxx_somajor}
%{_libdir}/libatf-c++.so.%{libatfcxx_somajor}.*


%package -n %{devatfcxx}
Summary: Automated Testing Framework - C++ bindings (headers)
Group: Development/C++
Provides: libatf-c++-devel = %{version}-%{release}
Provides: libatf-c++-devel%{?_isa} = %{version}-%{release}
Requires: %{libatfc} = %{version}-%{release}
Requires: %{devatfc} = %{version}-%{release}
Requires: %{libatfcxx} = %{version}-%{release}

%description -n %{devatfcxx}
%{common_description}

This package provides the libraries, header files and documentation to
develop applications that use the ATF C++ bindings.

%files -n %{devatfcxx}
%{_datadir}/aclocal/atf-c++.m4
%{_includedir}/atf-c++.hpp
%{_includedir}/atf-c++
%{_libdir}/libatf-c++.so
%{_libdir}/pkgconfig/atf-c++.pc
%{_mandir}/man3/atf-c++-api.3*
%{_mandir}/man3/atf-c++.3*


%package -n atf-sh
Summary: Automated Testing Framework - POSIX shell bindings
Requires: %{libatfcxx} = %{version}-%{release}
# Because urpmi is broken and can't handle file deps...
Provides: %{_bindir}/atf-sh

%description -n atf-sh
%{common_description}

This package provides the run-time libraries to run tests that use the
ATF POSIX shell bindings.

%files -n atf-sh
%{_bindir}/atf-sh
# Cheat a bit: While this directory should be supposedly owned by the main
# 'atf' package, 'atf' depends on atf-sh.  Therefore, it's easier to handle
# ownership here.
%{_datadir}/atf
%{_libexecdir}/atf-check
%{_mandir}/man1/atf-sh.1*

%package -n atf-sh-devel
Summary: Automated Testing Framework - POSIX shell bindings (headers)
Requires: atf-sh = %{version}-%{release}

%description -n atf-sh-devel
%{common_description}

This package provides the supporting files and documentation to develop
applications that use the ATF POSIX shell bindings.

%files -n atf-sh-devel
%{_datadir}/aclocal/atf-sh.m4
%{_libdir}/pkgconfig/atf-sh.pc
%{_mandir}/man1/atf-check.1*
%{_mandir}/man3/atf-sh-api.3*

%prep
%setup -q

# Put the README.Fedora file in the top-level directory of the source tree so
# that the %doc call below can pick it up.
cp -p %{SOURCE1} README.Fedora

%build
autoreconf -fiv
%configure INSTALL="/usr/bin/install -p" --disable-static
make %{?_smp_mflags} pkgtestsdir=%{_testsdir} testsdir=%{_testsdir}

%check
make check

%install
make install DESTDIR=%{buildroot} doc_DATA= \
             pkgtestsdir=%{_testsdir} testsdir=%{_pkgtestsdir}
rm %{buildroot}%{_libdir}/libatf*.la
