# Update from 3.6.0 to 3.8.3 is based on Fedora atlas package. See
# http://cvs.fedoraproject.org/viewvc/rpms/atlas/devel/atlas.spec?revision=1.23

%define enable_native_atlas 0

%define major		3
%define libatlas	libatlas
%define libname		%mklibname %{name} %{major}

Name:		atlas
Version:	3.10.3
Release:	%mkrel 12
Summary:        Automatically Tuned Linear Algebra Software
Group:          Sciences/Mathematics
License:        BSD
URL:            https://math-atlas.sourceforge.net/
Source0:        https://downloads.sourceforge.net/math-atlas/%{name}%{version}.tar.bz2
Source21:	https://math-atlas.sourceforge.net/errata.html
Source22:	https://math-atlas.sourceforge.net/faq.html
Source23:	https://www.cs.utsa.edu/~whaley/papers.html
Source30:	Makefile
Source31:	README.%{_real_vendor}
# Obtained by editing flags in the tarball from the sources with
# grep -r fpu | cut -d: -f 1 | sort -u | xargs sed -i -e 's,-mcpu=cortex-a8,-march=armv7-a,' -e 's,-mfpu=vfpv3,-mfpu=vfpv3-d16,' -e 's,-mtune=cortex-a8,,'
Source32:	ARMv732.tar.bz2

# Fedora patches:
# Properly pass -melf_* to the linker with -Wl, fixes FTBFS bug 817552
# https://sourceforge.net/tracker/?func=detail&atid=379484&aid=3555789&group_id=23725
Patch1:		atlas-melf.patch
Patch2:         atlas-throttling.patch
#credits Lukas Slebodnik
Patch3:		atlas-shared_libraries.patch

Patch4:		atlas-genparse.patch

# Unbundle LAPACK (BZ #1181369)
Patch5:		atlas.3.10.1-unbundle.patch
Patch6:		atlas-gcc10.patch
Patch15:	atlas-fgrep.patch

#Covscan
Patch101:	atlas-getri.patch

Requires:	gcc-gfortran liblapack-devel
BuildRequires:	gcc-gfortran
BuildRequires:	liblapack-devel

%description
The ATLAS (Automatically Tuned Linear Algebra Software) project is an
ongoing research effort focusing on applying empirical techniques in
order to provide portable performance. At present, it provides C and
Fortran77 interfaces to a portably efficient BLAS implementation, as
well as a few routines from LAPACK.

The performance improvements in ATLAS are obtained largely via
compile-time optimizations and tend to be specific to a given hardware
configuration. In order to package ATLAS some compromises
are necessary so that good performance can be obtained on a variety
of hardware. This set of ATLAS binary packages is therefore not
necessarily optimal for any specific hardware configuration.  However,
the source package can be used to compile customized ATLAS packages;
see the documentation for information.

########################################################################

#--#####################################################################
%ifarch %{ix86}
%define types base

#----###################################################################
%package	-n %{libname}-base
Summary:	ATLAS libraries for SSE3 extensions (Pentium IV)
Group:		System/Libraries
%ifarch %{ix86}
Obsoletes:      %{libname}-sse2 < 3.10.3-5
Obsoletes:      %{libname}-sse3 < 3.10.3-5
%endif

%description	-n %{libname}-base
This package contains the ATLAS (Automatically Tuned Linear Algebra
Software) libraries compiled with base optimizations.
This is a generic binary package. Install the "%{name}" package
to build a version tuned for your computer.

%files		-n %{libname}-base
%dir %{_libdir}/atlas-base
%{_libdir}/atlas-base/*.so.*
%{_sysconfdir}/ld.so.conf.d/atlas-base.conf

#------#################################################################
%package	-n %{libatlas}-base-devel
Summary:	Development files for ATLAS SSE3 (Pentium IV)
Group:		Development/Other
Requires:	%{libname}-base = %{version}-%{release}
%ifarch %{ix86}
Obsoletes:      %{libname}-sse2-devel < 3.10.3-5
Obsoletes:      %{libname}-sse3-devel < 3.10.3-5
%endif
Provides:	%{libatlas}-devel = %{version}-%{release}

%description	-n %{libatlas}-base-devel
This package contains headers and development libraries of ATLAS
(Automatically Tuned Linear Algebra Software) compiled with base
optimizations.

%files		-n %{libatlas}-base-devel
%doc doc/*
%{_libdir}/atlas-base/*.so
%{_libdir}/atlas-base/*.a
%dir %{_includedir}/atlas
%{_includedir}/atlas/*.h

#--#####################################################################
%else

%define types	%{_arch}

#----###################################################################
%package	-n %{libname}-%{_arch}
Summary:	ATLAS libraries for %{_arch}
Group:		System/Libraries
Provides:	%{libatlas} = %{version}-%{release}

%description	-n %{libname}-%{_arch}
This package contains the ATLAS (Automatically Tuned Linear Algebra
Software) libraries compiled with %{_arch} optimizations.
This is a generic binary package. Install the "%{name}" package
to build a version tuned for your computer.

%files		-n %{libname}-%{_arch}
%dir %{_libdir}/atlas
%{_libdir}/atlas/*.so.*
%{_sysconfdir}/ld.so.conf.d/atlas.conf

#------#################################################################
%package	-n %{libatlas}-%{_arch}-devel
Summary:	Development files for ATLAS for %{_arch}
Group:		Development/Other
Requires:	%{libname}-%{_arch} = %{version}-%{release}
Provides:	%{libatlas}-devel = %{version}-%{release}

%description	-n %{libatlas}-%{_arch}-devel
This package contains headers and development libraries of ATLAS
(Automatically Tuned Linear Algebra Software) compiled with %{_arch}
optimizations.

%files		-n %{libatlas}-%{_arch}-devel
%doc doc/*
%{_libdir}/atlas/*.so
%{_libdir}/atlas/*.a
%dir %{_includedir}/atlas
%{_includedir}/atlas/*.h

%endif	# ix86

%ifarch %{arm}
%define threads_option -t 2
%global mode %{nil}
%ifarch armv7hl
%global armflags -DATL_ARM_HARDFP=1
%else
%global armflags %{nil}
%endif
%else
%global mode -b %{__isa_bits}
%global armflags %{nil}
%if "%{?enable_native_atlas}" == "0"
%define threads_option -t 4 
%endif
%endif
 
%prep
%setup -q -n ATLAS
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p2
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 15 -p1

%patch -P 101 -p1

cp %{SOURCE21} %{SOURCE22} %{SOURCE23} doc

%ifarch %{arm}
%ifarch armv7hl
# This overrides flags to use hard abi on arm
cp -f %{SOURCE32} CONFIG/ARCHS/
# Set arm flags in atlcomp.txt
sed -i -e 's,-mfloat-abi=softfp,-mfloat-abi=hard,' CONFIG/src/atlcomp.txt
sed -i -e 's,-mcpu=cortex-a8,-march=armv7-a,' CONFIG/src/atlcomp.txt
sed -i -e 's,-mtune=cortex-a8,,' CONFIG/src/atlcomp.txt
sed -i -e 's,-mfpu=vfpv3,-mfpu=vfpv3-d16,' CONFIG/src/atlcomp.txt
%endif
# Some extra arm flags not needed
sed -i -e 's,-mfpu=vfpv3,,' tune/blas/gemm/CASES/*.flg
%endif

%build
for type in %{types}; do
    case $type in
	%{_arch})	libname=%{name}		;;
	*)		libname=%{name}-$type	;;
    esac
    mkdir -p %{_arch}_${type}
    pushd %{_arch}_${type}
	../configure  %{mode} %{?threads_option} %{?arch_option} -v 2 -D c -DWALL -Fa alg '%{armflags} -D_FORTIFY_SOURCE=2 -g -Wa,--noexecstack -fstack-protector-strong -fPIC' \
	    --prefix=%{buildroot}%{_prefix}				\
	    --incdir=%{buildroot}%{_includedir}				\
	    --libdir=%{buildroot}%{_libdir}/${libname}	
	    
	if [ "$type" = "x86_64" ]; then
	        sed -i 's#ARCH =.*#ARCH = HAMMER64SSE3#' Make.inc
                sed -i 's#-DATL_AVX\w*##g' Make.inc
                sed -i 's#-mavx\w*#-msse3#g' Make.inc
                sed -i 's#-mfma\w*#-msse3#g' Make.inc
	fi
	make build
	cd lib
	make shared
	make ptshared
    popd
done

%install
for type in %{types}; do
    case $type in
	%{_arch})	dirname=%{name}		;;
	*)		dirname=%{name}-$type	;;
    esac
    pushd %{_arch}_${type}
	make DESTDIR=%{buildroot} install || :
	mv %{buildroot}%{_includedir}/clapack.h %{buildroot}%{_includedir}/atlas
	mv %{buildroot}%{_includedir}/cblas.h %{buildroot}%{_includedir}/atlas
	mkdir -p %{buildroot}%{_libdir}/${dirname}
	cp -pr lib/*.so* %{buildroot}%{_libdir}/${dirname}/
	rm -f %{buildroot}%{_libdir}/${dirname}/*.a
	cp -pr lib/libcblas.a lib/libatlas.a lib/libf77blas.a lib/liblapack.a %{buildroot}%{_libdir}/${dirname}/
    popd
    mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
    echo "%{_libdir}/${dirname}"				\
	> %{buildroot}%{_sysconfdir}/ld.so.conf.d/${dirname}.conf
done

mkdir -p %{buildroot}%{_libdir}/%{name}
mkdir -p %{buildroot}%{_usrsrc}
tar jxf %{SOURCE0} -C %{buildroot}%{_usrsrc}

for i in Makefile README.%{_real_vendor}; do
   for s in _arch _includedir _libdir _sysconfdir name; do
      sed -e 's!%%{_arch}!%{_arch}!g' \
          -e 's!%%{_docdir}!%{_docdir}!g' \
          -e 's!%%{_includedir}!%{_includedir}!g' \
          -e 's!%%{_libdir}!%{_libdir}!g' \
          -e 's!%%{mode}!%{mode}!g' \
          -e 's!%%{name}!%{name}!g' \
          -e 's!%%{_prefix}!%{_prefix}!g' \
          -e 's!%%{release}!%{release}!g' \
          -e 's!%%{_sysconfdir}!%{_sysconfdir}!g' \
          -e 's!%%{_usrsrc}!%{_usrsrc}!g' \
          -e 's!%%{version}!%{version}!g' \
      < %{_sourcedir}/$i > %{buildroot}%{_usrsrc}/ATLAS/$i
   done
done
echo %{buildroot}%{_usrsrc}/ATLAS/$i

%check
for type in %{types}; do
	pushd %{_arch}_${type}
	make check ptcheck
	popd
done

%post
echo "

  Please check %{_usrsrc}/ATLAS/README.%{_real_vendor} for build instructions.

"

%files
%dir %{_usrsrc}/ATLAS
%{_usrsrc}/ATLAS/*
%dir %{_includedir}/%{name}
%dir %{_libdir}/%{name}
%doc doc/*
