%define url_ver %(echo %{version}|cut -d. -f1,2)

%bcond_without dvi
%bcond_without epub

%define major 3
%define api 1.5.0
%define girname     %mklibname %{name}-gir %{api}
%define libname     %mklibname %{name} %{major}
%define develname   %mklibname -d %{name}

Summary:    MATE Document viewer
Name:       atril
Version:    1.28.1
Release:    %mkrel 1
License:    GPLv2+ and GFDL
URL:        https://mate-desktop.org/
Group:      Graphical desktop/MATE
Source0:    https://pub.mate-desktop.org/releases/%{url_ver}/%{name}-%{version}.tar.xz

BuildRequires:  ghostscript
BuildRequires:  itstool
BuildRequires:  libt1lib-devel
BuildRequires:  mate-common
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(ddjvuapi)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
%if %{with dvi}
#gw just like xdvi, needed for rendering the fonts
BuildRequires:  pkgconfig(kpathsea)
%endif
BuildRequires:  pkgconfig(libcaja-extension)
BuildRequires:  pkgconfig(libgxps)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{url_ver}
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(sm)
%if %{with epub}
BuildRequires:  pkgconfig(webkit2gtk-4.1)
%endif
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  xsltproc
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(synctex)
BuildRequires:  autoconf-archive

Requires:    ghostscript
Requires:    ghostscript-module-X
# for comics support
Requires:    unzip
Requires:    zip
# for org.mate.lockdown schema
Requires:    mate-desktop-schemas >= %{url_ver}

%description
Atril is the MATE Document viewer. It supports Portable Document Format (PDF),
PostScript (PS), Encapsulated PostScript (EPS), DJVU and XPS formats.

%package dvi
Summary:  TeX DVI document support for atril
Group:    Graphical desktop/MATE
#gw just like xdvi, needed for rendering the fonts
Requires: texlive
Requires: %{name} = %{version}-%{release}

%description dvi
This package adds support for displaying .dvi files to atril. These files are
produced by TeX, often using a macro package like LaTeX.

%package -n %{libname}
Group:    System/Libraries
Summary:  MATE Document viewer library

%description -n %{libname}
This is the MATE Document viewer library, the shared parts of %{name}.

%package -n %{girname}
Summary:  GObject Introspection interface description for %{name}
Group:    System/Libraries
Requires: %{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}

%package -n %{develname}
Group:    Development/C
Summary:  MATE Document viewer library
Requires: %{libname} = %{version}-%{release}
Requires: %{girname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}

%description -n %{develname}
This is the MATE Document viewer library, the shared parts of %{name}.

%prep
%autosetup -p1

# build with webkit2gtk-4.1
sed -i "s|webkit2gtk-4.0|webkit2gtk-4.1|g" configure.ac

%build
# To fix overlinking issues needed:
NOCONFIGURE=1 ./autogen.sh
%configure \
    --with-pic                       \
    --disable-static                 \
    --disable-schemas-compile        \
    --enable-thumbnailer             \
    --enable-introspection           \
    --enable-gtk-doc                 \
    --enable-pdf                     \
    --enable-tiff                    \
    --enable-djvu                    \
    --enable-pixbuf                  \
    --enable-comics                  \
    --enable-t1lib=yes               \
    --enable-dvi=%{?with_dvi:yes}%{!?with_dvi:no} \
    --enable-epub=%{?with_epub:yes}%{!?with_epub:no} \
    --enable-xps

%make_build

%install
%make_install

%find_lang %{name} --with-gnome --all-name

%files -f %{name}.lang
%doc AUTHORS README*
%license COPYING
%{_bindir}/atril
%{_bindir}/atril-previewer
%{_bindir}/atril-thumbnailer
%{_libexecdir}/atrild
%{_datadir}/metainfo/atril.appdata.xml
%{_datadir}/applications/atril.desktop
%{_datadir}/%{name}/
%{_datadir}/caja/extensions/libatril-properties-page.caja-extension
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/thumbnailers/
%{_iconsdir}/hicolor/*/apps/atril*
%{_mandir}/man1/atril*

%dir %{_libdir}/%{name}/%{major}/
%dir %{_libdir}/%{name}/%{major}/backends

%{_libdir}/%{name}/%{major}/backends/libcomicsdocument.so
%{_libdir}/%{name}/%{major}/backends/comicsdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libdjvudocument.so
%{_libdir}/%{name}/%{major}/backends/djvudocument.%{name}-backend

%if %{with epub}
%{_libdir}/%{name}/%{major}/backends/libepubdocument.so
%{_libdir}/%{name}/%{major}/backends/epubdocument.%{name}-backend
%endif

%{_libdir}/%{name}/%{major}/backends/libpdfdocument.so
%{_libdir}/%{name}/%{major}/backends/pdfdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libpixbufdocument.so
%{_libdir}/%{name}/%{major}/backends/pixbufdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libpsdocument.so
%{_libdir}/%{name}/%{major}/backends/psdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libtiffdocument.so
%{_libdir}/%{name}/%{major}/backends/tiffdocument.%{name}-backend

%{_libdir}/%{name}/%{major}/backends/libxpsdocument.so
%{_libdir}/%{name}/%{major}/backends/xpsdocument.%{name}-backend

# caja extensions
%{_libdir}/caja/extensions-2.0/libatril-properties-page.so

%if %{with dvi}
%files dvi
%{_libdir}/atril/%{major}/backends/libdvidocument.so
%{_libdir}/atril/%{major}/backends/dvidocument.%{name}-backend
%endif

%files -n %{libname}
%{_libdir}/libatrildocument.so.%{major}{,.*}
%{_libdir}/libatrilview.so.%{major}{,.*}

%files -n %{girname}
%{_libdir}/girepository-1.0/AtrilDocument-%{api}.typelib
%{_libdir}/girepository-1.0/AtrilView-%{api}.typelib

%files -n %{develname}
%doc ChangeLog
%doc %{_datadir}/gtk-doc/html/atril
%doc %{_datadir}/gtk-doc/html/libatrildocument-%{api}
%doc %{_datadir}/gtk-doc/html/libatrilview-%{api}
%{_libdir}/libatrildocument.so
%{_libdir}/libatrilview.so
%{_libdir}/pkgconfig/atril*pc
%{_includedir}/atril*
%{_datadir}/gir-1.0/AtrilDocument-%{api}.gir
%{_datadir}/gir-1.0/AtrilView-%{api}.gir
