# build with Qt
%bcond_without		qt

%define build_jack	1

%define build_plf	0

%if "%{?distro_section}" == "tainted"
%define build_plf	1
%endif

#comment out when not prerelease
#define prel	beta1

%define rel	3

%global __provides_exclude_from	%{?__provides_exclude_from:%__provides_exclude_from|}%{_libdir}/audacious/.*\\.so

Summary:	Audacious Media Player core plugins
Name:		audacious-plugins
Epoch:		6
Version:	4.4.2
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	BSD
Group:		Sound/Players
Url:            https://audacious-media-player.org/
Source0:	https://distfiles.audacious-media-player.org/%{name}-%{version}%{?prel:-%prel}.tar.bz2
# Originally from Fedora
# Fedora customization: add default system-wide module_path
Patch0:		audacious-plugins-3.6-ladspa.patch
BuildRequires:	meson
BuildRequires:	pkgconfig(audacious) >= %{version}
BuildRequires:	pkgconfig(adplug)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(fluidsynth)
BuildRequires:	pkgconfig(libcdio)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(opus)
BuildRequires:	pkgconfig(opusfile)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(libnotify)
BuildRequires:	pkgconfig(libbinio)
BuildRequires:	pkgconfig(flac) >= 1.2.1
BuildRequires:	pkgconfig(wavpack)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libcddb)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(neon)
BuildRequires:	pkgconfig(libmms)
BuildRequires:	pkgconfig(libmtp)
BuildRequires:	pkgconfig(libcue)
BuildRequires:	pkgconfig(libbs2b)
BuildRequires:	pkgconfig(smbclient)
BuildRequires:	pkgconfig(libmodplug)
BuildRequires:	pkgconfig(gio-2.0) >= 2.0
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(liblircclient0)
BuildRequires:	pkgconfig(dbus-glib-1)
BuildRequires:	pkgconfig(sndio)
BuildRequires:	pkgconfig(libopenmpt)
BuildRequires:	pkgconfig(libpipewire-0.3)
#for sox resampler:
BuildRequires:	pkgconfig(soxr)

%if %{with qt}
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Multimedia)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6OpenGL)
BuildRequires:	cmake(Qt6OpenGLWidgets)
BuildRequires:	cmake(Qt6Widgets)
%endif

%if %{build_jack}
BuildRequires:	pkgconfig(jack) >= 1.9.7
%endif

%if %{build_plf}
BuildRequires:	faad2-devel
%endif
BuildRequires:	lame-devel

#for ladspa plugin
Requires:	ladspa

%description
Audacious is a media player based on the BMP music playing application.
Its primary goals are usability and usage of current desktop standards.

This contains the basic plugin distribution. Audacious is useless
without them.
%if %{build_plf}
This package is in "Tainted" as it violates some patents.
%endif

%package -n	audacious-wavpack
Group:		Sound/Players
Summary: 	Wavpack input plugin for Audacious
Requires:	audacious >= %{epoch}:%{version}

%description -n	audacious-wavpack
This is a wavpack input plugin for Audacious based on libwavpack.

%if %{build_jack}
%package -n	audacious-jack
Group:		Sound/Players
Summary:	Audacious output plugin for the jack sound server
Requires:	audacious >= %{epoch}:%{version}

%description -n	audacious-jack
Audacious audio output plugin for the jack audio server
(https://jackit.sourceforge.net/).
%endif

%package -n	audacious-pulse
Group:		Sound/Players
Summary:	Audacious output plugin for the Pulseaudio sound server
Requires:	audacious >= %{epoch}:%{version}
Provides:	audacious-esd
BuildRequires:	pkgconfig(libpulse)

%description -n	audacious-pulse
Audacious audio output plugin for the pulseaudio server.

%package -n	audacious-adplug
Summary:	AdLib player plugin for audacious
Group:		Sound/Players
Requires:	audacious >= %{epoch}:%{version}

%description -n	audacious-adplug
AdPlug is an Audacious input plugin It uses the AdPlug AdLib sound
player library to play back a wide range of AdLib (OPL2) music file
formats on top of an OPL2 emulator.  No OPL2 chip is required for
playback.

%package -n	audacious-fluidsynth
Summary:	Fluidsynth MIDI plugin for audacious
Group:		Sound/Players
Requires:	audacious >= %{epoch}:%{version}
Recommends:	fluid-soundfont-gm

%description -n	audacious-fluidsynth
FluidSynth is a real-time software synthesizer based on the SoundFont 2
specifications. It is a "software synthesizer". FluidSynth can read MIDI
events from the MIDI input device and render them to the audio device.

This is a fluidsynth backend for the Audacious Media Player to support the
playback of MIDI files with the fluidsynth engine.

%package -n	audacious-sid
Group:		Sound/Players
Summary:	Audacious input plugin for C64 SID files
BuildRequires:	pkgconfig(libsidplayfp) >= 1.0
Requires:	audacious >= %{epoch}:%{version}

%description -n	audacious-sid
Audacious-SID is a plugin for the Audacious Media Player which provides
support for playing the so-called "SID tunes", which are music
from old Commodore computer programs like games, demos, etc.

For the actual playing, it uses the excellent libsidplay (1|2)
emulator engine that emulates 6510 CPU and 6581/8580 Sound Interface
Device (SID) chip.

%prep
%autosetup -p1 -n %{name}-%{version}%{?prel:-%prel}

# with P2, fix hardcoded libdir
sed -i -e 's!__RPM_LIBDIR__!%{_libdir}!g' src/ladspa/plugin.cc

%build
%meson \
	%{?with_qt:-D qt=true} \
	%{!?with_qt:-D qt=false} \
	-D gtk=true \
%if !%build_plf
	-D aac=false \
%endif
	-D streamtuner=true
%meson_build

%install
%meson_install

%if !%{build_plf}
rm -fv %{buildroot}%{_libdir}/audacious/Input/{aac,aac-raw}.so
%endif

%find_lang %{name}

%files -f %name.lang
%doc COPYING
%dir %{_libdir}/audacious
%dir %{_libdir}/audacious/Container
%{_libdir}/audacious/Container/asx.so
%{_libdir}/audacious/Container/asx3.so
%{_libdir}/audacious/Container/audpl.so
%{_libdir}/audacious/Container/cue.so
%{_libdir}/audacious/Container/m3u.so
%{_libdir}/audacious/Container/pls.so
%{_libdir}/audacious/Container/xspf.so
%dir %{_libdir}/audacious/General
%{_libdir}/audacious/General/albumart.so
%{_libdir}/audacious/General/aosd.so
%{_libdir}/audacious/General/cd-menu-items.so
%{_libdir}/audacious/General/delete-files.so
%{_libdir}/audacious/General/gtkui.so
%{_libdir}/audacious/General/hotkey.so
%{_libdir}/audacious/General/lirc.so
%{_libdir}/audacious/General/lyrics-gtk.so
%{_libdir}/audacious/General/mpris2.so
%{_libdir}/audacious/General/notify.so
%{_libdir}/audacious/General/playlist-manager.so
%{_libdir}/audacious/General/scrobbler.so
%{_libdir}/audacious/General/search-tool.so
%{_libdir}/audacious/General/skins.so
%{_libdir}/audacious/General/statusicon.so
%{_libdir}/audacious/General/streamtuner.so
%{_libdir}/audacious/General/song_change.so
%if %{with qt}
%{_libdir}/audacious/General/albumart-qt.so
%{_libdir}/audacious/General/lyrics-qt.so
%{_libdir}/audacious/General/playlist-manager-qt.so
%{_libdir}/audacious/General/qthotkey.so
%{_libdir}/audacious/General/qtui.so
%{_libdir}/audacious/General/search-tool-qt.so
%{_libdir}/audacious/General/skins-qt.so
%{_libdir}/audacious/General/song-info-qt.so
%{_libdir}/audacious/General/statusicon-qt.so
%endif
%dir %{_libdir}/audacious/Input
%{_libdir}/audacious/Input/ffaudio.so
%{_libdir}/audacious/Input/cdaudio-ng.so
%{_libdir}/audacious/Input/console.so
%{_libdir}/audacious/Input/flacng.so
%{_libdir}/audacious/Input/madplug.so
%{_libdir}/audacious/Input/metronom.so
%{_libdir}/audacious/Input/modplug.so
%{_libdir}/audacious/Input/openmpt.so
%{_libdir}/audacious/Input/opus.so
%{_libdir}/audacious/Input/psf2.so
%{_libdir}/audacious/Input/sndfile.so
%{_libdir}/audacious/Input/tonegen.so
%{_libdir}/audacious/Input/vorbis.so
%{_libdir}/audacious/Input/vtx.so
%{_libdir}/audacious/Input/xsf.so

%if %{build_plf}
%{_libdir}/audacious/Input/aac-raw.so
%endif

%dir %{_libdir}/audacious/Effect/
%{_libdir}/audacious/Effect/background_music.so
%{_libdir}/audacious/Effect/bitcrusher.so
%{_libdir}/audacious/Effect/bs2b.so
%{_libdir}/audacious/Effect/compressor.so
%{_libdir}/audacious/Effect/crossfade.so
%{_libdir}/audacious/Effect/crystalizer.so
%{_libdir}/audacious/Effect/echo.so
%{_libdir}/audacious/Effect/ladspa.so
%{_libdir}/audacious/Effect/mixer.so
%{_libdir}/audacious/Effect/resample.so
%{_libdir}/audacious/Effect/silence-removal.so
%{_libdir}/audacious/Effect/speed-pitch.so
%{_libdir}/audacious/Effect/sox-resampler.so
%{_libdir}/audacious/Effect/stereo.so
%{_libdir}/audacious/Effect/voice_removal.so
%dir %{_libdir}/audacious/Output
%{_libdir}/audacious/Output/alsa.so
%{_libdir}/audacious/Output/filewriter.so
%{_libdir}/audacious/Output/oss4.so
%{_libdir}/audacious/Output/pipewire.so
%if %{with qt}
%{_libdir}/audacious/Output/qtaudio.so
%endif
%{_libdir}/audacious/Output/sdlout.so
%{_libdir}/audacious/Output/sndio-ng.so
%dir %{_libdir}/audacious/Transport/
%{_libdir}/audacious/Transport/gio.so
%{_libdir}/audacious/Transport/mms.so
%{_libdir}/audacious/Transport/neon.so
%dir %{_libdir}/audacious/Visualization
%{_libdir}/audacious/Visualization/blur_scope.so
%{_libdir}/audacious/Visualization/cairo-spectrum.so
%{_libdir}/audacious/Visualization/gl-spectrum.so
%if %{with qt}
%{_libdir}/audacious/Visualization/gl-spectrum-qt.so
%{_libdir}/audacious/Visualization/qt-spectrum.so
%{_libdir}/audacious/Visualization/vumeter-qt.so
%{_libdir}/audacious/Visualization/blur_scope-qt.so
%endif
%{_datadir}/audacious/

%files -n audacious-wavpack
%{_libdir}/audacious/Input/wavpack.so

%if %{build_jack}
%files -n audacious-jack
%{_libdir}/audacious/Output/jack-ng.so
%endif

%files -n audacious-pulse
%{_libdir}/audacious/Output/pulse_audio.so

%files -n audacious-sid
%{_libdir}/audacious/Input/sid.so

%files -n audacious-adplug
%{_libdir}/audacious/Input/adplug.so

%files -n audacious-fluidsynth
%{_libdir}/audacious/Input/amidi-plug.so
