# we don't want to provide private python extension libs
%global __exclude_provides_from %{python3_sitearch}/.*\\.so

# comment out when not pre-release
#define prel		20230114

%define rel		1

%define major		1
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

### set to %%bcond_with to do a bootstrap build
%bcond_without doc

Name:		audaspace
Version:	1.6.0
Release:	%mkrel %{?prel:0.git%prel.}%{rel}
Summary:	A feature rich high level audio library
License:	Apache License
Group:		Sound/Utilities
URL:		https://audaspace.github.io/
Source0:	https://github.com/audaspace/%{name}/archive/v%{version}/%{name}-%{?prel:%prel}%{?!prel:%version}.tar.%{?prel:xz}%{?!prel:gz}
BuildRequires:	cmake
BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libpipewire-0.3)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3-numpy-devel

%description
Audaspace (pronounced "outer space") is a high level audio library written
in C++ with language bindings for Python for example.
It started out as the audio engine of the 3D modelling application Blender
and is now released as a standalone library.

#------------------------------------------------

%if %{with doc}
%package	doc
Summary:	Documentation for %{name}
Group:		Documentation
BuildArch:	noarch
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(sphinx-rtd-theme)

%description	doc
This package contains documentation for %{name}.
%endif

#------------------------------------------------

%package -n	%{libname}
Summary:	Library for %{name}
Group:		System/Libraries

%description -n	%{libname}
Audaspace (pronounced "outer space") is a high level audio library written
in C++ with language bindings for Python for example.
It started out as the audio engine of the 3D modelling application Blender
and is now released as a standalone library.
This package contains library files for %{name}.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains header files for development with %{name}.

#------------------------------------------------

%package -n	python3-%{name}
Summary:	Python3 bindings package for %{name}
Group:		Development/Python
Requires:	python3dist(numpy)

%description -n	python3-%{name}
This package contains Python3 bindings for %{name}.

#------------------------------------------------

%package -n	python3-%{name}-devel
Summary:	Python3 development package for %{name}
Group:		Development/Python
Requires:	python3-%{name} = %{version}-%{release}

%description -n	python3-%{name}-devel
This package contains Python3 header files for development with %{name}.

#------------------------------------------------
%prep
%autosetup -p1 -n %{name}-%{?prel}%{?!prel:%version}

%build
%cmake \
	-DWITH_STRICT_DEPENDENCIES:BOOL=TRUE \
	-DUSE_SDL2:BOOL=TRUE \
	%if %{with doc}
	-DSPHINX_EXECUTABLE=%{_bindir}/sphinx-build \
	-DDOCUMENTATION_INSTALL_PATH:PATH=%{_docdir}/%{name} \
	%else
	-DWITH_DOCS:BOOL=FALSE \
	-DWITH_BINDING_DOCS:BOOL=FALSE \
	%endif
	-DDEFAULT_PLUGIN_PATH:PATH=%{_libdir}/%{name}/plugins
%cmake_build

%install
# FIXME: %%cmake_install fails install python module, should be fixed in CMakeLists.txt
%make_install -C build

%files
%doc AUTHORS LICENSE README.md
%{_bindir}/*

%if %{with doc}
%files doc
%{_docdir}/%{name}/
%endif

%files -n %{libname}
%doc AUTHORS LICENSE README.md
%{_libdir}/lib%{name}*.so.%{major}{,.*}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/libaud*.so.%{major}{,.*}

%files -n %{develname}
%doc AUTHORS LICENSE README.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}*.so
%{_libdir}/%{name}/plugins/libaud*.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n python3-%{name}
%doc AUTHORS LICENSE README.md
%{python3_sitearch}/aud.cpython-*.so
#{python3_sitearch}/%%{name}-%%{version}%%{?prel}-py%%{python3_version}.egg-info
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info

%files -n python3-%{name}-devel
%doc AUTHORS LICENSE README.md
%{_includedir}/python*/%{name}/
