%define major            1
%define libname          %mklibname audit %{major}
%define develname        %mklibname audit -d

%define auparsemajor     0
%define auparselibname   %mklibname auparse %{auparsemajor}
%define auparsedevelname %mklibname auparse -d

Summary:        User-space tools for Linux kernel auditing
Name:           audit
Version:        4.0.3
Release:        %mkrel 2
License:        LGPLv2+
Group:          System/Base
# https://people.redhat.com/sgrubb/audit/
URL:            https://github.com/linux-audit/audit-userspace
Source0:        https://github.com/linux-audit/audit-userspace/archive/v%{version}/audit-userspace-%{version}.tar.gz
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel >= 2.6
BuildRequires:  intltool
BuildRequires:  kernel-headers >= 5.0
BuildRequires:  krb5-devel
BuildRequires:  pkgconfig(libcap-ng)
BuildRequires:  pkgconfig(liburing)
BuildRequires:  libtool
BuildRequires:  openldap-devel
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig
BuildRequires:  tcp_wrappers-devel
# for macro definition:
BuildRequires:  pkgconfig(libsystemd)
Requires(preun): rpm-helper
Requires(post): rpm-helper
Requires(postun):rpm-helper
Requires:       tcp_wrappers
Requires:       %{name}-rules%{?_isa} = %{version}-%{release}

%description
The audit package contains the user space utilities for storing and searching
the audit records generate by the audit subsystem in the Linux kernel.

%package -n     %{libname}
Summary:        Main libraries for %{name}
Group:          System/Libraries

%description -n %{libname}
This package contains the main libraries for %{name}.

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       libaudit-devel = %{version}-%{release}
Provides:       audit-devel = %{version}-%{release}
Provides:       audit-libs-devel = %{version}-%{release}

%description -n %{develname}
This package contains development files for %{name}.

%package -n     %{auparselibname}
Summary:        Main libraries for %{name}
Group:          System/Libraries

%description -n %{auparselibname}
This package contains the main auparse libraries for %{name}.

%package -n     %{auparsedevelname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{auparselibname} = %{version}-%{release}
Provides:       auparse-devel = %{version}-%{release}


%description -n %{auparsedevelname}
This package contains development files for %{name}.

%package -n     python3-audit
Summary:        Python3 bindings for libaudit
License:        LGPLv2+
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n python3-audit
The python3-audit package contains the bindings so that libaudit
and libauparse can be used by python3.

%package -n     audispd-plugins
Summary:        Plugins for the audit event dispatcher
Group:          System/Base
Requires:       %{name} = %{version}

Conflicts:      audit < 3.1.2-6

%description -n audispd-plugins
The audispd-plugins package provides plugins for the real-time interface to the
audit system, audispd. These plugins can do things like relay events to remote
machines.

%package -n	audispd-plugins-zos
Summary:	z/OS plugin for the audit event dispatcher
Group:		System/Base
Requires:	%{name} = %{version}
Requires:	openldap

%description -n audispd-plugins-zos
The audispd-plugins-zos package provides a plugin that will forward all
incoming audit events, as they happen, to a configured z/OS SMF (Service
Management Facility) database, through an IBM Tivoli Directory Server
(ITDS) set for Remote Audit service.

%package rules
Summary:	audit rules and utilities
Group:		System/Base
License:	GPL-2.0-or-later
Recommends:	%{name} >= %{version}-%{release}

Conflicts:	audit < 3.1.2-6

%description rules
The audit rules package contains the rules and utilities to load audit rules.

%prep
%autosetup -n audit-userspace-%{version}

find -type d -name ".libs" | xargs rm -rf

# fix runstatedir
sed -i -e 's,/var/run,%{_rundir},g' $(grep -rl /var/run)

%build
./autogen.sh
# Remove the ids code, its not ready
sed -i 's/ ids / /' audisp/plugins/Makefile.am
sed -i 's/ ids / /' audisp/plugins/Makefile.in
%configure \
    --disable-static \
    --with-libwrap \
    --enable-gssapi-krb5=yes \
    --with-libcap-ng=yes \
    --with-arm --with-aarch64 --with-riscv \
    --without-golang \
    --enable-zos-remote \
    --enable-experimental \
    --with-io_uring

%make_build

%install
%{__install} -d %{buildroot}%{_sysconfdir}/%{name}/rules.d
%{__install} -d %{buildroot}%{_var}/log/audit
%{__install} -d %{buildroot}%{_libdir}/audit
%{__install} -d %{buildroot}%{_var}/spool/audit

%make_install

%post
%_tmpfilescreate %{name}

## This hack is because the auditd.service needs to be started before sysinit.target. So let's just enable and start
## the service manually after installation. This needs to be revisited after our %%_post_service has been adjusted
systemctl enable -q auditd.service
systemctl start -q auditd.service
# %%_post_service auditd.service

%preun
## For some unknow reason "systemctl stop" doesn't work so use "systemctl kill" instead:
## Failed to stop auditd.service: Operation refused, unit auditd.service may be requested
## by dependency only.
systemctl kill -q auditd.service
systemctl disable -q auditd.service

%post rules
# Copy default rules into place on new installation
files=`ls /etc/audit/rules.d/ 2>/dev/null | wc -w`
if [ "$files" -eq 0 ] ; then
# FESCO asked for audit to be off by default. #1117953
	if [ -e %{_datadir}/%{name}/rules/10-no-audit.rules ] ; then
	        cp %{_datadir}/audit/rules/10-no-audit.rules /etc/audit/rules.d/audit.rules
	else
		touch /etc/audit/rules.d/audit.rules
	fi
	chmod 0600 /etc/audit/rules.d/audit.rules
fi

%preun rules
%systemd_preun audit-rules.service
# If uninstalling, delete the rules loaded in the kernel
if [ $1 -eq 0 ] ; then
    auditctl -D > /dev/null 2>&1 || true
fi


%files
%doc README.md ChangeLog init.d/auditd.cron
%license COPYING
%attr(0644,root,root) %{_mandir}/man8/auditd.8*
%attr(0644,root,root) %{_mandir}/man8/aulast.8*
%attr(0644,root,root) %{_mandir}/man8/aulastlog.8*
%attr(0644,root,root) %{_mandir}/man8/aureport.8*
%attr(0644,root,root) %{_mandir}/man8/ausearch.8*
%attr(0644,root,root) %{_mandir}/man8/ausyscall.8*
%attr(0644,root,root) %{_mandir}/man5/auditd.conf.5*
%attr(0644,root,root) %{_mandir}/man5/ausearch-expression.5*
%attr(0644,root,root) %{_mandir}/man5/auditd-plugins.5*
%attr(0755,root,root) %{_sbindir}/auditd
%attr(0755,root,root) %{_sbindir}/aureport
%attr(0755,root,root) %{_sbindir}/ausearch
%attr(0755,root,root) %{_bindir}/aulast
%attr(0755,root,root) %{_bindir}/aulastlog
%attr(0755,root,root) %{_bindir}/ausyscall
%attr(644,root,root) %{_unitdir}/auditd.service
%attr(640,root,root) %{_tmpfilesdir}/%{name}.conf
%attr(750,root,root) %dir %{_libexecdir}/initscripts/legacy-actions/auditd
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/resume
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/rotate
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/state
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/stop
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/restart
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/condrestart
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/reload
%attr(0700,root,root) %dir %{_var}/log/audit
%attr(0750,root,root) %dir %{_sysconfdir}/audit/plugins.d
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/auditd.conf

%files -n %{libname}
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/libaudit.conf
%{_libdir}/libaudit.so.%{major}{,.*}
%attr(0644,root,root) %{_mandir}/man5/libaudit.conf.5*

%files -n %{develname}
%doc ChangeLog contrib/plugin
%{_libdir}/libaudit.so
%{_includedir}/libaudit.h
%{_includedir}/audit_logging.h
%{_includedir}/audit-records.h
%{_datadir}/aclocal/audit.m4
%{_libdir}/pkgconfig/audit.pc
%{_mandir}/man3/audit_*
%{_mandir}/man3/ausearch_*
%{_mandir}/man3/get_auditfail_action.3*
%{_mandir}/man3/set_aumessage_mode.3*

%files -n %{auparselibname}
%{_libdir}/libauparse.so.%{auparsemajor}{,.*}

%files -n %{auparsedevelname}
%doc contrib/plugin
%{_libdir}/libauparse.so
%{_includedir}/auparse-defs.h
%{_includedir}/auparse.h
%{_libdir}/pkgconfig/auparse.pc
%{_mandir}/man3/auparse_*

%files -n python3-audit
%{python3_sitearch}/*

%files rules
%doc rules
%attr(0755,root,root) %dir %{_datadir}/%{name}-rules
%attr(0644,root,root) %{_datadir}/%{name}-rules/*
%attr(0644,root,root) %{_mandir}/man8/auditctl.8*
%attr(0644,root,root) %{_mandir}/man8/augenrules.8*
%attr(0644,root,root) %{_mandir}/man7/audit.rules.7*
%attr(0755,root,root) %{_sbindir}/auditctl
%attr(0755,root,root) %{_sbindir}/augenrules
%attr(0644,root,root) %{_unitdir}/audit-rules.service
%attr(0750,root,root) %dir %{_sysconfdir}/audit
%attr(0750,root,root) %dir %{_sysconfdir}/audit/rules.d
%ghost %config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/rules.d/audit.rules
%ghost %config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audit.rules
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audit-stop.rules

%files -n audispd-plugins
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audisp-remote.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/au-remote.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/syslog.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audisp-statsd.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/au-statsd.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/af_unix.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audisp-filter.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/filter.conf
%attr(0755,root,root) %{_sbindir}/audisp-af_unix
%attr(0750,root,root) %{_sbindir}/audisp-remote
%attr(0750,root,root) %{_sbindir}/audisp-syslog
%attr(0750,root,root) %{_sbindir}/audisp-statsd
%attr(0750,root,root) %{_sbindir}/audisp-filter
%attr(0750,root,root) %dir %{_var}/spool/audit
%attr(0644,root,root) %{_mandir}/man5/audisp-remote.conf.5*
%attr(0644,root,root) %{_mandir}/man8/audisp-af_unix.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-remote.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-syslog.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-statsd.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-filter.8*

%files -n audispd-plugins-zos
%attr(0644,root,root) %{_mandir}/man8/audispd-zos-remote.8*
%attr(0644,root,root) %{_mandir}/man5/zos-remote.conf.5*
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/audispd-zos-remote.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/zos-remote.conf
%attr(0750,root,root) %{_sbindir}/audispd-zos-remote
