Name:           autofs
Version:        5.1.9
Release:        %mkrel 3
License:        GPLv2+
Summary:        A tool for automatically mounting and unmounting filesystems
Group:          System/Kernel and hardware
URL:            https://www.kernel.org/pub/linux/daemons/autofs
Source0:        https://www.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}.tar.gz
Patch1:         autofs-5.1.9-update-configure.patch
Patch2:         autofs-5.1.9-fix-ldap_parse_page_control-check.patch
Patch3:         autofs-5.1.9-fix-crash-in-make_options_string.patch
Patch4:         autofs-5.1.9-Fix-incompatible-function-pointer-types-in-cyrus-sasl-module.patch
Patch5:         autofs-5.1.9-fix-always-recreate-credential-cache.patch
Patch6:         autofs-5.1.9-fix-changelog.patch
Patch102:       autofs-5.0.6-separate-config-files.patch
Patch104:       autofs-5.0.7-do-not-install-init.patch
Patch105:       autofs-5.0.7-after-nss-lookup.patch
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  rpcgen
BuildRequires:  openldap-devel
BuildRequires:  krb-devel
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(libsystemd)

Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

Conflicts:      autosmb

%description
autofs is a daemon which automatically mounts filesystems when you use
them, and unmounts them later when you are not using them.  This can
include network filesystems, CD-ROMs, floppies, and so forth.

%prep
%autosetup -p1

%build
autoreconf -vfi
%serverbuild
# Without the -Wl,--no-undefined which is needed to build the modules.
%define _disable_ld_no_undefined 1
%configure \
    --with-mapdir=%{_sysconfdir}/%{name} \
    --with-confdir=%{_sysconfdir}/%{name} \
    --with-sasl=yes \
    --disable-mount-locking \
    --enable-ignore-busy \
    --with-libtirpc \
    --without-hesiod \
    --with-systemd=%{_unitdir}
%make_build DONTSTRIP=1

mkdir examples
cp samples/ldap* examples
cp samples/autofs.schema examples

rm -f README.gentoo

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/autofs
mkdir -p %{buildroot}%{_mandir}/{man5,man8}
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_sysconfdir}/auto.master.d

%make_build install INSTALLROOT=%{buildroot}

pushd samples
%make_build install INSTALLROOT=%{buildroot}
popd

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 samples/autofs.service %{buildroot}%{_unitdir}/autofs.service

cat > README.urpmi <<EOF
Mageia RPM specific notes

setup
-----
Configuration handling in Mageia package differs from upstream one on several
points:
- the automounts daemon configuration file is %{_sysconfdir}/autofs/autofs.conf
- the autofs service configuration file is %{_sysconfdir}/sysconfig/autofs

Upgrade
-------
Map files have been moved from %{_sysconfdir} to %{_sysconfdir}/autofs. Upgrade
procedure should handle the change automatically.
LDAP usage has changed between autofs 4 and 5. The LDAP schema used has now to
be configured explicitely in autofs configuration, so as to avoid useless
queries. As this can't be handled by package upgrade procedure, you'll have to
edit your configuration manually. See auto.master(5) for details.

EOF

# tune default configuration
perl -pi -e 's|^BROWSE_MODE="no"|BROWSE_MODE="yes"|' \
    %{buildroot}%{_sysconfdir}/autofs/autofs.conf
perl -pi \
    -e 's|^/misc\t/etc/(.*)$|#/misc\t%{_sysconfdir}/%{name}/\1|;' \
    -e 's|^/net\t|#/net\t|;' \
    %{buildroot}%{_sysconfdir}/autofs/auto.master

%post
%_post_service autofs

%preun
%_preun_service autofs

%files
%doc INSTALL CHANGELOG CREDITS README* examples
%config(noreplace) %{_sysconfdir}/autofs
%{_unitdir}/autofs.service
%{_sbindir}/automount
%{_mandir}/*/*
%{_libdir}/%{name}
%{_libdir}/libautofs.so
%dir %{_sysconfdir}/auto.master.d
