# filter out bogus auto-requires
%global __requires_exclude ^devel\\(libMoleQueue.*)$

Name:		avogadrolibs
Version:	1.99.0
Release:	%mkrel 2
Summary:	An advanced molecular editor
License:	BSD
Group:		Sciences/Chemistry
Url:		https://www.openchemistry.org/projects/avogadro2/
Source0:	https://github.com/OpenChemistry/avogadrolibs/archive/%{version}/%{name}-%{version}.tar.gz
# External source code for avogadrolibs >= 1.91.0
# See https://github.com/OpenChemistry/avogadrolibs/issues/362
%global commit	b00be69a09cfd959a562db8ec769796427ce2a66
Source1:	https://github.com/OpenChemistry/avogenerators/archive/%{commit}/avogenerators-%{commit}.tar.gz
%global molecule_commit ecfb0c27ce02550ff6014a35fbe6a4483032403d
Source2:	https://github.com/OpenChemistry/molecules/archive/%{molecule_commit}/molecules-%{molecule_commit}.tar.gz
%global crystals_commit de0860674eb50acabca9f8168536ebdfffba18de
Source3:	https://github.com/OpenChemistry/crystals/archive/%{crystals_commit}/crystals-%{crystals_commit}.tar.gz
%global fragments_commit 8dc711a59d016604b3e9b6d59dec178b8e6ccd36
Source4:	https://github.com/OpenChemistry/fragments/archive/%{fragments_commit}/fragments-%{fragments_commit}.tar.gz
# Upstream patches
Patch1:		0001-Fix-wrong-variable-name.patch
Patch2:		0001-Fix-building-Qt-Plugins-without-spglib.patch
Patch3:		0001-Further-fixes-for-Qt6.patch
Patch4:		0001-Minor-tweaks-to-use-QRegularExpression-for-Qt6-support.patch
Patch5:		0001-Add-everything-back-in-after-QRegExp-porting.patch
Patch6:		0001-Switch-deprecated-Foreground-constant-for-QColorRole-to-WindowText.patch
Patch7:		0001-Migrate-to-QRegularExpression.patch
Patch8:		0001-Port-to-QRegularExpression-to-try-to-get-scripts-working.patch
Patch9:		0001-Port-GAMESS-input-highlighting-to-QRegularExpression.patch
Patch10:	0001-Port-coordinate-editor-to-use-QRegularExpression.patch
Patch11:	0001-Remove-QRegExp-include.patch
Patch12:	0001-Port-to-QRegularExpression-in-molequeue_inputgenerator.patch
Patch13:	0001-Port-to-QRegExp-while-removing-possibility-of-other-syntaxes.patch
Patch14:	0001-port-to-QMultiMap.patch
Patch15:	0001-Add-svg-back-in-for-Qt6.patch

BuildRequires:	cmake
BuildRequires:	boost-devel
BuildRequires:	cmake(libmsym)
BuildRequires:	cmake(nlohmann_json)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(spglib)
BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6OpenGL)
BuildRequires:	cmake(Qt6OpenGLWidgets)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Svg)

%description
Avogadro is an advanced molecular editor designed for cross-platform use in
computational chemistry, molecular modeling, bioinformatics, materials science,
and related areas. It offers flexible rendering and a powerful plugin
architecture. The code in this repository is a rewrite of Avogadro with source
code split across a libraries repository and an application repository. Core
features and goals of the Avogadro project:

  * Open source distributed under the liberal 3-clause BSD license
  * Cross platform with nightly builds on Linux, Mac OS X and Windows
  * Intuitive interface designed to be useful to whole community
  * Fast and efficient embracing the latest technologies
  * Extensible, making extensive use of a plugin architecture
  * Flexible supporting a range of chemical data formats and packages

%files
%doc avogadrogenerators/README-avogenerators.md
%doc thirdparty/libgwavi/README-libgwavi.md
%doc %{_docdir}/AvogadroLibs/
%license LICENSE
%{_libdir}/avogadro2/
%dir %{_datadir}/avogadro2
%{_datadir}/avogadro2/crystals/
%{_datadir}/avogadro2/molecules/
%{_datadir}/avogadro2/fragments/

#----------------------------------------------------

%define core_major		1
%define libcorename		%mklibname avogadrocore %{core_major}

%package -n	%{libcorename}
Summary:	Avogadro Core library
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n	%{libcorename}
Avogadro Core library.

%files -n %{libcorename}
%{_libdir}/libAvogadroCore.so.%{core_major}{,.*}

#----------------------------------------------------

%define io_major		1
%define libioname		%mklibname avogadroio %{io_major}

%package -n	%{libioname}
Summary:	Avogadro IO library
Group:		System/Libraries

%description -n	%{libioname}
Avogadro IO library.

%files -n %{libioname}
%{_libdir}/libAvogadroIO.so.%{io_major}{,.*}

#----------------------------------------------------

%define molequeue_major		1
%define libmolequeuename	%mklibname avogadromolequeue %{molequeue_major}

%package -n	%{libmolequeuename}
Summary:	Avogadro MoleQueue library
Group:		System/Libraries

%description -n	%{libmolequeuename}
Avogadro MoleQueue library.

%files -n %{libmolequeuename}
%{_libdir}/libAvogadroMoleQueue.so.%{molequeue_major}{,.*}

#----------------------------------------------------

%define qtgui_major		1
%define libqtguiname		%mklibname avogadroqtgui %{qtgui_major}

%package -n	%{libqtguiname}
Summary:	Avogadro Qt Gui library
Group:		System/Libraries

%description -n	%{libqtguiname}
Avogadro Qt Gui library.

%files -n %{libqtguiname}
%{_libdir}/libAvogadroQtGui.so.%{qtgui_major}{,.*}

#----------------------------------------------------

%define qtopengl_major		1
%define libqtopenglname		%mklibname avogadroqtopengl %{qtopengl_major}

%package -n	%{libqtopenglname}
Summary:	Avogadro Qt OpenGL library
Group:		System/Libraries

%description -n	%{libqtopenglname}
Avogadro Qt OpenGL library.

%files -n %{libqtopenglname}
%{_libdir}/libAvogadroQtOpenGL.so.%{qtopengl_major}{,.*}

#----------------------------------------------------

%define qtplugins_major		1
%define libqtpluginsname	%mklibname avogadroqtplugins %{qtplugins_major}

%package -n	%{libqtpluginsname}
Summary:	Avogadro Qt Plugins library
Group:		System/Libraries

%description -n	%{libqtpluginsname}
Avogadro Qt Plugins library.

%files -n %{libqtpluginsname}
%{_libdir}/libAvogadroQtPlugins.so.%{qtplugins_major}{,.*}

#----------------------------------------------------

%define quantumio_major		1
%define libquantumioname	%mklibname avogadroquantumio %{quantumio_major}

%package -n	%{libquantumioname}
Summary:	Avogadro Quantum IO library
Group:		System/Libraries

%description -n	%{libquantumioname}
Avogadro Quantum IO library.

%files -n %{libquantumioname}
%{_libdir}/libAvogadroQuantumIO.so.%{quantumio_major}{,.*}

#----------------------------------------------------

%define rendering_major		1
%define librenderingname	%mklibname avogadrorendering %{rendering_major}

%package -n	%{librenderingname}
Summary:	Avogadro Rendering library
Group:		System/Libraries

%description -n	%{librenderingname}
Avogadro Rendering library.

%files -n %{librenderingname}
%{_libdir}/libAvogadroRendering.so.%{rendering_major}{,.*}

#----------------------------------------------------

%define calc_major         1
%define libcalcname        %mklibname avogadrocalc %{calc_major}

%package -n     %{libcalcname}
Summary:        Avogadro Calc library
Group:          System/Libraries

%description -n %{libcalcname}
Avogadro Calc library.

%files -n %{libcalcname}
%{_libdir}/libAvogadroCalc.so.%{calc_major}{,.*}

#----------------------------------------------------

%define devname		%mklibname %{name} -d

%package -n	%{devname}
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{name} >= %{version}-%{release}
Requires:	%{libcorename} >= %{version}-%{release}
Requires:	%{libioname} >= %{version}-%{release}
Requires:	%{libmolequeuename} >= %{version}-%{release}
Requires:	%{libqtguiname} >= %{version}-%{release}
Requires:	%{libqtopenglname} >= %{version}-%{release}
Requires:	%{libqtpluginsname} >= %{version}-%{release}
Requires:	%{libquantumioname} >= %{version}-%{release}
Requires:	%{librenderingname} >= %{version}-%{release}
Requires:       %{libcalcname} >= %{version}-%{release}
Provides:	avogadro2-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
The %{devname} package contains header files for developing applications
that use %{name}.

%files -n %{devname}
%{_includedir}/avogadro/
%{_libdir}/cmake/%{name}/
%{_libdir}/*.so

#----------------------------------------------------

%prep
%setup -q -a 1 -a 2 -a 3 -a 4
%autopatch -p1

# Make avogadro generators source code available for CMake
mv avogenerators-%{commit} avogadrogenerators
mv molecules-%{molecule_commit} ../molecules
mv crystals-%{crystals_commit} ../crystals
mv fragments-%{fragments_commit} ../fragments
mv avogadrogenerators/README.md avogadrogenerators/README-avogenerators.md
sed -e 's|../avogadrogenerators|avogadrogenerators|g' -i avogadro/qtplugins/quantuminput/CMakeLists.txt

mv thirdparty/libgwavi/README.md thirdparty/libgwavi/README-libgwavi.md

sed -i 's|(Qt5LinguistTools)|(Qt6LinguistTools)|' CMakeLists.txt

%build
%cmake_qt6 \
	-DQT_VERSION=6 \
	-DCMAKE_INSTALL_LIBDIR=%{_lib} \
	-DUSE_MMTF=OFF \
	-DCMAKE_SKIP_RPATH=ON \
	-DENABLE_TRANSLATIONS=ON \
	-DUSE_EXTERNAL_NLOHMANN=ON \
	-DUSE_EXTERNAL_PUGIXML=ON
%cmake_build

%install
%cmake_install
