%define upstream_name aws-cli

# Otherwise the expand doesn't work?
%global NAME %{upstream_name}-docs

Name:           aws-cli
Version:        2.17.55
Release:        %mkrel 2
Summary:        Universal Command Line Interface for Amazon Web Services (version 2)
License:        Apache License
Group:          Development/Tools
URL:            https://aws.amazon.com/cli
Source0:        https://github.com/aws/aws-cli/archive/%{version}/aws-cli-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
Requires:       python3-%{upstream_name} = %{version}

Provides:       bundled(python3dist(botocore)) = 2.0.0
Provides:       bundled(python3dist(s3transfer)) = 0.5.1

%description
The AWS Command Line Interface (CLI) is a unified tool to manage your AWS
services. With just one tool to download and configure, you can control
multiple AWS services from the command line and automate them through scripts.

The AWS CLI introduces a new set of simple file commands for efficient file
transfers to and from Amazon S3.

%package docs
Summary:        Additional documentation for %{upstream_name}
Group:          Documentation

%description docs
This package contains comprehensive CLI request/response examples for awscli
that can be viewed using e.g. 'aws ec2 run-instances help' when this package is
installed, but their absence doesn't impact the running of awscli.

Install this package if you need the examples, don't install it if you want to
reduce your image size but have the aws cli available.

%package -n python3-%{upstream_name}
Summary:        Universal Command Line Interface for Amazon Web Services (version 2)
Group:          Development/Python
License:        Apache License
BuildRequires:  pkgconfig(python3)
%{?python_provide:%python_provide python3-%{upstream_name}}

%description -n python3-%{upstream_name}
AWS CLI python libraries for Python 3.

%prep
%autosetup -p1

# fix permissions
find awscli/examples/ -type f -name '*.rst' -executable -exec chmod -x '{}' +

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

# The man pages are 34M, and mainly duplicates the 'help' subcommands'
#pushd doc
#make man

%install
%pyproject_install

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
echo "complete -C aws_completer aws" > %{buildroot}%{_datadir}/bash-completion/completions/aws
rm -f %{buildroot}%{_bindir}/aws.cmd
rm -f %{buildroot}%{_bindir}/aws_*_completer*

# The examples make up ~2/3 of the size, no need to ship it with the code and duplicate it
rm -Rf %{buildroot}%{python3_sitelib}/awscli/examples
mkdir -p %{buildroot}%{_defaultdocdir}/%{expand:%{_docdir_fmt}}/examples
ln -s %{_defaultdocdir}/%{expand:%{_docdir_fmt}}/examples %{buildroot}%{python3_sitelib}/awscli/examples

%files
%license LICENSE.txt
%doc README.rst
%{_bindir}/aws
%{_bindir}/aws_completer
%{_datadir}/bash-completion/completions/aws
%dir %{_defaultdocdir}/%{expand:%{_docdir_fmt}}/examples

%files docs
%doc awscli/examples

%files -n python3-%{name}
%license LICENSE.txt
%doc README.rst
%{python3_sitelib}/awscli/
%{python3_sitelib}/awscli-%{version}.dist-info/
