%global __provides_exclude perl\\(BackupPC::.*\\)
%global __requires_exclude perl\\(BackupPC::.*\\)

%define upstream_name BackupPC

Name:           backuppc
Version:        4.4.0
Release:        %mkrel 3
Summary:        High-performance, enterprise-grade backup system
Group:          Archiving/Backup
License:        GPLv2
Url:            https://backuppc.github.io/backuppc/
Source:         https://github.com/backuppc/backuppc/releases/download/%version/%{upstream_name}-%{version}.tar.gz
Source1:        BackupPC_Admin.c
Source2:        backuppc.service
Source3:        backuppc.tmpfiles
Source4:        backuppc.httpd
BuildRequires:  perl(BackupPC::XS) >= 0.620.0
BuildRequires:  perl(CGI)
BuildRequires:  perl(Compress::Zlib)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  perl(File::Listing)
Requires:       sendmail-command
Requires:       apache
Requires:       rsync-bpc
Requires:       perl(Net::FTP::AutoReconnect)
Requires:       perl(Net::FTP::RetrHandle)
Requires:       perl(BackupPC::XS)
Requires(post):     rpm-helper >= 0.24.8-1
Requires(preun):    rpm-helper >= 0.24.8-1
Recommends:         openssh-clients
Recommends:         samba-client

%description
BackupPC is a high-performance, enterprise-grade system
for backing up Linux, Win32, and laptops to a server's disk.
Features include clever pooling of identical files, no client-side
software, and a powerful Apache/CGI user interface.

%prep
%setup -q -n %{upstream_name}-%{version}

cp %{SOURCE1} .

# attempt to unbundle as much as possible
for m in Net/FTP; do
  rm -rf lib/$m
  sed -i "\@lib/$m@d" configure.pl 
done

%build
gcc -o BackupPC_Admin BackupPC_Admin.c %{optflags}

%install
%{__perl} configure.pl \
    --batch \
    --backuppc-user=backuppc \
    --dest-dir %{buildroot} \
    --config-dir %{_sysconfdir}/%{name}/ \
    --config-override CgiURL=\"http://localhost/%{name}\" \
    --config-override ClientNameAlias=undef \
    --config-override NmbLookupPath=\"%{_bindir}/nmblookup\" \
    --config-override ParPath=\"%{_bindir}/par2\" \
    --config-override PingPath=\"%{_bindir}/ping\" \
    --config-override Ping6Path=\"%{_sbindir}/ping6\" \
    --config-override RrdToolPath=\"%{_bindir}/rrdtool\" \
    --config-override RsyncBackupPCPath=\"%{_bindir}/rsync_bpc\" \
    --config-override RsyncClientPath=\"%{_bindir}/rsync\" \
    --config-override SendmailPath=\"%{_sbindir}/sendmail\" \
    --config-override SmbClientPath=\"%{_bindir}/smbclient\" \
    --config-override SshPath=\"%{_bindir}/ssh\" \
    --config-override TarClientPath=\"%{_bindir}/gtar\" \
    --config-override XferMethod=\"rsync\" \
    --cgi-dir %{_libexecdir}/%{name} \
    --data-dir %{_localstatedir}/lib/%{name}/ \
    --hostname localhost \
    --html-dir %{_datadir}/%{name}/html/ \
    --html-dir-url /%{name}/images \
    --install-dir %{_datadir}/%{name} \
    --log-dir %{_localstatedir}/log/%{name} \
    --no-set-perms \
    --uid-ignore

chmod +x %{buildroot}%{_datadir}/%{name}/bin/*
chmod +x %{buildroot}%{_libexecdir}/%{name}/BackupPC_Admin

# systemd
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service

# tmpfiles
install -D -m 0644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# apache configuration
install -D -m 0644 %{SOURCE4} %{buildroot}%{_webappconfdir}/%{name}.conf

# logs
install -d -m 755 %{buildroot}%{_localstatedir}/log/%{name}

# perl-suidperl is no longer avaialable, use a C wrapper
mkdir -p %{buildroot}%{_datadir}/%{name}/sbin
mv %{buildroot}%{_libexecdir}/%{name}/BackupPC_Admin \
   %{buildroot}%{_datadir}/%{name}/sbin/BackupPC_Admin
install -pm 0755 BackupPC_Admin %{buildroot}%{_libexecdir}/%{name}/

# remove useless files
rm -f %{buildroot}%{_sysconfdir}/%{name}/*.sample

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /bin/sh

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}
if [ $1 -ne 0 ] ; then
# previous releases of backuppc had root as the owner - undo this fault
  chown backuppc:backuppc %{_sysconfdir}/%{name}
fi

%postun
%_postun_userdel %{name}

%files
%doc ChangeLog README.md LICENSE doc/*
# backuppc must be able to edit the config file and create backup files
%dir %attr(-,backuppc,backuppc) %{_sysconfdir}/%{name}
%config(noreplace) %attr(-,backuppc,apache) %{_sysconfdir}/%{name}/*
%config(noreplace) %{_webappconfdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%{_datadir}/%{name}
%dir %attr(-,backuppc,backuppc) %{_localstatedir}/log/%{name}
%dir %attr(-,backuppc,backuppc) %{_localstatedir}/lib/%{name}
%attr(4750,backuppc,apache) %{_libexecdir}/%{name}/BackupPC_Admin
