%define mainrel 1
%define snapshot 20200220
%define rel 13

Name:           bear
Epoch:          1
Version:        0.7.0
Release:        %mkrel %{mainrel}.%{snapshot}.%{rel}
Summary:        Game engine and editors dedicated to creating great 2D games
Group:          Development/C++
License:        GPLv3+ and CC-BY-SA 3.0
URL:            https://github.com/j-jorge/bear
Source0:        %{name}-%{snapshot}.tar.xz
Patch1:         bear-boost-placeholders.patch
Patch2:		bear-missing-includes.patch
Patch3:		bear-rpath.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-to-man
BuildRequires:  gettext
BuildRequires:  libclaw-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  wxgtk3.0-devel

%description
The Bear engine is a set of C++ libraries and tools dedicated to creating
great 2D games. It has been used to create Plee the Bear (plee-the-bear),
Andy's Super Great Park (andy-super-great-park) and Tunnel (non packaged).

The engine comes with a set of tools, namely the Bear Factory, intended to
help creating resources for the game. These tools include a level editor,
a character/model editor and an animation editor.

#----------------------------------------------------------------------

%package engine
Summary:        Runtime libraries for games based on the Bear engine
Group:          System/Libraries

%description engine
The Bear engine is a set of C++ libraries and tools dedicated to creating
great 2D games. It has been used to create Plee the Bear (plee-the-bear),
Andy's Super Great Park (andy-super-great-park) and Tunnel (non packaged).

This package contains the runtime libraries used by the games based on
the Bear engine.

%files engine -f %{name}-engine.lang
%doc README.md LICENSE
%dir %{_libdir}/%{name}
%{_libdir}/bear/libbear_audio.so
%{_libdir}/bear/libbear_communication.so
%{_libdir}/bear/libbear_debug.so
%{_libdir}/bear/libbear_engine.so
%{_libdir}/bear/libbear_expr.so
%{_libdir}/bear/libbear_generic_items.so
%{_libdir}/bear/libbear_gui.so
%{_libdir}/bear/libbear_input.so
%{_libdir}/bear/libbear_net.so
%{_libdir}/bear/libbear_text_interface.so
%{_libdir}/bear/libbear_time.so
%{_libdir}/bear/libbear_universe.so
%{_libdir}/bear/libbear_visual.so
%{_datadir}/cmake/%{name}-engine/
%{_mandir}/man6/running-%{name}.6*

#----------------------------------------------------------------------

%package factory
Summary:        Level, animation and model editors for the Bear engine
Group:          Games/Other
Conflicts:      bear-factory < 1.0.8-7

%description factory
This package includes the level editor, animation editor and model editor
of the Bear Engine for Plee the Bear & Andy's Super Great Park.

%files factory -f %{name}-factory.lang
%{_bindir}/bend-image
%{_bindir}/bf*editor
%{_bindir}/image-cutter
%{_libdir}/%{name}/lib%{name}-editor.so
%dir %{_datadir}/%{name}-factory/
%{_datadir}/%{name}-factory/images/
%{_datadir}/%{name}-factory/item-description/
%{_datadir}/applications/bf*editor.desktop
%{_datadir}/applications/desc2img.desktop
%{_iconsdir}/hicolor/*/apps/%{name}-factory.png
%{_mandir}/man1/bf*editor.1*

#----------------------------------------------------------------------

%prep
%setup -qn %{name}-%{snapshot}
%autopatch -p1

# convenience.hpp was removed in boost 1.85.0
sed -i -e 's,filesystem/convenience.hpp,filesystem.hpp,g' $(grep -rl convenience.hpp)

# Boost.Math requires C++14
sed -i -e 's,c++11,c++14,g' $(grep -rl c++11)

%build
%cmake -GNinja -DBEAR_ENGINE_INSTALL_LIBRARY_DIR=%{_lib}/%{name} \
       -DBEAR_FACTORY_INSTALL_LIBRARY_DIR=%{_lib}/%{name} \
       -DBEAR_USES_FREEDESKTOP=ON \
       -DBEAR_EDITORS_ENABLED=ON
%cmake_build

%install
%cmake_install

%find_lang %{name}-engine
%find_lang %{name}-factory

rm -rf %{buildroot}%{_datadir}/pixmaps
