# This is a single package containing the beid-middleware, including the
# libraries as well as the firefox plugin used to register the libraries
# with firefox. This enables the use of Belgian eID, for signing and
# authentication for websites such as http://taxonweb.be . I put this all
# in one package, because this is always used together, and nothing else
# requires these files. This new version supersedes the old beid packages.

%define realname eid-mw

%define major		0
%define libname		%mklibname beidpkcs11_ %{major}
%define libeidviewer	%mklibname eidviewer %{major}
%define develname	%mklibname %{name} -d

Name:		beid-middleware
Summary:	Application to read information from the Belgian e-ID card
Version:	5.1.8
Release:	%mkrel 6
# The original parts are under the "eID Toolkit Software License",
# which by my reading is BSD-like; it's basically the BSD in stronger
# legal language with some added gumph about liability etc. It also
# contains bits of OpenSC (which is LGPLv2+) and OpenSSL (which is
# BSD). - AdamW 2008/09
# Looking at the unofficial link ( http://code.google.com/p/eid-mw ) and
# at the license file inside the svn tree, it seems that it's now released
# as LGPLv3 - alien 2011
License:	LGPLv3
Group:		Security
URL:		https://eid.belgium.be/
Source0:	https://dist.eid.belgium.be/continuous/sources/%{realname}-%{version}-v%{version}mw.tar.gz

BuildRequires:	gtk3-devel
BuildRequires:	libproxy-devel
BuildRequires:  p11-kit-devel
BuildRequires:	pkgconfig(xerces-c)
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	java
BuildRequires:	swig
BuildRequires:	subversion
BuildRequires:	zip
# need this for the c_rehash command
BuildRequires:	openssl-perl
Obsoletes:	beid < 4.0.0
Obsoletes:	%{_lib}beid2 < 4.0.0
Obsoletes:	%{_lib}beidcomm0 < 4.0.0
Obsoletes:	%{_lib}beidcommon0 < 4.0.0
Obsoletes:	%{_lib}beidgui1 < 4.0.0
Obsoletes:	%{_lib}beidlibopensc2 < 4.0.0
Obsoletes:	%{_lib}beidpcsclite2 < 4.0.0
Obsoletes:	%{_lib}beidpkcs11_2 < 4.0.0
# Suggesting the goverment supplied readers device drivers.
Recommends:	acr38u
Recommends:	ccid
Recommends:		pcsc-lite

%description
This application allows the user to read out any information from a
Belgian electronic ID card, by using libbeid and libbeidlibopensc to
read the data from the card and parse it. Both identity information
and information about the stored cryptographic keys can be read in a
user-friendly manner, and can easily be printed out or stored for
later review.

The application verifies the signature of the identity information,
checks whether it was signed by a government-issued key, and
optionally checks the certificate against the government's Certificate
Revocation List (CRL) and/or by using the Online Certificate Status
Protocol (OCSP) against the government's servers.

%package viewer
Summary:	Graphical application to read information from the Belgian e-ID card
Group:		Security
Requires:	%{name} >= %{version}-%{release}

%description viewer
This application allows the user to read out any information from a
Belgian electronic ID card, by using libbeid and libbeidlibopensc to
read the data from the card and parse it. Both identity information
and information about the stored cryptographic keys can be read in a
user-friendly manner, and can easily be printed out or stored for
later review.

The application verifies the signature of the identity information,
checks whether it was signed by a government-issued key, and
optionally checks the certificate against the government's Certificate
Revocation List (CRL) and/or by using the Online Certificate Status
Protocol (OCSP) against the government's servers.
This package provides the graphical viewer.

%package -n	%{libname}
Summary:	Library for %{name}
Group:		System/Libraries

%description -n	%{libname}
Library for %{name}.

%package -n	%{libeidviewer}
Summary:	Library for eid-viewer
Group:		System/Libraries

%description -n	%{libeidviewer}
Library for eid-viewer.

%package -n %{develname}
Summary:	Devel files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libeidviewer} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 5.1.8-5

%description -n %{develname}
Devel files for %{name}.

%prep
%setup -q -n %{realname}-%{version}-v%{version}mw

%build
%configure --enable-p11v220 --enable-webextension
%make_build

%install
%make_install
# remove static libraries
rm -f %{buildroot}%{_libdir}/*.{la,a}
# remove contents of the xpi
#rm -rf %%{buildroot}%%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be
# install the xpi itself
install -D -m 755 plugins_tools/xpi/signed-build/belgium_eid-1.0.32.xpi %{buildroot}%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be.xpi
install -D -m 755 plugins_tools/xpi/signed-build/eid_belgie-1.0.23.xpi %{buildroot}%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/eid_belgie@eid.belgium.be.xpi

%find_lang about-eid-mw
%find_lang dialogs-beid
%find_lang eid-viewer

# remove extra stuff for now, we'll do proper extra packages later on
# first, eid-viewer stuff

%files -f about-eid-mw.lang -f dialogs-beid.lang
%{_sysconfdir}/xdg/autostart/beid-update-nssdb.desktop
%{_libexecdir}/beid-*
%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/belgiumeid@eid.belgium.be.xpi
%{_datarootdir}/mozilla/extensions/{ec8030f7-c20a-464f-9b0e-13a3a9e97384}/eid_belgie@eid.belgium.be.xpi
%{_datadir}/eid-mw
%{_bindir}/about-eid-mw
%{_bindir}/beid-update-nssdb
%{_libdir}/pkcs11/beidpkcs11.so
%{_prefix}/lib/mozilla/pkcs11-modules/beidpkcs11.json
%{_prefix}/lib/mozilla/pkcs11-modules/beidpkcs11_alt.json
%{_prefix}/lib/mozilla/managed-storage/belgiumeid@eid.belgium.be.json
%{_datadir}/p11-kit/modules/beid.module
%{_datadir}/metainfo/be.belgium.eid.eidmw.metainfo.xml

%files viewer -f eid-viewer.lang
%{_datadir}/applications/eid-viewer.desktop
%{_bindir}/eid-viewer
%{_iconsdir}/hicolor/*/apps/eid-viewer.png
%{_datadir}/glib-2.0/schemas/eid-viewer.gschema.xml
%{_datadir}/metainfo/eid-viewer.appdata.xml

%files -n %{libname}
%{_libdir}/libbeidpkcs11.so.%{major}{,.*}

%files -n %{libeidviewer}
%{_libdir}/libeidviewer.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/libbeidpkcs11.so
%{_libdir}/libeidviewer.so
%{_libdir}/pkgconfig/libbeidpkcs11.pc
%{_includedir}/beid/
%{_includedir}/eid-viewer/
%{_includedir}/eid-util/
