
# bcond_without is built by default, unless --without X is passed
# bcond_with is built only when --with X is passed to build
%bcond_with    SYSTEMTEST
%bcond_without GSSTSIG
%bcond_without JSON
# FIXME: Not ready. Should it be worked on?
%bcond_with    DLZ
# New MaxMind GeoLite support
%bcond_without GEOIP2
# Disabled temporarily until kyua is fixed on rawhide, bug #1926779
%bcond_without UNITTEST
%bcond_without LMDB
%bcond_with DOC
%bcond_without MAN

%define major_version 9.18.33
#define patch_version P4
%define dashpatch %{?patch_version:-%patch_version}%nil
%define dotpatch %{?patch_version:.%patch_version}%nil
%define chroot_prefix /var/named/chroot
%define chroot_create_directories \\\
	/dev /run/named %{_localstatedir}/{log,named,tmp} \\\
	%{_sysconfdir}/{crypto-policies/back-ends,pki/dnssec-keys,named} \\\
	%{_libdir}/bind %{_libdir}/named %{_datadir}/GeoIP

%define libname         %mklibname bind %version

# libisc-nosym requires to be linked with unresolved symbols
# When libisc-nosym linking is fixed, it can be defined to 1
# Visit https://bugzilla.redhat.com/show_bug.cgi?id=1540300
%define _disable_ld_no_undefined 1

Name:       bind
Version:    %{major_version}%{dotpatch}
Release:    %mkrel 2
Summary:    A DNS (Domain Name System) server
License:    MPLv2.0
Group:      System/Servers
URL:        https://www.isc.org/bind
Source0:    https://downloads.isc.org/isc/bind9/%{version}/%{name}-%{version}.tar.xz

Source1:  named.sysconfig
Source2:  https://downloads.isc.org/isc/bind9/%{version}/%{name}-%{version}.tar.xz.asc
Source3:  named.logrotate
Source4:  https://downloads.isc.org/isc/pgpkeys/codesign2021.txt
Source16: named.conf
# Refresh by command: dig @a.root-servers.net. +tcp +norec
# or from URL
Source17: https://www.internic.net/domain/named.root
Source18: named.localhost
Source19: named.loopback
Source20: named.empty
Source23: named.rfc1912.zones
Source25: named.conf.sample
Source27: named.root.key
Source35: bind.tmpfiles
Source36: trusted-key.key
Source37: named.service
Source38: named-chroot.service
Source41: setup-named-chroot.sh
Source42: generate-rndc-key.sh
Source43: named.rwtab
Source44: named-chroot-setup.service
Source46: named-setup-rndc.service
Source48: setup-named-softhsm.sh
Source49: named-chroot.files

# fedora patches
# FIXME: Is this still required?
Patch10: bind-9.5-PIE.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=2122010
Patch26: bind-9.18-unittest-netmgr-unstable.patch

# 
# Security Patches
# Patch100 -> ...
#

Recommends:   bind-utils
Recommends:   bind-dnssec-utils
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(libcap) >= 2.10
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libnghttp2)
BuildRequires:  pkgconfig(readline)
BuildRequires:  systemd
BuildRequires:  pkgconfig(libuv)
%if %{with DLZ}
BuildRequires:  openldap-devel
BuildRequires:  postgresql-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  mysql-devel
%endif
%if %{with UNITTEST} || %{with SYSTEMTEST}
BuildRequires:  softhsm
BuildRequires:  pkgconfig(cmocka)
%endif
%if %{with SYSTEMTEST}
# bin/tests/system dependencies
BuildRequires:  perl(Net::DNS) perl(Net::DNS::Nameserver) perl(Time::HiRes) perl(Getopt::Long)
# manual configuration requires this tool
BuildRequires:  iproute
%endif
%if %{with GSSTSIG}
BuildRequires:  krb5-devel
%endif
%if %{with LMDB}
BuildRequires:  lmdb-devel
%endif
%if %{with JSON}
BuildRequires:  json-c-devel
%endif
%if %{with GEOIP2}
BuildRequires:  pkgconfig(libmaxminddb)
%endif
# Needed to regenerate dig.1 manpage
%if %{with DOC} || %{with MAN}
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  doxygen
%endif

%description
BIND (Berkeley Internet Name Domain) is an implementation of the DNS
(Domain Name System) protocols. BIND includes a DNS server (named),
which resolves host names to IP addresses; a resolver library
(routines for applications to use when interfacing with DNS); and
tools for verifying that the DNS server is operating properly.

%package utils
Summary: Utilities for querying DNS name servers
Group:      Networking/Other
Conflicts:  bind < 9.11.5.P1-3
Conflicts:  bind-dnssec-utils < 9.11.9
Obsoletes: %{name}-pkcs11-utils < 32:9.18.4-2

%description utils
Bind-utils contains a collection of utilities for querying DNS (Domain
Name System) name servers to find out information about Internet
hosts. These tools will provide you with the IP addresses for given
host names, as well as other information about registered domains and
network addresses.

You should install %{name}-utils if you need to get information from DNS name
servers.

%package dnssec-utils
Summary: DNSSEC keys and zones management utilities
Group:      Networking/Other
Conflicts:  bind-utils < 9.11.5.P1-6
Obsoletes: python3-%{name} < 9.18.0

%description dnssec-utils
%{name}-dnssec-utils contains a collection of utilities for editing
DNSSEC keys and BIND zone files. These tools provide generation,
revocation and verification of keys and DNSSEC signatures in zone files.

You should install %{name}-dnssec-utils if you need to sign a DNS zone
or maintain keys for it.

%package -n %{libname}
Summary: Libraries used by the BIND DNS packages
Group:   System/Libraries

%description -n %{libname}
Contains heavyweight version of BIND suite libraries used by both named DNS
server and utilities in bind-utils package.

%package    devel
Summary:    Include files and libraries needed for bind-dyndb-ldap
Group:      Development/C
Requires:   %{libname} = %{version}-%{release}

%description devel
The %{name}-devel package contains full version of the header files and libraries
required for building bind-dyndb-ldap. Upstream no longer supports nor recommends
bind libraries for third party applications.

%package chroot
Summary:        A chroot runtime environment for the ISC BIND DNS server, named(8)
Prefix:         %{chroot_prefix}
# grep is required due to setup-named-chroot.sh script
Requires:       grep
Requires:       %{name} = %{version}-%{release}

%description chroot
This package contains a tree of files which can be used as a
chroot(2) jail for the named(8) program from the BIND package.
Based on the code from Jan "Yenya" Kasprzak <kas@fi.muni.cz>


%if %{with DLZ}
%package dlz-filesystem
Summary: BIND server filesystem DLZ module
Group:   System/Servers
Requires: bind = %{version}-%{release}

%description dlz-filesystem
Dynamic Loadable Zones filesystem module for BIND server.

%package dlz-ldap
Summary: BIND server ldap DLZ module
Group:   System/Servers
Requires: bind = %{version}-%{release}

%description dlz-ldap
Dynamic Loadable Zones LDAP module for BIND server.

%package dlz-mysql
Summary: BIND server mysql and mysqldyn DLZ modules
Group:   System/Servers
Requires: bind = %{version}-%{release}

%description dlz-mysql
Dynamic Loadable Zones MySQL module for BIND server.
Contains also mysqldyn module with dynamic DNS updates (DDNS) support.

%package dlz-sqlite3
Summary: BIND server sqlite3 DLZ module
Requires: bind = %{version}-%{release}

%description dlz-sqlite3
Dynamic Loadable Zones sqlite3 module for BIND server.
%endif

%if %{with DOC}
%package doc
Summary:   BIND 9 Administrator Reference Manual
Requires:  python3-sphinx_rtd_theme
BuildArch: noarch

%description doc
BIND (Berkeley Internet Name Domain) is an implementation of the DNS
(Domain Name System) protocols. BIND includes a DNS server (named),
which resolves host names to IP addresses; a resolver library
(routines for applications to use when interfacing with DNS); and
tools for verifying that the DNS server is operating properly.

This package contains BIND 9 Administrator Reference Manual
in HTML and PDF format.
%endif

%prep
%autosetup -n %{name}-%{version} -p1



%build
## We use out of tree configure/build for export libs
%define _configure "../configure"

%serverbuild

CFLAGS="$CFLAGS $RPM_OPT_FLAGS"
export CFLAGS
export STD_CDEFINES="$CPPFLAGS"


sed -i -e \
's/([bind_VERSION_EXTRA],\s*\([^)]*\))/([bind_VERSION_EXTRA], \1-RH)/' \
configure.ac

autoreconf --force --install

mkdir build

%if %{with DLZ}
# DLZ modules do not support oot builds. Copy files into build
mkdir -p build/contrib/dlz
cp -frp contrib/dlz/modules build/contrib/dlz/modules
%endif

pushd build
LIBDIR_SUFFIX=
export LIBDIR_SUFFIX
%configure \
  --localstatedir=%{_var} \
  --with-pic \
  --disable-static \
  --includedir=%{_includedir}/bind9 \
  --with-tuning=large \
  --with-libidn2 \
%if %{with GEOIP2}
  --with-maxminddb \
%endif
%if %{with GSSTSIG}
  --with-gssapi=yes \
%endif
%if %{with LMDB}
  --with-lmdb=yes \
%else
  --with-lmdb=no \
%endif
%if %{with JSON}
  --with-json-c \
%endif
%if %{with UNITTEST}
  --with-cmocka \
%endif
  --enable-fixed-rrset \
  --enable-full-report \
;


%make_build

%if %{with DOC}
  make doc
%endif

%if %{with DLZ}
  pushd contrib/dlz/modules
  for DIR in filesystem ldap mysql mysqldyn sqlite3; do
    make -C $DIR CFLAGS="-fPIC -I../include $CFLAGS $LDFLAGS -DPTHREADS=1" LDFLAGS="$LDFLAGS"
  done
  popd
%endif
	
popd # build

%install

# Build directory hierarchy
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
mkdir -p %{buildroot}%{_libdir}/{bind,named}
mkdir -p %{buildroot}%{_localstatedir}/named/{slaves,data,dynamic}
mkdir -p %{buildroot}%{_mandir}/{man1,man5,man8}
mkdir -p %{buildroot}/run/named
mkdir -p %{buildroot}%{_localstatedir}/log

#chroot
for D in %{chroot_create_directories}; do
    mkdir -p %{buildroot}/%{chroot_prefix}${D}
done

# create symlink as it is on real filesystem
pushd %{buildroot}/%{chroot_prefix}/var
ln -s ../run run
popd

# these are required to prevent them being erased during upgrade of previous
touch %{buildroot}/%{chroot_prefix}/etc/named.conf
#end chroot

pushd build
%make_install
popd

# Remove unwanted files
rm -f %{buildroot}/etc/bind.keys

# Systemd unit files
install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE37} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE38} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE44} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE46} %{buildroot}%{_unitdir}

mkdir -p %{buildroot}%{_libexecdir}
install -m 755 %{SOURCE41} %{buildroot}%{_libexecdir}/setup-named-chroot.sh
install -m 755 %{SOURCE42} %{buildroot}%{_libexecdir}/generate-rndc-key.sh

install -m 755 %{SOURCE48} %{buildroot}%{_libexecdir}/setup-named-softhsm.sh

install -m 644 %SOURCE3 %{buildroot}/etc/logrotate.d/named
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/named
install -m 644 %{SOURCE49} %{buildroot}%{_sysconfdir}/named-chroot.files

pushd ${RPM_BUILD_ROOT}%{_sbindir}
# Compatibility with previous major versions, only for selected binaries
for BIN in named-checkconf named-checkzone named-compilezone
do
  ln -s ../bin/$BIN $BIN
done
popd

%if %{with DLZ}
  pushd build
  pushd contrib/dlz/modules
  for DIR in filesystem ldap mysql mysqldyn sqlite3; do
    %make_install -C $DIR libdir=%{_libdir}/bind
  done
  pushd %{buildroot}/%{_libdir}/named
    cp -s ../bind/dlz_*.so .
  popd
  mkdir -p doc/{mysql,mysqldyn}
  cp -p mysqldyn/testing/README doc/mysqldyn/README.testing
  cp -p mysqldyn/testing/* doc/mysqldyn
  cp -p mysql/testing/* doc/mysql
  popd
  popd
%endif

# Remove libtool .la files:
find %{buildroot}/%{_libdir} -name '*.la' -exec '/bin/rm' '-f' '{}' ';';

install -d -m 755 %{buildroot}%{_sysconfdir}/rsyslog.d/
cat > %{buildroot}%{_sysconfdir}/rsyslog.d/named.conf <<'EOF'
$AddUnixListenSocket %{chroot_prefix}/dev/log
EOF

# 9.16.4 installs even manual pages for tools not generated
%if %{without DNSTAP}
rm -f %{buildroot}%{_mandir}/man1/dnstap-read.1* || true
%endif
%if %{without LMDB}
rm -f %{buildroot}%{_mandir}/man8/named-nzd2nzf.8* || true
%endif

pushd %{buildroot}%{_mandir}/man8
ln -s ddns-confgen.8.gz tsig-keygen.8.gz
popd
pushd ${RPM_BUILD_ROOT}%{_mandir}/man1
ln -s named-checkzone.1.gz named-compilezone.1.gz
popd

%if %{with DOC}
mkdir -p %{buildroot}%{_pkgdocdir}
cp -a build/doc/arm/_build/html %{buildroot}%{_pkgdocdir}
rm -rf %{buildroot}%{_pkgdocdir}/html/.{buildinfo,doctrees}
# Share static data from original sphinx package
for DIR in %{python3_sitelib}/sphinx_rtd_theme/static/*
do
  BASE=$(basename -- "$DIR")
  BINDTHEMEDIR="%{buildroot}%{_pkgdocdir}/html/_static/$BASE"
  if [ -d "$BINDTHEMEDIR" ]; then
    rm -rf "$BINDTHEMEDIR"
    ln -s "$DIR" "$BINDTHEMEDIR"
  fi
done
%endif

# Ghost config files:
touch %{buildroot}%{_localstatedir}/log/named.log

# configuration files:
install -m 644 %{SOURCE16} %{buildroot}%{_sysconfdir}/named.conf
touch %{buildroot}%{_sysconfdir}/rndc.{key,conf}
install -m 644 %{SOURCE27} %{buildroot}%{_sysconfdir}/named.root.key
install -m 644 %{SOURCE36} %{buildroot}%{_sysconfdir}/trusted-key.key
mkdir %{buildroot}%{_sysconfdir}/named

# data files:
mkdir -p %{buildroot}%{_localstatedir}/named
install -m 644 %{SOURCE17} %{buildroot}%{_localstatedir}/named/named.ca
install -m 644 %{SOURCE18} %{buildroot}%{_localstatedir}/named/named.localhost
install -m 644 %{SOURCE19} %{buildroot}%{_localstatedir}/named/named.loopback
install -m 644 %{SOURCE20} %{buildroot}%{_localstatedir}/named/named.empty
install -m 644 %{SOURCE23} %{buildroot}%{_sysconfdir}/named.rfc1912.zones 

# sample bind configuration files for %%doc:
mkdir -p sample/etc sample/var/named/{data,slaves}
install -m 644 %{SOURCE25} sample/etc/named.conf
# Copy default configuration to %%doc to make it usable from system-config-bind
install -m 644 %{SOURCE16} named.conf.default
install -m 644 %{SOURCE23} sample/etc/named.rfc1912.zones
install -m 644 %{SOURCE18} %{SOURCE19} %{SOURCE20} sample/var/named
install -m 644 %{SOURCE17} sample/var//named/named.ca
for f in my.internal.zone.db slaves/my.slave.internal.zone.db slaves/my.ddns.internal.zone.db my.external.zone.db; do 
  echo '@ in soa localhost. root 1 3H 15M 1W 1D
  ns localhost.' > sample/var/named/$f; 
done
:;

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 644 %{SOURCE35} %{buildroot}%{_tmpfilesdir}/named.conf

mkdir -p %{buildroot}%{_sysconfdir}/rwtab.d
install -m 644 %{SOURCE43} %{buildroot}%{_sysconfdir}/rwtab.d/named

%triggerun -- bind < 9.11.5.P1-2.mga7   
# stop the service so as to be able to umount old chroot
systemctl condstop named.service

%pre
%_pre_useradd named /var/named /bin/false

%post
%_tmpfilescreate named
%_post_service named

%preun
%_preun_service named

%postun
%_postun_userdel named

%post chroot
%_post_service named-chroot

%preun chroot
%_preun_service named-chroot
%_preun_service named-chroot-setup

%files
# TODO: Move from lib/bind to lib/named, as used by upstream
# FIXME: current build targets filters into %%_libdir/bind again?
%dir %{_libdir}/bind
%{_libdir}/bind/filter*.so
%dir %{_libdir}/named
%config(noreplace) %{_sysconfdir}/sysconfig/named
%config(noreplace) %{_sysconfdir}/named.root.key
%config(noreplace) %{_sysconfdir}/logrotate.d/named
%{_tmpfilesdir}/named.conf
%{_sysconfdir}/rwtab.d/named
%{_unitdir}/named.service
%{_unitdir}/named-setup-rndc.service
%{_bindir}/named-journalprint
%{_bindir}/named-checkconf
%{_bindir}/named-rrchecker
%{_bindir}/mdig
%{_sbindir}/named
%{_sbindir}/rndc*
%{_sbindir}/named-checkconf
%{_libexecdir}/generate-rndc-key.sh
%{_libexecdir}/setup-named-softhsm.sh
%{_mandir}/man1/mdig.1*
%{_mandir}/man1/named-rrchecker.1*
%{_mandir}/man5/named.conf.5*
%{_mandir}/man5/rndc.conf.5*
%{_mandir}/man8/rndc.8*
%{_mandir}/man8/named.8*
%{_mandir}/man1/named-checkconf.1*
%{_mandir}/man8/rndc-confgen.8*
%{_mandir}/man1/named-journalprint.1*
%{_mandir}/man8/filter-*.8*
%doc README.md named.conf.default
%doc sample/

# main configuration
%dir %{_sysconfdir}/named
%config(noreplace) %verify(not link) %{_sysconfdir}/named.conf
%config(noreplace) %verify(not link) %{_sysconfdir}/named.rfc1912.zones
%attr(-,named,named) %dir %{_localstatedir}/named
%attr(-,named,named) %dir %{_localstatedir}/named/slaves
%attr(-,named,named) %dir %{_localstatedir}/named/data
%attr(-,named,named) %dir %{_localstatedir}/named/dynamic
%ghost %{_localstatedir}/log/named.log
%config %verify(not link) %{_localstatedir}/named/named.ca
%config %verify(not link) %{_localstatedir}/named/named.localhost
%config %verify(not link) %{_localstatedir}/named/named.loopback
%config %verify(not link) %{_localstatedir}/named/named.empty
%ghost %config(noreplace) %{_sysconfdir}/rndc.key
# ^- rndc.key now created on first install only if it does not exist
%ghost %config(noreplace) %{_sysconfdir}/rndc.conf
# ^- The default rndc.conf which uses rndc.key is in named's default internal config -
#    so rndc.conf is not necessary.

%files -n %{libname}
%{_libdir}/libdns-%{version}.so
%{_libdir}/libirs-%{version}.so
%{_libdir}/libisc-%{version}.so
%{_libdir}/libbind9-%{version}.so
%{_libdir}/libns-%{version}.so
%{_libdir}/libisccc-%{version}.so
%{_libdir}/libisccfg-%{version}.so


%files utils
%{_bindir}/dig
%{_bindir}/delv
%{_bindir}/host
%{_bindir}/nslookup
%{_bindir}/nsupdate
%{_bindir}/arpaname
%{_sbindir}/ddns-confgen
%{_sbindir}/tsig-keygen
%{_bindir}/nsec3hash
%{_bindir}/named-checkzone
%{_bindir}/named-compilezone
%{_sbindir}/named-checkzone
%{_sbindir}/named-compilezone
%if %{with DNSTAP}
%{_bindir}/dnstap-read
%{_mandir}/man1/dnstap-read.1*
%endif
%if %{with LMDB}
%{_bindir}/named-nzd2nzf
%{_mandir}/man1/named-nzd2nzf.1*
%endif
%{_mandir}/man1/host.1*
%{_mandir}/man1/nsupdate.1*
%{_mandir}/man1/dig.1*
%{_mandir}/man1/delv.1*
%{_mandir}/man1/nslookup.1*
%{_mandir}/man1/arpaname.1*
%{_mandir}/man8/ddns-confgen.8*
%{_mandir}/man8/tsig-keygen.8*
%{_mandir}/man1/nsec3hash.1*
%{_mandir}/man1/named-checkzone.1*
%{_mandir}/man1/named-compilezone.1*
%{_sysconfdir}/trusted-key.key

%files dnssec-utils
%{_bindir}/dnssec*
%{_mandir}/man1/dnssec*.1*

%files devel
%{_libdir}/libbind9.so
%{_libdir}/libisccc.so
%{_libdir}/libns.so
%{_libdir}/libdns.so
%{_libdir}/libirs.so
%{_libdir}/libisc.so
%{_libdir}/libisccfg.so
%dir %{_includedir}/bind9
%{_includedir}/bind9/bind9
%{_includedir}/bind9/isccc
%{_includedir}/bind9/ns
%{_includedir}/bind9/dns
%{_includedir}/bind9/dst
%{_includedir}/bind9/irs
%{_includedir}/bind9/isc
%{_includedir}/bind9/isccfg

%files chroot
%config(noreplace) %{_sysconfdir}/rsyslog.d/named.conf
%config(noreplace) %{_sysconfdir}/named-chroot.files
%{_unitdir}/named-chroot.service
%{_unitdir}/named-chroot-setup.service
%{_libexecdir}/setup-named-chroot.sh
%defattr(0664,root,named,-)
%ghost %dev(c,1,3) %verify(not mtime) %{chroot_prefix}/dev/null
%ghost %dev(c,1,8) %verify(not mtime) %{chroot_prefix}/dev/random
%ghost %dev(c,1,9) %verify(not mtime) %{chroot_prefix}/dev/urandom
%ghost %dev(c,1,5) %verify(not mtime) %{chroot_prefix}/dev/zero
%defattr(0644,root,named,0755)
%dir %{chroot_prefix}
%dir %{chroot_prefix}/dev
%dir %{chroot_prefix}%{_sysconfdir}
%dir %{chroot_prefix}%{_sysconfdir}/named
%dir %{chroot_prefix}%{_sysconfdir}/pki
%dir %{chroot_prefix}%{_sysconfdir}/pki/dnssec-keys
%dir %{chroot_prefix}%{_sysconfdir}/crypto-policies
%dir %{chroot_prefix}%{_sysconfdir}/crypto-policies/back-ends
%dir %{chroot_prefix}%{_localstatedir}
%dir %{chroot_prefix}/run
%ghost %config(noreplace) %{chroot_prefix}%{_sysconfdir}/named.conf
%defattr(-,root,root,-)
%dir %{chroot_prefix}/usr
%dir %{chroot_prefix}/%{_libdir}
%dir %{chroot_prefix}/%{_libdir}/bind
%dir %{chroot_prefix}/%{_datadir}/GeoIP
%defattr(0664,root,named,01775)
%dir %{chroot_prefix}%{_localstatedir}/named
%defattr(0664,named,named,0775)
%dir %{chroot_prefix}%{_localstatedir}/tmp
%dir %{chroot_prefix}%{_localstatedir}/log
%defattr(-,named,named,-)
%dir %{chroot_prefix}/run/named
%{chroot_prefix}%{_localstatedir}/run

%if %{with DLZ}
%files dlz-filesystem
%{_libdir}/{named,bind}/dlz_filesystem_dynamic.so

%files dlz-mysql
%{_libdir}/{named,bind}/dlz_mysql_dynamic.so
%doc build/contrib/dlz/modules/doc/mysql
%{_libdir}/{named,bind}/dlz_mysqldyn_mod.so
%doc build/contrib/dlz/modules/doc/mysqldyn

%files dlz-ldap
%{_libdir}/{named,bind}/dlz_ldap_dynamic.so
%doc contrib/dlz/modules/ldap/testing/*

%files dlz-sqlite3
%{_libdir}/{named,bind}/dlz_sqlite3_dynamic.so
%doc contrib/dlz/modules/sqlite3/testing/*

%endif

%if %{with DOC}
%files doc
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/html
%doc %{_pkgdocdir}/Bv9ARM.html
%endif
