%define bname		Bitcoin

Summary:	%{bname} payment network
Name:		bitcoin
Version:	29.0
Release:	%mkrel 1
License:	MIT
Group:		Office/Finance
Url:		https://bitcoin.org/
Source0:	https://github.com/bitcoin/bitcoin/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	bitcoin.service
Source3:	bitcoin.sysconfig
Source4:	bitcoin-tmpfiles.conf
Source5:	bitcoin-qt.desktop
Source6:	bitcoin-qt.protocol
BuildRequires:	cmake
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(miniupnpc)
BuildRequires:	pkgconfig(libqrencode)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5DBus)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5LinguistTools)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5Test)
BuildRequires:	cmake(Qt5Widgets)
BuildRequires:	pkgconfig(libevent)
BuildRequires:	pkgconfig(libzmq)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	db-devel
BuildRequires:	libnatpmp-devel
BuildRequires:	systemtap-sdt-devel

%description
%{bname} is an innovative payment network and a new kind of money.

%package -n bitcoind
Summary:	%{bname} command line client
Group:		Office/Finance

%description -n bitcoind
bitcoind is the original %{bname} command line client.

%package qt
Summary:	%{bname} graphical Qt client
Group:		Office/Finance

%description qt
%{bname}-Qt is the original %{bname} graphical client.

%prep
%autosetup -p1

%build
%if 0
./autogen.sh
sed -i -e "s/void main/int main/g" configure
export CPPFLAGS="%{optflags} -I%{_includedir}/db53 -fPIC"
%configure \
    BDB_INCLUDE_PATH=%{_includedir}/db53 \
    --disable-static \
    --enable-usdt \
    --disable-silent-rules \
    --with-incompatible-bdb
%endif
# Bitcoin kernel library used only as part of the testing for now:
%cmake \
    -DBerkeleyDB_INCLUDE_DIR:PATH=%{_includedir}/db53 \
    -DBUILD_BENCH:BOOL=ON \
    -DBUILD_CLI:BOOL=ON \
    -DBUILD_DAEMON:BOOL=ON \
    -DBUILD_GUI:BOOL=ON \
    -DBUILD_KERNEL_LIB:BOOL=ON \
    -DBUILD_TESTS:BOOL=ON \
    -DBUILD_TX:BOOL=ON \
    -DBUILD_UTIL:BOOL=ON \
    -DBUILD_UTIL_CHAINSTATE:BOOL=ON \
    -DENABLE_WALLET:BOOL=ON \
    -DINSTALL_MAN:BOOL=ON \
    -DWITH_BDB:BOOL=ON \
    -DWITH_DBUS:BOOL=ON \
    -DWITH_QRENCODE:BOOL=ON \
    -DWITH_SQLITE:BOOL=ON \
    -DWITH_USDT:BOOL=ON \
    -DWITH_ZMQ:BOOL=ON

%cmake_build

%install
%cmake_install

# Remove Bitcoin Kernel Library for now (https://github.com/bitcoin/bitcoin/issues/27587)
rm -frv %{buildroot}%{_libdir}

# Remove test files so that they aren't shipped. Tests have already been run
rm -f %{buildroot}%{_bindir}/test_*

mkdir -p %{buildroot}%{_localstatedir}/lib/bitcoin
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install share/examples/bitcoin.conf %{buildroot}%{_sysconfdir}

for size in 16 32 64 128 256; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps
  install -m644 share/pixmaps/bitcoin${size}.png %{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
install -m 0644 contrib/completions/bash/bitcoind.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}d
install -m 0644 contrib/completions/bash/bitcoin-cli.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}-cli
install -m 0644 contrib/completions/bash/bitcoin-tx.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}-tx

mkdir -p %{buildroot}%{_datadir}/applications
install -m 0644 %{SOURCE5} %{buildroot}%{_datadir}/applications

mkdir -p %{buildroot}%{_datadir}/kservices5
install -m 0644 %{SOURCE6} %{buildroot}%{_datadir}/kservices5

%pre -n bitcoind
%_pre_useradd %{name} /dev/null /bin/false

%post -n bitcoind
if ! /usr/bin/id bitcoin &>/dev/null; then
       /usr/sbin/useradd -r -g bitcoin -s /bin/false -c "Bitcoin" -d /run/bitcoin bitcoin
fi
%_tmpfilescreate %{name}
%_post_service %{name}

%preun -n bitcoind
%_preun_service %{name}

%files -n bitcoind
%config (noreplace) %{_sysconfdir}/sysconfig/bitcoin
%config (noreplace) %{_sysconfdir}/bitcoin.conf
%dir %attr(0750, bitcoin, bitcoin) %{_localstatedir}/lib/bitcoin
%dir %ghost %attr(0750, bitcoin, bitcoin) %{_rundir}/bitcoin
%ghost %attr(0660, -, -) %{_rundir}/bitcoin/bitcoin.pid
%{_unitdir}/bitcoin.service
%{_tmpfilesdir}/bitcoin.conf
%{_bindir}/bitcoind
%{_bindir}/bitcoin-cli
%{_bindir}/bitcoin-tx
%{_bindir}/bitcoin-util
%{_bindir}/bitcoin-wallet
%{_bindir}/bench_bitcoin
%{_datadir}/bash-completion/completions/bitcoind
%{_datadir}/bash-completion/completions/bitcoin-cli
%{_datadir}/bash-completion/completions/bitcoin-tx
%{_mandir}/man1/bitcoin-cli.1*
%{_mandir}/man1/bitcoin-tx.1*
%{_mandir}/man1/bitcoind.1*
%{_mandir}/man1/bitcoin-util.1*
%{_mandir}/man1/bitcoin-wallet.1*

%files qt
%{_bindir}/%{name}-qt
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/kservices5/%{name}-qt.protocol
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/bitcoin-qt.1.*
