%define basen black-hole-solver
%define libname_orig lib%{basen}

%define major      1
%define libname    %mklibname %{basen} %{major}
%define develname  %mklibname %{basen} -d
%define staticname %mklibname %{basen} -d -s

Name:          %{basen}
Version:       1.14.0
Release:       %mkrel 3
Summary:       The Black Hole Solitaire Solver Executable
License:       MIT
Group:         Games/Cards
URL:           https://www.shlomifish.org/open-source/projects/black-hole-solitaire-solver/
Source0:       https://fc-solve.shlomifish.org/downloads/fc-solve/%{basen}-%{version}.tar.xz
BuildRequires: cmake
BuildRequires: perl(Carp)
BuildRequires: perl(Cwd)
BuildRequires: perl(Data::Dumper)
BuildRequires: perl(Dir::Manifest)
BuildRequires: perl(Env::Path)
BuildRequires: perl(File::Path)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Inline)
BuildRequires: perl(Inline::C)
BuildRequires: perl(List::MoreUtils)
BuildRequires: perl(Path::Tiny)
BuildRequires: perl(Test::Differences)
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::RunValgrind)
BuildRequires: perl(Test::Some)
BuildRequires: perl(Test::Trap)
BuildRequires: perl(base)
BuildRequires: perl(lib)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildRequires: perl-devel
BuildRequires: pkgconfig(librinutils)
BuildRequires: pkgconfig(libxxhash)
BuildRequires: python3
BuildRequires: valgrind

Requires:      %{libname} = %version-%release

%description
This is a solver, written in C, to solve the Solitaire variants “Golf”,
“Black Hole” and “All in a Row”. It provides a portable C library, and
a command line application that after being fed with a layout will emit the
cards to move.

%files
%doc NEWS.asciidoc README.md TODO.quicktask
%license COPYING
%_bindir/black-hole-solve
%{_mandir}/*/*

#--------------------------------------------------------------------

%package -n %{libname}
Summary:       The Black Hole Solver dynamic libraries
Group:         Games/Cards

%description -n %{libname}
Contains the Black Hole Solver libraries that are used by some programs.

This package is mandatory for the Black Hole Solver executable too.

%files -n %{libname}
%license COPYING
%{_libdir}/libblack_hole_solver.so.%{major}{,.*}

#--------------------------------------------------------------------

%package -n %{develname}
Summary:       The Black Hole Solitaire development tools
Group:         Games/Cards
Requires:      %{libname} = %version-%release
Provides:      %{name}-devel = %{version}-%{release}

%description -n %{develname}
Development tools for the Black Hole Solitaire Solver.

%files -n %{develname}
%_includedir/black-hole-solver/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libblack_hole_solver.so

#--------------------------------------------------------------------

%package -n %{staticname}
Summary:       The Black Hole Solver static libraries
Group:         Games/Cards
Requires:      %{develname} = %version-%release

%description -n %{staticname}
Black Hole Solitaire Solver is a library for automatically solving boards of
Golf, Black Hole, and All in a Row solitaires. This package contains the static
libraries.

It is not generally required.

%files -n %{staticname}
%{_libdir}/libblack_hole_solver.a

#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
%cmake -DBUILD_STATIC_LIBRARY=1 \
       -DLOCALE_INSTALL_DIR=%{_datadir}/locale \
       -DLIB_INSTALL_DIR=%{_libdir} \
       -DDISABLE_APPLYING_RPATH=TRUE \
       -DUSE_SYSTEM_XHASH=TRUE
%cmake_build -j1

%check
%ifarch %arm32
# valgrind suppression not working without glibc-debuginfo breaks it
rm -f t/valgrind.t
%endif
rm -f t/clang-format.t
rm -f t/perltidy.t
# fails due to build containing binaries
rm -f t/style-trailing-space.t
cd %{_vpath_builddir}
# %%make_build test
%__perl ../run-tests.pl

%install
%cmake_install
