%define major	2
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

%define uname	bladeRF

#define rcver	rc3

Name:		bladerf
Version:	2024.05
Release:	%mkrel %{?rcver:0.%{rcver}.}2
Summary:	A Software Defined Radio (SDR) platform
Group:		Communications/Radio
License:	GPLv2
URL:		https://nuand.com/
# Don't use upstream tarball as it does not contain git submodules
# Clone git, checkout tag and then 'git submodule init'; 'git submodule update' and re-create tarball OR...
# Modify mk-tar for the tag required and run ./mk-tar in SOURCES to create tarball with git submodules.
Source0:	https://github.com/Nuand/%{uname}/archive/%{version}%{?rcver:-%{rcver}}/%{uname}-%{version}%{?rcver:-%{rcver}}.tar.bz2
Source1:	mk-tar

Patch0:		bladerf-2024.05_calloc_order.patch

BuildRequires:	cmake
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	doxygen

%description
%{uname} is a Software Defined Radio (SDR) platform designed to enable a
community of hobbyists, and professionals to explore and experiment with the
multidisciplinary facets of RF communication.

%package -n %{libname}
Summary:	Library files for %{uname}
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}

%package -n %{devname}
Summary:	Development files for %{uname}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{uname}-devel = %{version}-%{release}

%description -n %{devname}
Files needed to develop software against libbladerf.

%description -n %{libname}
bladerf library files.

%package doc
Summary:	HTML documentation for %{uname}
Group:		Documentation
BuildArch:	noarch

%description doc
HTML documentation for %{uname}

%prep
%autosetup -p1 -n %{uname}-%{version}%{?rcver:-%{rcver}}

# install cmake config files into '${_libdir} path
sed -i 's|share/cmake|%{_lib}/cmake|' host/libraries/libbladeRF/CMakeLists.txt

%build
%cmake \
    -DBUILD_DOCUMENTATION=ON

%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_udevrulesdir}
mv %{buildroot}%{_sysconfdir}/udev/rules.d/88-nuand*.rules %{buildroot}%{_udevrulesdir}/

mkdir -p %{buildroot}%{_iconsdir}
cp %{buildroot}%{_docdir}/libbladeRF/html/logo.png %{buildroot}%{_iconsdir}/%{name}.png

cat > %{name}-doc.desktop << EOF
[Desktop Entry]
Version=1.0
Name=BladeRF Documentation
GenericName=BladeRF Documentation
Exec=xdg-open %{_docdir}/libbladeRF/html/index.html
Icon=%{name}
Terminal=false
Type=Application
Categories=System;Documentation;X-Mageia-CrossDesktop;
EOF

# Fix Version string in .pc
sed -i '/Version/c Version: %{version}' %{buildroot}%{_libdir}/pkgconfig/lib%{uname}.pc

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}-doc.desktop

%files
%doc CONTRIBUTORS README.md
%{_udevrulesdir}/88-nuand*.rules
%{_bindir}/%{uname}-cli
%{_bindir}/%{uname}-fsk

%files -n %{libname}
%{_libdir}/lib%{uname}.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/lib%{uname}.h
%{_libdir}/pkgconfig/lib%{uname}.pc
%{_libdir}/lib%{uname}.so
%{_includedir}/bladeRF1.h
%{_includedir}/bladeRF2.h
%{_libdir}/cmake/bladeRF/

%files doc
%{_docdir}/libbladeRF/html/
%{_datadir}/applications/%{name}-doc.desktop
%{_iconsdir}/%{name}.png
%{_mandir}/man1/bladeRF-cli.1.*
