# NOTE: Please update also the version and rebuild yafaray if blender is updated

# LTS versioning infos: https://www.blender.org/download/lts/

# branch: blender-v4.1-release
# commit: b292cfe5a936f816f9a3567b39995ba3c7b82f8a
# comment out when not git-snapshot
#define git	git20230620
#
# use 'define gitfinal 1' if the git-snapshot is also a final release
# comment out 'define gitfinal' when the git-snapshot is not a final release
#define gitfinal 1

# default to build with OSL
%define oslapi 1.13
%ifarch aarch64 x86_64
%bcond_without	openshading
%else
%bcond_with	openshading
%endif

# default to build with opensubdiv
%bcond_without	opensubdiv

# build with oidn and openpgl only available on x86_64 and aarch64 arches
%ifarch aarch64 x86_64
%bcond_without	embree
%bcond_without	openpgl
%else
%bcond_with	embree
%bcond_with	openpgl
%endif
# build with oidn only available on x86_64 arch
%ifarch x86_64
%bcond_without	oidn
%bcond_without	oneapi
%else
%bcond_with	oidn
%bcond_with	oneapi
%endif

# build with openxr support
%bcond_without	openxr

%bcond_without	wayland

%bcond_with	materialx

# build with/without usd support
# (https://docs.blender.org/manual/en/4.1/files/import_export/usd.html)
#
# Note that it's not said that the latest USD works as the one to be bundled with this
# blender package. Please check it matches with blender upstream version of USD lib (or pretty close)
# before updating.
# Note also that the USD lib is patched with internal blender's usd.diff patch, before being used with
# blender.
%define usdver	23.08
%ifnarch %{arm32} %{ix86}
#aarch64
%bcond_with	usd
# the usd support is provided through a bundled library
# (without = use usd as bundled, with = use usd as system shared lib)
%bcond_with	usd_bundled
%else
# disable USD for armv7 and i586
%bcond_with	usd
%bcond_with	usd_bundled
%endif

%define rel 4

Name:		blender
Version:	4.2.4
Release:	%mkrel %{?git:%{?gitfinal:%{rel}}%{!?gitfinal:0.%git.%{rel}}}%{!?git:%{rel}}
Summary:	A fully functional 3D modeling/rendering/animation package
License:	GPLv2+
Group:		Graphics/3D
URL:		https://www.blender.org/
Source0:	https://download.blender.org/source/%{name}-%{version}%{?git:-%git}.tar.%{?git:gz}%{!?git:xz}
# Script to download and update to git branch 3.6 build the tarball
Source2:	get_git_blender-4.1_and_build_tgz.sh
# internal USD library
Source10:	https://github.com/PixarAnimationStudios/OpenUSD/archive/v%{usdver}/OpenUSD-%{usdver}.tar.gz
Source11:	build_usd_bundled.sh
# https://github.com/PixarAnimationStudios/USD/issues/1592
Source12:	USD-22.05b-disable-malloc-hooks.patch
#
Source13:	USD-22.05b-fix-array.patch
#
Source14:	1297.patch
#
Patch0:		0003-locales_directory_install.patch
Patch1:		blender-4.1.1-static-lib.patch
Patch2:		blender-4.1.1-embree3-shared.patch
# FFmpeg 7 compatibility patch with syntax error fixed
# https://projects.blender.org/blender/blender/pulls/121947
Patch10:	blender-ffmpeg7.patch
# FFmpeg 7 compatibility for audaspace plugin
Patch11:	https://projects.blender.org/blender/blender/pulls/121960.patch
#  Fix crash on creating fluid domain with python 3.12 and up #130160
Patch13:	https://projects.blender.org/blender/blender/pulls/130160.patch

# Upstream patches (100-200)
# Python 3.13 compatibility
# https://projects.blender.org/blender/blender/pulls/129191
Patch20:	blender-python3.13.patch
#
# Blender doesn't officially support 32-bit build since 2.80. See also:
# https://developer.blender.org/T67184
ExcludeArch:	%{ix86} %{arm32}

BuildRequires:	cmake
BuildRequires:	git-core
BuildRequires:	openimageio
BuildRequires:	boost-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	libgomp-devel
BuildRequires:	lzo-devel
%if %{with embree}
BuildRequires:	embree4-devel
%endif
%if %{with openpgl}
BuildRequires:	cmake(openpgl)
%endif
%if %{with materialx}
BuildRequires:	materialx-devel
BuildRequires:	materialx
%endif
%if %{with opensubdiv}
BuildRequires:	opensubdiv-devel
%endif
%if %{with openshading}
BuildRequires:	openshadinglanguage%{oslapi}
BuildRequires:	libopenshadinglanguage%{oslapi}-devel
%endif
%if %{with oidn}
BuildRequires:	cmake(OpenImageDenoise)
%endif
%if %{with openxr}
BuildRequires:	pkgconfig(openxr)
%endif
%if %{without usd_bundled} && %{with usd}
BuildRequires:	usd-devel
%endif
# OneAPI stuff
%if %{with oneapi}
BuildRequires:	pkgconfig(level-zero)
%endif
BuildRequires:	pkgconfig(hidapi-hidraw)
%if %{with wayland}
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(libdecor-0) >= 0.1.0
BuildRequires:	pkgconfig(wayland-client)
BuildRequires:	pkgconfig(wayland-protocols)
BuildRequires:	pkgconfig(xkbcommon)
%endif
BuildRequires:	libharu-devel
# versions < 7.0.0 have linkage problems
BuildRequires:	openvdb-devel >= 7.0.0
BuildRequires:	potrace-devel
BuildRequires:	python3-numpy-devel
BuildRequires:	spnav-devel
BuildRequires:	cmake(Alembic)
BuildRequires:	cmake(OpenCOLLADA)
BuildRequires:	pkgconfig(audaspace)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(fribidi)
BuildRequires:	pkgconfig(harfbuzz)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gmp)
BuildRequires:	pkgconfig(gmpxx)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(jemalloc)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(OpenColorIO) >= 2.0
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(OpenImageIO)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(opus)
BuildRequires:	pkgconfig(python3) >= 3.9
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(xxf86vm)
BuildRequires:	python3dist(requests)
BuildRequires:	python3dist(zstandard)

Requires:		python(abi) >= 3.9
Requires:		python3dist(requests)
Requires:		python3dist(zstandard)
Requires:		python3dist(numpy)
Requires:		python3dist(audaspace)
Requires(post,preun):	GConf2

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%prep
%autosetup -p1 -n %{name}-%{version}%{?git:-%git}

find -name '.svn' -print | xargs rm -rf

%build
BUILD_DATE="$(stat -c '%%y' '%{SOURCE0}' | date -f - '+%%Y-%%m-%%d')"
BUILD_TIME="$(stat -c '%%y' '%{SOURCE0}' | date -f - '+%%H:%%M:%%S')"

export LD=%{_bindir}/ld.gold

# build internal USD lib
%if %{with usd_bundled}
export BUNDLED_LIBDIRS=$(pwd)/libraries
install -m 755 %{SOURCE11} .
./build_usd_bundled.sh \
	--target ${BUNDLED_LIBDIRS} \
	--source %{SOURCE10} \
	--patch  %{SOURCE12} \
	--patch2 $(pwd)/build_files/build_environment/patches/usd.diff \
	--patch3 %{SOURCE13} \
	--patch4 %{SOURCE14} \
	--version %{usdver} \
	--libdir %{_libdir} \
	--cxxflags "%{optflags}"
%endif

%ifarch %{ix86}
# build non-sse flavour
%cmake \
	-DBUILDINFO_OVERRIDE_DATE="$BUILD_DATE" \
	-DBUILDINFO_OVERRIDE_TIME="$BUILD_TIME" \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DWITH_INSTALL_PORTABLE:BOOL=OFF \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{python3_version} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-D_ffmpeg_INCLUDE_DIR=%{_includedir} \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_IMAGE_OPENJPEG:BOOL=ON \
	-DWITH_OPENCOLLADA:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_CYCLES:BOOL=ON \
%if %{with embree}
	-DWITH_CYCLES_EMBREE:BOOL=ON \
%else
	-DWITH_CYCLES_EMBREE:BOOL=OFF \
%endif
%if %{with openshading}
	-DWITH_CYCLES_OSL:BOOL=ON \
%endif
%if %{with opensubdiv}
	-DWITH_OPENSUBDIV:BOOL=ON \
%endif
%if %{with oidn}
	-DWITH_OPENIMAGEDENOISE:BOOL=ON \
%else
	-DWITH_OPENIMAGEDENOISE:BOOL=OFF \
%endif
%if %{with openxr}
	-DWITH_XR_OPENXR:BOOL=ON \
%endif
%if %{with usd}
	-DWITH_USD:BOOL=ON \
%endif
%if %{with usd_bundled}
	-DUSD_LIBRARY:FILEPATH=${BUNDLED_LIBDIRS}/usd/lib/libusd_usd_m.a \
	-DUSD_INCLUDE_DIR:FILEPATH=${BUNDLED_LIBDIRS}/usd/include \
%else
	-DUSD_LIBRARY=%{_libdir}/libusd_usd_ms.so \
%endif
	-DWITH_CXX_GUARDEDALLOC:BOOL=OFF \
	-DWITH_MEM_JEMALLOC:BOOL=ON \
	-DWITH_OPENCOLORIO:BOOL=ON \
	-DWITH_SDL:BOOL=ON \
	-DWITH_ALEMBIC:BOOL=ON \
	-DWITH_OPENVDB:BOOL=ON \
	-DWITH_OPENVDB_BLOSC:BOOL=ON \
	-DWITH_DOC_MANPAGE:BOOL=ON \
	-DWITH_INPUT_NDOF:BOOL=ON \
	-DWITH_SYSTEM_AUDASPACE:BOOL=ON \
	-DWITH_SYSTEM_EIGEN3:BOOL=ON \
	-DWITH_SYSTEM_LZO:BOOL=ON \
	-DWITH_CPU_SIMD:BOOL=OFF \
	-DCXX_HAS_SSE:BOOL=OFF \
	-DCXX_HAS_AVX:BOOL=OFF \
	-DCXX_HAS_AVX2:BOOL=OFF \
	-DSUPPORT_SSE2_BUILD:BOOL=OFF \
	-DSUPPORT_SSE_BUILD:BOOL=OFF \
	-DWITH_JACK:BOOL=ON \
	-DWITH_LIBS_PRECOMPILED:BOOL=OFF
%cmake_build
mv %{_vpath_builddir} non-sse
%endif

#build sse flavour
%cmake \
	-DBUILDINFO_OVERRIDE_DATE="$BUILD_DATE" \
	-DBUILDINFO_OVERRIDE_TIME="$BUILD_TIME" \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DWITH_INSTALL_PORTABLE:BOOL=OFF \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{python3_version} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-D_ffmpeg_INCLUDE_DIR=%{_includedir} \
	-DPYTHON_NUMPY_INCLUDE_DIRS=%{python3_sitearch}/numpy/_core/include \
	-DPYTHON_NUMPY_PATH=%{python3_sitearch}/numpy/_core/include \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_IMAGE_OPENJPEG:BOOL=ON \
	-DWITH_OPENCOLLADA:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_CYCLES:BOOL=ON \
%if %{with embree}
	-DWITH_CYCLES_EMBREE:BOOL=ON \
%else
	-DWITH_CYCLES_EMBREE:BOOL=OFF \
%endif
%if %{with openshading}
	-DWITH_CYCLES_OSL:BOOL=ON \
%endif
%if %{with opensubdiv}
	-DWITH_OPENSUBDIV:BOOL=ON \
%endif
%if %{with oidn}
	-DWITH_OPENIMAGEDENOISE:BOOL=ON \
%endif
%if %{with openxr}
	-DWITH_XR_OPENXR:BOOL=ON \
%endif
%if %{with usd}
	-DWITH_USD:BOOL=ON \
%endif
%if %{with oneapi}
	-DWITH_CYCLES_DEVICE_ONEAPI:BOOL=ON \
%endif
%if %{with usd_bundled}
	-DUSD_LIBRARY:FILEPATH=${BUNDLED_LIBDIRS}/usd/lib/libusd_usd_m.a \
	-DUSD_INCLUDE_DIR:FILEPATH=${BUNDLED_LIBDIRS}/usd/include \
%endif
	-DWITH_CXX_GUARDEDALLOC:BOOL=OFF \
	-DWITH_MEM_JEMALLOC:BOOL=ON \
	-DWITH_OPENCOLORIO:BOOL=ON \
	-DWITH_SDL:BOOL=ON \
	-DWITH_ALEMBIC:BOOL=ON \
	-DWITH_OPENVDB:BOOL=ON \
	-DWITH_OPENVDB_BLOSC:BOOL=ON \
	-DWITH_DOC_MANPAGE:BOOL=ON \
	-DWITH_INPUT_NDOF:BOOL=ON \
	-DWITH_SYSTEM_AUDASPACE:BOOL=ON \
	-DWITH_SYSTEM_EIGEN3:BOOL=ON \
	-DWITH_SYSTEM_LZO:BOOL=ON \
%ifarch %{ix86}
	-DSUPPORT_SSE2_BUILD:BOOL=ON \
	-DCXX_HAS_AVX:BOOL=OFF \
	-DCXX_HAS_AVX2:BOOL=OFF \
%endif
%ifarch %{ix86} x86_64
	-DWITH_CYCLES:BOOL=ON \
%else
	-DWITH_CYCLES:BOOL=OFF \
%endif
	-DWITH_JACK:BOOL=ON \
	-DWITH_MATERIALX:BOOL=OFF \
	-DWITH_LIBS_PRECOMPILED:BOOL=OFF
%cmake_build

#TODO package Hydra, Materialx, USD, oneapi-level-zero

%install
#install sse flavour
%cmake_install

%ifarch %{ix86}
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.sse

#install non-sse flavour
rm -fr %{_vpath_builddir}
mv non-sse %{_vpath_builddir}
%cmake_install
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.nonsse

# install wrapper
cat >> %{buildroot}%{_bindir}/blender <<EOF 
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse2\`"
fi

if [ "x\$SSE" == x ]; then
	%{_bindir}/%{name}.nonsse "\$@"
else
	%{_bindir}/%{name}.sse "\$@"
fi
EOF
chmod 0755 %{buildroot}%{_bindir}/blender
%endif

# Deal with docs in the files section
rm -rf %{buildroot}%{_docdir}/%{name}/*
# Deal with unneeded languages dir
rm -rf %{buildroot}%{_datadir}/locale/languages

sed -i -e 's,#!/usr/bin/python,#!/usr/bin/python3,' %{buildroot}%{_bindir}/blender-thumbnailer %{buildroot}%{_datadir}/%{name}/*/scripts/modules/blend_render_info.py

%find_lang %{name}

%post
if [ -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type boolean --set /desktop/gnome/thumbnailers/application@x-blender/enable true
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type string --set /desktop/gnome/thumbnailers/application@x-blender/command "blender-thumbnailer %u %o"
fi

%preun
if [ "$1" = "0" -a -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/enable
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/command
fi

%files -f %{name}.lang
%license COPYING
%license doc/license/*-license.txt
%license release/text/copyright.txt
%doc release/text/readme.html
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*.1.*
%{_iconsdir}/hicolor/*/apps/%{name}*.*
%{_metainfodir}/org.%{name}.Blender.metainfo.xml
