%define major		1
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Name:		blosc
Version:	1.21.6
Release:	%mkrel 1
Summary:	A blocking, shuffling and lossless compression library
License:	MIT
Group:		System/Libraries
URL:		https://www.blosc.org/
Source0:	https://github.com/Blosc/c-blosc/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(snappy)
BuildRequires:	pkgconfig(zlib)

%description
Blosc is a compressor for binary data, designed to transmit data to
the processor cache faster than the traditional, non-compressed,
direct memory fetch approach via a memcpy() call. Blosc is not only a
compressor for data size reduction, but also for accelerating
memory-bound computations.

It uses the blocking technique to reduce activity on the memory bus,
which works by dividing datasets in blocks that are small enough to
fit in caches of processors and perform (de)compression there. SIMD
and multi-threading capabilities are leveraged if available.

Blosc is a metacompressor; it can use different compression
algorithms, such as BloscLZ, LZ4, LZ4HC, Snappy and Zlib.

%package -n	%{libname}
Summary:	A blocking, shuffling and lossless compression library
Group:		System/Libraries

%description -n	%{libname}
Blosc is a metacompressor (using actual algorithms like BloscLZ, LZ4,
LZ4HC, Snappy or Zlib) for binary data, with a focus on reducing
memory bus activity.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for developing
applications that use %{name}.

%prep
%setup -q -n c-blosc-%{version}
%autopatch -p1

# https://github.com/Blosc/c-blosc/issues/190
sed -i 's|lib/pkgconfig|%{_lib}/pkgconfig|' CMakeLists.txt

%build
%cmake \
	-DBUILD_STATIC=OFF \
	-DBUILD_FUZZERS=OFF \
	-DCMAKE_C_FLAGS:STRING="%{optflags}" \
	-DPREFER_EXTERNAL_SNAPPY=ON \
	-DPREFER_EXTERNAL_ZLIB=ON \
	-DPREFER_EXTERNAL_ZSTD=ON \
	-DPREFER_EXTERNAL_LZ4=ON
%cmake_build

%install
%cmake_install

%files -n %{libname}
%doc ANNOUNCE.rst README.md README_THREADED.rst RELEASE_NOTES.rst THANKS.rst
%license LICENSES/*.txt
%{_libdir}/libblosc.so.%{major}
%{_libdir}/libblosc.so.%{version}

%files -n %{develname}
%doc README.md
%doc examples/
%{_includedir}/blosc.h
%{_includedir}/blosc-export.h
%{_libdir}/libblosc.so
%{_libdir}/pkgconfig/blosc.pc
