%define major		4
%define libname		%mklibname %{name}_ %{major}
%define develname	%mklibname %{name} -d

Name:		blosc2
Version:	2.17.0
Release:	%mkrel 1
Summary:	High performance compressor optimized for binary data
Group:		System/Libraries
License:	BSD-3-Clause
URL:		https://www.blosc.org/
Source0:	https://github.com/Blosc/c-blosc2/archive/v%{version}/c-blosc2-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	ninja-build
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libxxhash)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(zlib-ng)

%description
Blosc is a high performance compressor optimized for binary data
(i.e. floating-point numbers, integers, and booleans, although it can handle
string data too). It has been designed to transmit data to the processor cache
faster than the traditional, non-compressed, direct memory fetch approach via a
memcpy() OS call. Blosc main goal is not just to reduce the size of large
datasets on-disk or in-memory, but also to accelerate memory-bound computations.

C-Blosc2 is the new major version of C-Blosc, and is backward compatible with
both the C-Blosc1 API and its in-memory format. However, the reverse thing is
generally not true for the format; buffers generated with C-Blosc2 are not
format-compatible with C-Blosc1.

%package -n	%{libname}
Summary:	A blocking, shuffling and lossless compression library
Group:		System/Libraries

%description -n	%{libname}
Blosc is a metacompressor (using actual algorithms like BloscLZ, LZ4,
LZ4HC, Snappy or Zlib) for binary data, with a focus on reducing
memory bus activity.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for developing
applications that use %{name}.

%prep
%autosetup -n c-blosc2-%{version} -p1

# https://github.com/Blosc/c-blosc2/issues/489
rm plugins/codecs/ndlz/xxhash.?
sed -r -i '/xxhash.c/d' plugins/codecs/ndlz/CMakeLists.txt

# let's do this to make it clear that we're not using those
rm -r internal-complibs/* internal-complibs

%build
%cmake  -GNinja \
	-DBUILD_STATIC:BOOL=OFF \
	-DBUILD_FUZZERS:BOOL=OFF \
	-DPREFER_EXTERNAL_LZ4:BOOL=ON \
	-DPREFER_EXTERNAL_ZLIB:BOOL=ON \
	-DPREFER_EXTERNAL_ZSTD:BOOL=ON \
	-DDEACTIVATE_AVX2:BOOL=ON \
	-DCMAKE_C_FLAGS:STRING="%{optflags} -Wno-unused-variable"
        # We need to pass the distro build flags here, otherwise they are ignored.
        # Silence warnings about stupid programming errors.
%cmake_build

%install
%cmake_install

%check
# Tests fail with -j12: https://github.com/Blosc/c-blosc2/issues/432
%ctest -j1

%files -n %{libname}
%doc ANNOUNCE.* README* RELEASE_NOTES.* THANKS.* ROADMAP.rst FAQ.*
%license LICENSE.txt
%{_libdir}/libblosc2.so.%{major}
%{_libdir}/libblosc2.so.%{version}

%files -n %{develname}
%doc README.rst
%{_includedir}/b2nd.h
%{_includedir}/blosc2.h
%{_includedir}/%{name}/
%{_libdir}/libblosc2.so
%{_libdir}/pkgconfig/blosc2.pc
%{_libdir}/cmake/Blosc2/
