%define         Werror_cflags      %nil
%define         crel %(echo %{version} | cut -d. -f1,2)

%define         devel_name  %mklibname %{name} -d
%define         static_name %mklibname %{name} -s -d

Summary:        The BOINC client core
Name:           boinc-client
Version:        8.2.0
Release:        %mkrel 1
License:        LGPLv2+
Group:          Sciences/Other
URL:            https://boinc.berkeley.edu/
Source0:        https://github.com/BOINC/boinc/archive/client_release/%{crel}/%{version}/%{name}_release-%{crel}-%{version}.tar.gz
Source1:        boinc-client.service
Source2:        boinc-client-tmpfiles.conf
Source4:        trim
Source6:        boinc-client.logrotate
#squidf: avoid log pollution
Source10:       40boinc-client.sh

# Fedora patches:
Patch1:         disable_idle_time_detection.patch

# Mageia patches

BuildRequires:  docbook2x
BuildRequires:  gettext
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(freeglut)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  wxgtk-devel

Requires(pre):    rpm-helper >= %{rpmhelper_required_version}
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}

Obsoletes:      boinc-client-devel <= 7.24
Obsoletes:      boinc-client-static <= 7.24

%description
The Berkeley Open Infrastructure for Network Computing (BOINC) is an open-
source software platform which supports distributed computing, primarily in
the form of "volunteer" computing and "desktop Grid" computing.  It is well
suited for problems which are often described as "trivially parallel".  BOINC
is the underlying software used by projects such as SETI@home, Einstein@Home,
ClimatePrediciton.net, the World Community Grid, and many other distributed
computing projects.
This package installs the BOINC client software, which will allow your
computer to participate in one or more BOINC projects, using your spare
computer time to search for cures for diseases, model protein folding, study
global warming, discover sources of gravitational waves, and many other types
of scientific and mathematical research.


%package -n boinc-manager
Summary:        GUI to control and monitor %{name}
Group:          Sciences/Other
Requires:       %{name} = %{version}-%{release}

%description -n boinc-manager
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.


%package -n %{devel_name}
Summary:        Development files for %{name}
Group:          Development/Other
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig(openssl)
Requires:       mysql-devel

%description -n %{devel_name}
This package contains development files for %{name}.


%package -n %{static_name}
Summary:        Static libraries for %{name}
Group:          Sciences/Other
Requires:       %{devel_name} = %{version}-%{release}

%description -n %{static_name}
This package contains static libraries for %{name}.


%prep
%autosetup -p1 -n %{name}_release-%{crel}-%{version}

# Fix encoding
for file in $(ls | grep checkin_notes_20); do
    iconv -f ISO-8859-1 -t UTF-8 -o ${file}.utf8 ${file}
    mv ${file}.utf8 ${file}
done

# Fix file permissions
for file in $(ls clientgui | grep .cpp$ ) $(ls clientgui | grep .h$ ); do 
    chmod 644 clientgui/${file}
done

# Since https://git.savannah.gnu.org/cgit/autoconf.git/commit/?id=ec90049dfcf4538750e61d675d885157fa5ca7f8
# AC_CHECK_DECLS call with CXXFLAGS=-mavx fails in arm
%ifarch %{arm} aarch64
sed -i -e 's/\s\?-mavx//g' configure.ac
%endif

%build
export CXXFLAGS="%{build_cxxflags} -Wno-deprecated-declarations"

#squidf: add x86_64 platform for consistency, at least
%ifarch x86_64
%global boinc_platform x86_64-pc-linux-gnu
%endif
%ifarch %{ix86}
%global boinc_platform i686-pc-linux-gnu
%endif
%ifarch powerpc ppc
%global boinc_platform powerpc-linux-gnu
%endif
%ifarch powerpc64 ppc64
%global boinc_platform ppc64-linux-gnu
%endif
%ifarch aarch64
%global boinc_platform aarch64-unknown-linux-gnu
%endif

./_autosetup

%configure  \
                --disable-silent-rules \
                --disable-fcgi \
                --disable-shared \
                --disable-server \
                --enable-client \
                --enable-optimize \
                --enable-manager \
                --enable-unicode \
                --enable-dynamic-client-linkage \
                --with-wxdir=%{_libdir} \
                --with-wx-config=$(which wx-config) \
                --with-ssl \
                --with-x \
                --with-boinc-platform=%{boinc_platform} \
                STRIP=:

%make_build

%install
mkdir -p %{buildroot}%{_iconsdir}/hicolor/16x16/apps
mkdir -p %{buildroot}%{_iconsdir}/hicolor/32x32/apps
mkdir -p %{buildroot}%{_iconsdir}/hicolor/48x48/apps
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_localstatedir}/lib/boinc
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions

%make_install

# Use custom systemd script and logrotate configuration file
rm -f %{buildroot}%{_sysconfdir}/init.d/%{name} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

#squidf: https://github.com/BOINC/boinc/issues/2256
%{__mkdir_p} %{buildroot}%{_sysconfdir}/profile.d
%{__install} -m 644 %{SOURCE10} %{buildroot}%{_sysconfdir}/profile.d/40boinc-client.sh

# Install Icons
install -p -m644 packages/generic/sea/boincmgr.16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/boincmgr.png
install -p -m644 packages/generic/sea/boincmgr.32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/boincmgr.png
install -p -m644 packages/generic/sea/boincmgr.48x48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/boincmgr.png
install -p -m644 clientgui/res/boinc.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/boincmgr.svg

desktop-file-install %{?_remove_encoding} \
  --dir %{buildroot}%{_datadir}/applications \
  clientgui/res/boinc.desktop

%find_lang BOINC-Manager
%find_lang BOINC-Client

# bash-completion
install -p -m644 client/scripts/boinc.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}


%pre
%_pre_useradd boinc /dev/null /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel boinc


%files -f BOINC-Client.lang
%doc checkin_notes checkin_notes_*
%license COPYING COPYRIGHT
%{_bindir}/boinc
%{_bindir}/boinc_client
%{_bindir}/boinccmd
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf

%{_mandir}/man?/boinccmd.?.*
%{_mandir}/man?/boinc.?.*
%attr(-,boinc,boinc) %{_localstatedir}/lib/boinc/
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_datadir}/bash-completion/completions/boinc-client

%files -n boinc-manager -f BOINC-Manager.lang
%{_bindir}/boincmgr
%{_bindir}/boincscr
%{_datadir}/applications/boinc.desktop
%{_iconsdir}/hicolor/*/apps/boincmgr.png
%{_iconsdir}/hicolor/*/apps/boinc.png
%{_iconsdir}/hicolor/scalable/apps/boinc.svg
%{_iconsdir}/hicolor/scalable/apps/boincmgr.svg
%{_datadir}/boinc-manager/
%{_mandir}/man?/boincmgr.?.*
%{_sysconfdir}/profile.d/40boinc-client.sh

%files -n %{static_name}
%{_libdir}/libboinc.a
%{_libdir}/libboinc_api.a
%{_libdir}/libboinc_crypt.a
%{_libdir}/libboinc_graphics2.a
%{_libdir}/libboinc_opencl.a

%files -n %{devel_name}
%{_includedir}/boinc/
%{_libdir}/pkgconfig/libboinc.pc
%{_libdir}/pkgconfig/libboinc_api.pc
%{_libdir}/pkgconfig/libboinc_crypt.pc
%{_libdir}/pkgconfig/libboinc_graphics2.pc
%{_libdir}/pkgconfig/libboinc_opencl.pc
