Name:           boomaga
Version:        3.0.0
Release:        %mkrel 8
Summary:        A virtual printer for viewing a document before printing
Group:          System/Printing
License:        GPLv2 and LGPLv2+
Url:            https://boomaga.github.io/
Source0:        https://github.com/Boomaga/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:         0001-Remove-garbage-lines.patch
Patch2:         0001-Fix-typos.patch
# mga#31859
Patch3:         0001-Fix-incompatibility-with-GhostScript-9.54.patch

BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  ghostscript-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(poppler-cpp)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  pkgconfig(snappy)

Requires(pre):  ghostscript
Requires:       snappy
Requires(preun):cups-common
Requires(post): paper-utils
Requires(pre):  task-printing-server


%description
Boomaga (BOOklet MAnager) is a virtual printer for viewing a document
before printing it out using the physical printer. The program is very
simple to work with. Running any program, click “print” and select
“Boomaga” to see in several seconds (CUPS takes some time to respond)
the Boomaga window open. If you print out one more document,
it gets added to the previous one, and you can also print them
out as one. Regardless of whether your printer supports duplex
printing or not, you would be able to easily print on both sides
of the sheet. If your printer does not support duplex printing,
point this out in the settings, and Booklet would ask you to turn
over the pages half way through printing your document.

The program can also help you get your documents prepared a bit
before printing. At this stage Boomaga makes it possible to:

 * Paste several documents together.
 * Print several pages on one sheet.
 * 1, 2, 4, 8 pages per sheet
 * Booklet. Folding the sheets in two, you’ll get a book.

%prep
%setup -q
%autopatch -p1

%build
%cmake_qt5
%cmake_build

%install
%cmake_install

%__mkdir -p %{buildroot}%{_datadir}/%{name}/scripts
%__install -m 755 scripts/installPrinter.sh %{buildroot}%{_datadir}/%{name}/scripts/
chmod +x %{buildroot}%{_datadir}/%{name}/scripts/installPrinter.sh
mkdir -p %{buildroot}/%{_localstatedir}/cache/%{name}

# Add translation lang tags
(cd %{buildroot} && find . -name '*.qm') | sed -e 's|^.||' | sed -e \
    's:\(.*/translations/boomaga_\)\([a-z_A-Z]\+\)\(.*qm$\):%lang(\2) \1\2\3:'\
        >> %{name}.lang

%pre
if [ $1 -eq 1 ];then
# Start cups if is stopped
  if [ "$(systemctl is-active cups.service)" != "active" ]; then
    systemctl start cups
    sleep 2
  fi
fi

%post
# Install the printer to cups backends
if [ $1 -eq 1 ]; then
    sh %{_datadir}/%{name}/scripts/installPrinter.sh ||:
fi

%triggerun -- boomaga < 3.0.0-4
# Start cups if is stopped
if [ "$(systemctl is-active cups.service)" != "active" ]; then
    touch /run/cups.boomaga
    systemctl start cups
    sleep 2
fi

%triggerpostun -- boomaga < 3.0.0-4
if [ -f /run/cups.boomaga ]; then
    systemctl stop cups
    rm -rf /run/cups.boomaga
fi

%preun
# Uninstall the printer
if [ $1 -eq 0 ]; then
  if [ "$(systemctl is-active cups.service)" != "active" ]; then
    systemctl start cups
    sleep 2
    lpadmin -x "Boomaga" ||:
    systemctl stop cups
  else
    lpadmin -x "Boomaga" ||:
  fi
fi

%files -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/scripts
%{_bindir}/%{name}
%attr(700,root,root) %{_prefix}/lib/cups/backend/%{name}
%dir %{_localstatedir}/cache/%{name}
%{_datadir}/dbus-1/services/org.%{name}.service
%{_mandir}/man1/%{name}.1*
%{_datadir}/ppd/%{name}/
%{_datadir}/%{name}/scripts/installPrinter.sh
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml
