# After updating boost to new version, please rebuild the following pkgs very
# first before others to not broke BS:
#
# source-highlight
# gdb

%define toplev_dirname		%{name}_%(echo "%{version}"|tr \. _)

%define libname			%mklibname %{name} %{version}
%define devname			%mklibname %{name} -d
%define devnamestatic		%mklibname %{name} -d -s

%define libnamempi		%mklibname %{name}_openmpi %{version}
%define devnamempi		%mklibname %{name}_openmpi -d

%define libnamempich		%mklibname %{name}_mpich %{version}
%define devnamempich		%mklibname %{name}_mpich -d

%define libnamegraphmpich	%mklibname %{name}_graph_parallel-mpich %{version}

%define python3name		python%{python3_version_nodots}
%define numpy3name		numpy%{python3_version_nodots}

%define libnamepy3		%mklibname %{name}_%{python3name} _%{version}
%define devnamepy3		%mklibname %{name}_python3 -d

%define libnamempipy3		%mklibname %{name}_mpi_%{python3name} _%{version}
%define devnamempipy3		%mklibname %{name}_mpi_python3 -d

%define libnamempichpy3		%mklibname %{name}_mpich_%{python3name} _%{version}
%define devnamempichpy3		%mklibname %{name}_mpich_python3 -d

%define libnamegraphmpi		%mklibname %{name}_graph_parallel-openmpi %{version}

# In Mageia openmpi and mpich can't coexist
%bcond_with mpich

#(eatdirt) openmpi has dropped 32 bits support
%ifarch %arm32 %ix86
%bcond_with    openmpi
%else
%bcond_without openmpi
%endif

%bcond_without context
%bcond_without python3

%ifarch %{ix86} x86_64
  %bcond_without quadmath
%else
  %bcond_with quadmath
%endif

%ifarch x86_64
  %bcond_without stacktrace_from_exception
%else
  %bcond_with stacktrace_from_exception
%endif

Name: boost
Summary: The free peer-reviewed portable C++ source libraries
Version: 1.87.0
Release: %mkrel 6
License: Boost and MIT and Python
URL: https://www.boost.org/
Group: Development/C++
Source0: https://archives.boost.io/release/%{version}/source/%{toplev_dirname}.tar.bz2
Source1: libboost_thread.so

BuildRequires: gcc-c++
BuildRequires: m4
BuildRequires: libstdc++-devel
BuildRequires: bzip2-devel
BuildRequires: zlib-devel
BuildRequires: lzma-devel
BuildRequires: zstd-devel
%if %{with python3}
BuildRequires: pkgconfig(python3)
BuildRequires: python3-numpy-devel
%endif
BuildRequires: icu-devel
%if %{with quadmath}
BuildRequires: libquadmath-devel
%endif
%if %{with openmpi}
BuildRequires: openmpi
BuildRequires: openmpi-devel
%endif
%if %{with mpich}
BuildRequires: mpich
BuildRequires: mpich-devel
BuildRequires: mpicxx
%endif

#Upstream patches
#
Patch1: 0001-Fix-operator-for-shared_ptr-and-intrusive_ptr.-Fixes.patch

# Add a manual page for bjam, based on the on-line documentation:
# https://www.boost.org/boost-build2/doc/html/bbv2/overview.html
Patch5: boost-1.48.0-add-bjam-man-page.patch

# https://svn.boost.org/trac/boost/ticket/9038
Patch51: boost-1.81.0-pool-test_linking.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=1541035
Patch96: boost-1.83.0-build-optflags.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=1318383
Patch97: boost-1.85.0-no-rpath.patch

#https://github.com/boostorg/move/issues/59
Patch98: boost-1.87.0-missdef.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=1541035
Patch83: boost-1.76.0-b2-build-flags.patch

# https://lists.boost.org/Archives/boost/2020/04/248812.php
Patch88: boost-1.73.0-cmakedir.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=1923740
# https://github.com/boostorg/build/issues/696
Patch95: boost-1.75.0-boost-build-fix.patch

###
# From openSUSE:
# Slightly modified to still build static boost_test_exec_monitor
Patch101: dynamic_linking.patch

###
# Mageia patches:

# Fix library overlinking
Patch201: boost-1.85.0-linking.patch

# Fix linking with py3
Patch202: boost-1.57.0-python-libpython_dep.patch

# Hack to fix mpi build
Patch203: boost-1.72.0-mpi-python-build.patch

%bcond_with tests
%bcond_with docs_generated

%define boostlibs %{?with_context:context coroutine fiber} %{?with_python3:%numpy3name %python3name} atomic charconv chrono container contract date_time exception filesystem graph %{?with_openmpi:graph_parallel} iostreams json locale log log_setup math_c99 math_c99f math_c99l math_tr1 math_tr1f math_tr1l nowide prg_exec_monitor process program_options random regex serialization stacktrace_addr2line stacktrace_basic %{?with_stacktrace_from_exception:stacktrace_from_exception} stacktrace_noop system thread timer type_erasure unit_test_framework url wave wserialization

# (Anssi 01/2010) dashes are converted to underscores for macros ($lib2);
# The sed script adds _ when library name ends in number.

%define major %(echo %{version}|cut -d. -f1,2)

%{expand:%(for lib in %boostlibs; do lib2=${lib/-/_}; cat <<EOF
%%global libname$lib2 %%mklibname boost_$(echo $lib | sed 's,[0-9]$,&_,') %{version}
%%package -n %%{libname$lib2}
Summary:    Boost $lib shared library
# no one should require this, but provided anyway for maximum compatibility:
Provides:   boost = %version-%release
Group:      System/Libraries
EOF
done)}

# (Anssi 01/2010) splitted expand contents due to rpm bug failing build,
# triggered by a too long expanded string.

%{expand:%(for lib in %boostlibs; do lib2=${lib/-/_}; cat <<EOF
%%description -n %%{libname$lib2}
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains the shared library needed for
running programs dynamically linked against Boost $lib.
EOF
done)}

%{expand:%(for lib in %boostlibs; do lib2=${lib/-/_}; cat <<EOF
%%files -n %%{libname$lib2}
%%%%license LICENSE_1_0.txt
%{_libdir}/libboost_$lib.so.%{major}{,.*}
EOF
done)}

%description
Boost provides free peer-reviewed portable C++ source libraries.  The
emphasis is on libraries which work well with the C++ Standard
Library, in the hopes of establishing "existing practice" for
extensions and providing reference implementations so that the Boost
libraries are suitable for eventual standardization. (Some of the
libraries have already been included in the C++ 2011 standard and
others have been proposed to the C++ Standards Committee for inclusion
in future standards.)

%package -n %{devnamepy3}
Summary: Development files for Boost.Python 3
Group: Development/C++
Requires: %{libnamepy3} = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}
Provides: %{name}-python3-devel = %{version}-%{release}
Provides: lib%{name}-python3-devel = %{version}-%{release}

%description -n %{devnamepy3}
Development files for Python 3 variant of Boost.Python.

%package -n %{devname}
Summary: The libraries and headers needed for Boost development
Group: Development/C++
Requires: %{expand:%(for lib in %boostlibs; do echo -n "%%{libname${lib/-/_}} = %{version}-%{release} "; done)}
%if %{with python3}
Requires: %{devnamepy3} = %{version}-%{release}
%endif
##
# /usr/include/boost/python/detail/wrap_python.hpp:57:11: fatal error: pyconfig.h: No such file or directory
##
Requires: python3-devel

Provides: %{name}-devel = %{version}-%{release}
Provides: lib%{name}-devel = %{version}-%{release}
# Required because thread linker script stops auto generation of devel(...) provide
Provides: devel(libboost_thread%([ "%{?_lib}" = "lib64" ] && echo "(64bit)")) = %{version}-%{release}

%description -n %{devname}
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains headers and shared library
symlinks needed for Boost development.

%package -n %{devnamestatic}
Summary: The Boost C++ static development libraries
Group: System/Libraries
Requires: %{name}-devel = %{version}-%{release}
Provides: boost-devel-static = %{version}-%{release}

%description -n %{devnamestatic}
Static Boost C++ libraries.

%package devel-doc
Summary: Documentation for developers using Boost
Group: Development/C++
BuildArch: noarch

%description devel-doc
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains documentation needed for Boost
development.

%package examples
Summary: Source examples for the Boost C++ libraries
Group: Documentation
#BuildArch: noarch
Requires: %{name}-devel >= %{version}-%{release}

%description examples
This package contains example source files distributed with boost.

%package -n %{libnamempi}
Summary: Run-time component of Boost.MPI-OpenMPI library
Group: System/Libraries
Conflicts: %{libnamempich}

%description -n %{libnamempi}
Run-time support for Boost.MPI-OpenMPI, a library providing a clean C++
API over the OpenMPI implementation of MPI.

%package -n %{devnamempi}
Summary: Development files for Boost.MPI-OpenMPI
Group: System/Libraries
Requires: %{name}-devel = %{version}-%{release}
Requires: %{libnamempi} = %{version}-%{release}
Requires: %{libnamegraphmpi} = %{version}-%{release}
Provides: %{name}-openmpi-devel = %{version}-%{release}
Provides: lib%{name}-openmpi-devel = %{version}-%{release}
Conflicts: %{devnamempich}

%description -n %{devnamempi}
Devel package for Boost.MPI-OpenMPI, a library providing a clean C++
API over the OpenMPI implementation of MPI.

%package -n %{libnamempipy3}
Summary: Python 3 run-time component of Boost.MPI-OpenMPI library
Group: System/Libraries
Conflicts: %{libnamempichpy3}

%description -n %{libnamempipy3}
Python support for Boost.MPI-OpenMPI, a library providing a clean C++
API over the OpenMPI implementation of MPI.

%package -n python3-boost-openmpi
Summary: Python 3 bindings for Boost.MPI-OpenMPI library
Group: Development/Python

%description -n python3-boost-openmpi
This package contains the Boost.MPI-OpenMPI bindings for Python 3.

%package -n %{libnamegraphmpi}
Summary: Run-time component of parallel boost graph library
Group: System/Libraries
Conflicts: %{libnamegraphmpich}

%description -n %{libnamegraphmpi}
Run-time support for the Parallel BGL graph library.  The interface and
graph components are generic, in the same sense as the the Standard
Template Library (STL).  The libraries in this package use OpenMPI
back-end to do the parallel work.

%package -n %{devnamempipy3}
Summary: Development files for Boost.MPI-OpenMPI Python 3 component
Group: Development/Other
Requires: boost-devel = %{version}-%{release}
Requires: %{devnamepy3} = %{version}-%{release}
Requires: %{libnamempipy3} = %{version}-%{release}
Provides: %{name}-mpi-python3-devel = %{version}-%{release}
Provides: lib%{name}-mpi-python3-devel = %{version}-%{release}
Conflicts: %{devnamempichpy3}

%description -n %{devnamempipy3}
Devel package for the Python 3 interface of Boost.MPI-OpenMPI, a library
providing a clean C++ API over the OpenMPI implementation of MPI.

%package -n %{libnamempich}
Summary: Run-time component of Boost.MPI-MPICH library
Group: System/Libraries
Conflicts: %{libnamempi}

%description -n %{libnamempich}
Run-time support for Boost.MPI-MPICH, a library providing a clean C++
API over the MPICH implementation of MPI.

%package -n %{libnamempichpy3}
Summary: Python 3 run-time component of Boost.MPI-MPICH library
Group: System/Libraries
Conflicts: %{libnamempipy3}

%description -n %{libnamempichpy3}
Python 3 support for Boost.MPI-MPICH, a library providing a clean C++
API over the MPICH implementation of MPI.

%package -n python3-boost-mpich
Summary: Python 3 bindings for Boost.MPI-MPICH library
Group: Development/Python

%description -n python3-boost-mpich
This package contains the Boost.MPI-MPICH bindings for Python 3.

%package -n %{devnamempichpy3}
Summary: Development files for Boost.MPI-MPICH Python 3 component
Group: Development/Other
Requires: boost-devel = %{version}-%{release}
Requires: %{libnamepy3} = %{version}-%{release}
Requires: %{libnamempichpy3} = %{version}-%{release}
Provides: %{name}-mpich-python3-devel = %{version}-%{release}
Provides: lib%{name}-mpich-python3-devel = %{version}-%{release}
Conflicts: %{devnamempipy3}

%description -n %{devnamempichpy3}
Devel package for the Python 3 interface of Boost.MPI-MPICH, a library
providing a clean C++ API over the MPICH implementation of MPI.

%package -n %{devnamempich}
Summary: Development files for Boost.MPI-MPICH
Group: Development/Other
Requires: %{name}-devel = %{version}-%{release}
Requires: %{libnamempich} = %{version}-%{release}
Requires: %{libnamegraphmpich} = %{version}-%{release}
Conflicts: %{devnamempi}

%description -n %{devnamempich}
Devel package for Boost.MPI-MPICH, a library providing a clean C++
API over the MPICH implementation of MPI.

%package -n %{libnamegraphmpich}
Summary: Run-time component of parallel boost graph library
Group: System/Libraries
Conflicts: %{libnamegraphmpi}

%description -n %{libnamegraphmpich}
Run-time support for the Parallel BGL graph library.  The interface and
graph components are generic, in the same sense as the Standard
Template Library (STL).  This libraries in this package use MPICH
back-end to do the parallel work.

%package build
Summary: Cross platform build system for C++ projects
Group: Development/Tools
Requires: boost-jam
BuildArch: noarch

%description build
Boost.Build is an easy way to build C++ projects, everywhere. You name
your pieces of executable and libraries and list their sources.  Boost.Build
takes care about compiling your sources with the right options,
creating static and shared libraries, making pieces of executable, and other
chores -- whether you're using GCC, MSVC, or a dozen more supported
C++ compilers -- on Windows, OSX, Linux and commercial UNIX systems.

%package doctools
Summary: Tools for working with Boost documentation
Group: Publishing
Requires: docbook-dtds
Requires: docbook-style-xsl

%description doctools
Tools for working with Boost documentation in BoostBook or QuickBook format.

%package bjam
Summary: A low-level build tool
Group: Development/Tools
Obsoletes: %{name}-jam < 3.1.19
Provides: %{name}-jam = %{version}-%{release}
Requires: %{name}-build = %{version}-%{release}

%description bjam
Boost.Jam (BJam) is the low-level build engine tool for Boost.Build.
Historically, Boost.Jam is based on on FTJam and on Perforce Jam but has grown
a number of significant features and is now developed independently

%prep
%setup -q -n %{toplev_dirname}

%patch -P 1 -p2
%patch -P 5 -p1
%patch -P 51 -p1
%patch -P 96 -p1
%patch -P 97 -p1
%patch -P 98 -p1
%patch -P 83 -p1
%patch -P 88 -p1
%patch -P 101 -p1
%patch -P 201 -p1
%patch -P 202 -p1
%patch -P 203 -p1

# remove precompiled code
find . -name "*.o" -delete

%build
%set_build_flags
# Dump the versions being used into the build logs.
%if %{with python3}
PYTHON3_ABIFLAGS=$(/usr/bin/python3-config --abiflags)
: PYTHON3_VERSION=%{python3_version}
: PYTHON3_ABIFLAGS=${PYTHON3_ABIFLAGS}
%endif

# There are many strict aliasing warnings, and it's not feasible to go
# through them all at this time.
# There are also lots of noisy but harmless unused local typedef warnings.
export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -Wno-deprecated-declarations"
export RPM_LD_FLAGS="$RPM_LD_FLAGS"

cat > ./tools/build/src/user-config.jam << "EOF"
import os ;
local RPM_OPT_FLAGS = [ os.environ RPM_OPT_FLAGS ] ;
local RPM_LD_FLAGS = [ os.environ RPM_LD_FLAGS ] ;

using gcc : : : <compileflags>$(RPM_OPT_FLAGS) <linkflags>$(RPM_LD_FLAGS) ;
%if %{with openmpi} || %{with mpich}
using mpi ;
%endif
EOF

%if %{with python3}
cat >> ./tools/build/src/user-config.jam << EOF
using python : %{python3_version} : /usr/bin/python3 : /usr/include/python%{python3_version}${PYTHON3_ABIFLAGS} : : : : ${PYTHON3_ABIFLAGS} ;
EOF
%endif

./bootstrap.sh --with-toolset=gcc --with-icu --with-python=python3 --with-python-version=%{python3_version} --prefix=%{_prefix} --libdir=%{_libdir}

# N.B. When we build the following with PCH, parts of boost (math
# library in particular) end up being built second time during
# installation.  Unsure why that is, but all sub-builds need to be
# built with pch=off to avoid this.

echo ============================= build serial ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--build-type=minimal \
	--without-mpi --without-graph_parallel --build-dir=serial-build \
	--stagedir=serial-stage \
%if !%{with context}
	--without-context --without-coroutine --without-coroutine2 \
	--without-fiber \
%endif
%if !%{with python3}
	--without-python \
%endif
%if !%{with stacktrace_from_exception}
	boost.stacktrace.from_exception=off \
%endif
	variant=release threading=multi debug-symbols=on pch=off \
	link=shared runtime-link=shared define=BOOST_ALL_DYN_LINK \
%if %{with python3}
	python=%{python3_version} \
%endif
	stage

# See libs/thread/build/Jamfile.v2 for where this file comes from.
if [ $(find serial-build -type f -name has_atomic_flag_lockfree \
		-print -quit | wc -l) -ne 0 ]; then
	DEF=D
else
	DEF=U
fi

m4 -${DEF}HAS_ATOMIC_FLAG_LOCKFREE -DVERSION=%{version} \
	%{SOURCE1} > $(basename %{SOURCE1})

# Build MPI parts of Boost with OpenMPI support
%if %{with openmpi}

export MPI_COMPILER=openmpi-$HOSTTYPE

echo ============================= build $MPI_COMPILER ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--build-type=minimal \
	--with-mpi --with-graph_parallel --build-dir=$MPI_COMPILER-build \
	--stagedir=$MPI_COMPILER-stage \
	variant=release threading=multi debug-symbols=on pch=off \
	link=shared runtime-link=shared define=BOOST_ALL_DYN_LINK \
%if %{with python3}
	python=%{python3_version} \
%endif
	stage

# with openmpi
%endif

# Build MPI parts of Boost with MPICH support
%if %{with mpich}

export MPI_COMPILER=mpich-$HOSTTYPE

echo ============================= build $MPI_COMPILER ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--build-type=minimal \
	--with-mpi --with-graph_parallel --build-dir=$MPI_COMPILER-build \
	--stagedir=$MPI_COMPILER-stage \
	variant=release threading=multi debug-symbols=on pch=off \
	link=shared runtime-link=shared define=BOOST_ALL_DYN_LINK \
%if %{with python3}
        python=%{python3_version} \
%endif
	stage

# with mpich
%endif

echo ============================= build Boost.Build ==================
(cd tools/build
 ./bootstrap.sh --with-toolset=gcc)

%check
:


%install
cd %{_builddir}/%{toplev_dirname}

%if %{with openmpi}

export MPI_COMPILER=openmpi-$HOSTTYPE

echo ============================= install $MPI_COMPILER ==================
./b2 -q %{?_smp_mflags} \
	--build-type=minimal \
	--with-mpi --with-graph_parallel --build-dir=$MPI_COMPILER-build \
	--stagedir=$MPI_COMPILER-stage \
	--prefix=$RPM_BUILD_ROOT%{_prefix} \
	--libdir=$RPM_BUILD_ROOT%{_libdir} \
	variant=release threading=multi debug-symbols=on pch=off \
	link=shared runtime-link=shared define=BOOST_ALL_DYN_LINK \
%if %{with python3}
	python=%{python3_version} \
%endif
	install

%if %{with python3}
# Move Python module to proper location for automatic loading
mkdir -p ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/openmpi
touch ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/__init__.py
install -Dpm644 libs/mpi/build/__init__.py \
   ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/openmpi/__init__.py
mv ${RPM_BUILD_ROOT}%{_libdir}/boost-python%{python3_version}/mpi.so \
   ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/openmpi
rm -rf ${RPM_BUILD_ROOT}%{_libdir}/boost-python%{python3_version}/
# with python3
%endif

# with openmpi
%endif

%if %{with mpich}

export MPI_COMPILER=mpich-$HOSTTYPE

echo ============================= install $MPI_COMPILER ==================
./b2 -q %{?_smp_mflags} \
	--build-type=minimal \
	--with-mpi --with-graph_parallel --build-dir=$MPI_COMPILER-build \
	--stagedir=$MPI_COMPILER-stage \
	--prefix=$RPM_BUILD_ROOT%{_prefix} \
	--libdir=$RPM_BUILD_ROOT%{_libdir} \
	variant=release threading=multi debug-symbols=on pch=off \
	link=shared runtime-link=shared define=BOOST_ALL_DYN_LINK \
%if %{with python3}
	python=%{python3_version} \
%endif
	install

%if %{with python3}
# Move Python module to proper location for automatic loading
mkdir -p ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/mpich/
touch ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/__init__.py
install -Dpm644 libs/mpi/build/__init__.py \
   ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/mpich/__init__.py
mv ${RPM_BUILD_ROOT}%{_libdir}/boost-python%{python3_version}/mpi.so \
   ${RPM_BUILD_ROOT}%{python3_sitearch}/boost/mpich
rm -rf ${RPM_BUILD_ROOT}%{_libdir}/boost-python%{python3_version}/

# with python3
%endif

# with mpich
%endif

echo ============================= install serial ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--build-type=minimal \
	--without-mpi --without-graph_parallel --build-dir=serial-build \
	--stagedir=serial-stage \
%if !%{with context}
	--without-context --without-coroutine --without-coroutine2 \
	--without-fiber \
%endif
%if !%{with python3}
	--without-python \
%endif
	--prefix=$RPM_BUILD_ROOT%{_prefix} \
	--libdir=$RPM_BUILD_ROOT%{_libdir} \
	variant=release threading=multi debug-symbols=on pch=off \
	link=shared runtime-link=shared define=BOOST_ALL_DYN_LINK \
%if !%{with stacktrace_from_exception}
        boost.stacktrace.from_exception=off \
%endif
%if %{with python3}
	python=%{python3_version} \
%endif
	install

# Override DSO symlink with a linker script.  See the linker script
# itself for details of why we need to do this.
if [ -f $RPM_BUILD_ROOT%{_libdir}/libboost_thread.so ]; then # Must be present
  rm -f $RPM_BUILD_ROOT%{_libdir}/libboost_thread.so
  install -p -m 644 $(basename %{SOURCE1}) $RPM_BUILD_ROOT%{_libdir}/
fi

echo ============================= install Boost.Build ==================
(cd tools/build
 ./b2 --prefix=$RPM_BUILD_ROOT%{_prefix} \
      --bindir=$RPM_BUILD_ROOT%{_bindir} install
 # Fix some permissions
 chmod -x $RPM_BUILD_ROOT%{_datadir}/b2/src/options/help.jam
 chmod +x $RPM_BUILD_ROOT%{_datadir}/b2/src/tools/doxproc.py
 # Fix shebang using unversioned python
 sed -i '1s@^#!/usr/bin.python$@&3@' $RPM_BUILD_ROOT%{_datadir}/b2/src/tools/doxproc.py
 # Bjam was renamed as b2 long time ago
 ln -s %{_bindir}/b2 $RPM_BUILD_ROOT%{_bindir}/bjam
 # Not a real file
 rm -f $RPM_BUILD_ROOT%{_datadir}/b2/src/build/project.ann.py
 # Empty file
 rm -f $RPM_BUILD_ROOT%{_datadir}/b2/src/tools/doxygen/windows-paths-check.hpp
 # Install the manual page
 %{__install} -p -m 644 v2/doc/bjam.1 -D $RPM_BUILD_ROOT%{_mandir}/man1/bjam.1
)

%if %{with python3}
ln -s %{_libdir}/libboost_python%{python3_version_nodots}.so.%{version} %{buildroot}%{_libdir}/libboost_python3.so
ln -s %{_libdir}/libboost_numpy%{python3_version_nodots}.so.%{version} %{buildroot}%{_libdir}/libboost_numpy3.so
%endif

echo ============================= install Boost.QuickBook ==================
(cd tools/quickbook
 ../build/b2 --prefix=$RPM_BUILD_ROOT%{_prefix}
 %{__install} -p -m 755 ../../dist/bin/quickbook $RPM_BUILD_ROOT%{_bindir}/
 cd ../boostbook
 find dtd -type f -name '*.dtd' | while read tobeinstalledfiles; do
   install -p -m 644 $tobeinstalledfiles -D $RPM_BUILD_ROOT%{_datadir}/boostbook/$tobeinstalledfiles
 done
 find xsl -type f | while read tobeinstalledfiles; do
   install -p -m 644 $tobeinstalledfiles -D $RPM_BUILD_ROOT%{_datadir}/boostbook/$tobeinstalledfiles
 done
)

# Preparing the docs
rm -fr packagedoc
mkdir packagedoc
find -type f -not -path '*packagedoc*' \( -name '*.html' -o -name '*.htm' -o -name '*.css' -o -name '*.gif' -o -name '*.jpg' -o -name '*.png' -o -name '*README*' \) -exec cp --parents {} packagedoc/ \;

# Preparing the examples: All .hpp or .cpp files that are not in
# directories called test, src, or tools, as well as all files of any
# type in directories called example or examples.
rm -fr examples
mkdir examples
find libs -type f \( -name "*.?pp" ! -path "*test*" ! -path "*src*" ! -path "*tools*" -o -path "*example*" \) -exec cp --parents {} examples/ \;

# Find static libs
find %{buildroot} -name "*.a" -print

# Remove buildroot definition from cmake files
sed -i -e 's,%{buildroot},,g' $(find %{buildroot}%{_libdir}/cmake -name "*.cmake")

# Workaround file conflicts with older release until it's properly fixed
rm -rf %{buildroot}%{_libdir}/libboost_*.so.1

# Unneeded ATM
rm -rf %{buildroot}%{_datadir}/boost_predef/

%post doctools
CATALOG=%{_sysconfdir}/xml/catalog
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
 "http://www.boost.org/tools/boostbook/dtd" \
 "file://%{_datadir}/boostbook/dtd" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
 "http://www.boost.org/tools/boostbook/dtd" \
 "file://%{_datadir}/boostbook/dtd" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
 "http://www.boost.org/tools/boostbook/xsl" \
 "file://%{_datadir}/boostbook/xsl" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
 "http://www.boost.org/tools/boostbook/xsl" \
 "file://%{_datadir}/boostbook/xsl" $CATALOG

%postun doctools
# remove entries only on removal of package
if [ "$1" = 0 ]; then
  CATALOG=%{_sysconfdir}/xml/catalog
  %{_bindir}/xmlcatalog --noout --del \
    "file://%{_datadir}/boostbook/dtd" $CATALOG
  %{_bindir}/xmlcatalog --noout --del \
    "file://%{_datadir}/boostbook/xsl" $CATALOG
fi

%if %{with python3}
%files -n %devnamepy3
%license LICENSE_1_0.txt
%{_libdir}/libboost_numpy%{python3_version_nodots}.so
%{_libdir}/libboost_numpy3.so
%{_libdir}/libboost_python%{python3_version_nodots}.so
%{_libdir}/libboost_python3.so
%{_libdir}/cmake/boost_numpy-%{version}/
%{_libdir}/cmake/boost_python-%{version}/
%endif

%files devel-doc
%doc packagedoc/*

%files examples
%doc examples/*

%files -n %{devname}
%license LICENSE_1_0.txt
%{_includedir}/%{name}/
%{_libdir}/libboost_atomic.so
%{_libdir}/libboost_charconv.so
%{_libdir}/libboost_chrono.so
%{_libdir}/libboost_container.so
%{_libdir}/libboost_contract.so
%if %{with context}
%{_libdir}/libboost_context.so
%{_libdir}/libboost_coroutine.so
%endif
%{_libdir}/libboost_date_time.so
%{_libdir}/libboost_exception.so
%if %{with context}
%{_libdir}/libboost_fiber.so
%endif
%{_libdir}/libboost_filesystem.so
%{_libdir}/libboost_graph.so
%{_libdir}/libboost_iostreams.so
%{_libdir}/libboost_json.so
%{_libdir}/libboost_locale.so
%{_libdir}/libboost_log.so
%{_libdir}/libboost_log_setup.so
%{_libdir}/libboost_math_tr1.so
%{_libdir}/libboost_math_tr1f.so
%{_libdir}/libboost_math_tr1l.so
%{_libdir}/libboost_math_c99.so
%{_libdir}/libboost_math_c99f.so
%{_libdir}/libboost_math_c99l.so
%{_libdir}/libboost_nowide.so
%{_libdir}/libboost_prg_exec_monitor.so
%{_libdir}/libboost_unit_test_framework.so
%{_libdir}/libboost_process.so
%{_libdir}/libboost_program_options.so
%{_libdir}/libboost_random.so
%{_libdir}/libboost_regex.so
%{_libdir}/libboost_serialization.so
%{_libdir}/libboost_wserialization.so
%{_libdir}/libboost_stacktrace_addr2line.so
%{_libdir}/libboost_stacktrace_basic.so
%if %{with stacktrace_from_exception}
%{_libdir}/libboost_stacktrace_from_exception.so
%endif
%{_libdir}/libboost_stacktrace_noop.so
%{_libdir}/libboost_system.so
%{_libdir}/libboost_thread.so
%{_libdir}/libboost_timer.so
%{_libdir}/libboost_type_erasure.so
%{_libdir}/libboost_url.so
%{_libdir}/libboost_wave.so
%{_libdir}/cmake/boost_*-%{version}/
%{_libdir}/cmake/Boost*
%exclude %{_libdir}/cmake/boost_numpy-%{version}/
%exclude %{_libdir}/cmake/boost_python-%{version}/
%exclude %{_libdir}/cmake/boost_test_exec_monitor-%{version}/
%if %{with openmpi} || %{with mpich}
%exclude %{_libdir}/cmake/boost_mpi-%{version}/
%exclude %{_libdir}/cmake/boost_graph_parallel-%{version}/
%endif

%files -n %{devnamestatic}
%license LICENSE_1_0.txt
%{_libdir}/*.a
%{_libdir}/cmake/boost_test_exec_monitor-%{version}/

# OpenMPI packages
%if %{with openmpi}

%files -n %{libnamempi}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi.so.%{major}{,.*}

%files -n %{devnamempi}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi.so
%{_libdir}/libboost_graph_parallel.so
%{_libdir}/cmake/boost_mpi-%{version}/
%{_libdir}/cmake/boost_graph_parallel-%{version}/

%if %{with python3}

%files -n %{libnamempipy3}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi_python%{python3_version_nodots}.so.%{major}{,.*}

%files -n python3-boost-openmpi
%dir %{python3_sitearch}/boost/
%pycached %{python3_sitearch}/boost/__init__.py
%{python3_sitearch}/boost/openmpi/

%files -n %{devnamempipy3}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi_python%{python3_version_nodots}.so

#with python3
%endif

%files -n %{libnamegraphmpi}
%license LICENSE_1_0.txt
%{_libdir}/libboost_graph_parallel.so.%{major}{,.*}

# with openmpi
%endif

# MPICH packages
%if %{with mpich}

%files -n %{libnamempich}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi.so.%{major}{,.*}

%files -n %{devnamempich}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi.so
%{_libdir}/libboost_graph_parallel.so
%{_libdir}/cmake/boost_mpi-%{version}/
%{_libdir}/cmake/boost_graph_parallel-%{version}/

%if %{with python3}

%files -n %{libnamempichpy3}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi_python%{python3_version_nodots}.so.%{major}{,.*}

%files -n python3-boost-mpich
%dir %{python3_sitearch}/boost/
%pycached %{python3_sitearch}/boost/__init__.py
%{python3_sitearch}/boost/mpich/

%files -n %{devnamempichpy3}
%license LICENSE_1_0.txt
%{_libdir}/libboost_mpi_python%{python3_version_nodots}.so

# with python3
%endif

%files -n %{libnamegraphmpich}
%license LICENSE_1_0.txt
%{_libdir}/libboost_graph_parallel.so.%{major}{,.*}

# with mpich
%endif

%files build
%license LICENSE_1_0.txt
%{_datadir}/b2/

%files doctools
%license LICENSE_1_0.txt
%{_bindir}/quickbook
%{_datadir}/boostbook/

%files bjam
%license LICENSE_1_0.txt
%{_bindir}/b2
%{_bindir}/bjam
%{_mandir}/man1/bjam.1*
