%define pypi_name borgbackup
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

# comment out if not pre rel
#define prel    b1

# rel for bumping
%define rel     2

Name:           borgbackup
Version:        1.4.0
Release:        %mkrel %{?prel:0.%prel.}%{rel}
Group:          Archiving/Backup
Summary:        Deduplicated backups

License:        BSD
URL:            https://borgbackup.github.io/
%if 0%{?prel:1}
Source0:        https://github.com/borgbackup/borg/releases/download/%{version}%{?prel:%prel}/%{pypi_name}-%{version}%{?prel:%prel}.tar.gz
%else
Source0:        https://pypi.io/packages/source/b/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
%endif
Patch1:         0002-README.rst-Replace-img-src-with-text-link.patch
Patch2:         0003-disable-sphinx-man-page-build.patch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  libb2-devel
BuildRequires:  libacl-devel
BuildRequires:  libzstd-devel
BuildRequires:  xxhash-devel
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(llfuse)
BuildRequires:  python3-msgpack
BuildRequires:  python3dist(pkgconfig)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(setuptools-scm)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(python-dateutil)
BuildRequires:  python3dist(wheel)
Recommends:     python3dist(llfuse)


%description
BorgBackup (short: Borg) is a deduplicating backup program.
Optionally, it supports compression and authenticated encryption.

The main goal of Borg is to provide an efficient and secure way to backup data.
The data deduplication technique used makes Borg suitable for daily backups
since only changes are stored. The authenticated encryption technique makes
it suitable for backups to not fully trusted targets.


%prep
%autosetup -p1 -n %{pypi_name}-%{version}%{?prel:%prel}

# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

# remove .c files so cython rebuild them
for i in $(find . -type f -name "*.pyx"); do
  rm -rf ${i%.pyx}.c
done

%generate_buildrequires
%pyproject_buildrequires -x fuse


%build
BORG_OPENSSL_PREFIX=%{_libdir} \
BORG_LIBB2_PREFIX=%{_libdir} \
BORG_LIBLZ4_PREFIX=%{_libdir} \
BORG_LIBXXHASH_PREFIX=%{_libdir} \
BORG_LIBZSTD_PREFIX=%{_libdir} \
%pyproject_wheel

# MANPAGE GENERATION
# workaround to dump sphinx_rtd_theme dependency - not needed for manpages
export READTHEDOCS=True

# workaround to include borg module for usage generation
export PYTHONPATH=$(pwd)/build/$(ls build/ | grep 'lib.')

make -C docs man


%install
%pyproject_install

install -D -m 0644 docs/_build/man/borg*.1* %{buildroot}%{_mandir}/man1/borg.1

# add shell completions
%define bash_compdir %{_prefix}/share/bash-completion/completions
%define zsh_compdir %{_prefix}/share/zsh/site-functions

install -d  %{buildroot}%{bash_compdir}
install -d  %{buildroot}%{zsh_compdir}

install -D -m 0644 scripts/shell_completions/bash/* %{buildroot}%{bash_compdir}
install -D -m 0644 scripts/shell_completions/zsh/* %{buildroot}%{zsh_compdir}


%check
export PYTHONPATH=$(pwd)/build/$(ls build/ | grep 'lib.')

# exclude test_fuse: there is no modprobe in mock for fuse
# exclude test_non_ascii_acl: collate issue in BS
# exclude benchmark: not relevant for package build
# exclude test_dash_open: pytest stub has a bug and is fixed in 3.0.2 (epel7 uses 2.8.5)
# exclude test_mount_hardlinks: there is no modprobe in mock for fuse
# exclude test_create_stdin and test_swidth_mixed and test_swidth_cjk and test_progress_percentage_widechars: collate issue in BS
# exclude test_migrate_lock_alive: there is no modprobe in bs for fuse
py.test-3 -vk "not test_create_stdin and not test_swidth_mixed and not test_swidth_cjk and not test_non_ascii_acl and not test_fuse and not benchmark and not test_dash_open and not test_mount_hardlinks and not test_readonly_mount and not test_migrate_lock_alive and not test_progress_percentage_widechars" $PYTHONPATH/borg/testsuite/*.py


%files
%license LICENSE
%doc README.rst PKG-INFO AUTHORS
%doc docs/changes.rst
%{_mandir}/man1/*
%{python3_sitearch}/borg
%{python3_sitearch}/%{pypi_name}-%{version}%{?prel:%prel}.dist-info
%{_bindir}/borg
%{_bindir}/borgfs
%{_prefix}/share/bash-completion/completions/*
%{_prefix}/share/zsh/site-functions/*

