%define dlname Botan

%define api     2
%define major   19
%define libname %mklibname botan %{api} %{major}
%define devname %mklibname botan %{api} -d

Name:           botan2
Version:        2.19.5
Release:        %mkrel 3
Summary:        Crypto and TLS for C++
Group:          System/Libraries
License:        BSD
URL:            https://botan.randombit.net/
Source0:        https://botan.randombit.net/releases/%{dlname}-%{version}.tar.xz#!/%{name}-%{version}.tar.xz

# Upstram patch to fix test failure
Patch0:         https://github.com/randombit/botan/pull/2837.patch
Patch1:         0001-Remove-usage-of-deprecated-asio-API-boost-1.87.patch
Patch2:         0001-Fix-compilation-on-GCC-15.patch

BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  boost-devel
BuildRequires:  trousers-devel
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3dist(docutils)
BuildRequires:  python3dist(sphinx)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(sqlite3)

Requires:       python3

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library. This is the current stable release branch 2.x
of Botan.


%package -n     %{libname}
Summary:        Library files for %{name}
Group:          System/Libraries

%description -n %{libname}
The %{libname} package contains library files for %{name}.


%package -n     %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
Documentation for %{name}.

This package contains HTML documentation for %{name}.


%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package contains the Python3 binding for %{name}.


%prep
%autosetup -p1 -n %{dlname}-%{version}

%py_shebang_fix \
configure.py \
src/scripts/*.py \
src/python/*.py

%build
# we have the necessary prerequisites, so enable optional modules
%define enable_modules bzip2,zlib,boost,sqlite3,lzma,tpm

./configure.py \
        --distribution-info="%{_vendor} %{name} %{version}-%{release}" \
        --prefix=%{_prefix} \
        --libdir=%{_lib} \
        --docdir=%{_docdir} \
        --cc=gcc \
        --os=linux \
        --cpu=%{_arch} \
        --extra-cxxflags="%{build_cxxflags}" \
        --ldflags="%{build_ldflags}" \
        --enable-modules=%{enable_modules} \
        --with-python-versions=%{python3_version} \
        --with-sphinx \
        --enable-shared-library \
        --disable-static-library \
        --with-debug-info \
        --program-suffix=%{api} \
        --with-os-features=getrandom,getentropy

%make_build

%install
%make_install \
     INSTALL_CMD_EXEC="install -p -m 755" \
     INSTALL_CMD_DATA="install -p -m 644"

chmod 755 %{buildroot}%{python3_sitearch}/%{name}.py

mv %{buildroot}%{_mandir}/man1/botan.1 %{buildroot}%{_mandir}/man1/botan%{api}.1

find %{buildroot} -name '*.a' -delete

%check
%ifnarch %arm %ix86
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ./botan-test%{api}
%endif

%files
%license license.txt
%{_bindir}/botan%{api}
%{_mandir}/man1/botan%{api}.1.*

%files -n %{libname}
%license license.txt
%{_libdir}/libbotan-%{api}.so.%{major}{,.*}

%files -n %{devname}
%license license.txt
%{_includedir}/botan-%{api}/
%{_libdir}/libbotan-%{api}.so
%{_libdir}/pkgconfig/botan-%{api}.pc

%files doc
%license license.txt
%{_docdir}/botan-%{version}/

%files -n python3-%{name}
%license license.txt
%{python3_sitearch}/%{name}.py
%{python3_sitearch}/__pycache__/*
