%define major           0.8
%define libname         %mklibname brlapi %{major}
%define develname       %mklibname brlapi -d

# "fix" underlinking:
%define _disable_ld_no_undefined 1

%ifarch %arm %mips
%define build_java 0
%else
%define build_java 1
%endif

Name:           brltty
Version:        6.7
Release:        %mkrel 3
Summary:        Braille display driver for Linux/Unix
License:	LGPLv2+
Group:          Accessibility
URL:		https://brltty.app/
Source0:	https://brltty.app/archive/%{name}-%{version}.tar.xz
Source1: brltty.service
# Fedora patch
Patch1: brltty-6.3-loadLibrary.patch
# libspeechd.h moved in latest speech-dispatch (NOT sent upstream)
Patch2: brltty-6.3-libspeechd.patch
BuildRequires:  icu-devel
BuildRequires:  systemd-devel
BuildRequires:  bison
BuildRequires:  festival-devel
BuildRequires:  gpm-devel
BuildRequires:  libbraille-devel
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-findlib
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(setuptools)
BuildRequires:  speech_tools-devel
BuildRequires:  subversion
BuildRequires:  libespeak-devel
BuildRequires:  doxygen
BuildRequires:  python3-docutils

%description
BRLTTY is a background process (daemon) which provides
access to the Linux/Unix console (when in text mode)
for a blind person using a refreshable braille display.
It drives the braille display and provides complete
screen review functionality.
Some speech capability has also been incorporated.

%package -n %{libname}
Summary:    API for brltty
Group:      System/Libraries
License:    LGPLv2+

%description -n %{libname}
This package provides the run-time support for the Application
Programming Interface to BRLTTY.

Install this package if you have an application which directly accesses
a refreshable braille display.

%package -n %{develname}
Group:      Development/C
License:    LGPLv2+
Summary:    Headers, static archive, and documentation for BrlAPI
Provides:   brlapi-devel = %{version}-%{release}
Requires:   %{libname} = %{version}-%{release}

%description -n %{develname}
This package provides the header files, static archive, shared object
linker reference, and reference documentation for BrlAPI (the
Application Programming Interface to BRLTTY).  It enables the
implementation of applications which take direct advantage of a
refreshable braille display in order to present information in ways
which are more appropriate for blind users and/or to provide user
interfaces which are more specifically attuned to their needs.

Install this package if you are developing or maintaining an application
which directly accesses a refreshable braille display.

%package -n python3-brlapi
Summary:    Python 3 bindings for BrlAPI
Group:      Development/Python
%{?python_provide:%python_provide python3-brlapi}

%description -n python3-brlapi
This package provides the Python 3 binding for BrlAPI.

%if %{build_java}
%package -n brlapi-java
Group:      Development/Java
Summary:    Java binding for BrlAPI
BuildRequires:  java-devel

%description -n brlapi-java
This package provides the Java binding for BrlAPI.
%endif

%package -n ocaml-brlapi
Summary:    Ocaml bindings for BrlAPI
Group:      Development/OCaml
Obsoletes:  brlapi-ocaml < %{version}-%{release}

%description -n ocaml-brlapi
This package provides the OCaml binding for BrlAPI.

%package -n ocaml-brlapi-devel
Summary:    Development files for ocaml-brlapi
Group:      Development/OCaml
Requires:   ocaml-brlapi = %{version}-%{release}
Requires:   brlapi-devel

%description  -n ocaml-brlapi-devel
The ocaml-brlapi-devel package contains libraries and signature files for
developing applications that use ocaml-brlapi.

%package dracut
Summary:    brltty module for Dracut
Requires:   %{name}%{?_isa} = %{version}-%{release}
Requires:   dracut

%description dracut
This package provides brltty module for Dracut.

%prep
%autosetup -p1

# produce debuginfo for the OCaml interface
sed -i 's/@OCAMLC@/& -g/;s/@OCAMLOPT@/& -g/;s/@OCAMLMKLIB@/& -g/' \
    Bindings/OCaml/Makefile.in

%build
autoconf -v -f
# Add the openjdk include directories to CPPFLAGS
for i in -I/usr/lib/jvm/java/include{,/linux}; do
      java_inc="$java_inc $i"
done
export CPPFLAGS="$java_inc"

export LDFLAGS="%{?build_ldflags}"
export CFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"
export CXXFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"
export PYTHON=%{__python3}
%configure  CPPFLAGS="$java_inc" \
                --with-install-root="%{buildroot}" \
                --disable-relocatable-install \
                --disable-tcl-bindings \
                --disable-stripping

# Parallel build seems broken, thus disabling it
make

# documents
pushd Documents
# (tv) broken in 6.4:
#make
popd

%install
install -d -m 755 %{buildroot}%{_libdir}/ocaml/stublibs
# just to avoid an installation error
touch %{buildroot}%{_libdir}/ocaml/ld.conf
make install

# install polkit rules
pushd Authorization/Polkit
make install
popd

install -m644 Documents/%{name}.conf -D %{buildroot}%{_sysconfdir}/%{name}.conf
install -m644 Documents/%{name}.1 -D %{buildroot}%{_mandir}/man1/%{name}.1
rm -f %{buildroot}%{_libdir}/ocaml/ld.conf

%if %{build_java}
# Missing java library
install -d -m 755 %{buildroot}%{_libdir}/java/
cp Bindings/Java/*.so '%{buildroot}%{_libdir}/java/'
# for some reason 64-bit install libbrlapi_java.so in both lib and lib64
# So we'll remove it
%ifarch x86_64 aarch64
rm -rf %{buildroot}%{_prefix}/lib/java
%endif
%endif

# Missing ocaml library
cp Bindings/OCaml/*.a '%{buildroot}%{_libdir}/ocaml/brlapi/'
%ifnarch %mips
cp Bindings/OCaml/*.cmx '%{buildroot}%{_libdir}/ocaml/brlapi/'
%endif

install -Dpm 644 %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/brltty.service

directory="doc"
mkdir -p "${directory}"
for file in `find . \( -path "./${directory}" -o -path ./Documents \) -prune -o \( -name 'README*' -o -name '*.patch' -o -name '*.txt' -o -name '*
.html' -o -name '*.sgml' -o \( -path "./Bootdisks/*" -type f -perm +ugo=x \) \) -print`
do
   mkdir -p "${directory}/${file%/*}"
   cp -rp "${file}" "${directory}/${file}"
done

# handle locales
%find_lang %{name}
cp -p %{name}.lang ../

# install dracut module
make install-dracut

%post
%systemd_post brltty.service

%preun
%systemd_preun brltty.service

%postun
%systemd_postun_with_restart brltty.service

%files -f %{name}.lang
%doc README Documents/ChangeLog Documents/TODO
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_unitdir}/brltty.service
%{_bindir}/*
%{_sysconfdir}/%{name}
%{_sysconfdir}/X11/Xsession.d/90xbrlapi
%{_libdir}/%{name}
%{_libexecdir}/*
%{_mandir}/man1/*
%{_datadir}/gdm/greeter/autostart/xbrlapi.desktop
%{_datadir}/polkit-1/actions/org.a11y.brlapi.policy
%{_datadir}/polkit-1/rules.d/org.a11y.brlapi.rules

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/*.so
%{_libdir}/*.a
%{_includedir}/brlapi.h
%{_includedir}/brlapi_*.h
%{_includedir}/brltty
%{_libdir}/pkgconfig/brltty.pc
%{_mandir}/man3/*

%if %{build_java}
%files -n brlapi-java
%{_libdir}/java/libbrlapi_java.so
%{_datadir}/java/brlapi.jar
%endif

%files -n python3-brlapi
%{python3_sitearch}/*

%files -n ocaml-brlapi
%dir %{_libdir}/ocaml/brlapi
%{_libdir}/ocaml/brlapi/META
%{_libdir}/ocaml/brlapi/*.cma
%{_libdir}/ocaml/brlapi/*.cmi
%{_libdir}/ocaml/stublibs/*.so*

%files -n ocaml-brlapi-devel
%{_libdir}/ocaml/brlapi/*.a
%ifnarch %mips
%{_libdir}/ocaml/brlapi/*.cmxa
%{_libdir}/ocaml/brlapi/*.cmx
%endif
%{_libdir}/ocaml/brlapi/*.mli

%files dracut
%{_prefix}/lib/dracut/modules.d/99brltty/
%dir %{_sysconfdir}/brltty/Initramfs
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/dracut.conf
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/cmdline
