# Missing dependencies for tests
%bcond_with check

# Missing dependencies for documentation
%bcond_without doc

Name:           buildbot
Version:        4.2.1
Release:        %mkrel 1
Summary:        Build/test automation system
Group:          Development/Python
License:        GPLv2+
URL:            https://buildbot.net/

Source0:        %{pypi_source buildbot}
Source1:        %{pypi_source buildbot_worker}
Source2:        %{pypi_source buildbot_www}
Source3:        %{pypi_source buildbot_waterfall_view}
Source4:        %{pypi_source buildbot_grid_view}
Source5:        %{pypi_source buildbot_console_view}
# Build-time only component for buildbot
Source6:        %{pypi_source buildbot_pkg}
# Patch0:	        buildbot-req.patch
# Patch1:	        fix-build.patch
# Patch2:	        fix-buildbot-docs.patch
BuildArch:      noarch
# For making the build work from source

BuildRequires:  python3-devel
BuildRequires:  python3dist(setuptools)

%if %{with docs}
BuildRequires:  python3dist(sphinx) >= 1.4
BuildRequires:  python3dist(sphinxcontrib-blockdiag)
BuildRequires:  python3dist(sphinxcontrib-spelling)
BuildRequires:  python3dist(pyenchant)
BuildRequires:  (python3dist(docutils) >= 0.8 with python3dist(docutils) < 0.13)
BuildRequires:  python3dist(sphinx-jinja)
BuildRequires:  python3dist(towncrier)
%endif

Requires:       %{name}-master >= %{version}
Requires:       python3dist(automat) >= 20.2


%description
The BuildBot is a system to automate the compile/test cycle required by
most software projects to validate code changes. By automatically
rebuilding and testing the tree each time something has changed, build
problems are pinpointed quickly, before other developers are
inconvenienced by the failure.

%package        master
Summary:        buildbot master
Group:          Development/Python
Requires:       python3-boto
Recommends:       %{name}-doc

%description    master
The BuildBot is a system to automate the compile/test cycle required by
most software projects to validate code changes. By automatically
rebuilding and testing the tree each time something has changed, build
problems are pinpointed quickly, before other developers are
inconvenienced by the failure.
This package contains only the buildmaster implementation.

%package worker
Summary:        Build/test automation system
Obsoletes:      %{name}-slave < 0.9.0
Provides:       %{name}-slave = %{version}-%{release}

%if ! %{with docs}
Obsoletes:      %{name}-doc < %{version}-%{release}
%endif

%description worker
This package contains only the buildworker implementation.
The buildbot-master package contains the buildmaster.

%package www
Summary:        Build/test automation system

# Script to get bundled js
# cat \
# ./www/codeparameter/package.json \
# ./www/console_view/package.json \
# ./www/base/package.json \
# ./www/waterfall_view/package.json \
# ./www/data_module/package.json \
# ./www/grid_view/package.json \
# | jq '.dependencies' | sed 's/[{}, ]//g' | sort -u

Provides:        bundled(guanlecoja) = 0.8.0
Provides:        bundled(guanlecoja) = 0.8.3
Provides:        bundled(gulp) = 3.9.0
Provides:        bundled(gulp) = 3.9.1
Provides:        bundled(gulp-shell) = 0.4.1
Provides:        bundled(http-proxy) = 1.11.1
Provides:        bundled(minimist) = 1.1.1
Provides:        bundled(shelljs) = 0.5.3

%description www
Provides web frontend for buildbot.



%package        doc
Group:          Development/Python
License:        GPLv2+
Summary:        BuildBot documentation

%description    doc
Buildbot documentation.

%prep
%setup -q -b0 -b1 -b2 -b3 -b4 -b4 -b5 -b6

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if %{with docs}
pushd docs
make docs.tgz VERSION="%{version}" SPHINXBUILD=sphinx-build-3
popd
%endif

pushd ../%{name}_worker-%{version}
%pyproject_wheel
popd

# For buildbot_pkg build-time module to set version correctly
export BUILDBOT_VERSION=%{version}

# So that other modules can use buildbot-pkg import
export PYTHONPATH=%{_builddir}/%{name}-%{version}/build/lib:%{_builddir}/%{name}_pkg-%{version}/build/lib

bbweb_components=(pkg www waterfall_view grid_view console_view)

for bbweb_component in ${bbweb_components[@]}; do
	pushd ../%{name}_${bbweb_component}-%{version}
	sed -e "s/^    setup_requires=.*$//" -i setup.py
	%pyproject_wheel
	popd
done

%install
%pyproject_install

mkdir -p %{buildroot}%{_datadir}/%{name}/ \
         %{buildroot}%{_mandir}/man1/ \
         %{buildroot}%{_docdir}/%{name}-%{version}

# For buildbot_pkg build-time module to set version correctly
export BUILDBOT_VERSION=%{version}

# So that other modules can use buildbot-pkg import
export PYTHONPATH=%{_builddir}/%{name}-%{version}/build/lib:%{_builddir}/%{name}_pkg-%{version}/build/lib

bbweb_components=(www waterfall_view grid_view console_view)

for bbweb_component in ${bbweb_components[@]}; do
	pushd ../%{name}_${bbweb_component}-%{version}
	%pyproject_install
	popd
done

install -Dpm0644 -t %{buildroot}%{_mandir}/man1 docs/buildbot.1

%if %{with docs}
mkdir -p %{buildroot}%{_pkgdocdir}
tar xf docs/docs.tgz --strip-components=1 -C %{buildroot}%{_pkgdocdir}
%endif

# install worker files
pushd ../%{name}_worker-%{version}
%pyproject_install
install -Dpm0644 -t %{buildroot}%{_mandir}/man1 docs/buildbot-worker.1
popd

# Purge windows-only files
rm -vf %{buildroot}%{_bindir}/*windows*

%if %{with check}
%check
trial buildbot.test
%endif

%files

%files          master
%doc %{_mandir}/man1/buildbot.1*
%doc COPYING CREDITS NEWS UPGRADING
%{_bindir}/buildbot
%{python3_sitelib}/buildbot/
%{python3_sitelib}/buildbot_pkg.py
%{_datadir}/%{name}/
%{python3_sitelib}/buildbot-*dist-info/
%{python3_sitelib}/buildbot_pkg-*.dist-info/
%{python3_sitelib}/__pycache__/buildbot_pkg*

%files worker
%doc NEWS UPGRADING
%license COPYING
%{_bindir}/buildbot-worker
%{_mandir}/man1/buildbot-worker.1*
%{python3_sitelib}/buildbot_worker/
%{python3_sitelib}/buildbot_worker-*dist-info/

%files www
%license COPYING
%{python3_sitelib}/buildbot_www/
%{python3_sitelib}/buildbot_www-*.dist-info/
%{python3_sitelib}/buildbot_waterfall_view/
%{python3_sitelib}/buildbot_waterfall_view-*dist-info/
%{python3_sitelib}/buildbot_grid_view/
%{python3_sitelib}/buildbot_grid_view-*dist-info/
%{python3_sitelib}/buildbot_console_view/
%{python3_sitelib}/buildbot_console_view-*dist-info/

%if %{with docs}
%files          doc
%{_docdir}/%{name}-%{version}
%endif
