%bcond_with   		uclibc
%define Werror_cflags	%{nil}
%define _ssp_cflags	%{nil}

Summary:	Multi-call binary combining many common Unix tools into one executable
Name:		busybox
Epoch:		1
# stick to stable releases, usually minor number is even
Version:	1.37.0
Release:	%mkrel 1
License:	GPLv2
Group:		Shells
URL:		https://www.busybox.net/
Source0:	https://www.busybox.net/downloads/%{name}-%{version}.tar.bz2
Source1:	https://www.busybox.net/downloads/%{name}-%{version}.tar.bz2.sig
Patch0:		busybox-1.31.1-stime-fix.patch
Source2:	busybox-1.15.2-config
Source3:	busybox-1.17.2-minimal-config
Patch1:		busybox-i.15.2-no-march_i386.patch
# sha1_process_block64_shaNI is only valid on x86
# most of the calls are wrapped in an arch conditional, but they missed one.
Patch2:		busybox-1.37.0-fix-conditional-for-sha1_process_block64_shaNI.patch 
Patch12:	busybox-1.2.2-ls.patch
Patch17:	busybox-1.26.2-use-Os.diff
Patch19:	busybox-1.27.2-CVE-2014-9645.patch
Patch23:	busybox-1.24.2-CVE-2016-6301.patch
# Patches from Alpine Linux for CVE-2022-28391
Patch100:       https://git.alpinelinux.org/aports/plain/main/busybox/0001-libbb-sockaddr2str-ensure-only-printable-characters-.patch
Patch101:       https://git.alpinelinux.org/aports/plain/main/busybox/0002-nslookup-sanitize-all-printed-strings-with-printable.patch

BuildRequires:	gcc
BuildRequires:	pkgconfig(libtirpc)
%if %{with uclibc}
BuildRequires:	uClibc-static-devel >= 0.9.30.3-3
%define __cc	%{uclibc_cc}
%define	cflags	%{uclibc_cflags}
%else
BuildRequires:	glibc-static-devel
%define	cflags	%{optflags}
%endif
BuildRequires:	kernel-userspace-headers

%description
BusyBox combines tiny versions of many common UNIX utilities into a
single small executable. It provides minimalist replacements for most
of the utilities you usually find in GNU coreutils, shellutils, etc.
The utilities in BusyBox generally have fewer options than their
full-featured GNU cousins; however, the options that are included provide
the expected functionality and behave very much like their GNU counterparts.
BusyBox provides a fairly complete POSIX environment for any small or
embedded system.

BusyBox has been written with size-optimization and limited resources in
mind. It is also extremely modular so you can easily include or exclude
commands (or features) at compile time. This makes it easy to customize
your embedded systems. To create a working system, just add /dev, /etc,
and a kernel.

%package	static
Group:		Shells
Summary:	Static linked busybox

%description	static
This package contains a static linked busybox.

%prep
%setup -q
%patch -P 0 -p1 -b .stime
%patch -P 1 -b .no_march~ -p1
%patch -P 2 -p1 -b .shani-fix
%patch -P 12 -b .ls~ -p1
%patch -P 17 -b .Os~ -p1
%patch -P 19 -p1 -b .modprobe
%patch -P 23 -p1 -b .ntpd-dos
%patch -P 100 -p1
%patch -P 101 -p1

%build
cat %{SOURCE2} |sed \
	-e 's|^.*CONFIG_EXTRA_CFLAGS.*$|CONFIG_EXTRA_CFLAGS="%{cflags} -fno-strict-aliasing"|g' \
	> .config
yes "" | %make_build oldconfig V=1
%make_build CC=%{__cc} LDFLAGS="%{ldflags}" V=1
mv busybox_unstripped busybox.full.static
sed -i "s|^.*CONFIG_EXTRA_CFLAGS=\"|CONFIG_EXTRA_CFLAGS=\"$(pkg-config  libtirpc --cflags)|g" .config
%make_build CC=%{__cc} LDFLAGS="%{ldflags} $(shell pkg-config  libtirpc --cflags)" V=1 CONFIG_STATIC=n
mv busybox_unstripped busybox.full


%if %{with uclibc}
cat %{SOURCE3} |sed \
	-e 's|^.*CONFIG_EXTRA_CFLAGS.*$|CONFIG_EXTRA_CFLAGS="%{cflags} -fno-strict-aliasing"|g' \
	> .config
yes "" | %make_build oldconfig V=1
%make_build CC=%{__cc} LDFLAGS="%{ldflags}" V=1
mv busybox_unstripped busybox.minimal.static
%make_build CC=%{__cc} LDFLAGS="%{ldflags}" V=1 CONFIG_STATIC=n
mv busybox_unstripped busybox.minimal
%endif

%check
# FIXME
%if 0
%make_build CC=%{__cc} V=1 check
%endif

%install
install -m755 busybox.full -D %{buildroot}%{_bindir}/busybox
install -m755 busybox.full.static -D %{buildroot}/bin/busybox.static
%if %{with uclibc}
install -m755 busybox.minimal -D %{buildroot}%{uclibc_root}%{_bindir}/busybox.minimal
install -m755 busybox.minimal.static -D %{buildroot}%{uclibc_root}/bin/busybox.minimal.static
%endif

%files
%doc AUTHORS README TODO
%{_bindir}/busybox
%if %{with uclibc}
%{uclibc_root}%{_bindir}/busybox.minimal
%endif

%files static
%doc AUTHORS README TODO
/bin/busybox.static
%if %{with uclibc}
%{uclibc_root}/bin/busybox.minimal.static
%endif
