#
# Please do not update/rebuild/touch this package before asking first
# neoclust and/or daviddavid
# This package is part of the KDE Stack.
#

%bcond_without analitza
%ifarch aarch64 x86_64
%bcond_without embedded_documentation
%else
%bcond_with embedded_documentation
%endif

%define rel 1

Name:           cantor
Version: 25.04.0
Release:        %mkrel %{rel}
Summary:        KDE Interface for doing Mathematics and Scientific Computing
Group:          Sciences/Mathematics
License:        GPLv2
URL:            https://apps.kde.org/cantor/
Source:         https://download.kde.org/stable/release-service/%version/src/%{name}-%version.tar.xz

# Branch patches 100->200
# Trunk patches 200->300

# Mageia patches 500->600

BuildRequires:  kf6-rpm-macros

BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Help)
%if %{with embedded_documentation}
BuildRequires:  cmake(Qt6WebEngineCore)
BuildRequires:  cmake(Qt6WebEngineWidgets)
%endif

BuildRequires:  cmake(KF6Config)
BuildRequires:  cmake(KF6Crash)
BuildRequires:  cmake(KF6Completion)
BuildRequires:  cmake(KF6DocTools)
BuildRequires:  cmake(KF6NewStuffCore)
BuildRequires:  cmake(KF6NewStuff)
BuildRequires:  cmake(KF6IconThemes)
BuildRequires:  cmake(KF6TextEditor)
BuildRequires:  cmake(KF6CoreAddons)
BuildRequires:  cmake(KF6Archive)
BuildRequires:  cmake(KF6Parts)
BuildRequires:  cmake(KF6SyntaxHighlighting)
BuildRequires:  cmake(KF6TextWidgets)
BuildRequires:  cmake(KF6KIO)
BuildRequires:  cmake(KF6XmlGui)
BuildRequires:  cmake(KF6I18n)

%if %{with analitza}
BuildRequires:  cmake(Analitza6)
%endif

BuildRequires:  pkgconfig(poppler-qt6)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libR)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(libqalculate)
BuildRequires:  pkgconfig(luajit)

Recommends:     cantor-handbook
# The only example downloadable through the GUI uses the octave engine
Recommends:     octave


%description
Cantor is a KDE Application aimed to provide a nice interface
for doing Mathematics and Scientific Computing. It doesn't implement
its own Computation Logic, but instead is built around different
Backends.

%files -f %name.lang
%_kf6_bindir/cantor
%_kf6_bindir/cantor_rserver
%_kf6_bindir/cantor_pythonserver
%_kf6_bindir/cantor_scripteditor
%_kf6_libdir/libcantor_config.so
%_kf6_libdir/cantor_pythonbackend.so
%_kf6_datadir/cantor/
%_kf6_datadir/config.kcfg/cantor.kcfg
%_kf6_datadir/config.kcfg/cantor_libs.kcfg
%if %{with analitza}
%_kf6_datadir/config.kcfg/kalgebrabackend.kcfg
%endif
%_kf6_datadir/config.kcfg/luabackend.kcfg
%_kf6_datadir/config.kcfg/maximabackend.kcfg
%_kf6_datadir/config.kcfg/pythonbackend.kcfg
%_kf6_datadir/config.kcfg/qalculatebackend.kcfg
%_kf6_datadir/config.kcfg/rserver.kcfg
%_kf6_datadir/config.kcfg/sagebackend.kcfg
%_kf6_datadir/config.kcfg/scilabbackend.kcfg
%dir %_qt6_plugindir/cantor_plugins
%_qt6_plugindir/cantor_plugins/assistants
%_qt6_plugindir/cantor_plugins/backends
%_qt6_plugindir/cantor_plugins/panels
%_kf6_plugindir/parts/cantorpart.so
%_kf6_iconsdir/*/*/*/*.png
%_kf6_datadir/knsrcfiles/*.knsrc
%_kf6_datadir/mime/packages/cantor.xml
%_kf6_metainfodir/org.kde.cantor.appdata.xml
%_kf6_applicationsdir/org.kde.cantor.desktop
%_kf6_datadir/config.kcfg/octavebackend.kcfg.in

#------------------------------------------------------------------------------

%package        handbook
Summary:        Cantor Handbook
Group:          Documentation
BuildArch:      noarch

%description    handbook
This package provides Cantor handbook.

%files handbook
%doc README.md
%docdir %_kf6_docdir/HTML/
%_kf6_docdir/HTML/*/cantor

#------------------------------------------------------------------------------

%define cantorlibs_major 28
%define libcantorlibs %mklibname cantorlibs %{cantorlibs_major}

%package -n     %libcantorlibs
Summary:        Runtime library for cantor
Group:          System/Libraries

%description -n %libcantorlibs
Runtime library for cantor.

%files -n %libcantorlibs
%_kf6_libdir/libcantorlibs.so.%{cantorlibs_major}{,.*}
%_kf6_libdir/libcantorlibs.so.%{version}

#------------------------------------------------------------------------------

%define cantor_devel %mklibname %{name} -d

%package -n %{cantor_devel}
Summary:        Devel stuff for %{name}
Group:          Development/KDE and Qt
Requires:       %libcantorlibs = %version-%release
Provides:       %{name}-devel = %version-%release

%description -n %{cantor_devel}
Files needed to build applications based on %{name}.

%files -n %{cantor_devel}
%_includedir/%{name}/
%_kf6_libdir/libcantorlibs.so
%_kf6_libdir/cmake/Cantor/

#------------------------------------------------------------------------------

%prep
%autosetup -p1

%build
%cmake_kf6 %{!?with_embedded_documentation:-DENABLE_EMBEDDED_DOCUMENTATION=OFF}
%cmake_build

%install
%cmake_install
%find_lang %name
