# Please keep this package in sync with FC

%global major   5
%define libname %mklibname capstone %major
%define devname %mklibname capstone -d

Name:           capstone
Version:        5.0.6
Release:        %mkrel 1
Summary:        A lightweight multi-platform, multi-architecture disassembly framework
License:        BSD-3-Clause AND BSD-4-Clause AND APSL-2.0 AND NCSA AND MIT
URL:            https://www.capstone-engine.org/
VCS:            https://github.com/capstone-engine/capstone/
#               https://github.com/capstone-engine/capstone/releases

%global         common_desc %{expand:
Capstone is a disassembly framework with the target of becoming the ultimate
disasm engine for binary analysis and reversing in the security community.}


%define _lto_cflags %{nil}

Group:          System/Libraries

%global         gituser         capstone-engine
%global         gitname         capstone
# 5.0.1 release
%global         gitdate         20230823
%global         commit          097c04d9413c59a58b00d4d1c8d5dc0ac158ffaa
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

#               https://github.com/capstone-engine/capstone/releases
Source0:        https://github.com/capstone-engine/capstone/releases/download/%{version}/%{name}-%{version}.tar.xz

# Manpage for cstool is missing in the package, add one generated by help2man
Source1:        cstool.1

# Ocaml binding is not using local path for the includes/links
Patch1:         capstone-5.0.1-ocaml.patch


# Build with python3 package by default
%bcond_without  python3

# Build with java binding
%bcond_without  java

# Build without ocaml binding - it is not ready to be distributed as ocaml shared library
%bcond_with  ocaml



%global srcname distribute

BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  git

%if %{with java}
BuildRequires:  jna
BuildRequires:  java-devel
%endif

%if %{with python3}
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  python3-pytest
%endif

%if %{with ocaml}
BuildRequires:  ocaml
BuildRequires:  ocaml-ocamlbuild
%endif

%description
%{common_desc}

%package        -n %libname
Summary:        A lightweight multi-platform, multi-architecture disassembly framework
Group:          System/Libraries
Obsoletes:      %{_lib}capstone0 < 3.0.4-3

%description    -n %libname
Library for Capstone.
%{common_desc}

%package        -n %devname
Summary:        Development files for %{name}
Group:		Development/Other
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Provides:	capstone-devel = %{version}-%{release}

%description    -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with python3}
%package	-n python3-capstone
#BuildArch:      noarch
Summary:	Python3 bindings for %{name}
Group:		Development/Python
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description	-n python3-capstone
%{common_desc}
The python3-%{name} package contains python3 bindings for %{name}.
%endif


%if %{with java}
%package        java
Summary:        Java bindings for %{name}
Group:          Development/Java
Requires:       %{name} >= %{version}-%{release}
BuildArch:      noarch

%description    java
%{common_desc}
The %{name}-java package contains java bindings for %{name}.
%endif

%if %{with ocaml}
%package        -n ocaml-%{name}
Summary:        OCaml bindings for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    -n ocaml-%{name}
%{common_desc}
The ocaml-%{name} package contains OCaml bindings for %{name}.
%endif


%prep
%autosetup -n %{gitname}-%{version} -p1

%if %{with python3}
pushd bindings/python
%pyproject_buildrequires
popd
%endif


%build
V=1 CFLAGS="%{optflags}" \
PREFIX="%{_prefix}" LIBDIRARCH="%{_lib}" INCDIR="%{_includedir}" \
%make_build PYTHON3=%{__python3}

# Fix pkgconfig file
grep -v archive capstone.pc > capstone.pc.tmp
mv capstone.pc.tmp capstone.pc

# build python bindings
%if %{with python3}
pushd bindings/python
%pyproject_wheel
%endif
popd

%if %{with java}
# build java bindings needs some python runtime
pushd bindings/java
%make_build PYTHON2=%{__python3} CFLAGS="%{optflags}" # %{?_smp_mflags} parallel seems broken
popd
%endif

%if %{with ocaml}
pushd bindings/ocaml
# build ocaml bindings needs some python runtime
%if %{with python3}
%make_build PYTHON2=%{__python3} CFLAGS="%{optflags}" -j1 # %{?_smp_mflags} parallel seems broken
%else
%make_build PYTHON2=%{__python2} PYTHON3=%{__python2} CFLAGS="%{optflags}" -j1 # %{?_smp_mflags} parallel seems broken
%endif
popd
%endif

%install
DESTDIR=%{buildroot} PREFIX="%{_prefix}" LIBDIRARCH=%{_lib} \
INCDIR="%{_includedir}" make install

# cleanup static libraries
find %{buildroot} -name '*.la' -delete
find %{buildroot} -name '*.a' -delete

# add the manpage
install -d -D %{buildroot}%{_mandir}/man1
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_mandir}/man1/

# install python bindings
%if %{with python3}
pushd bindings/python
%pyproject_install
%pyproject_save_files capstone
%endif
popd

%if %{with java}
# install java bindings
install -D -p -m 0644 bindings/java/%{name}.jar  %{buildroot}%{_javadir}/%{name}.jar
%endif

%if %{with ocaml}
# install ocaml binding
%endif

%check
# ln -s libcapstone.so.5 libcapstone.so
make check LD_LIBRARY_PATH="`pwd`"

%if %{with python3}
pushd bindings/python
#pytest -sv -k "not testcb and not test_cs_disasm_quick"
popd
%endif

%if %{with ocaml}
pushd bindings/ocaml
make check LD_LIBRARY_PATH="`pwd`"
popd
%endif

%files
%license LICENSE.TXT LICENSE_LLVM.TXT
%doc CREDITS.TXT ChangeLog README.md SPONSORS.TXT
%{_bindir}/cstool
%{_mandir}/man1/cstool.1*

%files -n %libname
%{_libdir}/*.so.%{major}{,.*}

%files -n %devname
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*


%if %{with python3}
%files -n python3-capstone -f %{pyproject_files}
%exclude %{python3_sitelib}/capstone/include/
%exclude %{python3_sitelib}/capstone/lib/
%endif


%if %{with java}
%files java
%{_javadir}/
%endif


%if %{with ocaml}
%files -n ocaml-%{name}
%endif


