# Dont provide or require internal libs. Using new rpm builtin filtering
%global _privatelibs libjack[.]so.*
%global __provides_exclude ^(%{_privatelibs})$
%global __requires_exclude ^(%{_privatelibs})$

%define git_date       20241124
%define carla_commit   17000e7fe99459b25a50094a8b00bdfa12f2bfbc
# External Carla-Plugins
%define plugins_commit 7e6c2206f0e2ba65a996e67e98c005af1412684c

Name:           carla
Version:        2.6.0
Release:        %mkrel 0.git%{git_date}.2
Summary:        An audio plugin host
License:        GPLv2+
Group:          Sound/Utilities
Url:            https://kxstudio.linuxaudio.org/Applications:Carla

Source0:        https://github.com/falkTX/Carla/archive/%{carla_commit}/Carla-%{carla_commit}.tar.gz
Source1:        https://github.com/falkTX/Carla-Plugins/archive/%{plugins_commit}.tar.gz
Patch0:         0001-Use-system-flac-vorbis-ogg.patch
Patch1:         0002-Remove-rpath-from-.pc-files.patch
Patch2:         0003-Use-correct-plugin-paths-for-openSUSE.patch
Patch3:         Carla-single-libs-path.patch

BuildRequires:  file
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(pkg-config)

# for extra native plugins
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gig)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(ntk)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(pyliblo3)
BuildRequires:  python3dist(rdflib)
BuildRequires:  python3-qt6-devel
# for extra samplers support
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gl)
# for plugin GUIs
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)

Requires:       python3dist(pyliblo3)
Requires:       python3-rdflib
Requires:       python3-qt6-core
Requires:       python3-qt6-gui
Requires:       python3-qt6-widgets
Requires:       python3-qt6-svg
Requires:       python3-qt6-svgwidgets

%description
Carla is an audio plugin host, with support for many audio drivers
and plugin formats. It features automation of parameters via MIDI CC
and full OSC control. It currently supports LADSPA, DSSI, LV2, VST2/3
and AU plugin formats, plus GIG, SF2 and SFZ sounds banks.
It further supports bridging Window plugins using Wine.

%files
%doc README.md doc
%{_sysconfdir}/ld.so.conf.d/carla.conf
%{_bindir}/carla
%{_bindir}/carla-control
%{_bindir}/carla-database
%{_bindir}/carla-jack-multi
%{_bindir}/carla-jack-patchbayplugin
%{_bindir}/carla-jack-single
%{_bindir}/carla-osc-gui
%{_bindir}/carla-patchbay
%{_bindir}/carla-rack
%{_bindir}/carla-settings
%{_bindir}/carla-single
%{_libdir}/carla/
%{_libdir}/lv2/carla.lv2/
%{_datadir}/carla/
%{_datadir}/applications/carla.desktop
%{_datadir}/applications/carla-control.desktop
%{_datadir}/applications/carla-jack-multi.desktop
%{_datadir}/applications/carla-jack-single.desktop
%{_datadir}/applications/carla-patchbay.desktop
%{_datadir}/applications/carla-rack.desktop
%{_datadir}/icons/hicolor/*/apps/carla*.*
%{_datadir}/mime/packages/carla.xml
%{_metainfodir}/studio.kx.carla.appdata.xml

#--------------------------------------------------------------------

%package devel
Summary:        Header files to access Carla's API
Group:          Development/C++
Requires:       carla = %{version}-%{release}

%description devel
This package contains header files needed when writing software using
Carla's several APIs.

%files devel
%{_includedir}/carla/
%{_libdir}/pkgconfig/carla-host-plugin.pc
%{_libdir}/pkgconfig/carla-native-plugin.pc
%{_libdir}/pkgconfig/carla-standalone.pc
%{_libdir}/pkgconfig/carla-utils.pc

#--------------------------------------------------------------------

%package vst
Summary:        CarlaRack and CarlaPatchbay VST plugins
Group:          Sound/Utilities
Requires:       carla = %{version}-%{release}

%description vst
This package contains Carla VST plugins, including CarlaPatchbayFX,
CarlaPatchbay, CarlaRackFX, and CarlaRack.

%files vst
%{_libdir}/vst/

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n Carla-%{carla_commit} -a1

# External Carla-Plugins
mv Carla-Plugins-%{plugins_commit}/* source/native-plugins/external/
rm -r Carla-Plugins-%{plugins_commit}

# remove windows stuff
rm -rf data/{macos,windows}

# E: wrong-script-interpreter /usr/lib64/python3/dist-packages/carla_backend.py /usr/bin/env python3
find . -type f \( -name "*.py" \) -exec sed -i "s|#!/usr/bin/env python3|#!%{__python3}|g" {} \;
sed -i "s|#!/usr/bin/env python3|#!%{__python3}|" source/frontend/{carla,carla-control,carla-jack-multi,carla-jack-single,carla-patchbay,carla-rack}
sed -i "s|#!/usr/bin/env python|#!%{__python3}|" source/frontend/widgets/paramspinbox.py

# fix libdir path
sed -i "s|/lib/carla|/%{_lib}/carla|" \
  data/{carla,carla-control,carla-database,carla-jack-multi,carla-jack-patchbayplugin,carla-jack-single,carla-patchbay,carla-rack,carla-settings} \
  source/backend/engine/CarlaEngineJack.cpp

# Fix metainfo install dir
sed -i -e 's|$(DESTDIR)$(PREFIX)/share/appdata/studio.kx.carla.appdata.xml|$(DESTDIR)$(PREFIX)/share/metainfo/studio.kx.carla.appdata.xml|g' Makefile
sed -i -e 's|$(DESTDIR)$(PREFIX)/share/appdata|$(DESTDIR)$(PREFIX)/share/metainfo|g' Makefile

# Fix for 32bit system
sed -i 's|/usr/lib64|%{_libdir}|' source/frontend/carla_widgets.py

%build
%set_build_flags
export EXTERNAL_PLUGINS=true
make features
%make_build SKIP_STRIPPING=true NOOPT=true

%install
%make_install  -- PREFIX="%{_prefix}" LIBDIR="%{_libdir}"

# Create a vst directory
install -m 755 -d %{buildroot}%{_libdir}/vst/

# E: non-executable-script /usr/share/carla/paramspinbox.py 644 /usr/bin/env python
find %{buildroot} -type f \( -name "*.py" \) -exec chmod a+x {} \;

# E: non-executable-script /usr/share/carla/carla 644 /usr/bin/python3
chmod a+x %{buildroot}%{_datadir}/carla/{carla,carla-control,carla-jack-multi,carla-jack-single,carla-patchbay,carla-rack}

# fix perm due rpmlint W: unstripped-binary-or-object /usr/lib64/carla/libcarla_interposer-jack-x11.so
find %{buildroot}%{_libdir} -name '*.so' -exec chmod +x '{}' ';'

# make sure carla plugins are found
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/carla > %{buildroot}%{_sysconfdir}/ld.so.conf.d/carla.conf
