%define basen     cddlib
%define major     0
%define libname   %mklibname %{basen} %{major}
%define develname %mklibname %{basen} -d

Name:           cddlib
Version:        0.94m
Release:        %mkrel 2
Summary:        A library for generating all vertices in convex polyhedrons
Group:          Development/C
License:        GPLv2+
URL:            https://www.inf.ethz.ch/personal/fukudak/cdd_home/
Source0:        https://github.com/cddlib/cddlib/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  gmp-devel
BuildRequires:  texlive-texmf

%description
The C-library cddlib is a C implementation of the Double Description
Method of Motzkin et al. for generating all vertices (i.e. extreme points)
and extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities:

   P = { x=(x1, ..., xd)^T :  b - A  x  >= 0 }

where A is a given m x d real matrix, b is a given m-vector
and 0 is the m-vector of all zeros.

The program can be used for the reverse operation (i.e. convex hull
computation). This means that one can move back and forth between
an inequality representation and a generator (i.e. vertex and ray)
representation of a polyhedron with cdd. Also, cdd can solve a linear
programming problem, i.e. a problem of maximizing and minimizing
a linear function over P.

%package -n %{libname}
Summary:        cddlib libraries

%description -n %{libname}
The C-library cddlib is a C implementation of the Double Description
Method of Motzkin et al. for generating all vertices (i.e. extreme points)
and extreme rays of a general convex polyhedron in R^d given by a system
of linear inequalities:

   P = { x=(x1, ..., xd)^T :  b - A  x  >= 0 }

where A is a given m x d real matrix, b is a given m-vector
and 0 is the m-vector of all zeros.

The program can be used for the reverse operation (i.e. convex hull
computation). This means that one can move back and forth between
an inequality representation and a generator (i.e. vertex and ray)
representation of a polyhedron with cdd. Also, cdd can solve a linear
programming problem, i.e. a problem of maximizing and minimizing
a linear function over P.

%package -n %{develname}
Summary:        Headers for cddlib
Requires:       gmp-devel
Requires:       %{libname} = %{version}-%{release}
Provides:       %{basen}-devel = %{version}-%{release}


%description -n %{develname}
Include files for cddlib.


%package static
Summary:        Static libraries for cddlib

%description static
Static libraries for cddlib.


%package tools
Summary:        Sample binaries that use cddlib
Requires:       %{libname} = %{version}-%{release}

%description tools
Sample binaries that use cddlib.


%prep
%autosetup

# Fix the FSF's address
for f in `find . -type f -print0 | xargs -0 grep -Fl '675 Mass'`; do
  sed -i.orig \
    's/675 Mass Ave, Cambridge, MA 02139/51 Franklin Street, Suite 500, Boston, MA  02110-1335/' \
    $f
  touch -r $f.orig $f
  rm -f $f.orig
done

# Force rebuilding of the documentation
rm -f doc/cddlibman.pdf


%build
%configure

# Get rid of undesirable hardcoded rpaths; workaround libtool reordering
# -Wl,--as-needed after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' \
    -i libtool

%make_build

# Need one more invocation of pdflatex to get cross references correct
pushd doc
pdflatex cddlibman
popd


%install
%make_install
rm -f %{buildroot}%{_libdir}/*.la

# Do not prematurely install documentation
rm -fr %{buildroot}%{_pkgdocdir}


%files -n %{libname}
%doc AUTHORS ChangeLog
%license COPYING
%{_libdir}/libcdd.so.%{major}{,.*}
%{_libdir}/libcddgmp.so.%{major}{,.*}


%files -n %{develname}
%doc doc/cddlibman.pdf examples*
%{_includedir}/cddlib
%{_libdir}/libcdd.so
%{_libdir}/libcddgmp.so
%{_libdir}/pkgconfig/%{name}.pc


%files static
%{_libdir}/libcdd.a
%{_libdir}/libcddgmp.a


%files tools
%{_bindir}/*

