%bcond_without spice

%global _disable_ld_no_undefined 1

%if %{with spice}
%define spice_mode enabled
%else
%define spice_mode disabled
%endif


%define commit f2fb5a2019c6df1d221c7407a9d7fa8731fd6a4e
%define datacommit d20a4500410af19bd508eba567c9220890e9e316
%define gitrel  %(c=%{commit}; echo ${c:0:7})
%define gitdatarel %(c=%{datacommit}; echo ${c:0:7})
%define spicerel 711ffdb
%define date 20250103

%define rel	2

Summary:	A real-time visual space simulation
Name:		celestia
Version:	1.7.0
Release:	%mkrel -c %{date}git.%{gitrel} %{rel}
License:	GPLv2+
Group:		Sciences/Astronomy
URL:		https://celestia.space/
Source0:	https://api.github.com/repos/CelestiaProject/Celestia/tarball/%{gitrel}#/celestia-1.7.0-git.%{date}.%{gitrel}.tar.gz
Source1:	%{name}.desktop
Source2:	https://api.github.com/repos/CelestiaProject/CelestiaContent/tarball/%{gitdatarel}#/celestia-data-1.7.0-git.%{date}.%{gitdatarel}.tar.gz
%if %{with spice}
Source10:	https://api.github.com/repos/OpenSpace/Spice/tarball/%{spicerel}#/cspice-%{spicerel}.tar.gz
%endif
Source11:	celestia.cfg

BuildRequires:	cmake
BuildRequires:	gettext-devel
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6OpenGLWidgets)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(gconf-2.0)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(lua) >= 5.3
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(epoxy)
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(fmt)
BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(libavif)
BuildRequires:	desktop-file-utils
BuildRequires:	libstdc++-static-devel
BuildRequires:	luajit-devel
BuildRequires:	pkgconfig(libavif)
BuildRequires:	gperf
Requires:	%{name}-data >= %{version}


#include a cjk font
Requires:      google-noto-sans-cjk-ttc-fonts

%description
Celestia is a free real-time space simulation that lets you experience
our universe in three dimensions. Unlike most planetarium software,
Celestia doesn't confine you to the surface of the Earth. You can
travel throughout the solar system, to any of over 100,000 stars, or
even beyond the galaxy. All travel in Celestia is seamless; the
exponential zoom feature lets you explore space across a huge range of
scales, from galaxy clusters down to spacecraft only a few meters
across. A 'point-and-goto' interface makes it simple to navigate
through the universe to the object you want to visit.

%package data
Summary:        Real-time 3D visualization of space
Group:          Sciences/Astronomy
Requires:       %{name} >= %{version}
BuildArch:      noarch

%description data
Unlike most planetarium software, Celestia doesn't confine you to the
surface of the Earth. You can travel throughout the solar system, to
any of over 100,000 stars, or even beyond the galaxy.
All movement in Celestia is seamless; the exponential zoom feature lets
you explore space across a huge range of scales, from galaxy clusters
down to spacecraft only a few meters across. A 'point-and-goto'
interface makes it simple to navigate through the universe to the
object you want to visit.
Celestia is expandable. Celestia comes with a large catalog of stars,
galaxies, planets, moons, asteroids, comets, and spacecraft. If that's
not enough, you can download dozens of easy to install add-ons with
more objects.

Data (catalogs, fonts, models, scripts, shaders, textures, ...)
required by Celestia.

%prep
%setup -q -n CelestiaProject-Celestia-%{gitrel}
%if %{with spice}
tar xzf %{SOURCE10}  -C thirdparty
mv thirdparty/OpenSpace-Spice-%{spicerel}/* thirdparty/Spice
%endif
%autopatch -p1
mkdir -p content
tar xzf %{SOURCE2}  --strip-components=1 -C content

%build
%cmake \
  -DGIT_COMMIT=%{gitrel} \
  -DENABLE_SPICE=%{?with_spice:ON}%{?!with_spice:OFF} \
  -DENABLE_QT5=OFF \
  -DENABLE_QT6=ON \
  -DENABLE_GLUT=ON \
  -DENABLE_FFMPEG=ON \
  -DENABLE_NLS=ON \
  -DENABLE_LIBAVIF=ON

%cmake_build

pushd content
%cmake
%cmake_build
popd

%install
%cmake_install

pushd content
%cmake_install
popd

pushd %{_vpath_builddir}/thirdparty/Spice
install -D -m 0755 libspice.so -t %{buildroot}%{_libdir} 
popd

mv %{buildroot}/%{_bindir}/celestia-qt6 %{buildroot}/%{_bindir}/celestia
install -p -m 644 -D celestia-logo.png \
  %{buildroot}%{_datadir}/pixmaps/celestia.png

cp -r content/extras %{buildroot}%{_datadir}/%{name}
cp -r content/extras-standard %{buildroot}%{_datadir}/%{name}

install -D -m 0644 -t %{buildroot}%{_datadir}/applications/ %{SOURCE1}
install -D -m 0644 -t %{buildroot}%{_datadir}/%{name} %{SOURCE11}
install -D -m 0644 -t %{buildroot}%{_defaultdocdir}/%{name}/ \
	AUTHORS COPYING ChangeLog README.md

# lang tmp hack
for po_path in po; do
    pushd $po_path
    for po_file in $(ls *.po); do
        mo_lang=$(basename $po_file .po)
        mo_path=%{buildroot}%{_datadir}/locale/$mo_lang/LC_MESSAGES
        test $po_path = "po" && mo_name=%{name}.mo || mo_name=%{name}_constellations.mo
        mkdir -p $mo_path
        msgfmt -o $mo_path/$mo_name $po_file
    done
    popd
done


%find_lang %{name}
%find_lang %{name}-data
cat %{name}-data.lang >> %{name}.lang

#use system ttf fonts
rm -rf %{buildroot}/%{_datadir}/celestia/fonts

%files -f %{name}.lang
%doc AUTHORS ChangeLog README
%doc devguide.txt controls.txt coding-standards.html
%license COPYING
%{_bindir}/*
%{_libdir}/*
%{_datadir}/applications/*.desktop
%{_docdir}/%{name}/
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}*.1*
%{_datadir}/metainfo/*.xml

%files data
%{_datadir}/%{name}/
