# CGAL 5 is now a header-only library, with dependencies. It no
# longer has any binary to build, but cannot be noarch because of
# arch-specific dependencies

%global debug_package %{nil}

%define uname   CGAL

%define devname   %mklibname %{name} -d
%define devnameqt %mklibname %{name}-qt -d

Name:           cgal
Version:        6.0.1
Release:        %mkrel 1
Summary:        Computational Geometry Algorithms Library
Group:          System/Libraries
License:        LGPLv3+ and GPLv3+ and Boost
URL:            https://www.cgal.org/
Source0:        https://github.com/CGAL/cgal/releases/download/v%{version}/%{uname}-%{version}.tar.xz

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  gmp-devel
BuildRequires:  mpfr-devel
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(zlib)

%description
The goal of the CGAL Open Source Project is to provide easy access
to efficient and reliable geometric algorithms in the form of a C++
library. CGAL is used in various areas needing geometric computation,
such as: computer graphics, scientific visualization, computer aided
design and modeling, geographic information systems, molecular biology,
medical imaging, robotics and motion planning, mesh generation, numerical
methods... More on the projects using CGAL web page.

#----------------------------------------------------------------------------

%package -n     %{devname}
Group:          Development/C++
Summary:        Development files and tools for CGAL applications
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{uname}-devel = %{version}-%{release}

Requires:       boost-devel
Requires:       gmp-devel
Requires:       mpfr-devel
Recommends:     pkgconfig(eigen3)
Recommends:     pkgconfig(zlib)

%description -n %{devname}
This package provides the headers files and tools you may need to
develop applications using CGAL.

%files -n       %{devname}
%license AUTHORS LICENSE LICENSE.BSL LICENSE.RFL LICENSE.LGPL LICENSE.GPL
%doc CHANGES.md
%{_includedir}/%{uname}/
%exclude %{_includedir}/CGAL/Qt
%{_libdir}/cmake/%{uname}/
%{_bindir}/%{name}*
%exclude %{_bindir}/%{name}_make_macosx_app
%{_mandir}/man1/%{name}_create_cmake_script.1*

#----------------------------------------------------------------------------

%package -n     %{devnameqt}
Group:          Development/C++
Summary:        Development files and tools for CGAL applications using Qt 6
Provides:       %{name}-qt-devel = %{version}-%{release}
Provides:       %{uname}-qt-devel = %{version}-%{release}

Requires:       %{devname} = %{version}-%{release}
Requires:       cmake(Qt6Core)
Requires:       cmake(Qt6Gui)
Requires:       cmake(Qt6OpenGL)
Requires:       cmake(Qt6OpenGLWidgets)
Requires:       cmake(Qt6Svg)
Requires:       cmake(Qt6Widgets)
Requires:       cmake(Qt6Xml)

%description -n %{devnameqt}
This package provides the headers files and tools you may need to
develop applications using CGAL and Qt 6.

%files -n       %{devnameqt}
%{_includedir}/CGAL/Qt/

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{uname}-%{version}

%build
%cmake \
       -DCGAL_INSTALL_LIB_DIR=%{_lib} \
       -DCGAL_INSTALL_DOC_DIR=
%cmake_build

%install
%cmake_install
