%define major           4.4
%define libname         %mklibname %{name} %{major}
%define libname_devel   %mklibname %{name} -d

%define srcname         CGNS

Name:    cgns
Version: 4.4.0
Release: %mkrel 2
Summary: Computational fluid dynamics notation system
License: zlib
Group:   Sciences/Physics
URL:     https://cgns.github.io
Source0: https://github.com/CGNS/CGNS/archive/v%{version}/%{srcname}-%{version}.tar.gz

Patch1:  cgns-4.3.0-libdir.patch
Patch2:  0001-backport-gcc14-fedora-patch.patch

BuildRequires: cmake
BuildRequires: gcc-gfortran
BuildRequires: hdf5-devel
BuildRequires: hdf5
BuildRequires: pkgconfig(x11)
BuildRequires: tcl
BuildRequires: pkgconfig(tcl)
BuildRequires: pkgconfig(tk)
BuildRequires: pkgconfig(gl)
BuildRequires: pkgconfig(glu)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xmu)

%description
The CFD General Notation System (CGNS) provides a general, portable,
and extensible standard for the storage and retrieval of computational
fluid dynamics (CFD) analysis data. It consists of a collection of
conventions, and free and open software implementing those
conventions. It is self-descriptive, machine-independent,
well-documented, and administered by an international steering
committee.

%package -n %{libname}
Summary:        Libraries for CGNS
Group:          System/Libraries

%description -n %{libname}
%{summary}.

%package -n %{libname_devel}
Summary:        Development files for CGNS
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{libname_devel}
This package provides the CGNS header and module files required to
compile C and Fortran programs that use CNGS.

%prep
%setup -q -n %{srcname}-%{version}
%autopatch -p1

# Skip RPATH
sed -i \
  -e '/CMAKE_SKIP_BUILD_RPATH/s/FALSE/TRUE/' \
  -e 's/CMAKE_SKIP_BUILD_RPATH/CMAKE_SKIP_RPATH/' \
  CMakeLists.txt

%build
%cmake \
        -DCGNS_ENABLE_FORTRAN:BOOL=ON	\
        -DCGNS_BUILD_CGNSTOOLS:BOOL=ON	\
	-DCGNS_ENABLE_HDF5:BOOL=ON	\
	-DCGNS_BUILD_SHARED:BOOL=ON	\
	-DHDF5_NEED_ZLIB:BOOL=ON	\
%ifarch x86_64 aarch64
        -DCGNS_ENABLE_64BIT:BOOL=ON	\
%endif
	%nil
%cmake_build

%install
%cmake_install

# drop static build
rm -rf %{buildroot}%{_libdir}/libcgns.a

%files
%doc README.md license.txt
%{_bindir}/*
%{_datadir}/cgnstools

%files -n %{libname}
%{_libdir}/libcgns.so.%{major}

%files -n %{libname_devel}
%{_includedir}/*
%{_libdir}/libcgns.so
%{_libdir}/cmake/cgns
