# There is a plus on the end for unreleased versions, not for released versions
%global instdir %{name}-%{version}+

%bcond_with extracheck
%bcond_with pcre
%bcond_with gtk2

# This package uses toplevel ASMs which are incompatible with LTO
%global _lto_cflags %{nil}

%define ver	2.49.93
%define date	20240901

Name:		clisp
Summary:	ANSI Common Lisp implementation
Epoch:		1
Version:	%{ver}
# The project as a whole is GPL-2.0-or-later.  Exceptions:
# - Some documentation is dual-licensed as GPL-2.0-or-later OR GFDL-1.2-or-later
# - src/gllib is LGPL-2.1-or-later
# - src/socket.d and modules/clx/mit-clx/doc.lisp are HPND
# - src/xthread.d and modules/asdf/asdf.lisp are X11
License:	GPL-2.0-or-later AND (GPL-2.0-or-later OR GFDL-1.2-or-later) AND LGPL-2.1-or-later AND HPND AND X11
Release:	%mkrel 0.git%{date}.1
URL:		http://www.clisp.org/
Group:		Development/Other
Source0:	https://gitlab.com/gnu-clisp/clisp/-/archive/master/clisp-master.tar.bz2
# Upstream dropped this file from the distribution
Source1:	https://gitlab.com/sam-s/clhs/-/raw/master/clhs.el
# Updated translations
Source2:	https://translationproject.org/latest/clisp/sv.po
Source3:	https://translationproject.org/latest/clisp/de.po
# https://sourceforge.net/p/clisp/patches/35/
Patch0:		%{name}-db.patch
# https://sourceforge.net/p/clisp/patches/32/
Patch1:		%{name}-format.patch
# The combination of register and volatile is nonsensical
Patch2:		%{name}-register-volatile.patch
# A test that writes to /dev/pts/0 succeeds or fails apparently at random.
# I can only guess that /dev/pts/0 may or may not be what the test expects.
# Perhaps we are racing with something else that allocates a pty.  Disable
# the test for now.
Patch3:		%{name}-pts-access.patch
# Fix HAVE_DB_STAT_ACCEPT_TXN test in the Berkeley DB module
# https://gitlab.com/gnu-clisp/clisp/-/merge_requests/8
Patch4:		%{name}-c99.patch
# Fix mismatched pointer types in the Berkeley DB module
# https://gitlab.com/gnu-clisp/clisp/-/merge_requests/9
Patch5:		%{name}-bdb-mismatched-pointer.patch
# Fix the new-clx build, which was broken by a recent gnulib update
# https://gitlab.com/gnu-clisp/clisp/-/merge_requests/10
Patch6:		%{name}-new-clx.patch
# Do not call the deprecated siginterrupt function
Patch7:		%{name}-siginterrupt.patch
# Adapt to changes in pari 2.17
Patch8:		%{name}-pari.patch

# Work around a problem inlining a function on ppc64le
# See https://bugzilla.redhat.com/show_bug.cgi?id=2049371
Patch100:	%{name}-no-inline.patch

BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(ice)
BuildRequires:	diffutils
BuildRequires:	emacs
BuildRequires:	fcgi-devel
BuildRequires:	ffcall-devel
BuildRequires:	gcc
BuildRequires:	gdbm-devel
BuildRequires:	gettext-devel
BuildRequires:	ghostscript
BuildRequires:	locales-en
BuildRequires:	locales-fr
BuildRequires:	locales-ja
BuildRequires:	locales-zh
BuildRequires:	groff
%if %{with gtk2}
BuildRequires:	gtk2-devel
BuildRequires:	pkgconfig(libglade-2.0)
%endif
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre)
%endif
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(xft)

BuildRequires:	libdb-devel
BuildRequires:	%{_lib}sigsegv-devel
BuildRequires:	unistring-devel
BuildRequires:	pkgconfig(libxcrypt)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(sm)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xau)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xpm)
BuildRequires:	imake
BuildRequires:	make
%if 0
BuildRequires:	pari-devel
%endif
BuildRequires:	postgresql-devel
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(zlib)
Provides:	ansi-cl

# clisp contains a copy of gnulib, which has been granted a bundling exception:
# https://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Packages_granted_exceptions
Provides:	bundled(gnulib)

%description
ANSI Common Lisp is a high-level, general-purpose programming
language.  GNU CLISP is a Common Lisp implementation by Bruno Haible
of Karlsruhe University and Michael Stoll of Munich University, both
in Germany.  It mostly supports the Lisp described in the ANSI Common
Lisp standard.  It runs on most Unix workstations (GNU/Linux, FreeBSD,
NetBSD, OpenBSD, Solaris, Tru64, HP-UX, BeOS, NeXTstep, IRIX, AIX and
others) and on other systems (Windows NT/2000/XP, Windows 95/98/ME)
and needs only 4 MiB of RAM.

It is Free Software and may be distributed under the terms of GNU GPL,
while it is possible to distribute commercial proprietary applications
compiled with GNU CLISP.

The user interface comes in English, German, French, Spanish, Dutch,
Russian and Danish, and can be changed at run time.  GNU CLISP
includes an interpreter, a compiler, a debugger, CLOS, MOP, a foreign
language interface, sockets, i18n, fast bignums and more.  An X11
interface is available through CLX, Garnet, CLUE/CLIO.  GNU CLISP runs
Maxima, ACL2 and many other Common Lisp packages.


%package	devel
Summary:	Development files for CLISP
Group:		Development/Other
Provides:	%{name}-static = %{version}-%{release} 
Requires:	%{name} = %{epoch}:%{version}-%{release}
Conflicts:	%{name} < 1:2.49.92

%description	devel
Files necessary for linking CLISP programs.


%prep
%setup -qn %{name}-master
%autopatch -M99 -p0
%ifarch %{power64}
%autopatch 100 -p0
%endif
cp -p %{SOURCE1} emacs
cp -p %{SOURCE2} %{SOURCE3} src/po

# We only link against libraries in system directories, so we need -L dir in
# place of -Wl,-rpath -Wl,dir
cp -p src/build-aux/config.rpath config.rpath.orig
sed -i -e 's/${wl}-rpath ${wl}/-L/g' src/build-aux/config.rpath

# Fix modules that need access to symbols in libgnu.a
sed -i 's/\(${GLLIB_A}\) \(${LIBS}\)/-Wl,--whole-archive \1 -Wl,--no-whole-archive \2 -ldl/' src/makemake.in

# When building modules, put -Wl,--as-needed before the libraries to link
sed -i "s/CC='\${CC}'/CC='\${CC} -Wl,--as-needed'/" src/makemake.in

# Enable firefox to be the default browser for displaying documentation
sed -i 's/;; \((setq \*browser\* .*)\)/\1/' src/cfgunix.lisp

# Unpack the CLX manual
tar -C modules/clx -xzf modules/clx/clx-manual.tar.gz
chmod -R go+r modules/clx/clx-manual
chmod a-x modules/clx/clx-manual/html/doc-index.cgi

# On some koji builders, something is already listening on port 9090, which
# causes a spurious test failure.  Change to port 9096 for the test.
sed -i 's/9090/9096/g' tests/socket.tst

%build
# Do not need to specify base modules: i18n, readline, regexp, syscalls.
# The dirkey module currently can only be built on Windows/Cygwin/MinGW.
# The editor module is not in good enough shape to use.
# The matlab, netica, and oracle modules require proprietary code to build.
# The queens module is intended as an example only, not for actual use.
./configure --prefix=%{_prefix} \
	    --libdir=%{_libdir} \
	    --mandir=%{_mandir} \
	    --infodir=%{_infodir} \
	    --docdir=%{_pkgdocdir} \
	    --fsstnd=redhat \
	    --with-module=asdf \
	    --with-module=berkeley-db \
	    --with-module=bindings/glibc \
	    --with-module=clx/new-clx \
	    --with-module=dbus \
	    --with-module=fastcgi \
	    --with-module=gdbm \
%if %{with gtk2}
	    --with-module=gtk2 \
%endif
%if 0
	    --with-module=libsvm \
	    --with-module=pari \
%endif
%if %{with pcre}
	    --with-module=pcre \
%endif
	    --with-module=postgresql \
	    --with-module=rawsock \
	    --with-module=zlib \
	    --with-libreadline-prefix=$PWD/readline \
	    --with-ffcall \
%if %{with extracheck}
	    --cbcx \
%endif
	    build \
%if 0
	    CPPFLAGS="-I/usr/include/libsvm" \
%endif
	    CFLAGS="%{optflags} -Wa,--noexecstack" \
	    LDFLAGS="%(echo "%{ldflags}" | sed "s/-Wl,--no-undefined/-Wl,-z,noexecstack/")"

cd build
# Workaround libtool reordering -Wl,--as-needed after all the libraries.
sed -i 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' libtool
make
cd -

%install
make -C build DESTDIR=%{buildroot} install
cp -a build/full %{buildroot}%{_libdir}/%{instdir}
rm -f %{buildroot}%{_pkgdocdir}/doc/clisp.{dvi,1,ps}
rm -f %{buildroot}%{_pkgdocdir}/{COPYRIGHT,GNU-GPL}
cp -p doc/mop-spec.pdf %{buildroot}%{_pkgdocdir}/doc
cp -p doc/*.png %{buildroot}%{_pkgdocdir}/doc
cp -p doc/Why-CLISP* %{buildroot}%{_pkgdocdir}/doc
cp -p doc/regexp.html %{buildroot}%{_pkgdocdir}/doc
find %{buildroot}%{_libdir} -name '*.dvi' -exec rm -f {} \+
%find_lang %{name}
%find_lang %{name}low
cat %{name}low.lang >> %{name}.lang

# Compile the Emacs interface
pushd %{buildroot}%{_datadir}/emacs/site-lisp
%{_emacs_bytecompile} *.el
popd

# Put back the original config.rpath
cp -p config.rpath.orig %{buildroot}%{_libdir}/%{instdir}/build-aux/config.rpath

# Fix a missing executable bit
chmod a+x %{buildroot}%{_libdir}/%{instdir}/build-aux/depcomp

# Fix paths in the Makefiles
for mk in $(find %{buildroot}%{_libdir} -name Makefile); do
  sed -e "s,$PWD/modules,%{_libdir}/%{instdir}," \
      -e "s,$PWD/build/clisp,%{_bindir}/clisp," \
      -e "s,$PWD/build/linkkit,%{_libdir}/%{instdir}/linkkit," \
      -i $mk
done
for mk in %{buildroot}%{_libdir}/%{instdir}/{base,full}/makevars; do
  sed -e "s, -I$PWD[^']*,," \
      -e "s,%{_libdir}/lib\([[:alnum:]]*\)\.so,-l\1,g" \
      -i $mk
done

# Install config.h, which is needed in some cases
for dir in %{buildroot}%{_libdir}/%{instdir}/*; do
  cp -p build/$(basename $dir)/config.h $dir || :
done
cp -p build/config.h %{buildroot}%{_libdir}/%{instdir}
cp -p build/clx/new-clx/config.h \
   %{buildroot}%{_libdir}/%{instdir}/clx/new-clx

# Fix broken symlinks in the full set
pushd %{buildroot}%{_libdir}/%{instdir}/full
for obj in bogomips calls gettext readline regexi; do
  rm -f ${obj}.o
  ln -s ../base/${obj}.o ${obj}.o
done
for obj in libgnu libnoreadline lisp; do
  rm -f ${obj}.a
  ln -s ../base/${obj}.a ${obj}.a
done
for obj in fastcgi fastcgi_wrappers; do
  rm -f ${obj}.o
  ln -s ../fastcgi/${obj}.o ${obj}.o
done
%if 0
for obj in cpari pari; do
  rm -f ${obj}.o
  ln -s ../pari/${obj}.o ${obj}.o
done
%endif
rm -f bdb.o
ln -s ../berkeley-db/bdb.o bdb.o
rm -f clx.o
ln -s ../clx/new-clx/clx.o clx.o
%if %{with pcre}
rm -f cpcre.o
ln -s ../pcre/cpcre.o cpcre.o
%endif
rm -f dbus.o
ln -s ../dbus/dbus.o dbus.o
rm -f gdbm.o
ln -s ../gdbm/gdbm.o gdbm.o
%if %{with gtk2}
rm -f gtk.o
ln -s ../gtk2/gtk.o gtk.o
%endif
%if 0
rm -f libsvm.o
ln -s ../libsvm/libsvm.o libsvm.o
%endif
rm -f linux.o
ln -s ../bindings/glibc/linux.o linux.o
rm -f postgresql.o
ln -s ../postgresql/postgresql.o postgresql.o
rm -f rawsock.o
ln -s ../rawsock/rawsock.o rawsock.o
rm -f zlib.o
ln -s ../zlib/zlib.o zlib.o
popd

# Help the debuginfo generator
ln -s ../../src/modules.c build/base/modules.c
ln -s ../../src/modules.c build/full/modules.c

%files -f %{name}.lang
%license COPYRIGHT GNU-GPL
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_pkgdocdir}/
%dir %{_libdir}/%{instdir}/
%dir %{_libdir}/%{instdir}/asdf/
%{_libdir}/%{instdir}/asdf/asdf.fas
%dir %{_libdir}/%{instdir}/base/
%{_libdir}/%{instdir}/base/lispinit.mem
%{_libdir}/%{instdir}/base/lisp.run
%dir %{_libdir}/%{instdir}/berkeley-db/
%{_libdir}/%{instdir}/berkeley-db/*.fas
%{_libdir}/%{instdir}/berkeley-db/preload.lisp
%dir %{_libdir}/%{instdir}/bindings/
%dir %{_libdir}/%{instdir}/bindings/glibc/
%{_libdir}/%{instdir}/bindings/glibc/*.fas
%dir %{_libdir}/%{instdir}/clx/
%dir %{_libdir}/%{instdir}/clx/new-clx/
%{_libdir}/%{instdir}/clx/new-clx/*.fas
%{_libdir}/%{instdir}/clx/new-clx/clx-preload.lisp
%{_libdir}/%{instdir}/data/
%dir %{_libdir}/%{instdir}/dbus/
%{_libdir}/%{instdir}/dbus/*.fas
%{_libdir}/%{instdir}/dynmod/
%dir %{_libdir}/%{instdir}/fastcgi/
%{_libdir}/%{instdir}/fastcgi/*.fas
%dir %{_libdir}/%{instdir}/full/
%{_libdir}/%{instdir}/full/lispinit.mem
%{_libdir}/%{instdir}/full/lisp.run
%dir %{_libdir}/%{instdir}/gdbm/
%{_libdir}/%{instdir}/gdbm/*.fas
%{_libdir}/%{instdir}/gdbm/preload.lisp
%if %{with gtk2}
%dir %{_libdir}/%{instdir}/gtk2/
%{_libdir}/%{instdir}/gtk2/*.fas
%{_libdir}/%{instdir}/gtk2/preload.lisp
%endif
%if %{with pcre}
%dir %{_libdir}/%{instdir}/pcre/
%{_libdir}/%{instdir}/pcre/*.fas
%{_libdir}/%{instdir}/pcre/preload.lisp
%endif
%if 0
%dir %{_libdir}/%{instdir}/libsvm/
%{_libdir}/%{instdir}/libsvm/*.fas
%{_libdir}/%{instdir}/libsvm/preload.lisp
%dir %{_libdir}/%{instdir}/pari/
%{_libdir}/%{instdir}/pari/*.fas
%{_libdir}/%{instdir}/pari/preload.lisp
%endif
%dir %{_libdir}/%{instdir}/postgresql/
%{_libdir}/%{instdir}/postgresql/*.fas
%dir %{_libdir}/%{instdir}/rawsock/
%{_libdir}/%{instdir}/rawsock/*.fas
%{_libdir}/%{instdir}/rawsock/preload.lisp
%dir %{_libdir}/%{instdir}/zlib/
%{_libdir}/%{instdir}/zlib/*.fas
%{_datadir}/emacs/site-lisp/*
%{_datadir}/vim/vimfiles/after/syntax/*

%files devel
%doc modules/clx/clx-manual
%{_bindir}/%{name}-link
%{_mandir}/man1/%{name}-link.1*
%{_libdir}/%{instdir}/asdf/Makefile
%{_libdir}/%{instdir}/asdf/*.lisp
%{_libdir}/%{instdir}/asdf/*.sh
%{_libdir}/%{instdir}/base/*.a
%{_libdir}/%{instdir}/base/*.h
%{_libdir}/%{instdir}/base/*.o
%{_libdir}/%{instdir}/base/makevars
%{_libdir}/%{instdir}/berkeley-db/Makefile
%{_libdir}/%{instdir}/berkeley-db/*.h
%{_libdir}/%{instdir}/berkeley-db/dbi.lisp
%{_libdir}/%{instdir}/berkeley-db/*.o
%{_libdir}/%{instdir}/berkeley-db/*.sh
%{_libdir}/%{instdir}/bindings/glibc/Makefile
%{_libdir}/%{instdir}/bindings/glibc/*.lisp
%{_libdir}/%{instdir}/bindings/glibc/*.o
%{_libdir}/%{instdir}/bindings/glibc/*.sh
%{_libdir}/%{instdir}/build-aux/
%{_libdir}/%{instdir}/clx/new-clx/demos/
%{_libdir}/%{instdir}/clx/new-clx/README
%{_libdir}/%{instdir}/clx/new-clx/Makefile
%{_libdir}/%{instdir}/clx/new-clx/*.h
%{_libdir}/%{instdir}/clx/new-clx/clx.lisp
%{_libdir}/%{instdir}/clx/new-clx/image.lisp
%{_libdir}/%{instdir}/clx/new-clx/resource.lisp
%{_libdir}/%{instdir}/clx/new-clx/*.o
%{_libdir}/%{instdir}/clx/new-clx/*.sh
%{_libdir}/%{instdir}/config.h
%{_libdir}/%{instdir}/dbus/Makefile
%{_libdir}/%{instdir}/dbus/*.h
%{_libdir}/%{instdir}/dbus/*.lisp
%{_libdir}/%{instdir}/dbus/*.o
%{_libdir}/%{instdir}/dbus/*.sh
%{_libdir}/%{instdir}/fastcgi/README
%{_libdir}/%{instdir}/fastcgi/Makefile
%{_libdir}/%{instdir}/fastcgi/*.h
%{_libdir}/%{instdir}/fastcgi/*.lisp
%{_libdir}/%{instdir}/fastcgi/*.o
%{_libdir}/%{instdir}/fastcgi/*.sh
%{_libdir}/%{instdir}/full/*.a
%{_libdir}/%{instdir}/full/*.h
%{_libdir}/%{instdir}/full/*.o
%{_libdir}/%{instdir}/full/makevars
%{_libdir}/%{instdir}/gdbm/Makefile
%{_libdir}/%{instdir}/gdbm/*.h
%{_libdir}/%{instdir}/gdbm/gdbm.lisp
%{_libdir}/%{instdir}/gdbm/*.o
%{_libdir}/%{instdir}/gdbm/*.sh
%if %{with gtk2}
%{_libdir}/%{instdir}/gtk2/Makefile
%{_libdir}/%{instdir}/gtk2/*.cfg
%{_libdir}/%{instdir}/gtk2/*.glade
%{_libdir}/%{instdir}/gtk2/*.h
%{_libdir}/%{instdir}/gtk2/gtk.lisp
%{_libdir}/%{instdir}/gtk2/*.o
%{_libdir}/%{instdir}/gtk2/*.sh
%endif
%if 0
%{_libdir}/%{instdir}/libsvm/README
%{_libdir}/%{instdir}/libsvm/Makefile
%{_libdir}/%{instdir}/libsvm/*.h
%{_libdir}/%{instdir}/libsvm/libsvm.lisp
%{_libdir}/%{instdir}/libsvm/*.o
%{_libdir}/%{instdir}/libsvm/*.sh
%endif
%{_libdir}/%{instdir}/linkkit/
%if 0
%{_libdir}/%{instdir}/pari/README
%{_libdir}/%{instdir}/pari/Makefile
%{_libdir}/%{instdir}/pari/*.h
%{_libdir}/%{instdir}/pari/desc2lisp.lisp
%{_libdir}/%{instdir}/pari/pari.lisp
%{_libdir}/%{instdir}/pari/*.o
%{_libdir}/%{instdir}/pari/*.sh
%endif
%if %{with pcre}
%{_libdir}/%{instdir}/pcre/Makefile
%{_libdir}/%{instdir}/pcre/*.h
%{_libdir}/%{instdir}/pcre/*.lisp
%{_libdir}/%{instdir}/pcre/*.o
%{_libdir}/%{instdir}/pcre/*.sh
%endif
%{_libdir}/%{instdir}/postgresql/README
%{_libdir}/%{instdir}/postgresql/Makefile
%{_libdir}/%{instdir}/postgresql/*.h
%{_libdir}/%{instdir}/postgresql/*.lisp
%{_libdir}/%{instdir}/postgresql/*.o
%{_libdir}/%{instdir}/postgresql/*.sh
%{_libdir}/%{instdir}/rawsock/demos/
%{_libdir}/%{instdir}/rawsock/Makefile
%{_libdir}/%{instdir}/rawsock/*.h
%{_libdir}/%{instdir}/rawsock/sock.lisp
%{_libdir}/%{instdir}/rawsock/*.o
%{_libdir}/%{instdir}/rawsock/*.sh
%{_libdir}/%{instdir}/zlib/Makefile
%{_libdir}/%{instdir}/zlib/*.h
%{_libdir}/%{instdir}/zlib/*.lisp
%{_libdir}/%{instdir}/zlib/*.o
%{_libdir}/%{instdir}/zlib/*.sh
%{_datadir}/aclocal/%{name}.m4
