Name:           cloud-init
Version:        25.1
Release:        %mkrel 1
Summary:        Cloud instance init scripts

Group:          Networking/Other
License:        ASL 2.0 or GPLv3
URL:            https://github.com/canonical/cloud-init
Source0:        https://github.com/canonical/cloud-init/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        cloud-init-mageia.cfg
Source2:        cloud-init-README.mageia
Source3:        mageia.py
Source4:        cloud-init-tmpfiles.conf

BuildArch:      noarch

BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  systemd-units
# For tests
BuildRequires:  python3-configobj
# https://bugzilla.redhat.com/show_bug.cgi?id=1695953
BuildRequires:  python3-distro
# https://bugzilla.redhat.com/show_bug.cgi?id=1417029
BuildRequires:  python3-httpretty >= 0.8.14-2
BuildRequires:  python3-jinja2
BuildRequires:  python3-jsonpatch
BuildRequires:  python3-jsonschema
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-oauthlib
BuildRequires:  python3-prettytable
BuildRequires:  python3-serial
BuildRequires:  python3-PyYAML
BuildRequires:  python3-requests
BuildRequires:  python3-six
Requires:       dmidecode
Requires:       e2fsprogs
Requires:       hostname
Requires:       iproute2
Requires:       python3-libselinux
Requires:       net-tools
Requires:       policycoreutils-python3
Requires:       procps
Requires:       rsyslog
Requires:       shadow-utils
Requires:       xfsprogs
Requires:       run-parts
Requires:       cloud-utils-growpart
Requires(post):   systemd-units
Requires(preun):  systemd-units
Requires(postun): systemd-units

%description
Cloud-init is a set of init scripts for cloud instances.  Cloud instances
need special scripts to run during initialization to retrieve and install
ssh keys and to let the user run various scripts.


%prep
%autosetup -p1

# Change shebangs
sed -i -e 's|#!/usr/bin/env python|#!/usr/bin/env python3|' \
       -e 's|#!/usr/bin/python|#!/usr/bin/python3|' tools/* cloudinit/ssh_util.py

cp -p %{SOURCE2} README.mageia
cp %{SOURCE3} cloudinit/distros

%build
%py3_build


%install
%py3_install -- --init-system=systemd

mkdir -p %{buildroot}%{_sharedstatedir}/cloud

# We supply our own config file since our software differs from Ubuntu's.
cp -p %{SOURCE1} %{buildroot}%{_sysconfdir}/cloud/cloud.cfg

# /run/cloud-init needs a tmpfiles.d entry
mkdir -p %{buildroot}/run/cloud-init
mkdir -p %{buildroot}%{_tmpfilesdir}
cp -p %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

mkdir -p %{buildroot}%{_sysconfdir}/rsyslog.d
cp -p tools/21-cloudinit.conf %{buildroot}%{_sysconfdir}/rsyslog.d/21-cloudinit.conf

# Put files in /etc/systemd/system in the right place
# cp -a %{buildroot}/etc/systemd %{buildroot}/usr/lib
# rm -rf %{buildroot}/etc/systemd

%post
%_tmpfilescreate %{name}
if [ $1 -eq 1 ] ; then
    # Initial installation
    # Enabled by default per "runs once then goes away" exception
    /bin/systemctl enable cloud-config.service     >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-final.service      >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init-network.service       >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init-local.service >/dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable cloud-config.service >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-final.service  >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init-network.service   >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init-local.service >/dev/null 2>&1 || :
    # One-shot services -> no need to stop
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
# One-shot services -> no need to restart


%files
%doc ChangeLog README.mageia
%doc doc/*
%license LICENSE
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg
%dir               %{_sysconfdir}/cloud/cloud.cfg.d
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg.d/*.cfg
%doc               %{_sysconfdir}/cloud/cloud.cfg.d/README
%dir               %{_sysconfdir}/cloud/clean.d
%dir               %{_sysconfdir}/cloud/templates
%config(noreplace) %{_sysconfdir}/cloud/templates/*
%{_udevrulesdir}/66-azure-ephemeral.rules
%{_unitdir}/cloud-config.service
%{_unitdir}/cloud-final.service
%{_unitdir}/cloud-init-local.service
%{_unitdir}/cloud-config.target
%{_unitdir}/cloud-init.target
%{_unitdir}/cloud-init-main.service
%{_unitdir}/cloud-init-network.service
%{_systemdgeneratordir}/cloud-init-generator
%{_unitdir}/cloud-init-hotplugd.service
%{_unitdir}/cloud-init-hotplugd.socket
%{_unitdir}/sshd-keygen@.service.d/disable-sshd-keygen-if-cloud-init-active.conf
%{_tmpfilesdir}/%{name}.conf
%{python3_sitelib}/*
%{_libexecdir}/%{name}
%{_bindir}/cloud-init*
%{_bindir}/cloud-id
%ghost %dir /run/cloud-init
%dir %{_sharedstatedir}/cloud
%{_datadir}/bash-completion/completions/%{name}

%config(noreplace) %{_sysconfdir}/rsyslog.d/21-cloudinit.conf

