%define major         0
%define libname       %mklibname %name %major
%define libname_devel %mklibname %name -d

Name:           cmocka
Version:        1.1.7
Release:        %mkrel 1

License:        ASL 2.0
Group:          Development/C
Summary:        Lightweight library to simplify and generalize unit tests for C
Url:            https://cmocka.org/

Source0:        https://cmocka.org/files/1.1/%{name}-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  glibc-devel


%description
There are a variety of C unit testing frameworks available however many of them
are fairly complex and require the latest compiler technology. Some development
requires the use of old compilers which makes it difficult to use some unit
testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform
that will ultimately execute the test. Because of this assumption many
frameworks require the inclusion of standard C library headers in the code
module being tested which may collide with the custom or incomplete
implementation of the C library utilized by the code under test.

Cmocka only requires a test application is linked with the standard C library
which minimizes conflicts with standard C library headers. Also, CMocka tries
to avoid the use of some of the newer features of C compilers.

This results in CMocka being a relatively small library that can be used to
test a variety of exotic code. If a developer wishes to simply test an
application with the latest compiler then other unit testing frameworks may be
preferable.

This is the successor of Google's Cmockery.

%package -n %{libname}
Group:          Development/C
Summary:        Lightweight library to simplify and generalize unit tests for C

%description -n %{libname}
There are a variety of C unit testing frameworks available however many of them
are fairly complex and require the latest compiler technology. Some development
requires the use of old compilers which makes it difficult to use some unit
testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform
that will ultimately execute the test. Because of this assumption many
frameworks require the inclusion of standard C library headers in the code
module being tested which may collide with the custom or incomplete
implementation of the C library utilized by the code under test.

CMocka only requires a test application is linked with the standard C library
which minimizes conflicts with standard C library headers. Also, CMocka tries
to avoid the use of some of the newer features of C compilers.

This results in CMocka being a relatively small library that can be used to
test a variety of exotic code. If a developer wishes to simply test an
application with the latest compiler then other unit testing frameworks may be
preferable.

This is the successor of Google's Cmockery.

%package -n %{libname_devel}
Group:          Development/C
Summary:        Development headers for the cmocka library
Provides:       libcmocka-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Obsoletes:      %{_lib}cmocka0-static-devel < 1.1.5-7

%description -n %{libname_devel}
Development headers for the cmocka unit testing library.

%prep
%autosetup -p1

%ifarch armv7hl
# This upsets valgrind on 32bit arm
# https://bugzilla.redhat.com/show_bug.cgi?id=1699304
sed -i s/fstack-clash-protection/fno-fstack-clash-protection/g CompilerChecks.cmake
%endif

%build
%cmake \
  -DWITH_CMOCKERY_SUPPORT=ON \
  -DUNIT_TESTING=ON \
%cmake_build
%cmake_build -t doc
%cmake_build -t docs

%install
%cmake_install

%check
# The test suite doesn't automatically know to look at the "built"
# library, so we force it by creating an LD_LIBRARY_PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
make -C %{_vpath_builddir} test || cat Testing/Temporary/LastTest.log

%files -n %{libname}
%doc AUTHORS README.md ChangeLog
%license COPYING
%{_libdir}/libcmocka.so.%{major}{,.*}

%files -n %{libname_devel}
%doc build/doc/html
%{_includedir}/cmocka.h
%{_includedir}/cmocka_pbc.h
%dir %{_includedir}/cmockery
%{_includedir}/cmockery/cmockery.h
%{_includedir}/cmockery/pbc.h
%{_libdir}/libcmocka.so
%{_libdir}/pkgconfig/cmocka.pc
%{_libdir}/cmake/cmocka/
