# The SONAME of the proprietary library symlinks causes them to be needed at
# runtime, so we must include them in the main package
%global __requires_exclude devel\\(
%global __provides_exclude devel\\(

%define MODELS ip4800 mp250 mp280 mp495 mp495 mp495 mg5100 mg5200 mg6100 mg8100
#define MODEL_NUMS 356 369 370 373 374 375 376 377

%ifarch x86_64
%define arc 64
%else
%define arc 32
%endif

Name:		cnijfilter
Version:	3.40
Release:	%mkrel 1
Summary:	Canon Inkjet Printer Driver for Linux
License:	GPLv2 and Freeware
Group:		System/Printing
URL:		https://cweb.canon.jp/drv-upd/ij-mfp/bjlinux340-mg5130.html
Source0:	%name-source-%version-1.tar.gz
# fix "number of format specifications in 'msgid' and 'msgstr' does not match"
# fatal msgfmt error, translation misses %s-constructs, which the source has
Patch0:		cnijfilter-source-mga-id.po.patch
# cups filters should install to /usr/lib/cups not to /usr/lib64/cups
# because /usr/lib64/cups is only a symlink to /usr/lib/cups
Patch1:		cnijfilter-source-mga-pstocanonij_filter_libdir.patch
BuildRequires:	cups-devel
BuildRequires:	libtool
BuildRequires:	tiff-devel
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(popt)

%description

This Inkjet Printer Driver provides printing functions for Canon Inkjet
printers operating under the CUPS (Common UNIX Printing System) environment,
supporting the following printers:

%prep
%setup -q -n %name-source-%version-1

%patch -P 0 -p1 -b .id.po
%patch -P 1 -p1 -b .pstocanonij_filter_libdir

%build

# for autogen.sh
export NOCONFIGURE=1

for model in %{MODELS}; do
	mkdir -p $model
	for dir in ppd cnijfilter printui lgmon cngpijmon; do
		cp -aT $dir $dir-$model
		pushd $dir-$model
		./autogen.sh
		%configure \
			--program-suffix=$model \
			--enable-binpath=%{_bindir} \
			--enable-libpath=%{_libdir}/bjlib \
			--enable-progpath=%{_bindir}			
		%make
		popd
	done
done

#needed later in the build to link against
pushd lgmon
	./autogen.sh
	%configure \
		--enable-binpath=%{_bindir} \
		--enable-libpath=%{_libdir}/bjlib \
		--enable-progpath=%{_bindir}
	%make
popd


for i in libs cngpij pstocanonij backend backendnet cngpijmon/cnijnpr; do
	pushd $i
	./autogen.sh
	%configure \
	      --enable-progpath=%{_bindir}
	popd
done
%make
	  
%install
rm -rf %{buildroot}

for model in %{MODELS}; do
	for dir in ppd cnijfilter printui lgmon cngpijmon; do
		%make_install -C $dir-$model
	done
done

mkdir -p %{buildroot}%{_libdir}/bjlib

install -c -m 644 */database/* %{buildroot}%{_libdir}/bjlib
install -c -m 755 */libs_bin%{arc}/*.so.* %{buildroot}%{_libdir}


install -c -m 644 com/ini/cnnet.ini  %{buildroot}%{_libdir}/bjlib

%make_install
install -c -m 755 com/libs_bin%{arc}/*.so.* %{buildroot}%{_libdir}


%find_lang %name --all-name

%files -f %{name}.lang
%doc LICENSE-cnijfilter-%{version}EN.txt

%{_bindir}/cngpij
%{_bindir}/cnijnetprn
%{_bindir}/cnijnpr
%{_bindir}/cif*
%{_bindir}/cngpijmon*
%{_bindir}/lgmon*
%{_bindir}/printui*
%{_prefix}/lib/cups/backend/cnijnet
%{_prefix}/lib/cups/backend/cnijusb
%{_prefix}/lib/cups/filter/pstocanonij
%{_libdir}/bjlib/cif*.conf
%{_libdir}/bjlib/cnb_*0.tbl
%{_libdir}/bjlib/cnbpname*.tbl
%attr(644, lp, lp) %{_libdir}/bjlib/cnnet.ini
%{_libdir}/libcnbpcmcm*.so
%{_libdir}/libcnbpcmcm*.so.8.0.1
%{_libdir}/libcnbpcnclapi*.so
%{_libdir}/libcnbpcnclapi*.so.3.5.0
%{_libdir}/libcnbpcnclbjcmd*.so
%{_libdir}/libcnbpcnclbjcmd*.so.3.3.0
%{_libdir}/libcnbpcnclui*.so
%{_libdir}/libcnbpcnclui*.so.3.6.0
%{_libdir}/libcnbpess*.so
%{_libdir}/libcnbpess*.so.3.3.3
%{_libdir}/libcnbpo*.so
%{_libdir}/libcnbpo*.so.1.0.1
%{_libdir}/libcnbpo*.so.1.0.2
%{_libdir}/libcnnet.so
%{_libdir}/libcnnet.so.1.2.0
%{_datadir}/cngpijmon*/pixmaps/*.xpm
%{_datadir}/cups/model/canon*.ppd
%{_datadir}/printui*

