#
# git clone https://github.com/compiz-reloaded/compiz.git
# cd compiz
# DATE=$(git log -1 --format="%cd" --date=short | sed "s|-||g")
# git archive --format=tar --prefix=compiz-${DATE}/ master | xz > ../compiz-${DATE}.tar.xz
#

# comment out if not snapshot
#define gdate	20190717

# rel for bumping
%define rel	6

%define	major	0
%define	libname	%mklibname decoration %major
%define	devname %mklibname decoration -d

# List of plugins passed to ./configure.  The order is important
%global plugins	core,dbus,decoration,fade,minimize,move,obs,place,png,resize,scale,screenshot,svg,switcher,wall

Name:		compiz
Epoch:		1
Version:	0.8.18
Release:	%mkrel %{?gdate:0.git%gdate.}%{rel}
Summary:	OpenGL composite manager for Xgl and AIGLX
Group:		System/X11
URL:		https://github.com/compiz-reloaded/compiz
License:	GPLv2+ and LGPLv2+ and MIT
Source0:	https://github.com/compiz-reloaded/compiz/archive/v%{version}/%{name}-%{?gdate}%{?!gdate:%version}.tar.%{?gdate:xz}%{?!gdate:gz}
Source1:	mageia-top.png
Source10:	compiz.defaults
Source11:	compiz-fusion
Source12:	compiz-fusion.defaults

Patch0:		compiz-mageia-logo.patch
Patch1:		fix-plugins-svg.c-rsvg-features-include.patch
Patch2:		0001-Fix-compatibility-with-libxml-2.12.patch
Patch3:		0001-Fixed-compilation-with-gcc-14.patch

BuildRequires:	gettext-devel
BuildRequires:	intltool
BuildRequires:	xsltproc
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xcomposite)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xfixes)
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(ice)
BuildRequires:	pkgconfig(sm)
BuildRequires:	pkgconfig(libstartup-notification-1.0)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(dbus-glib-1)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(cairo-xlib-xrender)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	pkgconfig(libmarco-private) >= 1.22.2
BuildRequires:	pkgconfig(libwnck-3.0)

Requires:	compizconfig
Requires:	compiz-ccsm
Requires:	compiz-decorator
Requires:	compositing-wm-common

Conflicts:	compiz-decorator-gtk < 1:0.8.16.1

%description
Compiz is an OpenGL compositing manager, which means that it enhances
the overall user interaction by adding fancy effects to your windows,
from drop shadows to desktop effects like the Desktop Cube or the Expo view.

Compiz can also be a window manager, which means that it is the software
between you and your desktop apps. It enables you to move or resize windows,
to switch workspaces, to switch windows easily (using alt-tab or so), and so on.


%files -f %{name}.lang
%doc AUTHORS NEWS README*
%license COPYING COPYING.GPL COPYING.LGPL COPYING.MIT
%{_bindir}/%{name}
%{_bindir}/%{name}-window-decorator
%{_bindir}/%{name}-decorator
%{_bindir}/%{name}-fusion
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/compositing-wm/%{name}.defaults
%{_datadir}/compositing-wm/%{name}-fusion.defaults
%{_datadir}/applications/compiz-start.desktop
%{_datadir}/applications/compiz.desktop
%{_iconsdir}/hicolor/*/apps/compiz.*

#----------------------------------------------------------------------------

%package decorator-gtk
Summary:	GTK window decorator for compiz
Group:		System/X11

Provides:	compiz-decorator
Requires:	%{name} = %{epoch}:%{version}-%{release}

%description decorator-gtk
This package provides a GTK window decorator for the compiz OpenGL
compositing manager.

%files decorator-gtk
%{_bindir}/gtk-window-decorator
%{_iconsdir}/hicolor/*/apps/gtk-decorator.*
%{_datadir}/glib-2.0/schemas/org.compiz-0.gwd.gschema.xml

#----------------------------------------------------------------------------

%package -n %libname
Summary:	Shared libraries for compiz
Group:		System/X11
Obsoletes:	%{_lib}compiz0 < 0.9.13.1-7

%description -n %libname
This package provides shared libraries for compiz.

%files -n %libname
%{_libdir}/libdecoration.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n %devname
Summary:	Development files for compiz
Group:		Development/X11
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Obsoletes:	%{_lib}compiz-devel < 0.9.13.1-7

%description -n %devname
This package provides development files for compiz.

%files -n %devname
%{_includedir}/%{name}/
%{_libdir}/libdecoration.so
%{_libdir}/pkgconfig/compiz-cube.pc
%{_libdir}/pkgconfig/compiz-scale.pc
%{_libdir}/pkgconfig/compiz.pc
%{_libdir}/pkgconfig/libdecoration.pc

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{?gdate}%{?!gdate:%version}

# make autoreconf happy
mkdir -p m4

%build
autoreconf -vfi -Im4
intltoolize --force
%configure \
	--disable-rpath \
	--disable-static \
	--with-gtk=3.0 \
	--enable-gtk \
	--enable-librsvg \
	--enable-menu-entries \
	--with-default-plugins=%{plugins}
%make_build

%install
%make_install

# image for cube
install -Dpm644 %{_sourcedir}/mageia-top.png %{buildroot}%{_datadir}/compiz/%{_real_vendor}.png

install -D -m644 %{_sourcedir}/%{name}.defaults %{buildroot}%{_datadir}/compositing-wm/%{name}.defaults
install -m755 %{_sourcedir}/%{name}-fusion %{buildroot}%{_bindir}/%{name}-fusion
install -m644 %{_sourcedir}/%{name}-fusion.defaults %{buildroot}%{_datadir}/compositing-wm/%{name}-fusion.defaults

# we don't want these
find %{buildroot} -name "*.la" -delete

# Compiz now provides a script to choose decorator, so we dropped our own
# make a link to not break existing setup which rely on former script.
ln -s %{_bindir}/%{name}-decorator %{buildroot}/%{_bindir}/%{name}-window-decorator

%find_lang %{name}
