%define major	6
%define libname	%mklibname concord %major
%define devname	%mklibname concord -d

Summary:	Command-line Logitech Harmony remote programmer
Name:		concordance
Version:	1.5
Release:	%mkrel 6
License:	GPLv3+
Group:          System/Kernel and hardware
URL:		https://www.phildev.net/concordance/
Source:		https://github.com/jaymzh/concordance/releases/download/v%{version}/%{name}-%{version}.tar.bz2
BuildRequires:	pkgconfig(hidapi-libusb)
BuildRequires:	pkgconfig(libzip)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	python3-devel
BuildRequires:	perl-devel
BuildRequires:	swig

%description
This command-line software allows you to program your Logitech Harmony
remote using a configuration object retrieved from the Harmony website.

%package -n libconcord-common
Summary:	Common files of libconcord
Group:		System/Libraries

%description -n libconcord-common
Common files required by Logitech Harmony remote programmer library.

%package -n %{libname}
Summary:	System library of libconcord
Group:		System/Libraries
Requires:	libconcord-common >= %{version}-%{release}

%description -n %{libname}
Logitech Harmony remote programmer library for applications that use it.

%package -n %{devname}
Summary:	Development headers for libconcord
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	concord-devel = %{version}-%{release}

%description -n %{devname}
Development headers for developing applications that use libconcord, a
Logitech Harmony remote programmer library.

%package -n perl-concord
Summary:	Perl bindings for libconcord
Group:		Development/Perl
Requires:	%{libname} = %{version}-%{release}

%description -n perl-concord
Perl bindings for libconcord, a Logitech Harmony remote programmer
library.

%package -n python3-libconcord
Summary:	Python 3 bindings for libconcord
Group:		Development/Python
Requires:	%{libname} = %{version}-%{release}

%description -n python3-libconcord
Python 3 bindings for libconcord, a Logitech Harmony remote programmer
library.

%prep
%autosetup -p1

%build
pushd libconcord
  # patch0
  autoreconf -fi
  %configure --disable-static --disable-mime-update
  %make_build
  %make_build udev
popd

pushd libconcord/bindings/perl
  swig -perl5 concord.i
  %{__perl} Makefile.PL INSTALLDIRS=vendor INC=-I../..
  %make_build OTHERLDFLAGS="-L../../.libs" LDLOADLIBS="-lconcord"
popd

pushd concordance
  %configure CPPFLAGS=-I../libconcord LDFLAGS="%{?ldflags} -L../libconcord/.libs"
  %make_build
popd

pushd consnoop
  %make_build CXXFLAGS="%{optflags} %{?ldflags}"
popd

pushd libconcord/bindings/python
#   2to3-%{python3_version} -w libconcord.py
  %pyproject_wheel
popd

%install
%make_install -C libconcord \
	install_udev UDEVROOT=%{_prefix}
#
%make_install -C libconcord/bindings/perl
%make_install -C concordance

pushd libconcord/bindings/python
  %pyproject_install
  %pyproject_save_files libconcord
popd

# useful or not? include for now:
install -m755 consnoop/consnoop %{buildroot}%{_bindir}

# fix debug info extraction
chmod u+w %{buildroot}%{perl_vendorarch}/auto/concord/concord.so

%post -n libconcord-common
# apply new/updated rules
/sbin/udevadm trigger --subsystem-match=usb --attr-match=idVendor=046d --attr-match=idProduct="c1*"
/sbin/udevadm trigger --subsystem-match=usb --attr-match=idVendor=0400 --attr-match=idProduct="c359"

%files
%doc README.md
%doc Changelog
%{_bindir}/concordance
%{_mandir}/man1/concordance.1*

%files -n libconcord-common
%{_udevrulesdir}/80-libconcord-usbnet.rules
%{_udevrulesdir}/60-libconcord.rules
%{_prefix}/lib/udev/start_concordance_dhcpd.sh
%{_prefix}/lib/udev/start_concordance_dhcpd_wrapper.sh
%{_datadir}/mime/packages/libconcord.xml

%files -n %{libname}
%{_libdir}/libconcord.so.%{major}{,.*}

%files -n %{devname}
%doc libconcord/README
%{_bindir}/consnoop
%{_libdir}/libconcord.so
%{_includedir}/libconcord.h

%files -n perl-concord
%{perl_vendorarch}/concord.pm
%{perl_vendorarch}/auto/concord/

%files -n python3-libconcord -f %{pyproject_files}
