%bcond_with audacious
%bcond_without wlan
%bcond_without rsvg
%bcond_without wayland

Name:           conky
Version:        1.22.0
Release:        %mkrel 2
Summary:        A lightweight system monitor
License:        GPLv3+
Group:          Monitoring
Url:            https://github.com/brndnmtthws/conky
Source0:        https://github.com/brndnmtthws/conky/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  docbook-style-xsl
BuildRequires:  docbook5-style-xsl
BuildRequires:  docbook2x
BuildRequires:  git-core
BuildRequires:  gperf
BuildRequires:  man
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  libxslt-proc
BuildRequires:  libiw-devel
BuildRequires:  lua5.4-devel
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(xcb)

%{?with_wayland:BuildRequires:  wayland-devel wayland-tools pkgconfig(wayland-protocols)}

%{?with_rsvg:BuildRequires:  pkgconfig(librsvg-2.0)}
%{?with_wlan:BuildRequires: wireless-tools}
# There is no audclient beginning with audacious 3.5
# which is our current cauldron one and compilation
# fails. Disable audacious support until it is fixed by upstream.
%{?with_audacious:BuildRequires:        pkgconfig(dbus-glib-1) pkgconfig(audacious)}
BuildRequires:  pkgconfig(alsa)

%description
Conky is a free, light-weight system monitor for X,
that displays any information on your desktop.

%prep
%autosetup -p1

# remove some options from CFLAGS
sed -i 's/\(-Werror\|-Wno-format\|-pedantic\)//g' cmake/ConkyBuildOptions.cmake

# and use our CFLAGS
sed -i '/set(CMAKE_C_FLAGS/,+5d' cmake/ConkyBuildOptions.cmake

# remove executable bits from files included in %{_docdir}
chmod a-x extras/convert.lua

for i in AUTHORS; do
    iconv -f iso8859-1 -t utf8 -o ${i}{_,} && touch -r ${i}{,_} && mv -f ${i}{_,}
done

%build
%cmake \
	-DRELEASE=ON \
        -DMAINTAINER_MODE=ON \
        -DBUILD_BUILTIN_CONFIG=OFF \
        -DBUILD_PORT_MONITORS=OFF \
        -DBUILD_CURL=ON \
        -DBUILD_DOCS=OFF \
        -DBUILD_IBM=OFF \
        -DBUILD_IMLIB2=ON \
        -DBUILD_LUA_CAIRO=ON \
        -DBUILD_LUA_IMLIB2=ON \
        -DBUILD_MOC=OFF \
        -DBUILD_MPD=OFF \
        -DBUILD_NCURSES=OFF \
        -DBUILD_RSS=ON \
        -DBUILD_WEATHER_METAR=ON \
        -DBUILD_WEATHER_XOAP=ON \
        -DBUILD_XDBE=ON \
	-DBUILD_HSV_GRADIENT=0 \
    %{?with_wayland:        -DBUILD_WAYLAND=ON} \
    %{?with_audacious:      -DBUILD_AUDACIOUS=ON} \
    %{?with_wlan:           -DBUILD_WLAN=ON} \
    %{?with_rsvg:           -DBUILD_LUA_RSVG=ON} \
        -DBUILD_PULSEAUDIO=ON \
	-DBUILD_JOURNAL=ON \
	-DBUILD_XINPUT=OFF \
	-DBUILD_LUA_IMLIB2=OFF

%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_sysconfdir}/conky

install -m644 -p data/conky.conf %{buildroot}%{_sysconfdir}/conky
rm -rf %{buildroot}%{_docdir}/conky-*

rm -rf %{buildroot}%{_includedir}/Vc
rm -rf %{buildroot}%{_libdir}/cmake/Vc

%files
%doc AUTHORS README.md extras/*
%license COPYING
%dir %{_sysconfdir}/conky
%config %{_sysconfdir}/conky/conky.conf
%{_bindir}/conky
%{_libdir}/conky/
%{_libdir}/libconky_core.so
%{_datadir}/applications/conky.desktop
%{_iconsdir}/hicolor/scalable/apps/conky-logomark-violet.svg
