Name:           coq
Version:        8.16.1
Release:        %mkrel 1
Summary:        The Coq Proof Assistant
Group:          Sciences/Computer science
# The project as a whole is LGPL-2.1-only.  Exceptions:
# - clib/diff2.ml is MIT
# - gramlib is BSD-3-Clause
License:        LGPL-2.1-only AND MIT AND BSD-3-Clause
URL:            https://coq.inria.fr
Source0:        https://github.com/coq/coq/archive/V%{version}/%{name}-%{version}.tar.gz
Source2:        https://github.com/coq/coq/releases/download/V%{version}/coq-%{version}-reference-manual.pdf
# Sphinx documentation fails with sphinx 5+ (`language` must be set to
# an actual value, not `None`)
# https://github.com/coq/coq/pull/16310
Patch0:         16310.patch

BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-compiler-libs
BuildRequires:  ocaml-dune >= 2.5.0
BuildRequires:  ocaml-findlib-devel >= 1.8.1
BuildRequires:  ocaml-lablgtk3-devel
BuildRequires:  ocaml-lablgtk3-sourceview3-devel
BuildRequires:  ocaml-ounit-devel
BuildRequires:  ocaml-zarith-devel >= 1.11
BuildRequires:  ocaml-zarith >= 1.11
BuildRequires:  antlr4
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  texlive
BuildRequires:  imagemagick
BuildRequires:  gtksourceview3-devel
BuildRequires:  libicns-utils
BuildRequires:  python3-devel
BuildRequires:  python3dist(antlr4-python3-runtime)
BuildRequires:  rsync
BuildRequires:  time

# For documentation
BuildRequires:  antlr4
BuildRequires:  hevea
# For latexmk:
BuildRequires:  texlive-collection-basic
BuildRequires:  python3-devel
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme

Requires:       ocaml-findlib

# Exclude private ocaml interfaces that we don't Provide
%global __requires_exclude ocamlx?\\\((Configwin_types|Interface|Richpp|Serialize|Xml_p(arser|rinter)|Xmlprotocol)\\\)

%description
Coq is a proof assistant which:
  - allows to handle calculus assertions,
  - check mechanically proofs of these assertions,
  - helps to find formal proofs,
  - extracts a certified program from the constructive proof
    of its formal specification.


%package ide
Summary:        The Coq Integrated Development Interface
Group:          Sciences/Computer science
Requires:       %{name} = %{version}
Requires:       %{name}-ide-server = %{version}

%description ide
The Coq Integrated Development Interface is a graphical interface for the
Coq proof assistant.


%package ide-server
Summary:        The coqidetop language server
Group:          Sciences/Computer science

%description ide-server
The Coq Integrated Development Interface is a graphical interface for the
Coq proof assistant.
This package provides the coqidetop language server, an implementation of	
Coq's XML protocol which allows clients, such as CoqIDE, to interact with	
Coq in a structured way.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation
License:        Open Publication License
BuildArch:      noarch
Requires:       font(fontawesome)
Requires:       font(lato)
Requires:       font(robotoslab)

%description doc
The %{name}-doc package contains documentation for %{name}.

%prep
%autosetup -p1

fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}

# Use our CFLAGS
sed -e 's|-Wall.*-O2|%{build_cflags} %{build_ldflags} -Wno-unused|' \
    -e 's| -march=native||' \
    -i tools/configure/configure.ml

# Make sure debuginfo is generated
sed -i 's,-shared,& -g,g' tools/CoqMakefile.in

# Do not invoke env
for f in doc/tools/coqrst/notations/fontsupport.py;
do
  sed -i.orig 's,/usr/bin/env python2,%{python3},' $f
  fixtimestamp $f
done
for f in $(grep -Frl '%{_bindir}/env'); do
  sed -r -i.orig 's,(%{_bindir}/)env[[:blank:]]+([[:alnum:]]+),\1\2,g' $f
  fixtimestamp $f
done

%build
%global coqdocdir %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/coq-%{version}}

# Regenerate ANTLR files
cd doc/tools/coqrst/notations
antlr4 -Dlanguage=Python3 -visitor -no-listener TacticNotations.g
cd -

%ifarch %{ocaml_native_compiler}
%global opt_option -native-compiler yes -coqide opt -bin-annot
%else
%global opt_option -byte-only -coqide byte
%endif
%ifarch %{ocaml_natdynlink}
%global opt_option %{opt_option} -natdynlink yes
%else
%global opt_option %{opt_option} -natdynlink no
%endif

# Set our configuration options
./configure -prefix %{_prefix}                       \
            -libdir %{ocamldir}/coq                  \
            -mandir %{_mandir}                       \
            -docdir %{coqdocdir}                     \
            -configdir %{_sysconfdir}/xdg/%{name}    \
            -bytecode-compiler yes                   \
            %{opt_option}                            \
            -browser "xdg-open %s"                   \
            -with-doc no

# Build the binary artifacts
export SPHINXWARNOPT="-w$PWD/sphinx-warn.log"
make world VERBOSE=1


%install
%make_install

# FIXME: why didn't this install in libdir?
mkdir -p %{buildroot}%{ocamldir}
mv %{buildroot}%{_prefix}/lib/{coq*,stublibs} %{buildroot}%{ocamldir}

# Install the LaTeX style file
# mkdir -p %%{buildroot}%%{_texmf_main}/tex/latex/misc
# mv %%{buildroot}%%{_datadir}/texmf/tex/latex/misc/coqdoc.sty \
#    %%{buildroot}%%{_texmf_main}/tex/latex/misc
# rm -fr %%{buildroot}%%{_datadir}/texmf

# FIXME: dune ignores the configdir argument to configure
mkdir -p %{buildroot}%{_sysconfdir}/xdg/%{name}

for png in 256x256 48x48 32x32 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png ide/coqide/%{name}.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_pkgdocdir}
install -Dpm644 %{SOURCE2} %{buildroot}%{_pkgdocdir}/

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=CoqIDE
Comment=Coq integrated developpment environment
Exec=%{_bindir}/coqide
Icon=coq
Type=Application
Categories=Education;Science;Math;
EOF


%files
%doc %{_pkgdocdir}/coq-core/README.md
%doc %{_pkgdocdir}/coq-core/LICENSE
%{_bindir}/*
%{_libdir}/ocaml/coq
%{ocamldir}/coq-core/
%{ocamldir}/stublibs/dllcoqrun_stubs.so
%{_mandir}/man1/*
%{_datadir}/%{name}/
%exclude %{_bindir}/coqide*
%{_datadir}/texmf/tex/latex/misc/coqdoc.sty

%files ide
%doc %{_pkgdocdir}/coqide/README.md
%doc %{_pkgdocdir}/coqide/LICENSE
%doc %{_pkgdocdir}/coqide/FAQ
%{_sysconfdir}/xdg/coq/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_bindir}/coqide*
%{ocamldir}/coqide/

%files ide-server
%doc %{_pkgdocdir}/coqide-server/LICENSE
%doc %{_pkgdocdir}/coqide-server/README.md
%{_libdir}/ocaml/coqide-server/

%files doc
%doc %{_pkgdocdir}/coq-%{version}-reference-manual.pdf
%doc %{_pkgdocdir}/coqide/odoc-pages/index.mld
