Summary:	The GNU core utilities: a set of tools commonly used in shell scripts
Name:		coreutils
Version:	9.5
Release:	%mkrel 3
License:	GPLv3+
Group:		System/Base
Url:		https://www.gnu.org/software/coreutils/
Source0:	https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz

# disable the test-lock gnulib test prone to deadlock
Patch100: coreutils-8.26-test-lock.patch

# use python3 in tests
Patch103: coreutils-python3.patch

# df --direct
Patch104: coreutils-df-direct.patch

# coreutils no longer lists Cockpit logins in `who` (rhbz#2307847)
# https://git.savannah.gnu.org/cgit/gnulib.git/patch/?id=43f7f428a1665950233557bd97611bd5e996b5cb
Patch105: coreutils-9.5-readutmp-web-session.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=2325167
Patch106: coreutils-nproc-affinity-1.patch
Patch107: coreutils-nproc-affinity-2.patch

# fileutils
Patch1155:	coreutils-8.24-force-option--override--interactive-option.patch
Patch118:	fileutils-8.17-ls_h.patch
Patch500:	coreutils-8.3-mem.patch

# add info about TZ envvar to date manpage
Patch703:	coreutils-8.21-dateman.patch

# (sb) lin18nux/lsb compliance - multibyte functionality patch
# http://www.openi18n.org/subgroups/utildev/patch/
# fwang: we often get this patch from fedora
Patch800:	coreutils-i18n.patch

Patch909:	coreutils-5.1.0-64bit-fixes.patch

# https://qa.mandriva.com/show_bug.cgi?id=38577
Patch911:	coreutils-8.3-groupfix.patch

Patch1011:	coreutils-9.4-DIR_COLORS-mdkconf.patch
#(peroyvind): add back always red blinking on broken symlinks
Patch1013:	coreutils-8.2-always-blinking-colors-on-broken-symlinks.patch
#(peroyvind): fix a test that fails to compile with -Werror=format-security
Patch1014:	coreutils-8.22-check-string-format.patch

#getgrouplist() patch from Ulrich Drepper.
Patch2908:	coreutils-getgrouplist.patch

#Prevent buffer overflow in who(1) (bug #158405).
Patch2912:	coreutils-overflow.patch

# Fix error: implicit declaration of function 'xrealloc';
Patch3000:	coreutils-gcc14.patch

BuildRequires:	locales-fr
BuildRequires:	locales-ja
BuildRequires:	locales-zh
BuildRequires:	locales-tr
BuildRequires:	gettext
BuildRequires:	termcap-devel
BuildRequires:	texinfo >= 4.3
# We need automake which supports the dist-xz target
BuildRequires:	automake >= 1.10.2-2
# And tar which supports xz automagically since rpm.org seems to rely on this(..?)
BuildRequires:	tar >= 1.21-2
BuildRequires:	libacl-devel
BuildRequires:	libattr-devel
BuildRequires:	libgmp-devel
BuildRequires:	pkgconfig(libcap)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	strace
BuildRequires:	systemd-devel
Requires(pre):	filesystem >= 2.1.9-18

Provides:	mktemp = %{version}
Obsoletes:	mktemp < %{version}

Provides:	stat = %{version}
Provides:	%{_bindir}/env
Provides:	/bin/env
Obsoletes:	base64 < %{version}

%description
This package is the union of the old GNU fileutils, sh-utils, and
textutils packages.

These tools are the GNU versions of common useful and popular
file & text utilities which are used for:
- file management
- shell scripts
- modifying text file (splitting, joining, comparing, modifying, ...)

Most of these programs have significant advantages over their Unix
counterparts, such as greater speed, additional options, and fewer
arbitrary limits.

%package	doc
Summary:	Coreutils documentation in info format
Group:		Documentation
Requires:	coreutils >= 4.5.4-2
BuildArch:	noarch

%description	doc
This package contains coreutils documentation in GNU info format.

%prep
%autosetup -p1

chmod a+x tests/misc/sort-mb-tests.sh
chmod +w ./src/dircolors.h
./src/dcgen ./src/dircolors.hin > ./src/dircolors.h

%build
export CFLAGS="%{optflags} -fPIC"
export CPPFLAGS="-D_GNU_SOURCE=1 -Dlint"
autoreconf -fi
%configure \
	--enable-largefile \
	--enable-no-install-program=hostname,uptime,kill \
	--enable-install-program=arch \
	--without-selinux \
	--enable-systemd \
	--disable-rpath

%make_build
bzip2 -9 ChangeLog

%check
#make check

%install
%make_install

# let be compatible with old fileutils, sh-utils and textutils packages :
mkdir -p %{buildroot}{%{_sbindir},%{_sysconfdir}}

# chroot was in /usr/sbin :
mv %{buildroot}/{%{_bindir},%{_sbindir}}/chroot

install -m644 src/dircolors.hin -D %{buildroot}%{_sysconfdir}/DIR_COLORS

#TV# find_lang look for LC_MESSAGES, not LC_TIME:
#TV(cd %{buildroot}; find .%_datadir/locale/ -name coreutils.mo | fgrep LC_TIME | \
#TV	sed -e "s!^.*/share/locale/\([^/]*\)/!%lang(\1) %_datadir/locale/\1/!") >> %name.lang
find %{buildroot}%{_datadir}/locale/ -name coreutils.mo | fgrep LC_TIME | xargs rm -f

%find_lang %{name}

%files -f %{name}.lang
%doc README
%config(noreplace) %{_sysconfdir}/DIR_COLORS
%{_bindir}/[
%{_bindir}/arch
%{_bindir}/b2sum
%{_bindir}/base32
%{_bindir}/base64
%{_bindir}/basename
%{_bindir}/basenc
%{_bindir}/cat
%{_bindir}/chcon
%{_bindir}/chgrp
%{_bindir}/chmod
%{_bindir}/chown
%{_bindir}/cksum
%{_bindir}/comm
%{_bindir}/cp
%{_bindir}/csplit
%{_bindir}/cut
%{_bindir}/date
%{_bindir}/dd
%{_bindir}/df
%{_bindir}/dir
%{_bindir}/dircolors
%{_bindir}/dirname
%{_bindir}/du
%{_bindir}/echo
%{_bindir}/env
%{_bindir}/expand
%{_bindir}/expr
%{_bindir}/factor
%{_bindir}/false
%{_bindir}/fmt
%{_bindir}/fold
%{_bindir}/groups
%{_bindir}/head
%{_bindir}/hostid
%{_bindir}/id
%{_bindir}/install
%{_bindir}/join
%{_bindir}/link
%{_bindir}/ln
%{_bindir}/logname
%{_bindir}/ls
%{_bindir}/md5sum
%{_bindir}/mkdir
%{_bindir}/mkfifo
%{_bindir}/mknod
%{_bindir}/mktemp
%{_bindir}/mv
%{_bindir}/nice
%{_bindir}/nl
%{_bindir}/nohup
%{_bindir}/nproc
%{_bindir}/numfmt
%{_bindir}/od
%{_bindir}/paste
%{_bindir}/pathchk
%{_bindir}/pinky
%{_bindir}/pr
%{_bindir}/printenv
%{_bindir}/printf
%{_bindir}/ptx
%{_bindir}/pwd
%{_bindir}/readlink
%{_bindir}/realpath
%{_bindir}/rm
%{_bindir}/rmdir
%{_bindir}/runcon
%{_bindir}/seq
%{_bindir}/sha1sum
%{_bindir}/sha224sum
%{_bindir}/sha256sum
%{_bindir}/sha384sum
%{_bindir}/sha512sum
%{_bindir}/shred
%{_bindir}/shuf
%{_bindir}/sleep
%{_bindir}/sort
%{_bindir}/split
%{_bindir}/stat
%{_bindir}/stdbuf
%{_bindir}/stty
%{_bindir}/sum
%{_bindir}/sync
%{_bindir}/tac
%{_bindir}/tail
%{_bindir}/tee
%{_bindir}/test
%{_bindir}/timeout
%{_bindir}/touch
%{_bindir}/tr
%{_bindir}/true
%{_bindir}/truncate
%{_bindir}/tsort
%{_bindir}/tty
%{_bindir}/uname
%{_bindir}/unexpand
%{_bindir}/uniq
%{_bindir}/unlink
%{_bindir}/users
%{_bindir}/vdir
%{_bindir}/wc
%{_bindir}/who
%{_bindir}/whoami
%{_bindir}/yes
%{_sbindir}/chroot
# This should really be in %%_libdir since it is a library, but coreutils
# builds it using the _PROGRAMS automake primary to avoid libtool, and
# pkglibdir_PROGRAMS is not allowed by automake v1.11-373-g9ca6326
# (since programs should be in pkglibexecdir, and libraries in pkglibdir),
# hence it was put in libexecdir. This is not terribly important, so I
# let it be (note that moving it is not enough, the path is built into
# the stdbuf binary). - Anssi 2012-07
%dir %{_libexecdir}/coreutils
%{_libexecdir}/coreutils/libstdbuf.so

%files doc
%doc ABOUT-NLS ChangeLog.bz2 NEWS THANKS TODO
%{_infodir}/coreutils*
%{_mandir}/man*/*
