%define		sname turnserver

# We don't yet ship libmongoc
#bcond_with	build_mongodb
%bcond_without	build_redis

Name:		coturn
Version:	4.6.2
Release:	%mkrel 2
Group:		System/Servers
License:	BSD
Summary:	Free open source implementation of TURN and STUN Server
URL:		https://coturn.github.io
Source:		https://github.com/%{name}/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(openssl) >= 1.0.2
BuildRequires:	pkgconfig(libevent) >= 2.0
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	sqlite3-tools
BuildRequires:	pkgconfig(libpq)
BuildRequires:	mysql-devel
#if with build_mongodb
#BuildRequires:	pkgconfig(mongoc)
#endif
%if %with build_redis
BuildRequires:	pkgconfig(hiredis)
%endif

%description
The TURN Server is a VoIP media traffic NAT traversal server and gateway.
It can be used as a general-purpose network traffic TURN server and gateway, too.

%prep
%setup -q
%autopatch -p1

%build

# We don't like the way the docs, schemas and examples are packaged
# So we let them be installed and then remove them
%configure \
    -confdir=%{_sysconfdir}/%{sname} \
    -turndbdir=%{_localstatedir}/db \
    -docsdir=%{_datadir}/%{name}/doc \
    -examplesdir=%{_datadir}/%{name}/examples \
    -schemadir=%{_datadir}/%{name}/schema \
    -mandir=%{_datadir} \
    --disable-rpath

%make_build
%make_build sqlite/turndb

%check
%make_build check

%install

%make_install

# Is the client library really needed outside coturn?
rm -rf %{buildroot}%{_includedir}/turn
rm -f %{buildroot}%{_libdir}/libturnclient.a

# Remove docs, examples and schemas installed by Makefile
rm -rf %{buildroot}/%{_datadir}/%{name}
mv postinstall.txt README.urpmi

mv %{buildroot}%{_sysconfdir}/%{sname}/%{sname}.conf.default %{buildroot}%{_sysconfdir}/%{sname}/%{sname}.conf
install -D -p -m 0644 rpm/%{sname}.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/%{sname}
install -d %{buildroot}%{_localstatedir}/run/%{sname}
install -D -p -m 0644 rpm/%{sname}-tmpfiles.conf %{buildroot}%{_tmpfilesdir}/%{sname}.conf

# Revert to forking to avoid start timeout
# TODO: change back when fixed, see https://github.com/coturn/coturn/issues/118
sed -i -e 's!Type=notify!Type=exec\nPIDFile=/run/turnserver/turnserver.pid!' \
	-e 's!/var/run/turnserver/turnserver.pid!/run/turnserver/turnserver.pid!' \
	rpm/%{sname}.service.fc

install -D -p -m 0644 rpm/%{sname}.service.fc %{buildroot}%{_unitdir}/%{sname}.service

sed -i -e "s/#syslog/syslog/g" \
    -e "s/#no-stdout-log/no-stdout-log/g" \
    %{buildroot}/%{_sysconfdir}/%{sname}/%{sname}.conf

sed -i -e "s/#pidfile/pidfile/g" \
    -e "s:/var/run/turnserver.pid:/run/turnserver/turnserver.pid:g" \
    %{buildroot}%{_sysconfdir}/%{sname}/%{sname}.conf

%pre
%_pre_useradd %{sname} /var/run/%{sname} /bin/sh
%_pre_groupadd %{sname} %{sname}

%preun
%_preun_service %{sname}

%post
%_tmpfilescreate %{sname}
%_post_service %{sname}

%postun
%_postun_userdel %{sname}
%_postun_groupdel %{sname}

%files
%doc turndb examples/ca examples/etc examples/scripts
%doc AUTHORS.md ChangeLog INSTALL LICENSE README.* STATUS.md
%dir %attr(0755,root,turnserver) %{_sysconfdir}/%{sname}
%attr(0640,root,turnserver) %config(noreplace) %{_sysconfdir}/%{sname}/%{sname}.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{sname}
%{_unitdir}/%{sname}.service
%{_tmpfilesdir}/%{sname}.conf
%{_bindir}/turnadmin
%{_bindir}/turnserver
%{_bindir}/turnutils_peer
%{_bindir}/turnutils_stunclient
%{_bindir}/turnutils_uclient
%{_bindir}/turnutils_oauth
%{_bindir}/turnutils_natdiscovery
%attr(0640,turnserver,turnserver) %{_localstatedir}/db/turndb
%{_mandir}/man1/*
