Name:           courier-authlib
Version:        0.72.1
Release:        %mkrel 2
Summary:        Courier authentication library
Group:          System/Servers
License:        GPLv3
URL:            https://www.courier-mta.org/authlib/
Source0:        https://downloads.sourceforge.net/courier/%{name}-%{version}.tar.bz2
Source1:        courier-authlib.sysconftool.m4
Source2:        courier-authdaemon.service
Patch0:         courier-authlib-0.58.sysconftool.patch
BuildRequires:  expect
BuildRequires:  libltdl-devel
BuildRequires:  gdbm-devel
BuildRequires:  openldap-devel
BuildRequires:  pam-devel
BuildRequires:  mysql-devel
BuildRequires:  postgresql-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  courier-unicode-devel
BuildRequires:  pkgconfig(libidn2)

%description
The Courier authentication library provides authentication
services for other Courier applications.

This package contains the Courier authentication daemon and common
authentication modules:

 o authcustom
 o authpam
 o authpwd
 o authshadow
 o courierauthsaslclient
 o courierauthsasl

%package -n courier-authdaemon
Summary:        Courier authentication daemon
Group:          System/Servers
Requires:       %{name} = %{version}
Requires:       expect
Requires(post): systemd >= %{systemd_required_version}
Requires(pre):  rpm-helper

%description -n courier-authdaemon
This package contains the Courier authentication daemon.

%package userdb
Summary:        Userdb support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description userdb
This package installs the userdb support for the Courier
authentication library.  Userdb is a simple way to manage virtual
mail accounts using a GDBM-based database file.

Install this package in order to be able to authenticate with
userdb.

%package ldap
Summary:        LDAP support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description ldap
This package installs LDAP support for the Courier authentication
library. Install this package in order to be able to authenticate
using LDAP.

%package mysql
Summary:        MySQL support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description mysql
This package installs MySQL support for the Courier authentication
library. Install this package in order to be able to authenticate
using MySQL.

%package pgsql
Summary:        MySQL support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description pgsql
This package installs PostgreSQL support for the Courier
authentication library. Install this package in order to be able
to authenticate using PostgreSQL.

%package sqlite
Summary:        SQLite support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description sqlite
This package installs sqlite support for the Courier
authentication library. Install this package in order to be able to
authenticate using SQLite.

%package devel
Summary:        Development libraries for the Courier authentication library
Group:          Development/C
Requires:       %{name} = %{version}

%description devel
This package contains the development libraries and files needed
to compile Courier packages that use this authentication library.
Install this package in order to build the rest of the Courier
packages. After they are built and installed this package can be
removed. Files in this package are not needed at runtime.

%prep
%setup -q
%patch -P 0 -p0 -b .sysconftool

install -Dpm644 %{SOURCE1} sysconftool.m4

%build
autoreconf -vfi -I.
%configure \
    --disable-static \
    --with-syslog=MAIL \
    --disable-ltdl-install \
    --with-db=gdbm \
    --with-random=/dev/urandom \
    --with-mailuser=daemon \
    --with-mailgroup=daemon \
    --with-authdaemonrc=%{_sysconfdir}/courier/authdaemonrc \
    --with-authdaemonvar=%{_rundir}/courier/authdaemon \
    --with-makedatprog=%{_sbindir}/makedatprog \
    --with-userdb=%{_sysconfdir}/userdb \
    --with-pkgconfdir=%{_sysconfdir}/courier \
    --with-authuserdb \
    --with-authpam \
    --with-authldap \
    --with-authldaprc=%{_sysconfdir}/courier/authldaprc \
    --with-authpwd \
    --with-authshadow \
    --without-authvchkpw \
    --with-authpgsqlrc=%{_sysconfdir}/courier/authpgsqlrc \
    --with-authpgsql \
    --with-pgsql-libs=%{_libdir} \
    --with-pgsql-includes=%{_includedir}/pgsql \
    --with-authmysqlrc=%{_sysconfdir}/courier/authmysqlrc \
    --with-authmysql \
    --with-mysql-libs=%{_libdir} \
    --with-mysql-includes=%{_includedir}/mysql \
    --with-authcustom
%make_build
#make_build authinfo

%check
%{__make} check

%install
%make_install

find %{buildroot} -name '*.la' -delete

install -m 755 sysconftool %{buildroot}%{_libdir}/courier-authlib/

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/courier-authdaemon.service
mv %{buildroot}%{_libexecdir}/courier-authlib/authdaemond %{buildroot}%{_sbindir}/authdaemond

mv %{buildroot}%{_libexecdir}/courier-authlib/makedatprog %{buildroot}%{_sbindir}/makedatprog

# some utils...
# install -m 755 authinfo %%{buildroot}%%{_sbindir}/
#install -m 755 authdaemontest %%{buildroot}%%{_sbindir}/
#install -m 755 liblock/lockmail %%{buildroot}%%{_sbindir}/
#install -m 644 liblock/lockmail.1 %%{buildroot}%%{_mandir}/man1/

# fix configuration
for file in %{buildroot}%{_sysconfdir}/courier/*.dist; do
    mv $file  %{buildroot}%{_sysconfdir}/courier/`basename $file .dist`
done
chmod 644 %{buildroot}%{_sysconfdir}/courier/*

perl -pi \
    -e "s|^authmodulelist=.*|authmodulelist=\"authpam authpwd authshadow\"|g;" \
    -e "s|^authmodulelistorig=.*|authmodulelistorig=\"authpam authpwd authshadow\"|g;" \
    %{buildroot}%{_sysconfdir}/courier/authdaemonrc

cat > README.mga << EOF
Mageia RPM specific notes

Upgrade
------
Default upgrade procedure consists of shipping new configuration files with
.dist suffix, then running sysconftool script to merge with current
configuration. This packages ships new configuration files with their final
name instead, wich will be saved by rpm as .rpmnew if original ones have been
modified, and run sysconftools script during upgrade automatically.
EOF

# Fix path to libs
cat > courier-authlib.conf << EOF
%{_libdir}/courier-authlib
EOF
install -d %{buildroot}%{_sysconfdir}/ld.so.conf.d
install -m 755 courier-authlib.conf %{buildroot}%{_sysconfdir}/ld.so.conf.d

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
#Type Path                    Mode UID     GID     Age Argument
    d /run/courier            0775 root    courier -   -
    d /run/courier/authdaemon 0750 courier courier -   -
EOF

install -d -m 0755 %{buildroot}%{_rundir}/courier/authdaemon

%post -n courier-authdaemon
if [ -f %{_sysconfdir}/courier/authdaemonrc.rpmnew ]; then
    %{_libdir}/courier-authlib/sysconftool %{_sysconfdir}/courier/authdaemonrc.rpmnew >/dev/null
fi
%_tmpfilescreate %{name}
%_post_service courier-authdaemon

%preun -n courier-authdaemon
%_preun_service courier-authdaemon

%post ldap
if [ -f %{_sysconfdir}/courier/authldaprc.rpmnew ]; then
    %{_libdir}/courier-authlib/sysconftool %{_sysconfdir}/courier/authldaprc.rpmnew >/dev/null
fi

%post mysql
if [ -f %{_sysconfdir}/courier/authmysqlrc.rpmnew ]; then
    %{_libdir}/courier-authlib/sysconftool %{_sysconfdir}/courier/authmysqlrc.rpmnew >/dev/null
fi

%files
%license COPYING*
%doc README.mga README README.authdebug.html README.html README_authlib.html
%doc NEWS AUTHORS ChangeLog
%dir %{_sysconfdir}/courier
%dir %{_libdir}/courier-authlib
%dir %{_libexecdir}/courier-authlib
%{_sysconfdir}/ld.so.conf.d/courier-authlib.conf
%{_libexecdir}/courier-authlib/authsystem.passwd
%{_libdir}/courier-authlib/sysconftool
%{_libdir}/courier-authlib/libcourierauthsaslclient.so*
%{_libdir}/courier-authlib/libcourierauthsasl.so*
%{_libdir}/courier-authlib/libcourierauthcommon.so*
%{_libdir}/courier-authlib/libcourierauth.so*
%{_libdir}/courier-authlib/libauthcustom.so*
%{_libdir}/courier-authlib/libauthpam.so*
%{_libdir}/courier-authlib/libauthpwd.so*
%{_libdir}/courier-authlib/libauthshadow.so*
%{_libdir}/courier-authlib/libauthpipe.so*
%{_mandir}/man1/*

%files -n courier-authdaemon
%config(noreplace) %{_sysconfdir}/courier/authdaemonrc
%{_tmpfilesdir}/%{name}.conf
%{_sbindir}/authdaemond
%{_sbindir}/authenumerate
%{_sbindir}/authtest
%{_sbindir}/courierlogger
%{_sbindir}/authpasswd
%{_sbindir}/makedatprog
%{_unitdir}/courier-authdaemon.service
%dir %ghost %attr(0775, root, courier) %{_rundir}/courier
%dir %ghost %attr(0750, courier, courier) %{_rundir}/courier/authdaemon
%ghost %attr(0660, -, -) %{_rundir}/courier/authdaemon/authdaemon.pid

%files userdb
%doc userdb/makeuserdb.html userdb/userdb.html userdb/userdbpw.html
%{_sbindir}/makeuserdb
%{_sbindir}/pw2userdb
%{_sbindir}/userdb
%{_sbindir}/userdbpw
%{_libdir}/courier-authlib/libauthuserdb.so*
%{_mandir}/man8/*userdb*

%files ldap
%doc README.ldap authldap.schema
%config(noreplace) %{_sysconfdir}/courier/authldaprc
%{_libdir}/courier-authlib/libauthldap.so*

%files mysql
%doc README.authmysql.html README.authmysql.myownquery
%config(noreplace) %{_sysconfdir}/courier/authmysqlrc
%{_libdir}/courier-authlib/libauthmysql.so*

%files pgsql
%doc README.authpostgres.html
%config(noreplace) %{_sysconfdir}/courier/authpgsqlrc
%{_libdir}/courier-authlib/libauthpgsql.so*

%files sqlite
%doc README.authsqlite.html
%config(noreplace) %{_sysconfdir}/courier/authsqliterc
%{_libdir}/courier-authlib/libauthsqlite.so*

%files devel
%doc authlib.html auth_*.html
%{_bindir}/courierauthconfig
%{_includedir}/*
%{_mandir}/man3/*
