Name:           cppcheck
Version:        2.15.0
Release:        %mkrel 1
Summary:        Static analysis tool for C/C++
License:        GPLv3+
Group:          Development/C++
Url:            https://cppcheck.sourceforge.io/
Source:         https://github.com/danmar/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# Fix location of translations
Patch1:         cppcheck-2.11-translations.patch

BuildRequires:  cmake
BuildRequires:  docbook-style-xsl
BuildRequires:  libxslt-proc
# re-enable pcre support once an upstream port to pcre2
# https://trac.cppcheck.net/ticket/10610
#BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(setuptools-scm)
BuildRequires:  cmake(Qt6Charts)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)

%description
This program tries to detect bugs that your C/C++ compiler does not
find. Cppcheck is versatile. You can check non-standard code that includes
various compiler extensions, inline assembly code, etc. One of its goals
is no false positives.

%package gui
Summary:        Qt graphical user interface for cppcheck
Group:          Development/C++
Requires:       %{name} >= %{version}-%{release}

%description gui
This package contains the graphical user interface for cppcheck
based on Qt6.

%prep
%autosetup -p1
# Make sure bundled tinyxml2 is not used
rm -r externals/tinyxml2

%build
# re-enable pcre support once an upstream port to pcre2 (HAVE_RULES=ON)
%cmake -DHAVE_RULES=OFF \
       -DBUILD_GUI=ON \
       -DUSE_QT6=ON \
       -DWITH_QCHART=ON \
       -DFILESDIR=%{_datadir}/%{name} \
       -DUSE_BUNDLED_TINYXML2=OFF
%cmake_build

pushd htmlreport
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel
popd

# this command line is documented inside cppcheck.1.xml
pushd man
xsltproc --nonet --param man.charmap.use.subset "0" \
   --param make.year.ranges "1" --param make.single.year.ranges "1" \
   /usr/share/sgml/docbook/xsl-stylesheets/manpages/docbook.xsl \
   cppcheck.1.xml
popd

%check
%ifnarch aarch64
make -C build test
%endif
true

%install
%cmake_install

pushd htmlreport
%pyproject_install
# We only want the binary.
rm -rf %{buildroot}%{python3_sitelib}/cppcheck*
popd

install -D -m 0644 man/cppcheck.1 %{buildroot}%{_mandir}/man1/cppcheck.1

%files
%doc AUTHORS readme.txt
%license COPYING
%{_bindir}/cppcheck
%{_bindir}/cppcheck-htmlreport
%{_datadir}/cppcheck/
%{_mandir}/man1/cppcheck.1*

%files gui
%doc AUTHORS readme.txt
%license COPYING
%{_bindir}/cppcheck-gui
%{_datadir}/applications/cppcheck-gui.desktop
%{_iconsdir}/hicolor/*/apps/cppcheck-gui.png
%{_iconsdir}/hicolor/scalable/apps/cppcheck-gui.svg
