%define srcname stone_soup

Name:           crawl
Version:        0.32.1
Release:        %mkrel 3
Summary:        Dungeon Crawl Stone Soup, a roguelike RPG with 2D or ascii graphics
License:        GPLv2+
Group:          Games/Adventure
Url:            https://crawl.develz.org
Source0:        https://github.com/crawl/crawl/releases/download/%{version}/%{srcname}-%{version}-nodeps.tar.xz
Patch1:         stone_soup-build-flags.patch

BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  fonts-ttf-dejavu
BuildRequires:  lua5.1-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(pyyaml)

%description
Dungeon Crawl Stone Soup is a free rogue-like game of exploration and
treasure-hunting in dungeons filled with dangerous and unfriendly
monsters in a quest for the mystifyingly fabulous Orb of Zot.

The game has diverse species and many different character backgrounds
to choose from, deep tactical game-play, sophisticated magic, religion
and skill systems, and a grand variety of monsters to fight and run
from, making each game unique and challenging.

%package        common-data
Summary:        Common data for both game versions
Group:          Games/Adventure
BuildArch:      noarch

%description    common-data
This package contains common data used by the console and the tiles
version of the game.

%package        console
Summary:        Console version of Dungeon Crawl Stone Soup, a roguelike RPG
Group:          Games/Adventure
Requires:       %{name}-common-data = %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description    console
Dungeon Crawl Stone Soup is a free rogue-like game of exploration and
treasure-hunting in dungeons filled with dangerous and unfriendly
monsters in a quest for the mystifyingly fabulous Orb of Zot.

The game has diverse species and many different character backgrounds
to choose from, deep tactical game-play, sophisticated magic, religion
and skill systems, and a grand variety of monsters to fight and run
from, making each game unique and challenging.

This package contains the console version of Dungeon Crawl Stone Soup
(with ASCII characters). You can find a graphical version
with tiles in the package crawl-tiles.

%package        tiles
Summary:        Tiles version of Dungeon Crawl Stone Soup, a rogue-like RPG
Group:          Games/Adventure
Requires:       %{name}-common-data = %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description    tiles
Dungeon Crawl Stone Soup is a free rogue-like game of exploration and
treasure-hunting in dungeons filled with dangerous and unfriendly
monsters in a quest for the mystifyingly fabulous Orb of Zot.

The game has diverse species and many different character backgrounds
to choose from, deep tactical game-play, sophisticated magic, religion
and skill systems, and a grand variety of monsters to fight and run
from, making each game unique and challenging.

This package contains the tiles version of Dungeon Crawl Stone Soup.
You can find a console version with ASCII characters in the package
crawl-console.

%prep
%autosetup -p1 -n %{srcname}-%{version}

%{py3_shebang_fix} .

%define commonflags prefix=%{_prefix} DATADIR=%{_gamesdatadir}/%{name} BINDIR=%{_gamesbindir} NO_TRY_LLD=y

%build
export EXTERNAL_FLAGS="%{build_cxxflags}"
export EXTERNAL_LDFLAGS="%{build_ldflags}"

pushd source
%make_build %{commonflags}
mv %{name} %{name}-console
%make_build %{commonflags} TILES=y
popd

%install
export EXTERNAL_FLAGS="%{build_cxxflags}"
export EXTERNAL_LDFLAGS="%{build_ldflags}"

# Binaries
%make_install -C source %{commonflags} TILES=y
mv %{buildroot}%{_gamesbindir}/%{name} %{buildroot}%{_gamesbindir}/%{name}-tiles
install -m0755 source/%{name}-console %{buildroot}%{_gamesbindir}

# Symbolic link for crawl-console (used e.g. by noteye)
ln -s %{_gamesbindir}/%{name}-console %{buildroot}%{_gamesbindir}/%{name}

# Man page
install -D -m0644 docs/%{name}.6 %{buildroot}%{_mandir}/man6/%{name}.6

# Icons
install -D -m644 source/dat/tiles/stone_soup_icon-512x512.png %{buildroot}%{_iconsdir}/hicolor/512x512/apps/%{name}.png
install -D -m644 source/dat/tiles/stone_soup_icon-48x48.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png
install -D -m644 source/dat/tiles/stone_soup_icon-32x32.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
install -D -m644 source/dat/tiles/stone_soup_icon.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

# Menu entry
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Dungeon Crawl Stone Soup
Comment=Roguelike game with 2D graphics
GenericName=Roguelike game
Exec=%{name}-tiles
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Game;RolePlaying;
EOF

%files      common-data
%license LICENSE
%{_gamesdatadir}/%{name}/dat/
# Note: Some docs are loaded by the engine, shouldn't be moved (mga#28808).
%{_gamesdatadir}/%{name}/docs/
%{_gamesdatadir}/%{name}/settings/
%{_mandir}/man6/%{name}.6*
%exclude %{_gamesdatadir}/%{name}/dat/tiles/

%files      console
%{_gamesbindir}/%{name}
%{_gamesbindir}/%{name}-console

%files      tiles
%{_gamesbindir}/%{name}-tiles
%{_gamesdatadir}/%{name}/dat/tiles/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
