%undefine _hardened_build

%global major   2
%define libname %mklibname criu %{major}
%define devname %mklibname criu -d

Name:           criu
Version:        4.0
Release:        %mkrel 4
Summary:        Tool for Checkpoint/Restore in User-space
Group:          System/Base
License:        GPLv2
URL:            https://criu.org/
Source0:        https://github.com/checkpoint-restore/criu/archive/v%{version}/criu-%{version}.tar.gz
Source4:        criu-tmpfiles.conf
Patch:          Makefile.config-set-CR_PLUGIN_DEFAULT-variable.patch

BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  net2-devel
BuildRequires:  systemd
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libbsd)
BuildRequires:  pkgconfig(libnftables)
BuildRequires:  pkgconfig(libprotobuf-c)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  python3dist(pip)
BuildRequires:  python3dist(protobuf)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(wheel)
BuildRequires:  libdrm-devel

Requires:       python3-%{name} = %{version}-%{release}

Provides:       crtools = %{version}-%{release}
Obsoletes:      crtools < 1.2-2

# user-space and kernel changes are only available for x86_64, arm,
# ppc64le, aarch64 and s390x
# https://bugzilla.redhat.com/show_bug.cgi?id=902875
ExclusiveArch:  x86_64 %{arm} ppc64le aarch64 s390x

%description
criu is the user-space part of Checkpoint/Restore in User-space
(CRIU), a project to implement checkpoint/restore functionality for
Linux in user-space.

%package -n %{libname}
Summary:        A library for Checkpoint/Restore in User-space
Group:          System/Libraries

%description -n %{libname}
The %{libname} package contains libraries and header files for
developing applications that use criu.

%ifnarch %{arm}
%package amdgpu-plugin
Summary: AMD GPU plugin for %{name}
Requires: %{name} = %{version}-%{release}

%description amdgpu-plugin
This package contains the AMD GPU plugin for %{name}
%endif
%package cuda-plugin
Summary: CUDA plugin for %{name}
Requires: %{name} = %{version}-%{release}

%description cuda-plugin
This package contains the CUDA plugin for %{name}

%package -n python3-%{name}
Summary:        Python 3 bindings to %{name} library
Group:          Development/Python
Requires:       python3dist(protobuf)
Requires:       python3dist(ipaddr)
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
The python3-%{name} contains Python 3 bindings to the %{name} library.

%package -n %{devname}
Summary:        Development files for criu
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       criu-devel = %{version}-%{release}
Provides:       libcriu-devel = %{version}-%{release}

%description -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use criu.

%prep
%autosetup -p1

%build
# %%{?_smp_mflags} does not work
# -fstack-protector breaks build
CFLAGS+=`echo " %{optflags}" | sed -e 's,-fstack-protector\S*, ,g'` make V=1 WERROR=0 PREFIX=%{_prefix} RUNDIR=%{_rundir}/criu UNAME-M=%{_target_cpu} PYTHON=python3 PLUGINDIR=%{_libdir}/criu
%ifnarch %{arm}
make V=1 WERROR=0 PREFIX=%{_prefix} PLUGINDIR=%{_libdir}/criu amdgpu_plugin
%endif
make docs V=1 PYTHON=python3


%install
sed -e "s,--upgrade --ignore-installed,--no-index --no-deps -v --no-build-isolation,g" -i lib/Makefile -i crit/Makefile
make install-criu DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir}
make install-lib DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir} PYTHON=python3 PIPFLAGS="--no-build-isolation --no-index --no-deps --progress-bar off --upgrade --ignore-installed"

%ifnarch %{arm}
make install-amdgpu_plugin DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir} PLUGINDIR=%{_libdir}/criu
%endif
make install-cuda_plugin DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir} PLUGINDIR=%{_libdir}/criu
make install-crit DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir} PYTHON=python3 PIPFLAGS="--no-build-isolation --no-index --no-deps --progress-bar off --upgrade --ignore-installed"
make install-man DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir}

# upstream renamed the binary to criu
ln -s %{_sbindir}/criu %{buildroot}%{_sbindir}/crtools

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m 0755 %{buildroot}%{_rundir}/%{name}/

# remove static lib
rm -f %{buildroot}%{_libdir}/libcriu.a

%files
%{_bindir}/crit
%{_sbindir}/%{name}
%{_sbindir}/criu-ns
%{_sbindir}/crtools
%{_libexecdir}/%{name}/
%{_mandir}/man1/crit.1*
%{_mandir}/man1/criu-ns.1*
%{_mandir}/man1/compel.1*
%{_mandir}/man8/*
%ifarch %{arm}
%{_mandir}/man1/criu-amdgpu-plugin.1*
%endif
%dir %ghost %attr(0755, root, root) %{_rundir}/%{name}
%{_tmpfilesdir}/%{name}.conf
%doc README.md COPYING

%files -n %{libname}
%{_libdir}/libcriu.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/criu/
%{_libdir}/libcriu.so
%{_libdir}/pkgconfig/*.pc

%files -n python3-criu
%{python3_sitelib}/pycriu*/
%{python3_sitelib}/crit/
%{python3_sitelib}/crit-%{version}.dist-info/

%ifnarch %{arm}
%files amdgpu-plugin
%{_libdir}/%{name}/amdgpu_plugin.so
%{_mandir}/man1/criu-amdgpu-plugin.1*
%endif

%files cuda-plugin
%{_libdir}/%{name}/cuda_plugin.so
%doc plugins/cuda/README.md
