%define __python %{python3}

%global gname haclient
%global uname hacluster

%define	checkout	39d42c2

Name:		crmsh
Summary:	Pacemaker command line interface
Version:	4.4.0
Release:	%mkrel 3
License:	GPLv2
Url:		https://github.com/ClusterLabs/crmsh
Group:		System/Base
Source0:	https://github.com/ClusterLabs/crmsh/archive/%{version}/%{name}-%{version}.tar.gz
Requires(pre):	pacemaker
Requires:	python3
Requires:	python3dist(python-dateutil)
Requires:	python3dist(lxml)
Requires:	python3dist(pyyaml)
Requires:	python3dist(pygments)
Requires:	pssh
Requires:	pacemaker
Requires:	corosync

BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(lxml)
BuildRequires:	python3dist(pyyaml)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(python-dateutil)
BuildRequires:	python3dist(pygments)
BuildRequires:	pkgconfig(pacemaker)
BuildRequires:	cluster-glue-devel
BuildRequires:	automake
BuildRequires:	autoconf
BuildRequires:	asciidoc
BuildRequires:	libtool
BuildRequires:	corosync
BuildRequires:	procps
BuildRequires:	vim-minimal
BuildRequires:	xsltproc
BuildRequires:	dblatex
BuildRequires:	fop
BuildRequires:	w3m
BuildArch:	noarch

%description
crm shell, a Pacemaker command line interface.

Pacemaker is an advanced, scalable High-Availability cluster resource
manager for Heartbeat and/or Corosync.

%package test
Summary:        Test package for crmsh
Group:          System/Base
Requires:       crmsh
%if 0%{?with_regression_tests}
BuildRequires:  corosync
BuildRequires:  procps
BuildRequires:  python3dist(python-dateutil)
BuildRequires:  python3dist(nose)
BuildRequires:  vim
Requires:       pacemaker
Requires:       pssh
%endif

%description test
The crm shell is a command-line interface for High-Availability
cluster management on GNU/Linux systems. It simplifies the
configuration, management and troubleshooting of Pacemaker-based
clusters, by providing a powerful and intuitive set of features.

%package scripts
Summary:        Crm Shell Cluster Scripts
Group:          System/Base

%description scripts
Cluster scripts for crmsh. The cluster scripts can be run
directly from the crm command line, or used by user interfaces
like hawk to implement configuration wizards.

%prep
%autosetup -p1

# Force the local time
#
# 'hg archive' sets the file date to the date of the last commit.
# This can result in files having been created in the future
# when building on machines in timezones 'behind' the one the 
# commit occurred in - which seriously confuses 'make'
find . -exec touch \{\} \;

%build
./autogen.sh

%configure		\
	--localstatedir=%{_var} \
	--with-version=%{version}-%{release} \
	--docdir=%{_defaultdocdir}/%{name} \
	--libdir=%{python3_sitelib}/%{name}

%make_build  docdir=%{_defaultdocdir}/%{name}

%if 0%{?with_regression_tests}
        ./test/unit-tests.sh --quiet
    if [ ! $? ]; then
        echo "Unit tests failed."
        exit 1
    fi
%endif


%install
%make_install docdir=%{_defaultdocdir}/%{name}

# python shebangs
%py3_shebang_fix %{buildroot}%{_bindir}/crm


%if 0%{?with_regression_tests}
%post test
if [ ! -e /tmp/.crmsh_regression_tests_ran ]; then
    touch /tmp/.crmsh_regression_tests_ran
    if ! %{_datadir}/%{name}/tests/regression.sh ; then
        echo "Regression tests failed."
        cat crmtestout/regression.out
        exit 1
    fi
        cd %{_datadir}/%{name}/tests
        if ! ./cib-tests.sh ; then
                echo "CIB tests failed."
                exit 1
        fi
fi
%endif


%files
%{_bindir}/crm
%{_datadir}/%{name}/
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info
%{_mandir}/man8/crm*
%{_mandir}/man8/profiles*
%exclude %{_datadir}/%{name}/tests
%exclude %{_datadir}/%{name}/scripts

%{_defaultdocdir}/%{name}/COPYING
%{_defaultdocdir}/%{name}/AUTHORS
%{_defaultdocdir}/%{name}/ChangeLog
%{_defaultdocdir}/%{name}/README.md
%{_defaultdocdir}/%{name}/contrib/*
%{_defaultdocdir}/%{name}/crm.8.html
%{_defaultdocdir}/%{name}/profiles.html
%{_defaultdocdir}/%{name}/crmsh_crm_report.8.html
%config %{_sysconfdir}/crm

%dir %{_defaultdocdir}/%{name}
%dir %{_defaultdocdir}/%{name}/contrib
%dir %attr (770, %{uname}, %{gname}) %{_var}/cache/crm

%files test
%{_datadir}/%{name}/tests

%files scripts
%{_datadir}/%{name}/scripts
