%define subver          %{nil}
%define major		12
%define libname		%mklibname cryptsetup %{major}
%define dlibname	%mklibname cryptsetup -d

%define url_ver		%(echo %{version}|cut -d. -f1,2)

%bcond_with compatible

Name:		cryptsetup
Version:	2.7.5
Release:	%mkrel 1
Summary:	Utility for setting up encrypted filesystems
License:	GPLv2+ and LGPLv2+
Group:		System/Base
URL:		https://gitlab.com/cryptsetup/cryptsetup
%global upstream_version %{version_no_tilde}
Source0:	https://www.kernel.org/pub/linux/utils/cryptsetup/v%{url_ver}/cryptsetup-%{upstream_version}.tar.xz
Source1:	https://www.kernel.org/pub/linux/utils/cryptsetup/v%{url_ver}/cryptsetup-%{upstream_version}.tar.sign
BuildRequires:	asciidoctor
BuildRequires:	libgcrypt-devel >= 1.1.42
BuildRequires:	libgpg-error-devel
BuildRequires:	pkgconfig(blkid)
BuildRequires:	pkgconfig(devmapper)
BuildRequires:	pkgconfig(json-c)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(libargon2)
BuildRequires:	pkgconfig(pwquality)
BuildRequires:	pkgconfig(libssh)
Obsoletes:	cryptsetup-luks < 1.0.5
Provides:	cryptsetup-luks = %{version}-%{release}
Requires(pre):	filesystem >= 2.1.9-18
Requires(post):	systemd >= %{systemd_required_version}

%description
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

LUKS for dm-crypt is implemented in cryptsetup. cryptsetup-luks is
a complete replacement for the original cryptsetup. It provides all the
functionally of the original version plus all the LUKS features, which are
accessible by the luks* commands.

%package -n	%{libname}
Summary:	Library for setting up encrypted filesystems
Group:		System/Libraries

%description -n %{libname}
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

This package contains the shared libraries required for running
programs which use cryptsetup-luks.


%package -n	%{dlibname}
Summary:	Development library for setting up encrypted filesystems
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{dlibname}
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

This package contains the header files and development libraries
for building programs which use cryptsetup-luks.

%package ssh-token
Summary: Cryptsetup LUKS2 SSH token
Requires: %libname = %{version}-%{release}

%description ssh-token
This package contains the LUKS2 SSH token.


%prep
%autosetup -n cryptsetup-%{upstream_version} -p 1

%build
# to fix RPATH
autoreconf -fi

%configure --enable-pwquality --enable-libargon2 --disable-selinux
%if %{with compatible}
	--with-plain-mode=cbc-plain --with-luks1-keybits=128 \
%endif
# end of configure
%make_build

%install
%make_install

%find_lang %{name}

%post
%_tmpfilescreate %{_tmpfilesdir}/%{name}

%files -f %{name}.lang
%doc AUTHORS FAQ.md README.md
%{_sbindir}/cryptsetup
%{_sbindir}/veritysetup
%{_sbindir}/integritysetup
%{_mandir}/man8/cryptsetup.8*
%{_mandir}/man8/veritysetup.8*
%{_mandir}/man8/integritysetup.8*
%{_mandir}/man8/cryptsetup-benchmark.8*
%{_mandir}/man8/cryptsetup-bitlkDump.8*
%{_mandir}/man8/cryptsetup-bitlkOpen.8*
%{_mandir}/man8/cryptsetup-close.8*
%{_mandir}/man8/cryptsetup-config.8*
%{_mandir}/man8/cryptsetup-convert.8*
%{_mandir}/man8/cryptsetup-create.8*
%{_mandir}/man8/cryptsetup-erase.8*
%{_mandir}/man8/cryptsetup-fvault2Dump.8*
%{_mandir}/man8/cryptsetup-fvault2Open.8*
%{_mandir}/man8/cryptsetup-isLuks.8*
%{_mandir}/man8/cryptsetup-loopaesOpen.8*
%{_mandir}/man8/cryptsetup-luksAddKey.8*
%{_mandir}/man8/cryptsetup-luksChangeKey.8*
%{_mandir}/man8/cryptsetup-luksConvertKey.8*
%{_mandir}/man8/cryptsetup-luksDump.8*
%{_mandir}/man8/cryptsetup-luksErase.8*
%{_mandir}/man8/cryptsetup-luksFormat.8*
%{_mandir}/man8/cryptsetup-luksHeaderBackup.8*
%{_mandir}/man8/cryptsetup-luksHeaderRestore.8*
%{_mandir}/man8/cryptsetup-luksKillSlot.8*
%{_mandir}/man8/cryptsetup-luksOpen.8*
%{_mandir}/man8/cryptsetup-luksRemoveKey.8*
%{_mandir}/man8/cryptsetup-luksResume.8*
%{_mandir}/man8/cryptsetup-luksSuspend.8*
%{_mandir}/man8/cryptsetup-luksUUID.8*
%{_mandir}/man8/cryptsetup-open.8*
%{_mandir}/man8/cryptsetup-plainOpen.8*
%{_mandir}/man8/cryptsetup-reencrypt.8*
%{_mandir}/man8/cryptsetup-refresh.8*
%{_mandir}/man8/cryptsetup-repair.8*
%{_mandir}/man8/cryptsetup-resize.8*
%{_mandir}/man8/cryptsetup-status.8*
%{_mandir}/man8/cryptsetup-tcryptDump.8*
%{_mandir}/man8/cryptsetup-tcryptOpen.8*
%{_mandir}/man8/cryptsetup-token.8*
%{_tmpfilesdir}/%{name}.conf

%files -n %{dlibname}
%{_includedir}/libcryptsetup.h
%{_libdir}/libcryptsetup.so
%{_libdir}/pkgconfig/libcryptsetup.pc

%files -n %{libname}
%{_libdir}/libcryptsetup.so.%{major}{,.*}

%files ssh-token
%license COPYING COPYING.LGPL
%{_libdir}/%{name}/libcryptsetup-token-ssh.so
%{_mandir}/man8/cryptsetup-ssh.8.*
%{_sbindir}/cryptsetup-ssh
