%define _default_patch_fuzz 1

%define Werror_cflags %nil

%global __requires_exclude_from  %{_docdir}/%{name}

# Csound is really dumb about 64-bit
%ifarch x86_64 ia64 aarch64
%define build64bit 1
%define install64bit --word64
%define useDouble 1
%else
%define build64bit 0
%define install64bit %{nil}
%define useDouble 0
%endif

%define build_java 0
%{?_with_java: %{expand: %%global build_java 1}}

%define manualversion 6.18.0

Summary:	A sound synthesis language and library
Name:		csound
Version:	6.18.1
Release:	%mkrel 9
License:	LGPLv2+
Group:		Sound/Utilities
URL:		https://csound.github.io/

Source0:	https://github.com/csound/csound/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/csound/manual/releases/download/%{manualversion}/Csound%{manualversion}_manual_html.zip
# Some patches taken from the Fedora .spec - thanks!
Patch1:		0001-Add-support-for-using-xdg-open-for-opening-help.patch
Patch2:		0002-Default-to-PulseAudio.patch
Patch3:		0003-use-standard-plugins-path.patch
Patch4:		0004-fix-naming-conflicts.patch
Patch5:		0005-fixing-liblo-calls.patch
Patch6:		0006-type-mismatch-in-OSC.patch

BuildRequires:	cmake
BuildRequires:	swig
BuildRequires:	pkgconfig(sndfile) >= 1.2.0
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(fluidsynth)
BuildRequires:	pkgconfig(liblo)
BuildRequires:	pkgconfig(dssi)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(portaudio-2.0)
BuildRequires:	pkgconfig(portmidi)
BuildRequires:	tkinter3
%if %{build_java}
BuildRequires:	java-devel
BuildRequires:	jpackage-utils
%endif
BuildRequires:	lame-devel
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	gettext-devel
BuildRequires:	gcc-c++
BuildRequires:	boost-devel
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	docbook-style-xsl
BuildRequires:	xsltproc
BuildRequires:	python3-setuptools
BuildRequires:	python3-pygments
BuildRequires:	libgomp-devel
BuildRequires:	pkgconfig(eigen3)

Recommends:	csound-plugins

%global luaver %(lua -v | sed -r 's/Lua ([[:digit:]]+\\.[[:digit:]]+).*/\\1/')

%description
Csound is a sound and music synthesis system, providing facilities for
composition and performance over a wide range of platforms. It is not
restricted to any style of music, having been used for many years in
at least classical, pop, techno, ambient...

%package	devel
Summary:	Csound development files and libraries
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Conflicts:	%{name}-python < 5.13.0-3

%description	devel
Contains headers and libraries for developing applications that use Csound.

%package -n	python3-csound
Summary:	Python Csound development files and libraries
Group:		Development/Python
%{?python_provide:%python_provide python3-csound}
Requires:	%{name} = %{version}-%{release}
Requires:	python3
Provides:	csound-python = %{version}-%{release}

%description -n	python3-csound
Contains Python language bindings for developing Python applications that
use Csound.

%if %{build_java}
%package	java
Summary:	Java Csound support
Group:		Development/Java
Requires:	%{name} = %{version}-%{release}
Requires:	java-headless
Requires:	jpackage-utils

%description	java
Contains Java language bindings for developing and running Java
applications that use Csound.

%package	javadoc
Summary:	API documentation for Java Csound support
Group:		Development/Java

%description	javadoc
API documentation for the %{name}-java package.
%endif

%package	jack
Summary:	Jack Audio plugins for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	jackit
Conflicts:	csound < 6.10.0-1

%description	jack
Contains Jack Audio plugins for Csound.

%package	dssi
Summary:	Disposable Soft Synth Interface (DSSI) plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	dssi

%description	dssi
Disposable Soft Synth Interface (DSSI) plugin for Csound.

%package	osc
Summary:	Open Sound Control (OSC) plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description	osc
Open Sound Control (OSC) plugin for Csound.

%package	portaudio
Summary:	PortAudio plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description	portaudio
PortAudio plugin for Csound.

%package	doc
Summary:	Csound manual
Group:		Documentation
Requires:	%{name} >= %{version}-%{release}
BuildArch:	noarch

%description	doc
Canonical Reference Manual for Csound.


%prep
%autosetup -p1
# setup the manual
%setup -q -T -D -a 1

# Fix end of line encodings
%define fix_line_encoding() \
  sed -i.orig 's/\\r\\n/\\n/;s/\\r/\\n/g' %1; \
  touch -r %1.orig %1; \
  rm -f %1.orig;

for csd in $(find html/examples -name \*.csd); do
  %fix_line_encoding $csd
done

# Fix spurious executable bits except on the directory
chmod a-x html/examples/*
chmod a+x html/examples/musical

%build
%if "%{_libdir}" == "%{_prefix}/lib64"
    %global uselib64 ON
%else
    %global uselib64 OFF
%endif

# Terrible hack
%ifarch %{arm}
sed -i 's*//#define PFFFT_SIMD_DISABLE*#define PFFFT_SIMD_DISABLE*' OOps/pffft.c
%endif

%cmake -DUSE_LIB64:BOOL=%{uselib64} -DBUILD_LUA_INTERFACE:BOOL=OFF \
%if %{build_java}
       -DBUILD_JAVA_INTERFACE:BOOL=ON \
%endif
       -DSWIG_ADD_LIBRARY:BOOL=OFF -DBUILD=BUILD_PYTHON_INTERFACE:BOOL=ON \
       -DPYTHON_MODULE_INSTALL_DIR:STRING="%{python3_sitearch}" \
%ifarch %{x86}
       -DHAS_SSE2:BOOL=OFF -DHAS_FPMATH_SSE:BOOL=OFF \
%endif
%ifarch %{arm}
       -DHAVE_NEON:BOOL=OFF \
%endif
       -DUSE_PORTMIDI:BOOL=ON \
       -DBUILD_TESTS:BOOL=OFF

%cmake_build

%install
%cmake_install

%if %{build_java}

# Fix the Java installation
install -dm 755 %{buildroot}%{_javadir}
(cd %{buildroot}%{_javadir}; ln -s %{_libdir}/%{name}/java/csnd.jar .)

%endif


# Help the debuginfo generator
ln -s ../csound_orclex.c Engine/csound_orclex.c
ln -s ../csound_prelex.c Engine/csound_prelex.c

rm -rf %{buildroot}%{_datadir}/cmake/Csound/
rm -rf %{buildroot}%{_datadir}/samples/

chmod +x %{_builddir}/%{name}-%{version}/html/examples/musical

%find_lang %{name}6

%files -f %{name}6.lang
%license COPYING
%doc README.md Release_Notes
%{_bindir}/atsa
%{_bindir}/cs
%{_bindir}/csanalyze
%{_bindir}/csb64enc
%{_bindir}/csbeats
%{_bindir}/csdebugger
%{_bindir}/csound
%{_bindir}/cvanal
%{_bindir}/dnoise
%{_bindir}/cs-envext
%{_bindir}/cs-extract
%{_bindir}/cs-extractor
%{_bindir}/het_export
%{_bindir}/het_import
%{_bindir}/hetro
%{_bindir}/lpanal
%{_bindir}/lpc_export
%{_bindir}/lpc_import
%{_bindir}/makecsd
%{_bindir}/cs-mixer
%{_bindir}/pvanal
%{_bindir}/pv_export
%{_bindir}/pv_import
%{_bindir}/pvlook
%{_bindir}/cs-scale
%{_bindir}/cs-scot
%{_bindir}/scsort
%{_bindir}/sdif2ad
%{_bindir}/cs-sndinfo
%{_bindir}/cs-srconv
%{_bindir}/cs-src_conv
%{_libdir}/lib%{name}64.so.6.0
%{_libdir}/libcsnd6.so.6.0
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins-6.0
%{_libdir}/%{name}/plugins-6.0/libampmidid.so
%{_libdir}/%{name}/plugins-6.0/libarrayops.so
%{_libdir}/%{name}/plugins-6.0/libbformdec2.so
%{_libdir}/%{name}/plugins-6.0/libcontrol.so
%{_libdir}/%{name}/plugins-6.0/libdeprecated.so
%{_libdir}/%{name}/plugins-6.0/libdoppler.so
%{_libdir}/%{name}/plugins-6.0/libfractalnoise.so
%{_libdir}/%{name}/plugins-6.0/libftsamplebank.so
%{_libdir}/%{name}/plugins-6.0/libipmidi.so
%{_libdir}/%{name}/plugins-6.0/libjoystick.so
%{_libdir}/%{name}/plugins-6.0/liblfsr.so
%{_libdir}/%{name}/plugins-6.0/libmixer.so
%{_libdir}/%{name}/plugins-6.0/libpadsynth.so
%{_libdir}/%{name}/plugins-6.0/libpmidi.so
%{_libdir}/%{name}/plugins-6.0/libpvsops.so
%{_libdir}/%{name}/plugins-6.0/librtalsa.so
%{_libdir}/%{name}/plugins-6.0/librtpulse.so
%{_libdir}/%{name}/plugins-6.0/libscansyn.so
%{_libdir}/%{name}/plugins-6.0/libsignalflowgraph.so
%{_libdir}/%{name}/plugins-6.0/libstdutil.so
%{_libdir}/%{name}/plugins-6.0/libtrigenvsegs.so
%{_libdir}/%{name}/plugins-6.0/liburandom.so

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}64.so
%{_libdir}/libcsnd6.so

%files -n python3-csound
%{python3_sitearch}/*

%if %{build_java}
%files java
%{_libdir}/lib_jcsound6.so
%{_libdir}/lib_jcsound.so.1
%{_libdir}/csnd6.jar
%{_javadir}/csnd.jar

%files javadoc
%{_javadocdir}/%{name}-java
%endif

%files jack
%{_libdir}/%{name}/plugins-6.0/librtjack.so

%files dssi
%{_libdir}/%{name}/plugins-6.0/libdssi4cs.so

%files osc
%{_libdir}/%{name}/plugins-6.0/libosc.so

%files portaudio
%{_libdir}/%{name}/plugins-6.0/librtpa.so

%files doc
%doc html/
%doc examples/*
