%global debug_package %{nil}

# redefine macro for -S git_am to avoid problems with patches containing CR+LF as EOL
# such as Patch6 and Patch8, because the original source archive contains files with
# mixed use of LF or CR+LF.
%global __scm_apply_git_am(qp:m:) %{__git} am --reject --keep-cr %{-q} %{-p:-p%{-p*}}

# use clang instead of gcc
%define use_clang	0

%define compat_cuda_gccver	13

Name:       cuda-z
Version:    0.11.291
Release:    %mkrel 12
Summary:    Shows some basic information about CUDA-enabled GPUs and GPGPUs
Group:      Development/X11
License:    GPLv3
URL:        https://cuda-z.sourceforge.net/
# Code at https://sourceforge.net/projects/cuda-z
# Get Source code from svn repository here: https://svn.code.sf.net/p/cuda-z/code/trunk using:
# - svn co https://svn.code.sf.net/p/cuda-z/code/trunk cuda-z-<major_version>.<svn_revision>
# - add log file using: svn log > ChangeLog
# - remove unneeded binaries from bld/bin
# - create tarball
Source0:    %{name}-%{version}.tar.xz
Patch0:     cuda-z-0.11.291-fixbuild.patch
Patch1:	    cuda-z-0.11.291-fix-host-defines-includes.patch
Patch2:	    cuda-z-0.11.291-path-and-verbose.patch
Patch3:	    cuda-z-0.11.291-add-extra-arch.patch
# cuda 10.1 and beyond aren't able to compile the source with a reasonable
# (e.g. 20GB) amount of RAM. Use this patch as a temporary workaround. Note
# that this patch decreases the result of the performance test due to sub-optimization.
Patch4:	    cuda-z-0.11.291-enable-debug.patch
#
Patch5:     cuda-z-0.11.291-fix-formats.patch
Patch6:     cuda-z-0.11.291-fix-cast.patch
Patch7:     cuda-z-0.11.291-show-gpu-core-performance-in-bold.patch
Patch8:     cuda-z-0.11.291-fix-printing-of-multiprocessors-count.patch
Patch9:     cuda-z-0.11.291-enlarge-window.patch
# Re-enable standard optimization and unroll loops manually
Patch10:    cuda-z-0.11.291-drop-debug-option-and-enable-optimization-O3.patch
Patch11:    cuda-z-0.11.291-duplicate-loops-32.patch
# Update archs
Patch12:    cuda-z-0.11.291-update-architectures.patch
#
Patch13:    cuda-z-0.11.291-fix-to-match-for-x86_64-string-in-open-modules.patch
#
Patch14:    cuda-z-0.11.291-add-support-for-cuda-capability-9.0.patch
#
Patch15:    cuda-z-0.11.291-fix-various-deprecated-declarations-and-use-default-constructor.patch
#
Patch16:    cuda-z-0.11.291-c-14-in-pro-config.patch
#
%if %{use_clang}
BuildRequires: clang
%endif
%if %{mgaversion} >= 10
BuildRequires: compat-cuda-gcc%{compat_cuda_gccver}
%endif
BuildRequires: git-core
BuildRequires: qt5-devel
BuildRequires: nvidia-cuda-toolkit-devel
BuildRequires: imagemagick
BuildRequires: svn
Requires:      nvidia-cuda-toolkit
ExclusiveArch: x86_64

%description
CUDA-Z shows some basic information about CUDA-enabled GPUs and
GPGPUs. It works with nVIDIA Geforce, Quadro and Tesla cards, ION
chipsets.

CUDA-Z shows the following information:

    - Installed CUDA driver and dll version.
    - GPU core capabilities.
    - Integer and float point calculation performance.
    - Performance of double-precision operations if GPU is capable.
    - memory size and bandwidth.

This program also exports collected information to HTML format and
plain text file.

%prep
%autosetup -S git_am

%build
%if %use_clang
export NVCC_PREPEND_FLAGS="-ccbin clang++"
export CC=clang CXX=clang++
%endif
%if %{mgaversion} >= 10
export NVCC_APPEND_FLAGS="-std c++14 --compiler-bindir %{_prefix}/lib/compat-cuda-gcc%{compat_cuda_gccver}/bin"
export CXXFLAGS="%{optflags} -std=c++14"
export PATH=%{_prefix}/lib/compat-cuda-gcc%{compat_cuda_gccver}/bin:$PATH
%else
export NVCC_APPEND_FLAGS="-std c++14"
export CXXFLAGS="%{optflags} -std=c++14"
%endif

qmake-qt5
make

%install
mkdir -p %{buildroot}%{_bindir} \
   %{buildroot}%{_datadir}/icons/hicolor/{16x16,24x24,32x32,48x48,64x64,96x96,128x128,192x192,256x256}/apps

install -m 755 bin/cuda-z %{buildroot}/usr/bin
for i in 16x16 24x24 32x32 48x48 64x64 96x96 128x128 192x192 256x256; do
   convert res/img/icon.png %{buildroot}%{_datadir}/icons/hicolor/${i}/apps/cuda-z.png
done

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=CUDA-Z
GenericName=CUDA-Z
Comment=Shows infos about CUDA-enabled GPUs
Type=Application
Terminal=false
Icon=cuda-z
Categories=Development;DataVisualization;
Exec=cuda-z
EOF

desktop-file-install --dir %{buildroot}%{_datadir}/applications  %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%{_bindir}/cuda-z
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/cuda-z.png
%doc LICENSE.GPL3 ChangeLog
