# WARNING: This package is synced with FC

%if 0%{?fedora}
%bcond_without mdns
%bcond_without braille
%else
%bcond_without mdns
%bcond_with braille
%endif

# we build CUPS also with relro
%global _hardened_build 1

%define major     1
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Summary: OpenPrinting CUPS filters and backends
Name:    cups-filters
Version: 2.0.1
Release: %mkrel 1

# the CUPS exception text is the same as LLVM exception, so using that name with
# agreement from legal team
# https://lists.fedoraproject.org/archives/list/legal@lists.fedoraproject.org/message/A7GFSD6M3GYGSI32L2FC5KB22DUAEQI3/
License: Apache-2.0 WITH LLVM-exception

Group:   System/Printing
Url:     https://github.com/OpenPrinting/cups-filters
Source0: %{URL}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1: lftocrlf.ppd
Source2: lftocrlf

# autogen.sh
BuildRequires:  autoconf
# autogen.sh
BuildRequires:  automake
# filter binaries and backends are written in C
BuildRequires:  gcc
# autogen.sh
BuildRequires:  gettext-devel
# for autosetup
BuildRequires:  git-core
# autogen.sh
BuildRequires:  libtool
# uses make for compiling
BuildRequires:  make
# we use pkgconfig to get a proper devel packages
# proper CFLAGS and LDFLAGS
BuildRequires:  pkgconf-pkg-config
# uses CUPS API
BuildRequires:  pkgconfig(cups) >= 2.2.2
# uses cupsfilters API
BuildRequires:  pkgconfig(libcupsfilters) >= 2.0b3
# uses PPD API
BuildRequires:  pkgconfig(libppd) >= 2.0b3
# Make sure we get postscriptdriver tags.
BuildRequires:  python3-cups

%if %{with braille}
Recommends:     braille-printer-app
%endif
# needs cups dirs
Requires:       cups-filesystem

%description
Contains backends, filters, and other software that was
once part of the core CUPS distribution but is no longer maintained by
Apple Inc. In addition it contains additional filters developed
independently of Apple, especially filters for the PDF-centric printing
workflow introduced by OpenPrinting.

%package driverless
Summary:        OpenPrinting driverless backends and drivers for CUPS 2.X
License:        Apache-2.0 WITH LLVM-exception

# backends and drivers has been moved from the main package to subpackage
# to remove the avahi/mdns dependency needed for driverless
# remove after F40 is EOL and C10S is released
Conflicts:      cups-filters < 2.0.0

# finding device via driverless depends on running avahi-daemon
Requires:       avahi
# ippfind is used in driverless backend, not needed classic PPD based print queue
Requires:       cups-ipptool
# cups-browsed needs systemd-resolved or nss-mdns for resolving .local addresses of remote print queues
# let's not require a specific package and let the user decide what he wants to use.
# just recommend nss-mdns for Fedora for now to have working default, but
# don't hardwire it for resolved users
%if %{with mdns}
Recommends:     nss_mdns
%endif

# needs cups dirs
Requires:       cups-filesystem

%description driverless
Contains backends and drivers for driverless implementation for cups-filters,
which makes driverless printers to be seen when listing printers nearby and gives
a specific generated driver for driverless printer in the local network. They are
tools for backward compatibility with applications which don't handle CUPS temporary
queues.

%prep
%autosetup -S git

%build
# work-around Rpath
./autogen.sh

%configure --enable-driverless \
           --enable-universal-cups-filter \
           --disable-mutool \
           --disable-rpath \
           --disable-silent-rules \
           --disable-static

%make_build

%install
%make_install

# 2229776 - Add textonly driver back, but as lftocrlf
install -p -m 0755 %{SOURCE2} %{buildroot}%{_cups_serverbin}/filter/lftocrlf
install -p -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/ppd/cupsfilters/lftocrlf.ppd

# LSB3.2 requires /usr/bin/foomatic-rip,
# create it temporarily as a relative symlink
# we may use symlink to universal filter, but LSB is about guaranteed compatibility set
# among distibutions, so rather have the strict foomatic-rip filter...
ln -sf %{_cups_serverbin}/filter/foomatic-rip %{buildroot}%{_bindir}/foomatic-rip
#ln -sf %%{_cups_serverbin}/filter/universal %%{buildroot}%%{_bindir}/foomatic-rip

# remove license files which are in %%pkgdocdir
rm -f %{buildroot}%{_pkgdocdir}/{COPYING,NOTICE,LICENSE}

# remove INSTALL since it is unnecessary
rm -f %{buildroot}%{_pkgdocdir}/INSTALL

# remove CHANGES-1.x.md, since it is carried by a dependency
rm -f %{buildroot}%{_pkgdocdir}/CHANGES-1.x.md


%check
make check


%files
%license COPYING LICENSE NOTICE
%doc AUTHORS ABOUT-NLS CHANGES.md CONTRIBUTING.md DEVELOPING.md README.md
%{_bindir}/foomatic-rip
%attr(0744,root,root) %{_cups_serverbin}/backend/beh
# all backends needs to be run only as root because of kerberos
%attr(0744,root,root) %{_cups_serverbin}/backend/parallel
# Serial backend needs to run as root (bug #212577#c4).
%attr(0744,root,root) %{_cups_serverbin}/backend/serial
%attr(0755,root,root) %{_cups_serverbin}/filter/bannertopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/commandtoescpx
%attr(0755,root,root) %{_cups_serverbin}/filter/commandtopclx
%attr(0755,root,root) %{_cups_serverbin}/filter/foomatic-rip
%attr(0755,root,root) %{_cups_serverbin}/filter/gstopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/gstopxl
%attr(0755,root,root) %{_cups_serverbin}/filter/gstoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/imagetopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/imagetops
%attr(0755,root,root) %{_cups_serverbin}/filter/imagetoraster
# 2229776 - Add textonly driver back, but as lftocrlf
%attr(0755,root,root) %{_cups_serverbin}/filter/lftocrlf
%attr(0755,root,root) %{_cups_serverbin}/filter/pclmtoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/pdftopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/pdftops
%attr(0755,root,root) %{_cups_serverbin}/filter/pdftoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/pwgtopclm
%attr(0755,root,root) %{_cups_serverbin}/filter/pwgtopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/pwgtoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/rastertoescpx
%attr(0755,root,root) %{_cups_serverbin}/filter/rastertopclx
%attr(0755,root,root) %{_cups_serverbin}/filter/rastertops
%attr(0755,root,root) %{_cups_serverbin}/filter/texttopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/texttops
%attr(0755,root,root) %{_cups_serverbin}/filter/texttotext
%attr(0755,root,root) %{_cups_serverbin}/filter/universal
%{_datadir}/cups/drv/cupsfilters.drv
%{_datadir}/cups/mime/cupsfilters.types
%{_datadir}/cups/mime/cupsfilters.convs
%{_datadir}/cups/mime/cupsfilters-universal-postscript.convs
%{_datadir}/cups/mime/cupsfilters-universal.convs
%{_datadir}/ppd/cupsfilters
# escp.h and pcl.h are required during runtime, because
# CUPS PPD compiler (ppdc) uses them for generating drivers
# per request from cupsfilters.drv file
%{_datadir}/ppdc/escp.h
%{_datadir}/ppdc/pcl.h
%{_mandir}/man1/foomatic-rip.1.*

%files driverless
%license COPYING LICENSE NOTICE
%{_bindir}/driverless
%{_bindir}/driverless-fax
%{_cups_serverbin}/backend/driverless
%{_cups_serverbin}/backend/driverless-fax
%{_cups_serverbin}/driver/driverless
%{_cups_serverbin}/driver/driverless-fax
%{_mandir}/man1/driverless.1.*
