# WARNING: This package is synced with Fedora

%define major	2
%define libname	%mklibname %{name} %{major}

%bcond_with bootstrap

%global use_alternatives 1
%global lspp 1

# {_exec_prefix}/lib/cups is correct, even on x86_64.
# It is not used for shared objects but for executables.
# It's more of a libexec-style ({_libexecdir}) usage,
# but we use lib for compatibility with 3rd party drivers (at upstream request).
%global cups_serverbin %{_exec_prefix}/lib/cups
%global VERSION %{version}

Summary:	CUPS printing system - Server package
Name:		cups
Version:	2.4.12
Release:	%mkrel 1
License:	ASL 2.0
Group:		System/Printing
Url:		https://openprinting.github.io/cups/

# Apple stopped uploading the new versions into github, use OpenPrinting fork
Source0: https://github.com/OpenPrinting/cups/releases/download/v%{VERSION}/cups-%{VERSION}-source.tar.gz

Source2: macros.cups
# Backend for NCP protocol
Source3: ncp.backend
# Backend filter for nprint (Novell client) from Mark Horn
# (mark@hornclan.com)
Source11: http://www.hornclan.com/~mark/cups/nprint.2002011801
Source14: https://www.openprinting.org/download/printing/photo_print
# Perl script for automatic configuration of CUPS, especially access
# restrictions and broadcasting
Source15: correctcupsconfig
Source16: cjktexttops
# Nice level for now. bug #16387
Source18: cups.sysconfig

### FEDORA PATCHES ###

Patch1: cups-multilib.patch
# if someone makes a change to banner files, then there will <banner>.rpmnew
# with next update of cups-filters - this patch makes sure the banner file 
# changed by user is used and .rpmnew or .rpmsave is ignored
# Note: This could be rewrite with use a kind of #define and send to upstream
Patch2: cups-banners.patch
# don't export ssl libs to cups-config - can't find the reason.
Patch3: cups-no-export-ssllibs.patch
# enables old uri usb:/dev/usb/lp0 - leave it here for users of old printers
Patch4: cups-direct-usb.patch
# when system workload is high, timeout for cups-driverd can be reached -
# increase the timeout
Patch5: cups-driverd-timeout.patch
# usb backend didn't get any notification about out-of-paper because of kernel 
Patch6: cups-usb-paperout.patch
# uri compatibility with old Fedoras
Patch7: cups-uri-compat.patch
# use IP_FREEBIND, because cupsd cannot bind to not yet existing IP address
# by default
Patch8: cups-freebind.patch
# add support of multifile
Patch9: cups-ipp-multifile.patch
# prolongs web ui timeout
Patch10: cups-web-devices-timeout.patch
# failover backend for implementing failover functionality
# TODO: move it to the cups-filters upstream
Patch11: cups-failover-backend.patch
# add device id for dymo printer
Patch12: cups-dymo-deviceid.patch

%if %{lspp}
# selinux and audit enablement for CUPS - needs work and CUPS upstream wants
# to have these features implemented their way in the future
Patch100: cups-lspp.patch
%endif

#### UPSTREAM PATCHES (starts with 1000) ####

##### Patches removed because IMHO they aren't no longer needed
##### but still I'll leave them in git in case their removal
##### breaks something.

# END OF FEDORA PATCHES

### MAGEIA PATCHES ###

BuildRequires: automake
# gcc and gcc-c++ is no longer in buildroot by default
# gcc for most of files
BuildRequires: gcc
# gcc-c++ for ppdc and cups-driverd
BuildRequires: gcc-c++
BuildRequires: krb5-devel
BuildRequires: libacl-devel
# make is used for compilation
BuildRequires: make
BuildRequires: openldap-devel
BuildRequires: pam-devel
BuildRequires: pkgconf-pkg-config
BuildRequires: pkgconfig(avahi-client)
BuildRequires: pkgconfig(dbus-1)
BuildRequires: pkgconfig(gnutls)
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(libusb-1.0)
# Make sure we get postscriptdriver tags.
BuildRequires: python3-cups
BuildRequires: systemd
# needed for systemd rpm macros according FPG
BuildRequires: systemd-units
# needed for decompressing functions when reading from gzipped ppds
BuildRequires: zlib-devel

%if %{lspp}
BuildRequires: libselinux-devel
BuildRequires: audit-libs-devel
%endif

# For /usr/share/icons/ to exist and get icons installed
BuildRequires: desktop-common-data
# For desktop menus
Requires: xdg-utils

# getaddrinfo from glibc needs nss-mdns or systemd-resolved for resolving
# mdns .local addresses. Don't require a specific package for now and let
# the user to decide what to use
# just recommend nss-mdns for Fedora for now to have working default, but
# don't hardwire it for resolved users
%if 0%{?mageia}
Recommends: nss_mdns
%endif
# avahi is needed for mDNS discovery and sharing queues
Recommends: avahi
# for better migration - cups-browsed was part of cups-filters in the past,
# now it was splitted and no longer depends on cups-filters - the daemon will
# vanish during upgrade without a weak dependency at least
# remove once C10X is released
Recommends: cups-browsed
# for IPP-over-USB device support
Recommends: ipp-usb

%if 0%{?mageia} >= 10
# driverless stuff was splitted from cups-filters
Recommends: cups-filters-driverless
%endif

# We ship udev rules which use setfacl.
Requires: acl
Requires: %{name}-common >= %{version}-%{release}
Requires: %{name}-filesystem = %{version}-%{release}
Requires: hostname
Requires: printer-testpages
# Make sure we have some filters for converting to raster format.
Requires: cups-filters
Requires: systemd

Requires(post): systemd
Requires(post): grep, sed
Requires(preun): systemd
Requires(postun): systemd
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%package common
Summary: CUPS printing system - Common stuff
License: GPLv2
Group: System/Printing
Requires: %{libname} >= %{version}-%{release} update-alternatives hostname
Requires: libcupsfilters
# To satisfy LSB/FHS
Provides: lpddaemon
Provides: cups-ipptool = %{version}-%{release}

%package -n %{libname}-devel
Summary: CUPS printing system - development environment
License: LGPLv2
Group: Development/C
Requires: cups-common = %{version}-%{release}
Requires: %{libname} >= %{version}-%{release} 
Requires: gnutls-devel
Requires: krb5-devel
Requires: zlib-devel
Provides: libcups-devel = %{version}-%{release}
Provides: libcups2_1-devel = %{version}-%{release}
Provides: cups-devel = %{version}

%package -n %{libname}
Summary: CUPS printing system - libraries
License: LGPLv2 and zlib
Group: System/Libraries
Requires: hostname

%package filesystem
Summary: CUPS printing system - directory layout
Group: 	 System/Printing
BuildArch: noarch
Conflicts: %{name} < %{version}-%{release}

%package printerapp
Summary: CUPS printing system - tools for printer application
Requires: %{libname} = %{version}-%{release}
# ippeveprinter needs avahi for registering and sharing printer
Requires: avahi
# mdns address resolver (nss-mdns or systemd-resolved) is needed too,
# but don't require a specific package for now and let the user to choose
# what to use
# just recommend nss-mdns for Fedora for now to have working default, but
# don't hardwire it for resolved users
%if 0%{?mageia}
Recommends: nss_mdns
%endif

%description
CUPS printing system provides a portable printing layer for
UNIX® operating systems. It has been developed by Apple Inc.
to promote a standard printing solution for all UNIX vendors and users.
CUPS provides the System V and Berkeley command-line interfaces.
This is the main package needed for CUPS servers (machines where a
printer is connected to or which host a queue for a network
printer). It can also be used on CUPS clients so that they simply pick
up broadcasted printer information from other CUPS servers and do not
need to be assigned to a specific CUPS server by an
%{_sysconfdir}/cups/client.conf file.

%description common
The CUPS printing system provides a portable printing layer for
UNIX® operating systems. It contains the command line utilities for
printing and administration (lpr, lpq, lprm, lpadmin, lpc, ...), man
pages, locales, and a sample configuration file for daemon-less CUPS
clients (%{_sysconfdir}/cups/client.conf).

This package you need for both CUPS clients and servers.

%description -n %{libname}-devel
CUPS printing system provides a portable printing layer for
UNIX® operating systems. This is the development package for creating
additional printer drivers, and other CUPS services.

%description -n %{libname}
CUPS printing system provides a portable printing layer for
UNIX® operating systems. It has been developed by Apple Inc.
to promote a standard printing solution for all UNIX vendors and users.
CUPS provides the System V and Berkeley command-line interfaces.
The cups-libs package provides libraries used by applications to use CUPS
natively, without needing the lp/lpr commands.

%description filesystem
CUPS printing system provides a portable printing layer for
UNIX® operating systems. This package provides some directories which are
required by other packages that add CUPS drivers (i.e. filters, backends etc.).

%description printerapp
Provides IPP everywhere printer application ippeveprinter and tools for printing
PostScript and HP PCL document formats - ippevepcl and ippeveps. The printer
application enables older printers for IPP everywhere standard - so if older printer
is installed with a printer application, its print queue acts as IPP everywhere printer
to CUPS daemon. This solution will substitute printer drivers and raw queues in the future.

%prep
%setup -q -n cups-%{VERSION}
# Prevent multilib conflict in cups-config script.
%patch -P 1 -p1 -b .multilib
# Ignore rpm save/new files in the banners directory.
%patch -P 2 -p1 -b .banners
# Don't export SSLLIBS to cups-config.
%patch -P 3 -p1 -b .no-export-ssllibs
# Allow file-based usb device URIs.
%patch -P 4 -p1 -b .direct-usb
# Increase driverd timeout to 70s to accommodate foomatic (bug #744715).
%patch -P 5 -p1 -b .driverd-timeout
# Support for errno==ENOSPACE-based USB paper-out reporting.
%patch -P 6 -p1 -b .usb-paperout
# Allow the usb backend to understand old-style URI formats.
%patch -P 7 -p1 -b .uri-compat
# Use IP_FREEBIND socket option when binding listening sockets (bug #970809).
%patch -P 8 -p1 -b .freebind
# Fixes for jobs with multiple files and multiple formats.
%patch -P 9 -p1 -b .ipp-multifile
# Increase web interface get-devices timeout to 10s (bug #996664).
%patch -P 10 -p1 -b .web-devices-timeout
# Add failover backend (bug #1689209)
%patch -P 11 -p1 -b .failover
# Added IEEE 1284 Device ID for a Dymo device (bug #747866).
%patch -P 12 -p1 -b .dymo-deviceid

%if %{lspp}
# LSPP support.
%patch -P 100 -p1 -b .lspp
%endif

# UPSTREAM PATCHES

# Let local printers be broadcasted in the local network(s)
perl -p -i -e 's:(Listen\s+)localhost:$1*:' conf/cupsd.conf.in
perl -p -i -e 's:(Browsing\s+On):$1:' conf/cupsd.conf.in
perl -p -i -e 's:(<Location\s+/\s*>):$1\n  Allow \@LOCAL:' conf/cupsd.conf.in

# Allow remote administration in local network (connections are encrypted,
# so no security problem)
perl -p -i -e 's:(<Location\s+/admin(|/conf)\s*>):$1\n  Allow \@LOCAL:' conf/cupsd.conf.in

# Let the Makefiles not trying to set file ownerships
perl -p -i -e "s/ -o \\$.CUPS_USER.//" scheduler/Makefile
perl -p -i -e "s/ -g \\$.CUPS_GROUP.//" scheduler/Makefile
perl -p -i -e "s/ -o \\$.CUPS_USER.//" systemv/Makefile
perl -p -i -e "s/ -g \\$.CUPS_GROUP.//" systemv/Makefile

# Log to the system journal by default (bug #1078781, bug #1519331).
sed -i -e 's,^ErrorLog .*$,ErrorLog syslog,' conf/cups-files.conf.in
sed -i -e 's,^AccessLog .*$,AccessLog syslog,' conf/cups-files.conf.in
sed -i -e 's,^PageLog .*,PageLog syslog,' conf/cups-files.conf.in

# Let's look at the compilation command lines.
perl -pi -e "s,^.SILENT:,," Makedefs.in

# Load nprint backend
cp %{SOURCE11} nprint
# Load the "photo_print" utility
cp %{SOURCE14} photo_print
# Load the "cjktexttops" filter
cp %{SOURCE16} cjktexttops

# remove this once we don't have any patches changing configure stuff
aclocal -I config-scripts
autoconf -f -I config-scripts

%build
%serverbuild
# for the PHP module
%define _disable_ld_no_undefined 1
%set_build_flags
# cups can use different compiler if it is installed, so set to GCC for to be sure
export CC=%{__cc}
export CXX=%{__cxx}
# add Mageia specific flags to DSOFLAGS
export DSOFLAGS="$DSOFLAGS $RPM_LD_FLAGS"
export CFLAGS="$CFLAGS $RPM_OPT_FLAGS -DLDAP_DEPRECATED=1"
export CXXFLAGS="$CXXFLAGS $RPM_OPT_FLAGS -DLDAP_DEPRECATED=1"
export LDFLAGS="$LDFLAGS $RPM_LD_FLAGS -Wall -fstack-clash-protection -D_FORTIFY_SOURCE=2"
# --enable-debug to avoid stripping binaries
%configure --with-docdir=%{_datadir}/%{name}/www \
  --enable-debug \
  --enable-gssapi \
%if %{lspp}
	--enable-lspp \
%endif
	--enable-page-logging \
	--enable-relro \
	--enable-sync-on-close \
	--enable-webif \
	--with-access-log-level=actions \
	--with-cupsd-file-perm=0755 \
	--with-dbusdir=%{_sysconfdir}/dbus-1 \
	--with-dnssd=avahi \
	--with-log-file-perm=0600 \
	--with-ondemand=systemd \
	--with-pkgconfpath=%{_libdir}/pkgconfig \
	--with-rundir=%{_rundir}/cups \
	--with-tls=gnutls \
	--with-xinetd=no \
	--localedir=%{_datadir}/locale

# If we got this far, all prerequisite libraries must be here.
%make_build

%install
# %%make_install macro results into permission error during install phase,
# because it sets INSTALL env to 'install -p'.
# use the old make invocation for now, fix this upstream when upstream will
# have a time for github issues
make install DESTDIR=%{buildroot}

rm -rf	%{buildroot}%{_initddir} \
	%{buildroot}%{_sysconfdir}/init.d \
	%{buildroot}%{_sysconfdir}/rc?.d
mkdir -p %{buildroot}%{_unitdir}
find %{buildroot}%{_datadir}/cups/model -name "*.ppd" |xargs gzip -n9f

%if %{use_alternatives}
pushd %{buildroot}%{_bindir}
for i in cancel lp lpq lpr lprm lpstat; do
	mv $i $i.cups
done
cd %{buildroot}%{_sbindir}
mv lpc lpc.cups
cd %{buildroot}%{_mandir}/man1
for i in cancel lp lpq lpr lprm lpstat; do
	mv $i.1 $i-cups.1
done
cd %{buildroot}%{_mandir}/man8
mv lpc.8 lpc-cups.8
popd
%endif

# Install nprint backend
install -m 755 nprint %{buildroot}%{cups_serverbin}/backend/

# Link dnssd backend as mdns backend
(cd %{buildroot}%{cups_serverbin}/backend && ln -s dnssd mdns)

# Install "photo_print"
install -m 755 photo_print %{buildroot}%{_bindir}

# Install "cjktexttops"
install -m 755 cjktexttops %{buildroot}%{cups_serverbin}/filter/

ln -s %{_datadir}/printer-testpages/testprint.ps %{buildroot}%{_datadir}/cups/data/testprint-mga.ps

# Install startup script
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE18} %{buildroot}%{_sysconfdir}/sysconfig/cups
install -d %{buildroot}%{_sysconfdir}/modprobe.d

# Install script for automatic CUPS configuration
cp %{SOURCE15} %{buildroot}%{_sbindir}/correctcupsconfig
chmod a+rx %{buildroot}%{_sbindir}/correctcupsconfig

%ifarch x86_64
# This one will be removed soon, when all other packages are
# modified appropriately
ln -s %{cups_serverbin} %{buildroot}%{_libdir}/cups
%endif

# Install missing headers (Thanks to Oden Eriksson)
install -m644 cups/debug-private.h  %{buildroot}%{_includedir}/cups/
install -m644 cups/string-private.h %{buildroot}%{_includedir}/cups/
install -m644 config.h %{buildroot}%{_includedir}/cups/

# Multiarch fixes
%multiarch_includes %{buildroot}%{_includedir}/cups/config.h

install -p -m 755 %{SOURCE3} %{buildroot}%{cups_serverbin}/backend/ncp

# Ship an rpm macro for where to put driver executables.
mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -m 0644 %{SOURCE2} %{buildroot}%{_rpmconfigdir}/macros.d

# Create dummy config files /etc/cups/printers.conf,
# /etc/cups/classes.conf, and /etc/cups/client.conf
touch %{buildroot}%{_sysconfdir}/cups/printers.conf
touch %{buildroot}%{_sysconfdir}/cups/classes.conf
touch %{buildroot}%{_sysconfdir}/cups/client.conf

# deny MD5 digest authentication by default in client.conf
cat > %{buildroot}%{_sysconfdir}/cups/client.conf <<EOF
# MD5 Digest authentication is turned off by default
# because MD5 is marked as insecure for authentication.
#
# If you need MD5 Digest authentication and you are aware of
# potential security risk, turn MD5 Digest authentication on
# by changing the directive value to 'None'.

DigestOptions DenyMD5
EOF

# Remove links to the startup script, we make our own ones with chkconfig
rm -rf %{buildroot}%{_sysconfdir}/rc?.d/[SK]*
# Remove unshipped files.
rm -rf %{buildroot}%{_mandir}/cat? %{buildroot}%{_mandir}/*/cat?
# there are pdf-banners shipped with cups-filters (#919489)
rm -rf %{buildroot}%{_datadir}/cups/banners
rm -f %{buildroot}%{_datadir}/cups/data/testprint

# install /usr/lib/tmpfiles.d/cups.conf (bug #656566, bug #893834)
mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/cups.conf <<EOF
# See tmpfiles.d(5) for details

d %{_rundir}/cups 0755 root lp -
d %{_rundir}/cups/certs 0511 lp sys -

d /var/spool/cups/tmp - - - 30d
EOF

# /usr/lib/tmpfiles.d/cups-lp.conf (bug #812641)
cat > %{buildroot}%{_tmpfilesdir}/cups-lp.conf <<EOF
# Legacy parallel port character device nodes, to trigger the
# auto-loading of the kernel module on access.
#
# See tmpfiles.d(5) for details

c /dev/lp0 0660 root lp - 6:0
c /dev/lp1 0660 root lp - 6:1
c /dev/lp2 0660 root lp - 6:2
c /dev/lp3 0660 root lp - 6:3
EOF

# Prefer xdg-utils than htmlview (kde one)
sed -i s/htmlview/xdg-open/ %{buildroot}%{_datadir}/applications/*.desktop

# http://qa.mandriva.com/show_bug.cgi?id=28383
# Common PPD dirs
mkdir -p %{buildroot}%{_datadir}/ppd

# Make CUPS know them
ln -s /usr/local/share/ppd %{buildroot}%{_datadir}/cups/model/1-local-admin
ln -s /opt/share/ppd %{buildroot}%{_datadir}/cups/model/2-third-party
ln -s %{_datadir}/ppd %{buildroot}%{_datadir}/cups/model/3-distribution

# Common printer driver dirs
mkdir -p %{buildroot}%{_libdir}/printdriver
# Other dirs can't be handled here, but on %%post instead.

%pre
%ifarch x86_64
# Fix /usr/lib/cups directory, so that updates can be done
if [ -d %{_libdir}/cups ] && ! [ -h %{_libdir}/cups ]; then
    if [ -h %{cups_serverbin} ] || ! [ -e %{cups_serverbin} ]; then
        rm -f %{cups_serverbin}
        mv %{_libdir}/cups %{cups_serverbin}
    else
        rm -rf %{_libdir}/cups.rpmsave
        mv %{_libdir}/cups %{_libdir}/cups.rpmsave
        #echo 'Moved %{_libdir}/cups to %{_libdir}/cups.rpmsave' 1>&2
    fi
fi
%endif

%post
%_tmpfilescreate %{name}
%_tmpfilescreate %{name}-lp

# We can't enforce this. Bug #35993
for d in /opt/share/ppd /opt/lib/printdriver /usr/local/share/ppd /usr/local/lib/printdriver
do
  [ ! -e $d ] && mkdir -p $d || :
done
# End of 28383

# Previous migration script unnecessarily put PageLogFormat into cups-files.conf
# (see bug #1148995)
FILE=%{_sysconfdir}/cups/cups-files.conf
for keyword in PageLogFormat; do
    /bin/sed -i -e "s,^$keyword,#$keyword,i" "$FILE" || :
done

# Let CUPS daemon be automatically started at boot time
%_post_service cups
#_post_service cups-lpd

exit 0

%preun
# Let CUPS daemon not be automatically started at boot time any more
%_preun_service cups
#_preun_service cups-lpd

%postun
%_postun_groupdel lpadmin
#_postun_service cups-lpd

%post common
# Set up update-alternatives entries
%if %{use_alternatives}
/usr/sbin/alternatives --install %{_bindir}/lpr print %{_bindir}/lpr.cups 40 \
	 --slave %{_bindir}/lp print-lp %{_bindir}/lp.cups \
	 --slave %{_bindir}/lpq print-lpq %{_bindir}/lpq.cups \
	 --slave %{_bindir}/lprm print-lprm %{_bindir}/lprm.cups \
	 --slave %{_bindir}/lpstat print-lpstat %{_bindir}/lpstat.cups \
	 --slave %{_bindir}/cancel print-cancel %{_bindir}/cancel.cups \
	 --slave %{_sbindir}/lpc print-lpc %{_sbindir}/lpc.cups \
	 --slave %{_mandir}/man1/cancel.1.xz print-cancelman %{_mandir}/man1/cancel-cups.1.xz \
	 --slave %{_mandir}/man1/lp.1.xz print-lpman %{_mandir}/man1/lp-cups.1.xz \
	 --slave %{_mandir}/man8/lpc.8.xz print-lpcman %{_mandir}/man8/lpc-cups.8.xz \
	 --slave %{_mandir}/man1/lpq.1.xz print-lpqman %{_mandir}/man1/lpq-cups.1.xz \
	 --slave %{_mandir}/man1/lpr.1.xz print-lprman %{_mandir}/man1/lpr-cups.1.xz \
	 --slave %{_mandir}/man1/lprm.1.xz print-lprmman %{_mandir}/man1/lprm-cups.1.xz \
	 --slave %{_mandir}/man1/lpstat.1.xz print-lpstatman %{_mandir}/man1/lpstat-cups.1.xz
%endif
exit 0

%preun common
%if %{use_alternatives}
if [ $1 -eq 0 ] ; then
	/usr/sbin/alternatives --remove print %{_bindir}/lpr.cups
fi
%endif
exit 0

%triggerin -- samba-client
ln -sf %{_libexecdir}/samba/cups_backend_smb %{cups_serverbin}/backend/smb || :
exit 0

%triggerun -- samba-client
[ $2 = 0 ] || exit 0
rm -f %{cups_serverbin}/backend/smb

%files
%doc README.md CREDITS.md CHANGES.md
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/cupsd.conf
%config(noreplace) %attr(-,root,root) %{_sysconfdir}/sysconfig/cups
%ghost %config(noreplace) %{_sysconfdir}/cups/printers.conf
%ghost %config(noreplace) %{_sysconfdir}/cups/classes.conf
%attr(-,root,sys) %{_sysconfdir}/cups/cupsd.conf.default
%verify(not md5 size mtime) %config(noreplace) %attr(0640,root,lp) %{_sysconfdir}/cups/cups-files.conf
%attr(0640,root,lp) %{_sysconfdir}/cups/cups-files.conf.default
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/ppd
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/ssl
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/snmp.conf
%attr(0640,root,lp) %{_sysconfdir}/cups/snmp.conf.default
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/dbus*/system.d/cups.conf
%ghost %dir %attr(0755,root,lp) %{_rundir}/cups
%ghost %dir %attr(0511,lp,sys) %{_rundir}/cups/certs
%{_tmpfilesdir}/cups.conf
%{_tmpfilesdir}/cups-lp.conf
%{_datadir}/cups/drv/sample.drv
%{_datadir}/cups/examples
%{_datadir}/cups/mime/mime.types
%{_datadir}/cups/mime/mime.convs
%{_datadir}/cups/ppdc/*.defs
%{_datadir}/cups/ppdc/*.h
%dir %{_datadir}/%{name}/www
%dir %{_datadir}/%{name}/www/de
%dir %{_datadir}/%{name}/www/es
%dir %{_datadir}/%{name}/www/ja
%dir %{_datadir}/%{name}/www/ru
%{_datadir}/%{name}/www/images
%{_datadir}/%{name}/www/*.css
# 1658673 - html files cannot be docs, because CUPS web ui will not have
# introduction page on Fedora Docker image (because rpms are installed
# without docs there because of space reasons)
%{_datadir}/%{name}/www/index.html
%{_datadir}/%{name}/www/help
%{_datadir}/%{name}/www/robots.txt
%{_datadir}/%{name}/www/da/index.html
%{_datadir}/%{name}/www/de/index.html
%{_datadir}/%{name}/www/es/index.html
%{_datadir}/%{name}/www/fr/index.html
%{_datadir}/%{name}/www/ja/index.html
%{_datadir}/%{name}/www/ru/index.html
%{_datadir}/%{name}/www/pt_BR/index.html
%{_datadir}/%{name}/www/apple-touch-icon.png
%dir %{_datadir}/%{name}/usb
%{_datadir}/%{name}/usb/org.cups.usb-quirks
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.socket
%{_unitdir}/%{name}.path
%config(noreplace) %{_sysconfdir}/pam.d/cups
%{cups_serverbin}/cgi-bin
%{cups_serverbin}/daemon
%{cups_serverbin}/notifier
%{cups_serverbin}/filter/*
%{cups_serverbin}/monitor
%{cups_serverbin}/backend/*
%{_datadir}/cups/ipptool
%config(noreplace) %{_sysconfdir}/pam.d/cups
%{_tmpfilesdir}/cups.conf
%{_tmpfilesdir}/cups-lp.conf
%attr(0644, root, root)%{_unitdir}/%{name}.service
%attr(0644, root, root)%{_unitdir}/system-%{name}.slice
%attr(0644, root, root)%{_unitdir}/%{name}.socket
%attr(0644, root, root)%{_unitdir}/%{name}.path
%{_datadir}/cups/templates
%{_datadir}/cups/data
%exclude %{_datadir}/cups/doc
%{_datadir}/cups/model
%{_datadir}/cups/profiles
%attr(0755,root,lp) %{_var}/log/cups
# Set ownerships of spool directory which is normally done by 'make install'
# Because RPM does 'make install' as normal user, this has to be done here
%dir %attr(0710,root,sys) %{_var}/spool/cups
%dir %attr(01770,root,sys) %{_var}/spool/cups/tmp
%dir %attr(775,root,sys) %{_var}/cache/cups
%ghost %dir %attr(775,root,sys) %{_var}/cache/cups/rss
# Bug #28383 dirs
%dir %{_libdir}/printdriver
# Desktop menu and icons
%{_datadir}/applications/*
%{_iconsdir}/hicolor/*/apps/%{name}.png
%ifarch x86_64
# Compatibility link, will be removed soon
%{_libdir}/cups
%endif
%attr(0644, root, root)%{_unitdir}/cups-lpd.socket
%attr(0644, root, root)%{_unitdir}/cups-lpd@.service

%files common
%dir %config(noreplace) %attr(-,lp,sys) %{_sysconfdir}/cups
%ghost %config(noreplace) %attr(-,lp,sys) %{_sysconfdir}/cups/client.conf
%{_bindir}/*cups
%{_bindir}/cupstestppd
%{_bindir}/ippfind
%{_bindir}/ipptool
%{_bindir}/lpoptions
%{_bindir}/photo_print
%{_bindir}/ppdc
%{_bindir}/ppdhtml
%{_bindir}/ppdi
%{_bindir}/ppdmerge
%{_bindir}/ppdpo
%{_mandir}/man?/*
# printerapp
%exclude %{_mandir}/man1/ippeveprinter.1.*
%exclude %{_mandir}/man7/ippevepcl.7.*
%exclude %{_mandir}/man7/ippeveps.7.*
%{_sbindir}/*
# (akien) Those are actually needed for translation (mga#16321)
%lang(ca) %{_datadir}/locale/ca/cups_ca.po
%lang(cs) %{_datadir}/locale/cs/cups_cs.po
%lang(da) %{_datadir}/locale/da/cups_da.po
%lang(de) %{_datadir}/locale/de/cups_de.po
%lang(en) %{_datadir}/locale/en/cups_en.po
%lang(es) %{_datadir}/locale/es/cups_es.po
%lang(fr) %{_datadir}/locale/fr/cups_fr.po
%lang(it) %{_datadir}/locale/it/cups_it.po
%lang(ja) %{_datadir}/locale/ja/cups_ja.po
%lang(pt) %{_datadir}/locale/pt_BR/cups_pt_BR.po
%lang(ru) %{_datadir}/locale/ru/cups_ru.po
%lang(zh_CN) %{_datadir}/locale/zh_CN/cups_zh_CN.po

%files -n %{libname}
%{license} LICENSE
%{license} NOTICE
%{_libdir}/*.so.%{major}{,.*}

%files filesystem
%dir %{cups_serverbin}
%dir %{cups_serverbin}/backend
%dir %{cups_serverbin}/driver
%dir %{cups_serverbin}/filter
%dir %{_datadir}/cups
%dir %{_datadir}/cups/data
%dir %{_datadir}/cups/drv
%dir %{_datadir}/cups/mime
%dir %{_datadir}/cups/model
%dir %{_datadir}/cups/ppdc
%dir %{_datadir}/ppd

%files -n %{libname}-devel
%{_bindir}/cups-config
%{_includedir}/cups
%{_libdir}/*.so
%{_libdir}/pkgconfig/cups.pc
%multiarch %{multiarch_includedir}/cups/*
%{_rpmconfigdir}/macros.d/macros.cups

%files printerapp
%{_bindir}/ippeveprinter
%dir %{cups_serverbin}/command
%{cups_serverbin}/command/ippevepcl
%{cups_serverbin}/command/ippeveps
%{_mandir}/man1/ippeveprinter.1.*
%{_mandir}/man7/ippevepcl.7.*
%{_mandir}/man7/ippeveps.7.*
