Name:           cxxtest
Version:        4.4
Release:        %mkrel 7
Summary:        A JUnit-like testing framework for C++

Group:          Development/C++
License:        LGPLv2+
URL:            https://cxxtest.com/
Source0:        https://sourceforge.net/projects/cxxtest/files/cxxtest/%{version}/%{name}-%{version}.tar.gz

# Documentation
Source1:        https://cxxtest.com/guide.pdf

Patch0:         %{name}-shebang.patch

BuildArch:      noarch
BuildRequires:  asciidoc >= 8.5.0
BuildRequires:  python3-devel

# the --fog-parser option requires 'ply'
Requires:       python3-ply

%description
CxxTest is a JUnit/CppUnit/xUnit-like framework for C++.
Its advantages over existing alternatives are that it:
 - doesn't require RTTI
 - doesn't require member template functions
 - doesn't require exception handling
 - doesn't require any external libraries (including memory management,
   file/console I/O, graphics libraries)

%files -f %{pyproject_files}
%doc COPYING README Versions
%{_bindir}/cxxtestgen.py
%{_bindir}/cxxtestgen
%{_includedir}/cxxtest/
%{_datadir}/pkgconfig/%{name}.pc
%{_mandir}/man1/cxxtestgen.1.*


#--------------------------------------------------------------------

%package doc
Summary:        Documentation on how to use CxxTest
Group:          Documentation

%description doc
This package contains the documentation on how to use CxxTest.

%files doc
%doc guide.pdf doc/images/

#--------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1
cp -a %{SOURCE1} .
find . -name ".cvsignore" -delete


%build
cd python
%pyproject_wheel

# create pkgconfig file
cd ..
cat <<EOF >%{name}.pc
prefix=%{_prefix}
exec_prefix=%{_prefix}
includedir=%{_includedir}/%{name}

Name: %{name}
Description: A JUnit-like testing framework for C++
Version: %{version}
Cflags: -I\${includedir}
EOF

cd doc

# script to create asciidoc file for manpage of cxxtestgen
cat <<EOF >create_manpage.py
import sys
sys.path.insert(0, '../python/python3')
import cxxtest
cxxtest.create_manpage()
EOF

# create manpage
%{__python3} create_manpage.py
a2x -f manpage cxxtestgen.1.txt

%install
mkdir -p %{buildroot}%{_includedir}/cxxtest
install -D -p -m 644 cxxtest/* %{buildroot}%{_includedir}/cxxtest
install -D -p -m 644 %{name}.pc %{buildroot}%{_datadir}/pkgconfig/%{name}.pc

pushd python
%pyproject_install

# add symlink present in previous release of cxxtest
ln -s %{_bindir}/cxxtestgen %{buildroot}%{_bindir}/cxxtestgen.py
%pyproject_save_files cxxtest
popd

install -D -p -m 644 doc/cxxtestgen.1 %{buildroot}%{_mandir}/man1/cxxtestgen.1
