# Exclude plugin .so from provides.
%global __provides_exclude_from ^%{_libdir}/%{name}/(plugins|views)/.*\\.so$

# Needed if/when system lua is not compatible with current darktable.
# Darktable 3.8+ requires lua 5.4.
%if 0%{?mageia} >= 9
%bcond_without systemlua
%else
%bcond_with    systemlua
%endif

Name:           darktable
Version:        5.0.1
Release:        %mkrel 2
Summary:        Open source photography workflow application and RAW developer
Group:          Graphics/Photography
License:        GPLv3+
Url:            https://www.darktable.org
Source0:        https://github.com/darktable-org/darktable/releases/download/release-%{version}/%{name}-%{version}.tar.xz
Patch0:		darktable-5.0.0_r5m2.patch
Patch1:		17347.patch
Patch2:		17394.patch
BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  gmic-devel
BuildRequires:  gnome-doc-utils
BuildRequires:  intltool
BuildRequires:  iso-codes
BuildRequires:  libgomp-devel
BuildRequires:  perl-Image-ExifTool
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(colord-gtk)
BuildRequires:  pkgconfig(dbus-glib-1)
# Min version required to enable ISOBMFF to support cr3 files.
BuildRequires:  pkgconfig(exiv2) >= 0.27.4
BuildRequires:  pkgconfig(flickcurl)
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(libavif)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(libheif)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(OpenEXR) >= 3.0
BuildRequires:  pkgconfig(osmgpsmap-1.0)
BuildRequires:  pkgconfig(portmidi)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  po4a
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(Imath)
BuildRequires:  porttime-devel
%if %{with systemlua}
BuildRequires:  lua-devel
%else
Provides:       bundled(lua) = 5.4.3
%endif

# Cf. https://pagure.io/packaging-committee/issue/550
Provides:       bundled(rawspeed)

# Only supports 64-bit architectures.
ExclusiveArch:  x86_64 aarch64

Requires:       perl-Image-ExifTool

# Some CSS themes suggest to use the the Roboto font family.
Recommends:     roboto-fontface-fonts

%description
Darktable is an open source photography workflow application and
RAW developer. A virtual lighttable and darkroom for photographers.
It manages your digital negatives in a database, lets you view them
through a zoomable lighttable and enables you to develop raw images
and enhance them.

Advanced users may be interested in the optional %{name}-tools-noise
and %{name}-tools-basecurve packages for command line tools.

%package tools-noise
Summary:        Noise profiling tool to add support for new cameras in darktable
Group:          Graphics/Photography
Requires:       gnuplot
Requires:       ImageMagick

%description tools-noise
The darktable noise command line tool can be used to generate noise profiles for
new cameras which are not included yet in darktable. You can then contribute
these noise profiles to the darktable project.

The provided tools are:
%{_libexecdir}/%{name}/tools/%{name}-gen-noiseprofile
%{_libexecdir}/%{name}/tools/%{name}-noiseprofile

See https://pixls.us/articles/how-to-create-camera-noise-profiles-for-darktable/
for details.

%package tools-basecurve
Summary:        Basecurve tool for darktable
Group:          Graphics/Photography
Requires:       dcraw
Requires:       ImageMagick
Requires:       perl-Image-ExifTool

%description tools-basecurve
The darktable basecurve command line tool.

The provided tools are:
%{_libexecdir}/%{name}/tools/%{name}-curve-tool
%{_libexecdir}/%{name}/tools/%{name}-curve-tool-helper

See https://www.darktable.org/2013/10/about-basecurves/ for details.

%prep
%autosetup -p1

%build
%cmake \
  -DBINARY_PACKAGE_BUILD=ON \
  -DDONT_USE_INTERNAL_LUA=%{?with_systemlua:ON}%{!?with_systemlua:OFF} \
  -DPROJECT_VERSION="%{version}" \
  -DBUILD_NOISE_TOOLS=ON \
  -DBUILD_CURVE_TOOLS=ON \
  -DRAWSPEED_ENABLE_LTO=ON \
  -DTESTBUILD_OPENCL_PROGRAMS=OFF
%cmake_build

%install
%cmake_install

# Handle docs in files section.
rm -rf %{buildroot}%{_docdir}

# To find libdarktable.so without rpath.
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf << EOF
%{_libdir}/%{name}
EOF

%find_lang %{name} --with-man --all-name

%files -f %{name}.lang
%doc AUTHORS README.md RELEASE_NOTES.md
%license LICENSE
%config %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_bindir}/%{name}
%{_bindir}/%{name}-chart
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-cltest
%{_bindir}/%{name}-cmstest
%{_bindir}/%{name}-generate-cache
%{_bindir}/%{name}-rs-identify
%{_datadir}/applications/org.darktable.%{name}.desktop
%{_datadir}/metainfo/org.darktable.%{name}.appdata.xml
%{_datadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/%{name}*
%{_libdir}/%{name}/
%dir %{_libexecdir}/%{name}
%dir %{_libexecdir}/%{name}/tools
%{_mandir}/man1/%{name}*.1.*

%files tools-noise
%{_libexecdir}/%{name}/tools/%{name}-gen-noiseprofile
%{_libexecdir}/%{name}/tools/%{name}-noiseprofile
%{_libexecdir}/%{name}/tools/profiling-shot.xmp
%{_libexecdir}/%{name}/tools/subr.sh

%files tools-basecurve
%{_libexecdir}/%{name}/tools/%{name}-curve-tool
%{_libexecdir}/%{name}/tools/%{name}-curve-tool-helper
%{_datadir}/%{name}/tools/basecurve/
