%define dav_user %{name}
%define dav_group %{name}
%define dav_localstatedir /run
%define dav_syscachedir /var/cache

Summary:	File system driver that allows you to mount a WebDAV server
Name:		davfs2
Version:	1.7.1
Release:	%mkrel 1
License:	GPLv3+
Group:		System/Kernel and hardware
URL:		https://savannah.nongnu.org/projects/davfs2
Source0:	http://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz
Source1:	%{name}.tmpfiles.conf
Patch1:		segfault.patch
Patch2:		davfs2-neon-34.patch
Requires(pre):	filesystem >= 2.1.9-18
Requires(post):	systemd >= %{systemd_required_version}
Requires(pre):	rpm-helper
Requires(postun): rpm-helper
BuildRequires:	pkgconfig(neon) >= 0.27
BuildRequires:	gettext-devel >= 0.14.4
BuildRequires:	libtool
BuildRequires:	mercurial
Provides:	davfs = %{version}-%{release}
Obsoletes:	davfs < 0.2.5

%description
davfs2 is a Linux file system driver that allows you to mount a WebDAV server
as a local file system, like a disk drive. This way applications can access
resources on a Web server without knowing anything about HTTP or WebDAV. davfs2
runs as a daemon in userspace. It uses the kernel file system coda or fuse.
Most probably your Linux kernel includes at least one of this file systems. To
connect to the WebDAV server it makes use of the neon library. Neon supports
TLS/SSL (using OpenSSL or GnuTLS) and access via proxy server.

davfs2 allows you to e.g.

 * use a WebDAV server as workspace for a geographically distributed work
   group.
 * save documents on a WebDAV server and access and edit them via internet from
   wherever you want.
 * edit a web site in place, using your preferred development tools.


%prep
%autosetup -S hg

%build
autoreconf -vfi

export dav_user=%{dav_user}
export dav_group=%{dav_group}
export dav_localstatedir=%{dav_localstatedir}
export dav_syscachedir=%{dav_syscachedir}
export CFLAGS="%{optflags} -fcommon"

%configure \
    --disable-rpath \

%make_build

%install
install -d %{buildroot}%{dav_syscachedir}/%{name}
install -d %{buildroot}%{_datadir}/%{name}

%make_install

# (cg) For some reason install puts stuff here...
rm -rf %{buildroot}/sbin

# rename the binaries
ln -s %{_sbindir}/mount.davfs %{buildroot}%{_sbindir}/mount.%{name}
ln -s %{_sbindir}/umount.davfs %{buildroot}%{_sbindir}/umount.%{name}

# create tmpfiles directory
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# rename the manpages
find %{buildroot}%{_mandir} -name "*.gz" | xargs gunzip

%find_lang %{name} --all-name

%pre
%_pre_useradd %{dav_user} %{dav_localstatedir}/mount.%{name} /bin/false

%post
%_tmpfilescreate %{name}

%postun
%_postun_userdel %{dav_user}

%files -f %{name}.lang
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/INSTALL
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/certs
%dir %{_sysconfdir}/%{name}/certs/private
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/secrets
%{_sbindir}/mount.davfs*
%{_sbindir}/umount.davfs*
%{_tmpfilesdir}/%{name}.conf
%{_mandir}/man5/*
%{_mandir}/man8/*
%lang(de) %{_mandir}/de/man5/*
%lang(de) %{_mandir}/de/man8/*
%lang(es) %{_mandir}/es/man5/*
%attr(1775,root,%{dav_group}) %dir %{dav_syscachedir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
