%define        maj_version  %(echo %version | cut -d. -f 1-2)
Name:          db3
Version:       3.3.87
Release:       %mkrel 0
Summary:       Berkeley DB Java Edition
Group:         Development/Java
URL:           https://www.oracle.com/database/berkeley-db/je/index.html
# https://download.oracle.com/berkeley-db/
Source0:       https://download.oracle.com/berkeley-db/je-%{version}.tar.gz
# extracted from the main archive
Source1:       je-%{version}-docs.tar.gz
Source2:       je-jca-examples-%{version}.tar.gz
License:       BSD, GPL, Sleepycat Public License
BuildRequires: ant
BuildRequires: ant-junit
BuildRequires: ant-trax
BuildRequires: geronimo-ejb-3_1-api
BuildRequires: geronimo-j2ee-connector-1_6-api
BuildRequires: ecj
BuildRequires: junit
BuildRequires: mx4j
BuildRequires: java-devel
BuildRequires: velocity
BuildRequires: jpackage-utils
BuildRequires: asm3
Requires:      geronimo-ejb-3_1-api
Requires:      geronimo-j2ee-connector-1_6-api
Requires:      jpackage-utils
BuildArch:     noarch
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
Berkeley DB JE is a high performance, transactional storage engine
written entirely in Java. Like the highly successful Berkeley DB
product, Berkeley DB JE executes in the address space of the
application, without the overhead of client/server communication. It
stores data in the application's native format, so no runtime data
translation is required. Berkeley DB JE supports full ACID
transactions and recovery. It provides an easy-to-use interface,
allowing programmers to store and retrieve information quickly,
simply and reliably.

Berkeley DB JE was designed from the ground up in Java. It takes
full advantage of the Java environment. The Berkeley DB JE API
provides a Java Collections-style interface, as well as a
programmatic interface similar to the Berkeley DB API. The
architecture of Berkeley DB JE supports high performance and
concurrency for both read-intensive and write-intensive workloads.

%package demo
Group:         Development/Java
Summary:       Examples for %{name}
Requires:      %{name}

%description demo
Berkeley DB Java Edition.

This package contains examples for %{name}

%package eclipse
Group:         Development/Java
Summary:       Berkeley DB JE Eclipse Plugin
Requires:      %{name}

%description eclipse
Berkeley DB Java Edition.

This package contains Berkeley DB JE Eclipse Plugin

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}

%description javadoc
Berkeley DB Java Edition.

This package contains javadoc for %{name}

%package manual
Group:         Development/Java
Summary:       Documents for %{name}

%description manual
Berkeley DB Java Edition.

This package contains documents for %{name}

%prep

%setup -q -n je-%{version} -a 1 -a 2

for j in $(find . -name "*.jar" -o -name "*.class"); do
  rm -rf $j
done

%build

export JAVA_HOME=%{java_home}
export CLASSPATH=""
CLASSPATH=$CLASSPATH:$(build-classpath asm3/asm mx4j/mx4j geronimo-ejb-3.1-api geronimo-j2ee-connector-1.6-api)
CLASSPATH=$CLASSPATH:$(build-classpath junit ecj velocity ant/ant-junit ant)
ant \
  -Djvm=%{java_home}/bin/java \
  -Dj2ee.jarfile=$(build-classpath geronimo-j2ee-connector-1.6-api) \
  -Dbuild.sysclasspath=first \
  jar-hidingdoclet jar jcajar jmx eclipsejar \
  testex

export CLASSPATH=$CLASSPATH:docs/HidingDoclet.jar:build/lib/com.sleepycat.je_%{version}.jar:build/lib/je.jar:build/lib/jejca.jar:build/lib/jejmx.jar
ant \
  -Djvm=%{java_home}/bin/java \
  -Dj2ee.jarfile=$(build-classpath geronimo-j2ee-connector-1.6-api) \
  -Dexample.jca.srcdir=jca \
  -Dbuild.sysclasspath=first \
  javadoc-all jmx-examples jca-examples

%if 0
export CLASSPATH=$CLASSPATH:$(build-classpath ant/ant-trax)
ant test
%endif

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

mkdir -p %{buildroot}%{_javadir}/db3

install -pm 644 build/lib/je.jar \
  %{buildroot}%{_javadir}/db3/je-%{version}.jar
install -pm 644 build/lib/jejca.jar \
  %{buildroot}%{_javadir}/db3/jejca-%{version}.jar
install -pm 644 build/lib/jejca.rar  \
  %{buildroot}%{_javadir}/db3/jejca-%{version}.rar
install -pm 644 build/lib/jejmx.jar \
  %{buildroot}%{_javadir}/db3/jejmx-%{version}.jar

install -pm 644 build/lib/com.sleepycat.je_%{version}.jar \
  %{buildroot}%{_javadir}/db3/com.sleepycat.je-%{version}.jar

(
  cd %{buildroot}%{_javadir}/db3
  for jar in *-%{version}*; do
    ln -sf ${jar} ${jar/-%{version}/}
  done
)

mkdir -p %{buildroot}%{_javadocdir}/db3-%{version}
cp -pr docs/java/* %{buildroot}%{_javadocdir}/db3-%{version}
ln -s berkeley-db-%{version} %{buildroot}%{_javadocdir}/db3
rm -rf docs/java

mkdir -p %{buildroot}%{_datadir}/db3/examples
cp -pr examples/* %{buildroot}%{_datadir}/db3/examples

install -pm 644 build/lib/jejmx-example.jar  \
%{buildroot}%{_datadir}/db3/examples/jejmx-example-%{version}.jar
install -pm 644 build/lib/jejca-example.jar  \
%{buildroot}%{_datadir}/db3/examples/jejca-example-%{version}.jar

sed -i "s|java/index.html|%{_javadocdir}/db3/index.html|" docs/index.html
sed -i "s|http://www.oracle.com/technology/documentation/berkeley-db/je/java/index.html|%{_javadocdir}/db3/index.html|" docs/relnotes.html

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%dir %{_javadir}/db3
%{_javadir}/db3/je-%{version}.jar
%{_javadir}/db3/je.jar
%{_javadir}/db3/jejca-%{version}.jar
%{_javadir}/db3/jejca.jar
%{_javadir}/db3/jejca-%{version}.rar
%{_javadir}/db3/jejca.rar
%{_javadir}/db3/jejmx-%{version}.jar
%{_javadir}/db3/jejmx.jar
%doc LICENSE README

%files demo
%defattr(-,root,root)
%{_datadir}/db3/examples

%files eclipse
%defattr(-,root,root)
%{_javadir}/db3/com.sleepycat.je-%{version}.jar
%{_javadir}/db3/com.sleepycat.je.jar

%files javadoc
%defattr(-,root,root)
%{_javadocdir}/db3-%{version}
%{_javadocdir}/db3

%files manual
%defattr(-,root,root)
%doc docs/*

