%define with_maven 1
%define with_javadoc 0

Name:          dbunit
Version:       2.2.3
Release:       %mkrel 2
Summary:       DbUnit Framework - extension for JUnit
Group:         Development/Java
License:       LGPL
Url:           https://dbunit.sourceforge.net/
# svn export http://dbunit.svn.sourceforge.net/svnroot/dbunit/tags/release-2-2-3/ dbunit-2.2.3
Source0:       dbunit-2.2.3-src-svn.tar.gz
Source1:       dbunit-2.2.3-autogeneratedfiles.tar.gz
Source2:       dbunit-tests-error-summary.txt
Patch0:        dbunit-2.2.3-pom.patch
Patch1:        dbunit-2.2.3-DbUnitTaskTest.patch
BuildRequires: java-devel
BuildRequires: jpackage-utils

BuildRequires: ant
BuildRequires: ant-junit
BuildRequires: apache-commons-collections
BuildRequires: apache-commons-lang
BuildRequires: apache-poi
BuildRequires: hsqldb
BuildRequires: junit
BuildRequires: junit-addons
BuildRequires: mockmaker
BuildRequires: mockobjects
BuildRequires: slf4j

%if %with_maven
BuildRequires: maven
BuildRequires: maven-ant-plugin
BuildRequires: maven-changelog-plugin
BuildRequires: maven-changes-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-install-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-jxr
BuildRequires: maven-plugin-cobertura
BuildRequires: maven-plugin-jxr
BuildRequires: maven-project-info-reports-plugin
BuildRequires: maven-release
BuildRequires: maven-release-plugin
BuildRequires: maven-resources-plugin
#BuildRequires: maven-site-plugin
#BuildRequires: maven-skins
BuildRequires: maven-surefire-plugin
BuildRequires: maven-surefire-report-plugin
%else
BuildRequires: apache-commons-logging
BuildRequires: hamcrest
BuildRequires: liblog4j-java
BuildRequires: xerces-j2
BuildRequires: xml-commons-apis
%endif

Requires:      ant
Requires:      apache-commons-collections
Requires:      apache-commons-lang
Requires:      apache-poi
Requires:      junit
Requires:      junit-addons
Requires:      slf4j

Requires:      jpackage-utils
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:      java
BuildArch:     noarch

%description
DbUnit is a JUnit extension (also usable with Ant) targeted
for database-driven projects that, among other things, puts
your database into a known state between test runs. This is
an excellent way to avoid the myriad of problems that can
occur when one test case corrupts the database and causes
subsequent tests to fail or exacerbate the damage.
DbUnit has the ability to export and import your database
data to and from XML datasets. Since version 2.0, DbUnit can
works with very large dataset when use in streaming mode.
DbUnit can also helps you to verify that your database data
match expected set of values.

%if %with_javadoc
%package javadoc
Summary:       Javadocs for %{name}
Group:         Development/Java
Requires:      jpackage-utils

%description javadoc
This package contains the API documentation for %{name}
%endif

%prep
%setup -q -n dbunit-%{version}
%patch -P 0 -p0
%patch -P 1 -p0

for j in $(find . -name "*.jar"); do
  mv $j $j.no
done

(
  cd src/csv/orders
  jar -cf orders.jar orders.csv orders_row.csv table-ordering.txt
)

# poi fix
sed -i 's|workbook.setSheetName(index, metaData.getTableName(), HSSFWorkbook.ENCODING_UTF_16);|workbook.setSheetName(index, metaData.getTableName());|' src/java/org/dbunit/dataset/excel/XlsDataSet.java
sed -i 's|cell.setEncoding(HSSFCell.ENCODING_UTF_16);|//cell.setEncoding(HSSFCell.ENCODING_UTF_16);|' src/java/org/dbunit/dataset/excel/XlsDataSet.java

for c in $(find . -name "*.class"); do
  rm -rf $c
done

%if !%with_maven
  tar -xf %{SOURCE1}
  sed -i 's|haltonerror="true" haltonfailure="true"|haltonerror="false" haltonfailure="false"|' maven-build.xml
%endif

%build
%if %with_maven
%if %with_javadoc
  mvn-rpmbuild -Dmaven.test.failure.ignore=true ant:ant install javadoc:aggregate
%else
  mvn-rpmbuild -Dmaven.test.failure.ignore=true ant:ant install
%endif
%else
  export CLASSPATH=""
  CLASSPATH=$CLASSPATH:$(build-classpath ant ant-launcher commons-collections commons-lang hsqldb poi)
  CLASSPATH=$CLASSPATH:$(build-classpath junit-addons mockobjects-core mockobjects-jdk1.4 mockmaker)
  CLASSPATH=$CLASSPATH:$(build-classpath slf4j/api slf4j/nop commons-logging log4j xerces-j2)
  CLASSPATH=$CLASSPATH:$(build-classpath ant/ant-junit junit xml-commons-apis hamcrest/core)
  CLASSPATH=$CLASSPATH:target/classes:target/test-classes:target/csv

  ant \
    -Dmaven.settings.offline=true \
    -Dbuild.sysclasspath=only \
    -Dtestnotmatchpattern='*' \
    jar javadoc

%endif
%install
[ %{buildroot} != / ] && rm -rf %{buildroot}

mkdir -p %{buildroot}%{_javadir}
install -m 644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

mkdir -p %{buildroot}%{_mavenpomdir}
install -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar

%if %with_javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%endif

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_javadir}/%{name}.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%doc LICENSE.txt

%if %with_javadoc
%files javadoc
%{_javadocdir}/%{name}
%endif
