%bcond_with bootstrap
%bcond_with test
%bcond_with verbose
%bcond_without containers
%bcond_without sysusers

%define expat_version           2.0.1

%define lib_major 3
%define lib_api   1
%define lib_name  %mklibname dbus %{lib_api} %{lib_major}
%define develname %mklibname -d dbus

Summary:        D-Bus message bus
Name:           dbus
Version:        1.14.10
Release:        %mkrel 8
License:        GPLv2+ or AFL
Group:          System/Servers
URL:            https://www.freedesktop.org/Software/dbus
Source0:        https://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(expat) >= %{expat_version}
%if ! %{with bootstrap}
BuildRequires:  xmlto
BuildRequires:  docbook-dtd412-xml
BuildRequires:  doxygen
%endif
BuildRequires:  libtool
BuildRequires:  pkgconfig(libcap-ng)
BuildRequires:  pkgconfig(gio-2.0) >= 2.24
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(libsystemd)

Requires(pre):  shadow-utils
Provides:       should-restart = system
Provides:       dbus-common = %{version}-%{release}

%description
D-Bus is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package -n %{lib_name}
Summary:        Shared library for using D-Bus
Group:          System/Libraries
Requires:       dbus >= %{version}

%description -n %{lib_name}
D-Bus shared library.

%package -n %{develname}
Summary:        Libraries and headers for D-Bus
Group:          Development/C
Requires:       %{name} = %{version}
Requires:       %{lib_name} = %{version}
Provides:       lib%{name}-1-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      %{_lib}dbus-1_0-devel

%description -n %{develname}
Headers and static libraries for D-Bus.

%package x11
Summary:        X11-requiring add-ons for D-Bus
Group:          System/Servers
Requires:       dbus = %{version}

%description x11
D-Bus contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%package doc
Summary:        Developer documentation for D-BUS
Group:          Documentation
BuildArch:      noarch
Requires:       dbus = %{version}
Recommends:     devhelp
Conflicts:      libdbus-1-devel < 1.2.20
Conflicts:      lib64dbus-1-devel < 1.2.20

%description doc
This package contains developer documentation for D-Bus along with
other supporting documentation such as the introspect dtd file.

%prep
%autosetup -p1

%build

COMMON_ARGS="--disable-static --disable-selinux --enable-systemd --with-system-socket=/run/dbus/system_bus_socket --libexecdir=%{_libexecdir}/dbus-%{lib_api} --enable-user-session --runstatedir=%{_rundir} --with-dbus-user=messagebus"

#### Build once with tests to make check
%if %{with test}
%configure $COMMON_ARGS --enable-tests=yes \
               --enable-verbose-mode=yes \
               --enable-asserts=yes \
               --disable-doxygen-docs \
               --enable-userdb-cache \
               --disable-xml-docs
DBUS_VERBOSE=1 %make_build
make check

#### Clean up and build again
make clean
%endif

%configure $COMMON_ARGS --disable-tests --disable-asserts \
%if ! %{with bootstrap}
 --enable-doxygen-docs --enable-xml-docs \
 --htmldir=%{_datadir}/devhelp/books/%{name} \
%endif
 --enable-verbose-mode=%{?with_verbose:yes}%{!?with_verbose:no} \
 --enable-containers=%{?with_containers:yes}%{!?with_containers:no}
%make_build

%check
%__make check

%install
%make_install

mkdir -p %{buildroot}%{_sysconfdir}/X11/xinit.d
cat << EOF > %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus
#!/usr/bin/sh
# to be sourced
if [ -z "\$DBUS_SESSION_BUS_ADDRESS" ]; then
  eval \`/usr/bin/dbus-launch --exit-with-session --sh-syntax\`
fi
EOF
chmod 755 %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus

# create directory
mkdir %{buildroot}%{_datadir}/dbus-%{lib_api}/interfaces

# This is legacy
rm -rf %{buildroot}%{_unitdir}/dbus.target.wants

# link devhelp docs in docdir
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
pushd %{buildroot}%{_datadir}/devhelp/books/%{name}
for f in *; do
  ln -s ../../devhelp/books/%{name}/$f %{buildroot}%{_docdir}/%{name}-doc
done
popd

# python shebangs
%py3_shebang_fix %{buildroot}%{_docdir}/dbus/examples/

%if ! %{with sysusers}
rm -rf %{buildroot}%{_sysusersdir}/dbus.conf
%endif

%pre
# (cg) Do not require/use rpm-helper helper macros... we must do this manually
# to avoid dep loops during install
getent group messagebus > /dev/null || groupadd -f -r messagebus
getent passwd messagebus > /dev/null || useradd -r -c "system user for %{name}" -g messagebus -s /sbin/nologin -d / messagebus

%files
%doc NEWS doc/system-activation.txt
%license COPYING
%dir %{_datadir}/doc/dbus/examples
%{_datadir}/doc/dbus/examples/GetAllMatchRules.py
%{_datadir}/doc/dbus/examples/example-session-disable-stats.conf
%{_datadir}/doc/dbus/examples/example-system-enable-stats.conf
%{_datadir}/doc/dbus/examples/example-system-hardening-without-traditional-activation.conf
%dir %{_sysconfdir}/dbus-%{lib_api}
%config(noreplace) %{_sysconfdir}/dbus-%{lib_api}/*.conf
%dir %{_localstatedir}/lib/dbus
%dir %{_libdir}/dbus-1.0
%if %{with sysusers}
%{_sysusersdir}/dbus.conf
%endif
%{_tmpfilesdir}/dbus.conf
%{_datadir}/xml/dbus-1/*.dtd
%{_datadir}/xml/dbus-1/*.xml
%{_bindir}/dbus-cleanup-sockets
%{_bindir}/dbus-daemon
%{_bindir}/dbus-run-session
%{_bindir}/dbus-send
%{_bindir}/dbus-test-tool
%{_bindir}/dbus-update-activation-environment
%{_bindir}/dbus-uuidgen
%{_mandir}/man*/*
%dir %{_datadir}/dbus-%{lib_api}
%dir %{_datadir}/dbus-%{lib_api}/system.d
%dir %{_datadir}/dbus-%{lib_api}/session.d
%{_datadir}/dbus-%{lib_api}/interfaces
%{_datadir}/dbus-%{lib_api}/services
%{_datadir}/dbus-%{lib_api}/session.conf
%{_datadir}/dbus-%{lib_api}/system.conf
%{_datadir}/dbus-%{lib_api}/system-services
# See doc/system-activation.txt in source tarball for the rationale
# behind these permissions
%dir %{_libexecdir}/dbus-%{lib_api}
%attr(4750,root,messagebus) %{_libexecdir}/dbus-%{lib_api}/dbus-daemon-launch-helper
%{_unitdir}/dbus.service
%{_unitdir}/dbus.socket
%{_unitdir}/multi-user.target.wants/dbus.service
%{_unitdir}/sockets.target.wants/dbus.socket
%{_userunitdir}/dbus.service
%{_userunitdir}/dbus.socket
%{_userunitdir}/sockets.target.wants/dbus.socket

%files -n %{lib_name}
%license COPYING
%{_libdir}/*dbus-%{lib_api}*.so.%{lib_major}{,.*}

%files -n %{develname}
%{_libdir}/libdbus-%{lib_api}.so
%{_libdir}/dbus-1.0/include
%{_libdir}/pkgconfig/dbus-%{lib_api}.pc
%{_includedir}/dbus-1.0
%{_libdir}/cmake/DBus1/

%files x11
%{_sysconfdir}/X11/xinit.d/*
%{_bindir}/dbus-launch
%{_bindir}/dbus-monitor

%files doc
%doc %{_datadir}/devhelp/books/dbus
%{_docdir}/%{name}-doc
