#
# spec file for package deltarpm
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so
%define snap %nil

Name:           deltarpm
Version:        3.6.5
Release:        %mkrel 7
Summary:        Tools to Create and Apply deltarpms
License:        BSD-3-Clause
Group:          System/Packaging
URL:            https://github.com/rpm-software-management/deltarpm
%if 0%{?snap}
# Generate source by doing:
# git clone https://github.com/rpm-software-management/deltarpm.git
# cd deltarpm
# git archive --format=tar --prefix="deltarpm-git-20120324/" 7ed5208 | \
# bzip2 > deltarpm-git-20120324.tar.bz2
Source:		%{name}-%{version}-20120324.tar.bz2
%else
Source:         %{url}/archive/%{version}/%{name}-%{version}.tar.gz
%endif
# Patches from Fedora
# Mageia patches
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(rpm) >= 4.12.90
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  perl-devel
# we need to build against recent rpm, so avoid the new payload
%define _binary_payload w9.bzdio

%description
This package contains tools to create and apply deltarpms. A deltarpm
contains the difference between an old and a new version of an RPM,
which makes it possible to recreate the new RPM from the deltarpm and
the old one. You do not need to have a copy of the old RPM, because
deltarpms can also work with installed RPMs.

%package -n python3-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Python
Requires:       %{name} = %{version}

%description -n python3-deltarpm
Python bindings for deltarpm.

%package -n perl-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Perl
Requires:       %{name} = %{version}
Conflicts:      %{name} <= 3.6.1-11

%description -n perl-deltarpm
Perl bindings for deltarpm.

%prep
%if 0%{?snap}
%setup -q -n %{name}-git-20120324
%else
%autosetup -p1
%endif

%build
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" %{?_smp_mflags} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir}
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" %{?_smp_mflags} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir} python
pushd perl
perl Makefile.PL INSTALLDIRS=vendor
make
popd

%install
mkdir -p %{buildroot}%{_libdir}/rpm
make rpmdumpheader="%{_libdir}/rpm/rpmdumpheader" DESTDIR=%{buildroot} prefix=%{_prefix} mandir=%{_mandir} bindir=%{_bindir} install
# Remove wrongly installed Python module
rm -rf %{buildroot}%{_libdir}/python/site-packages/{_deltarpmmodule.so,deltarpm.py}

rm -rf %{buildroot}/usr/local

%make_install -C perl

# fix debug info extraction
chmod u+w %{buildroot}%{perl_vendorarch}/auto/deltarpm/deltarpm.so

%files
%doc README LICENSE.BSD
%{_bindir}/[^d]*
%{_mandir}/man8/*
%{_libdir}/rpm/rpmdumpheader

%files -n python3-deltarpm
%{python3_sitearch}/deltarpm.py
%{python3_sitearch}/_deltarpmmodule.so
%{python3_sitearch}/__pycache__/*

%files -n perl-deltarpm
%{_bindir}/drpmsync
%{perl_vendorarch}/auto/deltarpm/deltarpm.so
%{perl_vendorarch}/deltarpm.pm
%{_mandir}/man3/deltarpm.*
