# Filter out bogus and unwanted auto-provides
%global __provides_exclude_from %{python3_sitelib}/%{name}

# Use system or static libtorrent(-rasterbar)?
%define sys_libtorrent	1

Summary:	Full-featured GTK+ Bittorrent client
Name:		deluge
Version:	2.1.1
Release:	%mkrel 4
License:	GPLv3+ with exceptions
Group:		Networking/File transfer
URL:            https://deluge-torrent.org/
Source0:        https://ftp.osuosl.org/pub/deluge/source/2.1/%{name}-%{version}.tar.xz
Source1:	%{name}-daemon.service
Source2:	%{name}-web.service
# (Debian) add patch to disable checking for updates by default
Patch0:		new_release_check.patch
Patch2:		0001-Port-to-Ayatana-AppIndicator.patch
# Python 3.13 removes cgi module (bug 2292651)
# https://github.com/deluge-torrent/deluge/commit/5d96cfc72f
Patch3:		deluge-2.1.1-python3_13-cgi-removal.patch
BuildArch:	noarch
BuildRequires:	desktop-file-utils
BuildRequires:  python3-devel
BuildRequires:	imagemagick
BuildRequires:	intltool
%if %sys_libtorrent
BuildRequires:	python3dist(libtorrent)
%endif
BuildRequires:	systemd
Requires:	gtk+3.0
Requires:	librsvg2
Requires:	python3-pkg-resources
Requires:	python3dist(geoip)
Requires:	python3dist(pycairo)
Requires:	python3dist(pygobject)
Requires:	python3dist(pygame)
Requires:	python3dist(service-identity)
Requires:	xdg-utils
Recommends:	geoip
%if %sys_libtorrent
Requires:	python3dist(libtorrent)
%endif
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd


%description
Deluge is a Bittorrent client. Deluge is intended to bring a native,
full-featured client to Linux GTK+ desktop environments such as GNOME
and XFCE.

%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires

%build
%py3_build

%install
# https://dev.deluge-torrent.org/ticket/2034
# https://bugs.mageia.org/show_bug.cgi?id=20895
mkdir -p %{buildroot}%{_unitdir}
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}-daemon.service
install -m644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}-web.service
mkdir -p %{buildroot}/var/lib/%{name}
%py3_install
# macro pyproject_install does not install files in datadir

desktop-file-install \
  --remove-key=Version \
  --dir %{buildroot}%{_datadir}/applications \
%{buildroot}%{_datadir}/applications/*

mkdir -p %{buildroot}%{_metainfodir}
mv %{buildroot}%{_datadir}/appdata/deluge.appdata.xml %{buildroot}%{_metainfodir}/%{name}.appdata.xml
rmdir %{buildroot}%{_datadir}/appdata

## NOTE: The lang files should REEEAALLLY be in a standard place such as
##       /usr/share/locale or similar. It'd make things so much nicer for
##       the packaging. :O
## A bit of sed magic to mark the translation files with %%lang, taken from
## find-lang.sh (part of the rpm-build package) and tweaked somewhat. We
## cannot (unfortunately) call find-lang directly since it's not on a
## "$PREFIX/share/locale/"-ish directory tree.

pushd %{buildroot}
    find -type f -o -type l \
        | sed '
            s:%{buildroot}%{python3_sitelib}::
            s:^\.::
            s:\(.*/deluge/i18n/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:
            s:^\([^%].*\)::
            s:%lang(C) ::
            /^$/d' \
    > %{name}.lang

## Now we move that list back to our sources, so that '%%files -f' can find it
## properly.
popd && mv %{buildroot}/%{name}.lang .

%post
%_post_service deluge-daemon
%_post_service deluge-web

%preun
%_preun_service deluge-daemon
%_preun_service deluge-web

%files -f %{name}.lang 
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}*
%{python3_sitelib}/deluge/
%{python3_sitelib}/deluge-*.egg-info
%{_datadir}/applications/%{name}.desktop
%{_metainfodir}/%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.*
%{_iconsdir}/hicolor/*/apps/%{name}*.*
%{_unitdir}/*.service
%{_mandir}/man1/%{name}*.1.*
