%define oname denyhost

Name:             denyhosts
Version:          3.1
Release:          %mkrel 13
Summary:          A script to help thwart ssh server attacks

Group:            Networking/Other
License:          GPLv2
URL:              https://denyhost.sourceforge.net/
Source0:          https://download.sourceforge.net/%{oname}/%{name}-%{version}.tar.gz
Source1:          denyhosts.cron
Source3:          denyhosts-allowed-hosts
Source4:          denyhosts.sysconfig
Source5:          denyhosts.logrotate
Source6:          README.fedora
Source7:          denyhosts.service
Source8:          denyhosts.tmpfiles
Patch0:           denyhosts-3.1-mga-config.patch
Patch1:           denyhosts-3.1-rundir.patch
Patch2:           0001-Fixed-the-AttributeError-related-to-issue-54.patch

BuildArch:        noarch
BuildRequires:    pkgconfig(python3)
BuildRequires:    python3dist(ipaddr)
BuildRequires:    systemd-units
Requires:         openssh-server
Requires:         python3-ipaddr
Requires:         rsyslog
Requires(post):   rpm-helper
Requires(preun):  rpm-helper

%description
DenyHosts is a Python script that analyzes the sshd server log
messages to determine which hosts are attempting to hack into your
system. It also determines what user accounts are being targeted. It
keeps track of the frequency of attempts from each host and, upon
discovering a repeated attack host, updates the /etc/hosts.deny file
to prevent future break-in attempts from that host.  Email reports can
be sent to a system admin.


%prep
%setup -q -n %{name}
%autopatch -p1

# This must be moved before the Python build process runs so that we
# can include it as documentation.
mv plugins/README.contrib .

# And the permissions are off as well
chmod +x plugins/*


%build
%py3_build

%install
%py3_install
# pyproject_install installs /etc and /usr/share in site-packages

install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_sysconfdir}/cron.d
install -d %{buildroot}/%{_sysconfdir}/logrotate.d
install -d %{buildroot}/%{_sysconfdir}/sysconfig

install -d -m 700 %{buildroot}/%{_localstatedir}/lib/denyhosts
install -d %{buildroot}/%{_localstatedir}/log

install -p -m 600 denyhosts.conf %{buildroot}/%{_sysconfdir}/denyhosts.conf
install -p -m 755 daemon-control-dist %{buildroot}/%{_bindir}/denyhosts-control
install -p -m 644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/cron.d/denyhosts
install -p -m 644 %{SOURCE3} %{buildroot}/%{_localstatedir}/lib/denyhosts/allowed-hosts
install -p -m 644 %{SOURCE4} %{buildroot}/%{_sysconfdir}/sysconfig/denyhosts
install -p -m 644 %{SOURCE5} %{buildroot}/%{_sysconfdir}/logrotate.d/denyhosts
install -D -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 644 %{SOURCE8} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d %{buildroot}%{_rundir}/%{name}

# We don't want this because it serves no purpose on Mageia
rm -f %{buildroot}/%{_bindir}/daemon-control-dist

touch %{buildroot}/%{_localstatedir}/log/denyhosts

for i in allowed-warned-hosts hosts hosts-restricted hosts-root \
         hosts-valid offset suspicious-logins sync-hosts \
         users-hosts users-invalid users-valid; do
  touch %{buildroot}/%{_localstatedir}/lib/denyhosts/$i
done

# python shebangs
%{py3_shebang_fix} %{buildroot}%{_bindir}/denyhosts-control

%preun
%_preun_service %name

%post
%_tmpfilescreate %{name}
# Note that we do not automaticaly run --migrate, because we can't be
# sure that all of the hosts.deny entries were created by denyhosts
%_post_service %name

touch %{_logdir}/denyhosts
touch %{_localstatedir}/lib/denyhosts/allowed-warned-hosts
touch %{_localstatedir}/lib/denyhosts/hosts
touch %{_localstatedir}/lib/denyhosts/hosts-restricted
touch %{_localstatedir}/lib/denyhosts/hosts-root
touch %{_localstatedir}/lib/denyhosts/hosts-valid
touch %{_localstatedir}/lib/denyhosts/suspicious-logins
touch %{_localstatedir}/lib/denyhosts/sync-hosts
touch %{_localstatedir}/lib/denyhosts/users-hosts
touch %{_localstatedir}/lib/denyhosts/users-invalid
touch %{_localstatedir}/lib/denyhosts/users-valid

%postun
if [ $1 -ge 1 ] ; then
  systemctl restart %name.service >/dev/null 2>&1
fi


%files
%doc CHANGELOG.txt denyhosts.conf
%doc README*

%{_bindir}/denyhosts.py
%{_bindir}/denyhosts-control
%{python3_sitelib}/*
%{_mandir}/man8/%{oname}*

%config(noreplace) %{_sysconfdir}/denyhosts.conf
%config(noreplace) %{_sysconfdir}/cron.d/denyhosts
%config(noreplace) %{_sysconfdir}/logrotate.d/denyhosts
%config(noreplace) %{_sysconfdir}/sysconfig/denyhosts
%config(noreplace) %{_localstatedir}/lib/denyhosts/allowed-hosts

%ghost %{_logdir}/denyhosts
%ghost %{_localstatedir}/lib/denyhosts/allowed-warned-hosts
%ghost %{_localstatedir}/lib/denyhosts/hosts
%ghost %{_localstatedir}/lib/denyhosts/hosts-restricted
%ghost %{_localstatedir}/lib/denyhosts/hosts-root
%ghost %{_localstatedir}/lib/denyhosts/hosts-valid
%ghost %{_localstatedir}/lib/denyhosts/offset
%ghost %{_localstatedir}/lib/denyhosts/suspicious-logins
%ghost %{_localstatedir}/lib/denyhosts/sync-hosts
%ghost %{_localstatedir}/lib/denyhosts/users-hosts
%ghost %{_localstatedir}/lib/denyhosts/users-invalid
%ghost %{_localstatedir}/lib/denyhosts/users-valid

%dir %ghost %attr(0755, root, root) %{_rundir}/%{name}
%ghost %attr(0660, -, -) %{_rundir}/%{name}/denyhosts.pid

%dir %{_localstatedir}/lib/denyhosts

%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
