# Disabled per upstream to fix FTBFS.
%undefine _hardened_build

%global _smp_ncpus_max 8
%define _enable_debug_packages %{nil}
%define debug_package          %{nil}

#define snap 20170317
%global pkglibdir	%{_prefix}/lib/dietlibc

%ifarch %ix86 x86_64 aarch64
%bcond_without		ssp
%else
%bcond_with		ssp
%endif

%global myarch `uname -m | sed -e 's/i[4-9]86/i386/' -e 's/armv.*/arm/' -e 's!mips!%{_arch}!g'`

# This is eventually a biarch package, so no %%_lib for diethome
%define diethome %{_prefix}/lib/dietlibc

# Enable builds without testing (default shall always be testing)
%ifnarch aarch64
%define build_check		1
%else
%define build_check		0
%endif
%{expand: %{?_with_CHECK:	%%global build_check 1}}
%{expand: %{?_without_CHECK:	%%global build_check 0}}

Summary:	C library optimized for size
Name:		dietlibc
Version:	0.34
Release:	%mkrel 5
License:	GPLv2
Group:		Development/Other
URL:		https://www.fefe.de/dietlibc/
Source0:	https://www.fefe.de/dietlibc/%{name}-%{version}.tar.xz
# all in one from RH:
Patch0:         dietlibc-insecure-defpath.patch
Patch1:		dietlibc-0.34-path.patch
Patch5:		dietlibc-0.22-net-ethernet.patch
Patch6:		dietlibc-0.24-rpc-types.patch
Patch17:	dietlibc-0.34-x86_64-stat64.patch
Patch18:	dietlibc-0.27-x86_64-lseek64.diff
Patch23:	dietlibc-0.33-biarch.patch
Patch26:	dietlibc-0.27-kernel2.6-types.patch
# (UPSTREAMED differently)
Patch33:	dietlibc-0.34-fix-strncmp.patch
# (cjw) from PLD, see https://gcc.gnu.org/bugzilla/show_bug.cgi?id=26374
Patch34:	dietlibc-0.29-ppc-gcc-ldbl128.patch
Patch113:	dietlibc-0.34-i386-types.patch

# (UPSTREAMED)
Patch300:	diet_arm_eabi_time.patch
Patch301:	diet_arm_create_module.patch
# (tv) add string.h's basename (prevent libkmod to segfault in basebame())
Patch322:	basename.diff
Patch323:	fix-test.patch

# From Debian
Patch400:	aarch64-define-__clone.diff

# (wally) fix test failures on aarch64
Patch500:	dummy-RDTSC-implementation.patch


%description
Small libc for building embedded applications.

%package	devel
Group:          Development/C
Summary:        Development files for dietlibc
Obsoletes:	%{name}
Provides:	%{name} = %{version}-%{release}

%description	devel
Small libc for building embedded applications.

%prep

%setup -q

find . -type d -perm 0700 -exec chmod 755 {} \;
find . -type f -perm 0555 -exec chmod 755 {} \;
find . -type f -perm 0444 -exec chmod 644 {} \;

for i in `find . -type d -name CVS` `find . -type f -name .cvs\*` `find . -type f -name .#\*`; do
    if [ -e "$i" ]; then rm -rf $i; fi >&/dev/null
done

# P9999 is from fedora 
%patch -P 0 -p0 -b .rh
%patch -P 1 -p0 -b .mdkconfig
%patch -P 5 -p1 -b .net-ethernet
%patch -P 6 -p1 -b .rpc-types
%patch -P 17 -p1 -b .x86_64-stat64
#patch -P 18 -p0 -b .x86_64-lseek64
#patch -P 23 -p1 -b .biarch
#patch -P 26 -p1 -b .kernel2.6-types
%patch -P 33 -p1 -b .fix-strncmp

%patch -P 300 -p1 -b .arm_time
%patch -P 301 -p1 -b .arm_create_module
%patch -P 322 -p1 -b .readdir_r
%patch -P 323 -p1 -b .test

%patch -P 400 -p1 -b .__clone

%patch -P 500 -p1 -b .rdtsc

%patch -P 113 -p0 -b .386_types

%if %{without ssp}
sed -i -e 's!^#define WANT_SSP$!// \0!g;
	   s!.*\(#define WANT_STACKGAP\).*!\1!g' dietfeatures.h
%global xtra_fixcflags	-fno-stack-protector
%else
%global xtra_fixcflags	%nil
%endif

rm -f x86_64/getpriority.S

#WANT_VALGRIND_SUPPORT
# disable unwanted features
cp dietfeatures.h{,.tv}
sed -i \
    -e '/#define WANT_\(LARGEFILE_BACKCOMPAT\|\LINKER_WARNINGS\|IPV6_DNS\|HIGH_PRECISION_MATH\|SAFEGUARDNT_LINKER_WARNINGS\|PLUGPLAY_DNS\|SAFEGUARD\)/d' \
    dietfeatures.h
 
# fix execute permission on test scripts
chmod a+x test/{dirent,inet,stdio,string,stdlib,time}/runtests.sh

%global fixcflags	-fomit-frame-pointer -fno-exceptions -fno-asynchronous-unwind-tables %xtra_fixcflags -Os -g3 -Werror-implicit-function-declaration -Wno-unused -Wno-switch
%global basemakeflags	prefix=%_prefix BINDIR=%{_bindir} MAN1DIR=%{_mandir}/man1 CFLAGS="$RPM_OPT_FLAGS %fixcflags $XTRA_CFLAGS" PDIET=%pkglibdir STRIP=: MYARCH=%{myarch}
%global makeflags	%basemakeflags

%build
%make_build %makeflags DEBUG=1

%check
# make and run the tests
%if %{build_check}
cd test; rm *.c.* || :
%ifarch %mips %arm
sed -i -e 's!cycles empty!empty!' Makefile
%endif
# fix build in chroot:
export DIETHOME="%{_builddir}/%{name}-%{version}"

find -name "Makefile" | xargs perl -pi -e "s|^DIET.*|DIET=\"${DIETHOME}/bin-%{myarch}/diet\"|g" 	 
# compile test suite:
%make_build %makeflags all DEBUG=1
%make_build %makeflags -C inet all DEBUG=1

# run the tests
# getpass requires user input
perl -pi -e "s|^PASS.*|PASS=\"\"|g" runtests.sh
sh ./runtests.sh
cd ..
%endif

%install
make %makeflags DEBUG=1 DESTDIR=%{buildroot} install

%files devel
%doc AUTHOR BUGS CAVEAT CHANGES README THANKS TODO FAQ
%{_bindir}/diet
%{_bindir}/dnsd
%{_bindir}/elftrunc
%{_mandir}/man*/*
%dir %{diethome}
%dir %{diethome}/include
%{diethome}/include/*
%dir %{diethome}/lib-*
%{diethome}/lib-*/*


