#Based on spec from bero of openmadriva 
%global debug_package %{nil}
%define oname DisplayLink%20USB%20Graphics%20Software%20for%20Ubuntu%{version}-EXE
#We can get this from AUR https://aur.archlinux.org/cgit/aur.git/tree/PKGBUILD?h=displaylink
%define rdate 2024-10

#Use one tag from https://github.com/displaylink-rpm/displaylink-rpm/tags
%define     dlrel %{version}.0

Name:           displaylink
Version:        6.1
Release:        %mkrel 1
Summary:        DisplayLink USB Graphics driver
License:        Binary-only, distributable
Group:          System/Kernel and hardware
URL:            https://github.com/displaylink-rpm/displaylink-rpm/
#Upstream Sources
Source0:        https://www.synaptics.com/sites/default/files/exe_files/%{rdate}/%{oname}.zip?/DisplayLink_Linux-%{version}.zip
Source1:        https://github.com/displaylink-rpm/displaylink-rpm/raw/refs/tags/v%{dlrel}/20-displaylink.conf
Source2:        https://github.com/displaylink-rpm/displaylink-rpm/raw/refs/tags/v%{dlrel}/displaylink.logrotate
Source3:        https://github.com/displaylink-rpm/displaylink-rpm/raw/refs/tags/v%{dlrel}/95-displaylink.preset

#Extra Sources
Source100:      displaylink-release-notes-6.1.txt
Source101:      DISPLAYLINK-EULA
Source102:      README.install.urpmi

ExclusiveArch:  x86_64 aarch64 %{ix86} %{arm}

BuildRequires:  systemd-rpm-macros
BuildRequires:  sed
BuildRequires:  patchelf

%description
Driver for HDMI/VGA adapters built upon the DisplayLink DL-6xxx,
DL-5xxx, DL-41xx and DL-3xxx series of chipsets. This includes
numerous docking stations, USB monitors, and USB adapters.

%package -n %{name}-dkms-evdi
Summary:        DisplayLink for kernels without native evdi
Group:          System/Kernel and hardware
#The lib is dlopen()ed
# therefore no autogenerated dependency
Requires:       %{_lib}evdi
Requires:       dkms-evdi
Conflicts:      %{name}-nodkms
Conflicts:      %{name}-native-evdi
Provides:       %{name}

%description -n %{name}-dkms-evdi
Driver for HDMI/VGA adapters built upon the DisplayLink DL-6xxx,
DL-5xxx, DL-41xx and DL-3xxx series of chipsets. This includes
numerous docking stations, USB monitors, and USB adapters.

This package use the dkms evdi module

WARNING: This driver is distributed as a binary only. Neither you
nor the BlogDrake or Mageia teams can review what this binary, run as root,
actually does.
It may work, but it may also wipe your harddisk clean or send all
your data to someone who shouldn't have it.
Please complain to DisplayLink.

%ifnarch %{ix86}
%package native-evdi
Summary:        DisplayLink for kernels with native evdi
Group:          System/Kernel and hardware
#The lib is dlopen()ed
# therefore no autogenerated dependency
Requires:       %{_lib}evdi
# For kernels 6.6+ in 64b the module is included in kernel
Conflicts:      dkms-evdi
Conflicts:      %{name}-with-dkms
Conflicts:      %{name}-dkms-evdi
Provides:       %{name}

%description native-evdi
Driver for HDMI/VGA adapters built upon the DisplayLink DL-6xxx,
DL-5xxx, DL-41xx and DL-3xxx series of chipsets. This includes
numerous docking stations, USB monitors, and USB adapters.

This package use the native evdi module

WARNING: This driver is distributed as a binary only. Neither you
nor the BlogDrake or Mageia teams can review what this binary, run as root,
actually does.
It may work, but it may also wipe your harddisk clean or send all
your data to someone who shouldn't have it.
Please complain to DisplayLink.
%endif

%prep
%autosetup -p1 -c

chmod +x *.run
./displaylink-driver-*.run --noexec --keep

%build
# NOTHING TO BUILD!!!

%install
mkdir -p %{buildroot}%{_libexecdir}/%{name}

# Extra Files
install -Dm644 %{SOURCE100} %{buildroot}/%{_docdir}/displaylink/displaylink-release-notes-6.1.txt
install -Dm644 %{SOURCE101} %{buildroot}/%{_docdir}/displaylink/DISPLAYLINK-EULA
install -m644 %{SOURCE102} ./

# DisplayLinkManager binary...
%ifarch x86_64
cp -a displaylink-driver-*/x64-*/DisplayLinkManager %{buildroot}%{_libexecdir}/%{name}
%else
%ifarch %{ix86}
cp -a displaylink-driver-*/x86-*/DisplayLinkManager %{buildroot}%{_libexecdir}/%{name}
%else
%ifarch aarch64
cp -a displaylink-driver-*/aarch64-*/DisplayLinkManager %{buildroot}%{_libexecdir}/%{name}
%else
%ifarch %{arm}
cp -a displaylink-driver-*/arm-*/DisplayLinkManager %{buildroot}%{_libexecdir}/%{name}
%else
echo "Unsupported architecture"
exit 1
%endif
%endif
%endif
%endif

cd displaylink-driver-*[0-9]
# Firmware
cp *.spkg %{buildroot}%{_libexecdir}/%{name}/

patchelf  --remove-rpath %{buildroot}%{_libexecdir}/%{name}/DisplayLinkManager

# Systemd services and udev integration...
mkdir -p %{buildroot}%{_sysconfdir}/udev/rules.d %{buildroot}%{_libexecdir}/%{name} %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/pm/sleep.d

# Adjust to FHS paths instead of those created by the .run file
sed -i -e 's,/opt/displaylink,%{_libexecdir}/displaylink,g' *.sh

# Make sure we install to the buildroot
sed -i -e 's, /lib/systemd,%{buildroot}%{_prefix}/lib/systemd,g' -e 's, /etc/pm, %{buildroot}%{_sysconfdir}/pm,g' service-installer.sh
chmod +x *.sh
./udev-installer.sh systemd %{buildroot}%{_udevrulesdir}/99-displaylink.rules %{buildroot}%{_libexecdir}/%{name}/udev.sh
. ./service-installer.sh
create_dl_service systemd %{buildroot}%{_libexecdir}/%{name} %{buildroot}%{_prefix}

# Fix script pointing at buildroot
rm %{buildroot}%{_sysconfdir}/pm/sleep.d/10_displaylink
ln -s ../../..%{_libexecdir}/%{name}/suspend.sh %{buildroot}%{_sysconfdir}/pm/sleep.d/10_displaylink

# Module config
mkdir -p %{buildroot}%{_sysconfdir}/modprobe.d
echo 'options evdi initial_device_count=4' >%{buildroot}%{_sysconfdir}/modprobe.d/evdi.conf

# Xorg config
install -Dm0644 %{S:1} %{buildroot}%{_datadir}/X11/xorg.conf.d/20-displaylink.conf

# logs
mkdir -p %{buildroot}%{_localstatedir}/log/displaylink %{buildroot}%{_sysconfdir}/logrotate.d
cp %{S:2} %{buildroot}%{_sysconfdir}/logrotate.d/

# launch if installed
install -Dm0644 %{S:3} %{buildroot}%{_prefix}/lib/systemd/system-preset/95-displaylink.preset

%post -n %{name}-dkms-evdi
%systemd_post displaylink-driver.service

%preun -n %{name}-dkms-evdi
%systemd_preun displaylink-driver.service

%postun -n %{name}-dkms-evdi
%systemd_postun_with_restart displaylink-driver.service

%ifnarch %{ix86}
%post native-evdi
%systemd_post displaylink-driver.service

%preun native-evdi
%systemd_preun displaylink-driver.service

%postun native-evdi
%systemd_postun_with_restart displaylink-driver.service
%endif

%files -n %{name}-dkms-evdi
%doc README.install.urpmi
%{_docdir}/displaylink/DISPLAYLINK-EULA
%{_docdir}/displaylink/displaylink-release-notes-6.1.txt
%{_libexecdir}/%{name}
%{_sysconfdir}/pm/sleep.d/10_displaylink
%{_udevrulesdir}/99-displaylink.rules
%{_unitdir}/displaylink-driver.service
%{_sysconfdir}/modprobe.d/evdi.conf
%{_datadir}/X11/xorg.conf.d/20-displaylink.conf
%{_prefix}/lib/systemd/system-preset/*
%config(noreplace) %{_sysconfdir}/logrotate.d/displaylink.logrotate
%dir %{_localstatedir}/log/displaylink

%ifnarch %{ix86}
%files native-evdi
%doc README.install.urpmi
%{_docdir}/displaylink/DISPLAYLINK-EULA
%{_docdir}/displaylink/displaylink-release-notes-6.1.txt
%{_libexecdir}/%{name}
%{_sysconfdir}/pm/sleep.d/10_displaylink
%{_udevrulesdir}/99-displaylink.rules
%{_unitdir}/displaylink-driver.service
%{_sysconfdir}/modprobe.d/evdi.conf
%{_datadir}/X11/xorg.conf.d/20-displaylink.conf
%{_prefix}/lib/systemd/system-preset/95-displaylink.preset
%config(noreplace) %{_sysconfdir}/logrotate.d/displaylink.logrotate
%dir %{_localstatedir}/log/displaylink
%endif
