%define _hardened_build 1
%define _legacy_common_support 1

Name:       distcc
Version:    3.4
Release:    %mkrel 7
Summary:    Distributed C/C++ compilation
Group:      Development/Tools
License:    GPLv2+
URL:        https://distcc.org/
Source0:    https://github.com/distcc/distcc/releases/download/v%{version}/distcc-%{version}.tar.gz
Source1:    hosts.sample
Source2:    distccd.service
#https://github.com/distcc/distcc/issues/110
Patch1:     path-masquarade.patch
Patch2:     fix-segfault.patch

BuildRequires: binutils-devel
BuildRequires: pkgconfig(popt)
BuildRequires: pkgconfig(gtk+-3.0)
BuildRequires: lzo-devel
BuildRequires: pkgconfig(python3)
BuildRequires: desktop-file-utils
BuildRequires: avahi-common-devel
BuildRequires: pkgconfig(avahi-client)
BuildRequires: pkgconfig(avahi-core)
Conflicts: %{name}-server < 3.3.3

%description
distcc is a program to distribute compilation of C or C++ code across
several machines on a network. distcc should always generate the same
results as a local compile, is simple to install and use, and is often
two or more times faster than a local compile.

%package    gnome
Summary:    Gnome frontend of distcc monitoring tool
Requires:   %{name} = %{version}-%{release}

%description gnome
This package contains the Gnome frontend of the distcc monitoring tool.

%package     server
Summary:    Server for distributed C/C++ compilation
Group:      Development/Tools
License:    GPLv2+

Requires: %{name} = %{version}-%{release}
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description server
This package contains the compilation server needed to use %{name}.


%prep
%autosetup -p1

%build
./autogen.sh
#https://githubhot.com/repo/distcc/distcc/issues/454
export CFLAGS="%{build_cflags} -DPY_SSIZE_T_CLEAN"
%configure \
	--disable-Werror \
	--without-gnome \
	--with-gtk
%make_build


%install
%make_install

# Install sample hosts file
install -Dm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}/hosts

# Install sample distccd config file
install -Dm 0644 contrib/redhat/sysconfig %{buildroot}%{_sysconfdir}/sysconfig/distccd

# Install distcdd unit file
mkdir -p %{buildroot}%{_unitdir}
install -Dm 0755 %{SOURCE2} %{buildroot}%{_unitdir}/distccd.service

# Install distcc dirs
mkdir -p $RPM_BUILD_ROOT/usr/lib/distcc
mkdir -p $RPM_BUILD_ROOT/usr/lib/gcc-cross
if [ ! -d $RPM_BUILD_ROOT/usr/lib64 ]; then
  mkdir -p $RPM_BUILD_ROOT/usr/lib64	
fi
ln -s /usr/lib/distcc $RPM_BUILD_ROOT/usr/lib64/distcc

%post server
#[ $1 -lt 2 ] && /sbin/chkconfig --add distccd ||:
if [ $1 -eq 1 ] ; then
    # Initial installation
    /usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%post
%{_sbindir}/update-distcc-symlinks

%preun server
#[ $1 -eq 0 ] && /sbin/chkconfig --del distccd ||:
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /usr/bin/systemctl --no-reload disable distccd.service > /dev/null 2>&1 || :
    /usr/bin/systemctl stop distccd.service > /dev/null 2>&1 || :
fi

%postun server
/usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /usr/bin/systemctl try-restart distccd.service >/dev/null 2>&1 || :
fi

%files
%doc %{_datadir}/doc/%{name}
%{_bindir}/distcc
%{_bindir}/distccmon-text
%{_bindir}/lsdistcc
%{_bindir}/pump
%{_mandir}/man1/distcc.*
%{_mandir}/man1/distccmon-text*
%{_mandir}/man1/lsdistcc.*
%{_mandir}/man1/include_server*
%{_mandir}/man1/pump*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/hosts
%{python3_sitearch}/include_server*
%{_sbindir}/update-distcc-symlinks
%dir /usr/lib/distcc
/usr/lib64/distcc
%dir /usr/lib/gcc-cross

%files gnome
%{_bindir}/distccmon-gnome
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/distccmon-gnome.png

%files server
%doc COPYING README
%{_bindir}/distccd
%{_unitdir}/*
%{_sysconfdir}/default/distcc
%{_sysconfdir}/distcc/*allow*
%{_mandir}/man1/distccd*
%config(noreplace) %{_sysconfdir}/sysconfig/distccd
