
# Adapted from Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.

%define major           2
%define libname         %mklibname phobos %{major}
%define develname       %mklibname phobos -d
%define staticname       %mklibname phobos-static -d

%define bootstrap_version 2.088.0
%define sover	0_87
%define auto_bootstrap 0
%global debug_package %{nil}

Name:           dmd
Version:        2.094.1
Release:        %mkrel 5

Summary:        D Programming Language 2.0
License:        BSL-1.0
Group:          Development/Other
URL:            https://dlang.org/
Source:         https://github.com/dlang/dmd/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/dlang/druntime/archive/v%{version}.tar.gz#/druntime-%{version}.tar.gz
Source2:        https://github.com/dlang/phobos/archive/v%{version}.tar.gz#/phobos-%{version}.tar.gz
Source8:        http://downloads.dlang.org/releases/2.x/%{bootstrap_version}/dmd.%{bootstrap_version}.linux.tar.xz
Source9:        dmd.conf
# PATCH-FIX-OPENSUSE dmd_use_tarball_bootstrap.diff So the tarball is not downloaded
Patch0:         dmd_use_tarball_bootstrap.diff
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  xz
Recommends:     phobos-devel
# Bootstrap is only possible with x86*
ExclusiveArch:  %{ix86} x86_64
%ifarch i586
#!BuildIgnore:  gcc-PIE
%endif
%if !%{auto_bootstrap}
BuildRequires:  dmd
BuildRequires:  phobos-static-devel
%endif

%description
The D programming language is an object-oriented, imperative,
multi-paradigm system programming language. It has type inference,
automatic memory management and syntactic sugar for common types,
bounds checking, design by contract features, and a concurrency-aware
type system.

%package 	-n %{libname}
Summary:        Standard library for the D language
Group:          System/Libraries
Provides:       phobos = %{version}-%{release}
Provides:       libphobos = %{version}-%{release}

%description -n %{libname}
Phobos is the standard library for the D Programming Language.

This package contains the shared library needed to run programs compiled with
dmd.

%package 	-n %{develname}
Summary:        Development files for the D standard library
Group:          Development/Other
Requires:       %{libname} = %{version}
Provides:       phobos-devel = %{version}-%{release}

%description -n %{develname}
Phobos is the standard library for the D Programming Language.

This package contains the includes needed to compile programs against Phobos.

%package 	-n 	%{staticname}
Summary:        Development files for the D standard library
Group:          Development/Other
Requires:       %{develname} = %{version}
Provides:       phobos-static-devel = %{version}-%{release}

%description -n %{staticname}
Phobos is the standard library for the D Programming Language.

This package contains the static library for static linking. You don't need
this, unless you link statically, which is highly discouraged.

%prep
%setup -q
%setup -q -T -D -a 1
%setup -q -T -D -a 2
%patch -P 0 -p1
echo %{version} > phobos-%{version}/VERSION
cd %{_builddir}
ln -sf dmd-%{version} dmd
ln -sf druntime-%{version} druntime
ln -sf phobos-%{version} phobos
rm -rf druntime-%{version}
rm -rf phobos-%{version}
mv dmd-%{version}/druntime-%{version} .
mv dmd-%{version}/phobos-%{version} .

%build
# dmd
cd ..
pushd dmd
        cp %{SOURCE8} src
	make %{?_smp_mflags} -f posix.mak \
	%if %{auto_bootstrap}
		AUTO_BOOTSTRAP=1 \
	%endif
		BUILD=release \
		PIC=1 \
		ENABLE_RELEASE=1
popd

# druntime
pushd druntime
	make %{?_smp_mflags} -f posix.mak \
		BUILD=release \
		DMD="../dmd/generated/linux/release/*/dmd" \
		PIC=1 \
		ENABLE_RELEASE=1
popd

# phobos
pushd phobos
	make %{?_smp_mflags} -f posix.mak \
		BUILD=release \
		DMD="../dmd/generated/linux/release/*/dmd" \
		PIC=1 \
		ENABLE_RELEASE=1
popd

%install
# install files manually since the install script distributed put files all over the place
# dmd
install -dm755 %{buildroot}%{_bindir}
install -Dm755 %{_builddir}/dmd/generated/linux/release/*/dmd %{buildroot}%{_bindir}/dmd

install -dm755 %{buildroot}%{_sysconfdir}
install -Dm644 %{_sourcedir}/dmd.conf %{buildroot}%{_sysconfdir}/dmd.conf

install -dm755 %{buildroot}%{_mandir}
cp -r %{_builddir}/dmd/docs/man/* %{buildroot}%{_mandir}/

install -dm755 %{buildroot}%{_datadir}/licenses/dmd
install -Dm644 %{_builddir}/dmd/LICENSE.txt %{buildroot}%{_datadir}/licenses/dmd/LICENSE.txt

install -dm755 %{buildroot}%{_datadir}/%{name}/samples
cp -r %{_builddir}/dmd/samples/* %{buildroot}%{_datadir}/dmd/samples/

# phobos
install -dm755 %{buildroot}%{_libdir}
cp -a $(find %{_builddir}/phobos/generated/linux/release/ \( -iname "*.a" -a \! -iname "*.so.a" \) -o \( -iname "*.so*" -a \! -iname "*.o" -a \! -iname "*.a" \) ) %{buildroot}%{_libdir}

install -dm755 %{buildroot}%{_includedir}/dlang/dmd
cp -r %{_builddir}/phobos/{*.d,etc,std} %{buildroot}%{_includedir}/dlang/dmd
cp -r %{_builddir}/druntime/import/* %{buildroot}%{_includedir}/dlang/dmd/

%files
%doc README.md
%license LICENSE.txt
%config(noreplace) %{_sysconfdir}/dmd.conf
%{_bindir}/dmd
%{_datadir}/dmd
%{_mandir}/man*/*

%files -n %{libname}
%{_libdir}/libphobos2.so.*

%files -n %{develname}
%dir %{_includedir}/dlang
%dir %{_includedir}/dlang/dmd
%{_includedir}/dlang/dmd/*
%{_libdir}/libphobos2.so

%files -n %{staticname}
%{_libdir}/libphobos2.a
