%global libyui_major 16
Name:		dnfdragora
Version:	2.99.0
Release:	%mkrel 3
Summary:	DNF package-manager based on libYui abstraction
Group:		System/Packaging
License:	GPLv3+
URL:		https://github.com/manatools/%{name}
Source0:	%{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildArch:	noarch

BuildRequires:	cmake			>= 3.4.0
BuildRequires:	desktop-file-utils
BuildRequires:	gettext
BuildRequires:	appstream-util
BuildRequires:	pkgconfig
BuildRequires:	python3-devel		>= 3.4.0
BuildRequires:	python3-libdnf5
BuildRequires:	python3-manatools	>= 0.0.3
BuildRequires:	python3-yaml
BuildRequires:	python3-setuptools
BuildRequires:	python3-sphinx
BuildRequires:	python3-yui
BuildRequires:	python3-pyxdg
BuildRequires:	python3-cairosvg
BuildRequires:	python3-pillow
BuildRequires:	python3-pystray

Requires:	dnf5			>= 5.2.7
Requires:	dnf5daemon-server	>= 5.2.7
Requires:	filesystem
Requires:	hicolor-icon-theme
# Ensure base TUI deps are installed
Requires:	libyui-ncurses%{libyui_major}
Requires:	libyui-mga-ncurses%{libyui_major}
Requires:	python3-libdnf5		>= 5.2.7
Requires:	python3-manatools
Requires:	python3-yaml
Requires:	python3-yui
# Suggest users to select a GUI
Recommends:	%{name}-gui = %{version}-%{release}

%description
%{name} is a DNF frontend, based on rpmdragora from Mageia
(originally rpmdrake) Perl code.

%{name} is written in Python 3 and uses libYui, the widget
abstraction library written by SUSE, so that it can be run
using Qt 5, GTK+ 3, or ncurses interfaces.

%package qt
Summary:	Qt frontend for %{name}
Group:		System/Packaging
Provides:	%{name}-gui = %{version}-%{release}
Requires:	%{name}-common = %{version}-%{release}
Requires:	libyui-qt%{libyui_major}
Requires:	libyui-mga-qt%{libyui_major}
Supplements:	(%{name} and qtbase5-common)

%description qt
This package pulls in the dependencies to run %{name} with a Qt5 GUI.

%package gtk
Summary:	GTK+ frontend for %{name}
Group:		System/Packaging
Provides:	%{name}-gui = %{version}-%{release}
Requires:	%{name}-common = %{version}-%{release}
Requires:	libyui-gtk%{libyui_major}
Requires:	libyui-mga-gtk%{libyui_major}
Supplements:	(%{name} and gtk+3)

%description gtk
This package pulls in the dependencies to run %{name} with a GTK+3 GUI.

%package common
Summary:	Shared files for Qt and GTK+ flavours of %{name}
Group:		System/Packaging
# It's silly to install this without the actual program...
Requires:	%{name} = %{version}-%{release}
# Without this requirement, it's possible to have desktop files installed
# that won't do anything, since there's no GUI deps installed.
Requires:	%{name}-gui = %{version}-%{release}

%description common
This package contains shared files used by the Qt and GTK+ flavours of
%{name}, which are not strictly necessary for the ncurses flavour of the
main %{name} package.


%package updater
Summary:	Update notifier applet for %{name}
Group:		System/Packaging
Requires:	%{name}-gui = %{version}-%{release}
Requires:	libnotify
Requires:	python3-pyxdg
Requires:	python3-cairosvg
Requires:	python3-pillow
Requires:	python3-pystray

%description updater
%{name} is a DNF frontend, based on rpmdragora from Mageia
(originally rpmdrake) Perl code.

%{name} is written in Python 3 and uses libYui, the widget
abstraction library written by SUSE, so that it can be run
using Qt 5, GTK+ 3, or ncurses interfaces.

This package provides the update notifier applet for %{name}.


%prep
%autosetup -p1


%build
%cmake	-DCHECK_RUNTIME_DEPENDENCIES=ON				\
	-DENABLE_COMPS=OFF					\
	-Wno-dev
%cmake_build


%install
%cmake_install

%find_lang %{name}

%check
# Validate desktop-files.
%{_bindir}/desktop-file-validate				\
	%{buildroot}%{_datadir}/applications/*.desktop

# Validate AppData-files.
%{_bindir}/appstream-util validate-relax --nonet		\
	%{buildroot}%{_datadir}/appdata/*.appdata.xml


%files -f %{name}.lang
%doc README.md TODO.md %{name}.yaml.example
%license AUTHORS LICENSE
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.yaml
%{python3_sitelib}/%{name}/
%exclude %{python3_sitelib}/%{name}/updater.py
%exclude %{python3_sitelib}/%{name}/__pycache__/updater.cpython*.py?
%{_datadir}/%{name}/
%exclude %{_datadir}/applications/*%{name}-updater.desktop
%{_mandir}/man5/%{name}.yaml.5*
%{_mandir}/man8/%{name}.8*

%files updater
%{_bindir}/%{name}-updater
%{_datadir}/applications/*%{name}-updater.desktop
%{_sysconfdir}/xdg/autostart/*%{name}*.desktop
%{python3_sitelib}/%{name}/updater.py
%{python3_sitelib}/%{name}/__pycache__/updater.cpython*.py?

%files qt
# No files

%files gtk
# No files

%files common
%{_datadir}/appdata/*%{name}.appdata.xml
%{_datadir}/applications/*%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
