%define _serverbuild_flags -fstack-protector-all

Name:           dnsmasq
Version:        2.91
Release:        %mkrel 1
Summary:        A lightweight DHCP/caching DNS server
License:        GPLv2 or GPLv3
Group:          System/Servers
URL:            https://www.thekelleys.org.uk/dnsmasq/
Source0:        https://www.thekelleys.org.uk/dnsmasq/%{name}-%{version}.tar.xz
Source1:        %{name}.service

BuildRequires:          pkgconfig(dbus-1)
BuildRequires:          pkgconfig(libidn2)
BuildRequires:          pkgconfig(libnetfilter_conntrack)
BuildRequires:          pkgconfig(nettle)

Requires(pre):          rpm-helper
Requires(preun):        rpm-helper
Requires(post):         rpm-helper
Requires(postun):       rpm-helper

Obsoletes:              %{name}-base < 2.78-3

%description
Dnsmasq is lightweight, easy to configure DNS forwarder and DHCP server.
It is designed to provide DNS and, optionally, DHCP, to a small network.
It can serve the names of local machines which are not in the global
DNS. The DHCP server integrates with the DNS server and allows machines
with DHCP-allocated addresses to appear in the DNS with names configured
either in each host or in a central configuration file. Dnsmasq supports
static and dynamic DHCP leases and BOOTP for network booting of diskless
machines.

%package        utils
Summary:        Utilities for manipulating DHCP server leases
Group:          System/Servers

%description    utils
Utilities that use the standard DHCP protocol to
query/remove a DHCP server's leases.

%prep
%setup -q
%autopatch -p1

# fix the path to the trust anchor
sed -i 's|%%%%PREFIX%%%%|%{_prefix}|' dnsmasq.conf.example

#set default user /group in src/config.h
sed -i 's|#define CHUSER "nobody"|#define CHUSER "dnsmasq"|' src/config.h
sed -i 's|#define CHGRP "dip"|#define CHGRP "dnsmasq"|' src/config.h

# use /run instead of /var/run
sed -i 's|/var/run|%{_rundir}|g' $(grep -rl --exclude=CHANGELOG* /var/run)

# don't run build again with install
sed -i 's/^install-i18n.*i18n/install-i18n :/' Makefile

%build
%make_build all-i18n V=1 \
        CFLAGS="%{optflags}" \
        LDFLAGS="%{ldflags}" \
        PREFIX=%{_prefix} \
        COPTS="-DHAVE_DNSSEC -DHAVE_CONNTRACK -DHAVE_DBUS -DHAVE_LIBIDN2"
%make_build -C contrib/lease-tools CFLAGS="%{optflags}"

%install
# we don't want to run %%make_install as we want to use install-i18n target
%__make install-i18n PREFIX=%{_prefix} DESTDIR=%{?buildroot}

%__install -Dpm644 dnsmasq.conf.example %{buildroot}%{_sysconfdir}/dnsmasq.conf

%__install -Dpm755 contrib/lease-tools/dhcp_release %{buildroot}%{_bindir}/dhcp_release
%__install -Dpm644 contrib/lease-tools/dhcp_release.1 %{buildroot}%{_mandir}/man1/dhcp_release.1
%__install -Dpm755 contrib/lease-tools/dhcp_release6 %{buildroot}%{_bindir}/dhcp_release6
%__install -Dpm644 contrib/lease-tools/dhcp_release6.1 %{buildroot}%{_mandir}/man1/dhcp_release6.1
%__install -Dpm755 contrib/lease-tools/dhcp_lease_time %{buildroot}%{_bindir}/dhcp_lease_time
%__install -Dpm644 contrib/lease-tools/dhcp_lease_time.1 %{buildroot}%{_mandir}/man1/dhcp_lease_time.1

# Dnssec
%__install -Dpm644 trust-anchors.conf %{buildroot}%{_datadir}/%{name}/trust-anchors.conf

# Systemd
mkdir -p %{buildroot}%{_unitdir}
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}
rm -rf %{buildroot}%{_initrddir}

%find_lang %{name} --with-man

%pre
%_pre_useradd %{name} /dev/null /sbin/nologin

%post
%_post_service dnsmasq

%preun
%_preun_service dnsmasq

%files -f %{name}.lang
%doc CHANGELOG COPYING COPYING-v3 FAQ doc.html setup.html dbus/DBus-interface
%config(noreplace) %{_sysconfdir}/dnsmasq.conf
%{_unitdir}/%{name}.service
%{_sbindir}/dnsmasq
%{_mandir}/man8/dnsmasq.8*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/trust-anchors.conf

%files utils
%{_bindir}/dhcp_*
%{_mandir}/man1/dhcp_*
