Name:           docbook-style-xsl
Version:        1.79.2
Release:        %mkrel 7
Group:          Publishing
Summary:        Norman Walsh's modular stylesheets for DocBook
License:        Copyright only
URL:            https://sourceforge.net/projects/docbook
Source0:        https://github.com/docbook/xslt10-stylesheets/releases/download/release%2F{%version}/docbook-xsl-nons-%{version}.tar.bz2
Source1:        https://github.com/docbook/xslt10-stylesheets/releases/download/release%2F{%version}/docbook-xsl-doc-%{version}.tar.bz2
Source2: %{name}.Makefile
#Avoid proportional-column-width for passivetex (bug #176766).
Patch1: docbook-xsl-pagesetup.patch
#Hard-code the margin-left work around to expect passivetex (bug #113456).
Patch2: docbook-xsl-marginleft.patch
#fix of #161619 - adjustColumnWidths now available
Patch3: docbook-xsl-newmethods.patch
#change a few non-constant expressions to constant - needed for passivetex(#366441)
Patch4: docbook-xsl-non-constant-expressions.patch
#added fixes for passivetex extension and list-item-body(#161371)
Patch5: docbook-xsl-list-item-body.patch
#workaround missing mandir section problem (#727251)
Patch6: docbook-xsl-mandir.patch
#Non-recursive string.subst that doesn't kill smb.conf.5 generation
Patch7: docbook-style-xsl-non-recursive-string-subst.patch
BuildArch:      noarch
Provides:	docbook-xsl = %{version}
Requires:	docbook-dtd-xml
Requires(post): libxml2-utils
Requires(postun): libxml2-utils
Requires(post): xml-common
Requires(postun): xml-common

%description
These XSL stylesheets allow to convert any DocBook document to another
printed (for example, RTF or PostScript) or online (for example, HTML) format.
They are highly customizable.

%package doc
Summary         : Documentation for DocBook stylesheets
Group           : Documentation

%description doc
This package contains the documentation for these stylesheets:
structure, customization, etc.

%prep
%setup -c -T -n docbook-xsl-%{version}
tar jxf %{SOURCE0}
mv docbook-xsl-nons-%{version}/* .
pushd ..
tar jxf %{SOURCE1}
popd

%patch -P 1 -p1 -b .pagesetup
%patch -P 2 -p1 -b .marginleft
%patch -P 3 -p1 -b .newmethods
%patch -P 4 -p1 -b .nonconstant
%patch -P 5 -p1 -b .listitembody
%patch -P 6 -p1 -b .mandir
%patch -P 7 -p2 -b .non-recursive-subst

cp -p %{SOURCE2} Makefile

# fix of non UTF-8 files rpmlint warnings
for fhtml in $(find ./doc -name '*.html' -type f)
do
    iconv -f ISO-8859-1 -t UTF-8 "$fhtml" -o "$fhtml".tmp
    mv -f "$fhtml".tmp "$fhtml"
    sed -i 's/charset=ISO-8859-1/charset=UTF-8/' "$fhtml"
done

for f in $(find -name "*'*"); 
do
    mv -v "$f" $(echo "$f" | tr -d "'")
done

%build

%install
make install \
    BINDIR=%{buildroot}{_bindir} \
    DESTDIR=%{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}
cp -a VERSION.xsl \
    %{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}/VERSION.xsl
ln -sf xsl-stylesheets-%{version} \
    %{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets

rm -rf %{buildroot}%{_datadir}/sgml/docbook/xsl-stylesheets/extensions

%post
CATALOG=%{_sysconfdir}/xml/catalog
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
    "http://cdn.docbook.org/release/xsl-nons/%{version}" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
    "http://cdn.docbook.org/release/xsl-nons/%{version}" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
    "http://cdn.docbook.org/release/xsl-nons/current/" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
    "http://cdn.docbook.org/release/xsl-nons/current/" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
#keep the old one sourceforge URIs at least temporarily
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
    "http://docbook.sourceforge.net/release/xsl/current" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
    "http://docbook.sourceforge.net/release/xsl/current" \
    "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG

%postun
# do not remove on upgrade
if [ "$1" = 0 ]; then
    CATALOG=%{_sysconfdir}/xml/catalog
    %{_bindir}/xmlcatalog --noout --del \
        "file://%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}" $CATALOG
fi

%files
%doc BUGS TODO README VERSION NEWS* COPYING INSTALL
%{_datadir}/sgml/docbook/xsl-stylesheets-%{version}
%{_datadir}/sgml/docbook/xsl-stylesheets

%files doc
%doc doc docsrc
