%global debug_package %{nil}
%global provider github
%global provider_tld com
%global project containerd
%global repo containerd
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}

#debuginfo not supported with Go
%global gopath  %{_libdir}/golang
%define gosrc %{gopath}/src/pkg/%{import_path}

Name:           docker-%{repo}
Version:        1.7.27
Release:        %mkrel 1
Summary:        A daemon to control runC
License:        ASL 2.0
Group:	        System/Configuration

URL:            https://www.docker.com/
Source0:        https://%{import_path}/archive/v%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  glibc-static-devel
# ensure build uses golang 1.4 or above
BuildRequires:  golang >= 1.4
BuildRequires:  golang-github-cpuguy83-md2man
BuildRequires:  compat-golang-github-cpuguy83-md2man-2-devel
BuildRequires:  golang-github-urfave-cli-devel
BuildRequires:  golang-github-urfave-cli-2-devel
BuildRequires:  golang-github-matttproud-protobuf-extensions-devel
BuildRequires:  golang-github-google-uuid-devel
BuildRequires:  golang-github-beorn7-perks-devel
BuildRequires:  golang-github-cespare-xxhash-devel
BuildRequires:  compat-golang-github-cespare-xxhash-2-devel
BuildRequires:  golang-github-mrunalp-fileutils
BuildRequires:  docker-devel
BuildRequires:  golang-github-coreos-systemd-devel
BuildRequires:  golang-etcd-bbolt-devel
BuildRequires:  git
BuildRequires:  btrfs-devel
BuildRequires:  pkgconfig(libseccomp)
Requires:		opencontainers-runc >= 1.0.0rc5

%description
containerd is a daemon to control runC, built for performance and density. 

containerd leverages runC's advanced features such as seccomp and user 
namespace support as well as checkpoint and restore for cloning and 
live migration of containers.

%prep
%setup -q -n %{repo}-%{version}
# Remove git usage as we're building off Internet
perl -pi -e 's|VERSION \?=.*|VERSION=%{version}|' Makefile
perl -pi -e 's|REVISION=.*|REVISION=%{release}|' Makefile
perl -pi -e 's|run -mod=readonly |run -mod=vendor|' Makefile
perl -pi -e 's|^GO_BUILD_FLAGS=.*|GO_BUILD_FLAGS="-mod=vendor"|' Makefile
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s $(pwd) src/%{import_path}
# Align with docker
find . -type f -print0 | xargs -0 perl -pi -e 's|/run/containerd|/run/docker/containerd|g'

%build
# Force module usage with vendor provided ones
export GO111MODULE=on
# Non vendor modules are there
export GOPATH=%{_datadir}/gocode
# We need it to avoid writing cache under $GOPATH
mkdir -p $(pwd)/tmp
export GOMODCACHE=$(pwd)/tmp
cd src/%{import_path}
make PREFIX=%{_prefix}
make PREFIX=%{_prefix} man

%install
export GO111MODULE=on
mkdir -p %{buildroot}%{_bindir}
%make_install DESTDIR=%{buildroot} PREFIX=%{_prefix}

export GOMODCACHE=$(pwd)/tmp
cd src/%{import_path}
make DESTDIR=%{buildroot} PREFIX=%{_prefix} install-man

# prefix commands with docker as well
cd %{buildroot}%{_bindir}
for i in *; do
	ln -sf $i docker-$i
done

%files
%license LICENSE
%doc NOTICE *.md
%{_bindir}/*
%{_mandir}/*/*.xz
