# modifying the dockerinit binary breaks the SHA1 sum check by docker
%global __os_install_post %{_rpmconfigdir}/brp-compress
%global debug_package %{nil}
# Also update the commit ids below
%global moby_version 24.0.5

# binaries and unitfiles are currently called 'docker'
# to match with upstream supplied packages
%global origname docker
%global newname moby
%global service_name %{origname}

# moby
%global git_moby github.com/%{newname}/%{newname}
%global commit_moby a61e2b4c9c5f7c241aeb37f389b4444aee26bea4
%global shortcommit_moby %(c=%{commit_moby}; echo ${c:0:7})

# cli
%global git_cli github.com/%{origname}/cli
%global commit_cli ced099660009713e0e845eeb754e6050dbaa45d0
%global shortcommit_cli %(c=%{commit_cli}; echo ${c:0:7})
 
# tini
# 0.19.0
%global git_tini https://github.com/krallin/tini
%global commit_tini de40ad007797e0dcd8b7126f27bb87401d224240
%global shortcommit_tini %(c=%{commit_tini}; echo ${c:0:7})

#debuginfo not supported with Go
%global gopath  %{_libdir}/golang
%define gosrc %{gopath}/src/pkg/%{newname}

# docker-proxy / libnetwork  
%global git_libnetwork https://github.com/%{newname}/libnetwork
# master 2023-07-25
%global commit_libnetwork 67e0588f1ddfaf2faf4c8cae8b7ea2876434d91c
%global shortcommit_libnetwork %(c=%{commit_libnetwork}; echo ${c:0:7})

# go-ipath is computed as required whereas it doesn't seem so, so exlucing it
%global __requires_exclude golang-ipath

Name:           %{origname}
#Version:       1.3.1.git%{shortcommit_moby}
Version:        %{moby_version}
Release:        %mkrel 5
Summary:        Automates deployment of containerized applications
License:        ASL 2.0
Group:			System/Configuration

%global goipath         github.com/%{newname}/%{newname}
%gometa

URL:            https://www.docker.com
# only x86_64 for now: https://github.com/docker/docker/issues/136
#ExclusiveArch:  x86_64
Source0:        https://%{git_moby}/archive/v%{moby_version}.tar.gz

Source1: %{service_name}.service
Source2: %{origname}.sysconfig
Source3: %{origname}-storage.sysconfig
Source4: %{origname}-logrotate.sh
Source5: README.%{origname}-logrotate
Source6: %{origname}-network.sysconfig
Source7: %{service_name}.socket
Source8: %{origname}-network-cleanup.sh

Source10: %{git_libnetwork}/archive/%{commit_libnetwork}.tar.gz#/libnetwork-%{shortcommit_libnetwork}.tar.gz
Source11: %{git_tini}/archive/%{commit_tini}.tar.gz#/tini-%{shortcommit_tini}.tar.gz
Source12: https://%{git_cli}/archive/v%{version}.tar.gz#/cli-v%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  glibc-static-devel
BuildRequires:  make
BuildRequires:  cmake

# ensure build uses golang 1.13 or above
BuildRequires:  golang >= 1.19.7

BuildRequires:  pkgconfig(sqlite3)

BuildRequires:  golang-net-devel
BuildRequires:  golang-x-crypto-devel
BuildRequires:  golang-x-sys-devel
#BuildRequires:  golang-x-net-http-devel
BuildRequires:  golang-github-hashicorp-lru-devel
BuildRequires:  golang-github-spf13-cobra-devel
BuildRequires:  golang-github-sirupsen-logrus-devel
BuildRequires:  go-md2man
BuildRequires:  btrfs-devel
BuildRequires:  libltdl-devel
BuildRequires:  pkgconfig(devmapper)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(audit)
Requires:       systemd-units

# With docker >= 1.11 you now need containerd (and runC as a dep)
Requires:	docker-containerd >= 1.6.19

# need xz to work with ubuntu images
# https://bugzilla.redhat.com/show_bug.cgi?id=1045220
Requires:       xz

# https://bugzilla.redhat.com/show_bug.cgi?id=1035436
# this won't be needed for rhel7+
Requires:       bridge-utils
Requires:       tar
# The auplink command is required for network setup in ctn
#Requires:       aufs-tools

Requires:       iptables

# https://bugzilla.redhat.com/show_bug.cgi?id=1034919
# No longer needed in Fedora because of libcontainer
Requires:       libcgroup
Provides:       lxc-docker = %{version}

Obsoletes: docker-io < 1.2.0-8
Provides: docker-io = %{version}-%{release}
Obsoletes: docker-swarm
Provides: docker-swarm = %{version}-%{release}
Obsoletes: docker-vim

%description
Docker is an open-source engine that automates the deployment of any
application as a lightweight, portable, self-sufficient container that will
run virtually anywhere.

Docker containers can encapsulate any payload, and will run consistently on
and between virtually any server. The same container that a developer builds
and tests on a laptop will run at scale, in production*, on VMs, bare-metal
servers, OpenStack clusters, public instances, or combinations of the above.

%package devel
BuildRequires:  golang >= 1.4
Requires:       golang >= 1.4
Requires:       docker-pkg-devel
Summary:        A golang registry for global request variables (source libraries)
Provides: %{origname}-pkg-devel = %{version}-%{release}
Provides: golang(%{newname}) = %{version}-%{release}
#
Provides:       golang-github-docker-devel
Provides:       bundled(tini-static)
Provides:       bundled(golang(github.com/docker/cli))
 
%description devel
This is the source libraries for docker.

%package fish-completion
Summary: fish completion files for Docker
Requires: %{origname} = %{version}-%{release}
Requires: fish
Provides: %{origname}-io-fish-completion = %{version}-%{release}

%description fish-completion
This package installs %{summary}.

%package logrotate
Summary: cron job to run logrotate on Docker containers
Requires: %{origname} = %{version}-%{release}
Provides: %{origname}-io-logrotate = %{version}-%{release}

%description logrotate
This package installs %{summary}. logrotate is assumed to be installed on
containers for this to work, failures are silently ignored.

%package zsh-completion
Summary: zsh completion files for Docker
Requires: %{origname} = %{version}-%{release}
Requires: zsh
Provides: %{origname}-io-zsh-completion = %{version}-%{release}

%description zsh-completion
This package installs %{summary}.

%package nano
Summary: nano syntax highlighting files for Moby
Requires: %{name} = %{version}-%{release}
Requires: nano

%description nano
This package installs %{summary}.

%prep
%setup -q -n %{newname}-%{moby_version}
cp %{SOURCE5} .

# proxy
tar xzf %{SOURCE10} libnetwork-%{commit_libnetwork}/cmd/proxy/
perl -pi -e 's|Sirupsen|sirupsen|' libnetwork-%{commit_libnetwork}/cmd/proxy/*_proxy.go

# tini
tar zxf %{SOURCE11}

# cli
tar zxf %{SOURCE12}
# correct rpmlint errors for bash completion
#sed -i '/env bash/d' cli-%{version}/contrib/completion/bash/docker


%build
# Keep that for later move
BUILDPATH=$(pwd)

# DOCKER CLIENT
cd cli-%{version}
perl -pi -e 's|.*|%{version}|' VERSION
export VERSION=%{version}
perl -pi -e 's|GITCOMMIT=.*|GITCOMMIT=%{commit_cli}|' scripts/build/.variables

export GOPATH=$(pwd):%{_datadir}/gocode
mkdir -p src/github.com/%{name}/
ln -s $(pwd) src/github.com/%{name}/cli
./scripts/build/binary

# DOCKER SERVER
cd $BUILDPATH
export GOPATH=$(pwd):$(pwd)/vendor:%{_datadir}/gocode
ln -sf . src
# build docker-proxy / libnetwork
mv libnetwork-%{commit_libnetwork}/cmd/proxy/ cmd/
%goprep -k -e
%gobuild -o %{origname}-proxy cmd/proxy

export DISABLE_WARN_OUTSIDE_CONTAINER=1
# build tini
pushd tini-%{commit_tini}
export LDFLAGS="" 
%cmake .
(cd build ; make all)
mv build/tini-static ..
popd

export DOCKER_GITCOMMIT="%{shortcommit_moby}"
# build engine
export LDFLAGS="-w"
export LDFLAGS+=" -X github.com/docker/docker/dockerversion.Version=%{version}"
export LDFLAGS+=" -X github.com/docker/docker/dockerversion.GitCommit=%{shortcommit_moby}"
export LDFLAGS+=" -X github.com/docker/docker/dockerversion.IAmStatic=false"
export LDFLAGS+=" -X 'github.com/docker/docker/dockerversion.BuildTime=$(date -u --rfc-3339 ns)'"
#export BUILDTAGS="seccomp selinux journald"
export BUILDTAGS="journald"

# Remove vendored packages not allowed
rm -rf $(pwd)/vendor/{golang.org/x/net/http/httpguts,golang.org/x/net/http2/hpack,golang.org/x/net/idna,golang.org/x/crypto/,golang.org/x/text}
mkdir -p $(pwd)/vendor/github.com/%{origname}/%{origname}
for i in api builder bundles cli client cmd container contrib daemon distribution dockerversion errdefs hack image integration-cli internal layer libcontainerd libnetwork oci opts plugin profiles pkg quota reference registry restartmanager rootless runconfig volume; do
	ln -sf $(pwd)/$i $(pwd)/vendor/github.com/%{origname}/%{origname}
done
%gobuild -o %{origname}d cmd/dockerd
#DOCKER_DEBUG=1 bash -x hack/make.sh dynbinary
cd $BUILDPATH
rm -f src

%install
# install binaries
install -d %{buildroot}%{_bindir} 
install -p -m 755 cli-%{version}/build/%{origname} %{buildroot}%{_bindir}/%{origname}
install -p -m 755 %{origname}-proxy %{buildroot}%{_bindir}/%{origname}-proxy
install -d %{buildroot}%{_sbindir} 
install -p -m 755 %{origname}d %{buildroot}%{_sbindir}/%{origname}d

# Place to store images
install -d %{buildroot}%{_var}/cache/%{origname}

# install manpages
for m in cli-%{version}/man/*.[1-9].md; do
	m2=$(basename $m .md)
	d=$(dirname $m)
	echo "Creating man page for $m2"
	go-md2man < $m > $d/$m2
done
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 cli-%{version}/man/*.1 %{buildroot}%{_mandir}/man1
install -d %{buildroot}%{_mandir}/man5
install -p -m 644 cli-%{version}/man/*.5 %{buildroot}%{_mandir}/man5
install -d %{buildroot}%{_mandir}/man8
install -p -m 644 cli-%{version}/man/*.8 %{buildroot}%{_mandir}/man8

# install bash completion
install -d %{buildroot}%{_sysconfdir}/bash_completion.d
install -p -m 644 cli-%{version}/contrib/completion/bash/%{origname} %{buildroot}%{_sysconfdir}/bash_completion.d/%{origname}.bash

# install fish completion
# create, install and own /usr/share/fish/vendor_completions.d until
# upstream fish provides it
install -dp %{buildroot}%{_datadir}/fish/vendor_completions.d
install -p -m 644 cli-%{version}/contrib/completion/fish/%{origname}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d

# install container logrotate cron script
install -dp %{buildroot}%{_sysconfdir}/cron.daily/
install -p -m 755 %{SOURCE4} %{buildroot}%{_sysconfdir}/cron.daily/%{origname}-logrotate

# install zsh completion
install -d %{buildroot}%{_datadir}/zsh/site-functions
install -p -m 644 cli-%{version}/contrib/completion/zsh/_docker %{buildroot}%{_datadir}/zsh/site-functions

# for additional args
install -d %{buildroot}%{_sysconfdir}/sysconfig/
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{origname}
install -p -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/sysconfig/%{origname}-network
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{origname}-storage

# add nano files
install -dp %{buildroot}%{_datadir}/nano
install -p -m 644 contrib/syntax/nano/Dockerfile.nanorc %{buildroot}%{_datadir}/nano/Dockerfile.nanorc

for cli_file in LICENSE MAINTAINERS NOTICE README.md; do
	cp "cli-%{version}/$cli_file" "cli-$cli_file"
done

# install tini
install -p -m 755 tini-static %{buildroot}%{_bindir}/%{origname}-init

# install udev rules
install -d %{buildroot}%{_udevrulesdir}
install -p -m 644 contrib/udev/80-docker.rules %{buildroot}%{_udevrulesdir}
# install storage dir
install -d -m 700 %{buildroot}%{_libdir}/%{name}
# install systemd/init scripts
install -d %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE1} %{SOURCE7} %{buildroot}%{_unitdir}

# sources
install -d -p %{buildroot}%{gopath}/src/%{newname}
rm -rf pkg/symlink/testdata

# remove dirs that won't be installed in devel
rm -rf vendor docs bundles contrib/init hack project cli-%{version}/vendor cli-%{version}/docs cli-%{version}/build cli-%{version}/man cli-%{version}/src

# install sources to devel
for dir in */ ; do
	if [ "$dir" != "cli-%{version}" ]; then
		cp -rpav $dir %{buildroot}/%{gopath}/src/%{newname}/
	else
		cd $dir
		for d in */ ; do
			cp -rpav $d %{buildroot}/%{gopath}/src/%{newname}/
		done
		cd ..
	fi
done
rm -f %{buildroot}/%{gopath}/src/%{newname}/_build/src/github.com/%{newname}/%{newname}

#network cleanup
install -d %{buildroot}%{_sbindir}
install -p -m 755 %{SOURCE8} %{buildroot}%{_sbindir}/docker-network-cleanup

# Directory for plugins
install -d -m 0755 %{buildroot}%{_libexecdir}/%{name}/cli-plugins

# Warn with shorewall usage
cat > README.urpmi <<EOF
docker is managing its own iptables rules and can work with shorewall.

You may look at this post for examples of configuration https://gist.github.com/lukasnellen/20761a20286f32efc396e207d986295d

Remember to re-start shorewall first and docker afterwards when you make modifications to your firewall setup.
EOF

%pre
getent group docker > /dev/null || %{_sbindir}/groupadd -r docker
# If upgrade, try to export all images
if [ $1 -ge 2 ];then
	majver=`docker --version | awk '{print $3}' | cut -d. -f1`
	if [ $majver -ge 24 ]; then
		# No need to update from version 24 on.
		exit 0
	fi
	echo "Docker version is less than 24.x, migration of images needed"
	# Get storage location
	storage=`grep -E '^DOCKER_STORAGE_OPTIONS' /etc/sysconfig/docker-storage | cut -d' ' -f2 | sed 's/"//g'`
	if [ ! -d "$storage" ]; then
		echo "Unable to find Docker storage dir - aborting migration"
		exit -1
	fi
	mkdir -p $storage/save
	echo "Exporting Docker images to $storage/save"
	echo "This may really take a long time depending on the number of images !!"
	echo "You also need enough room under $storage to host them"
	date
	# Export images and tags to recreate them once update is done
	for i in `docker image ls -q | sort -u`; do
		echo "Exporting image $i to $storage/save/$i.tar.xz"
		docker save $i | xz > $storage/save/$i.tar.xz && /bin/true
	done
	docker image ls > $storage/save/tags.txt
	echo "Renamig the backed up aufs directory as aufs.old"
	mv $storage/aufs $storage/aufs.old
	mv $storage/image/aufs $storage/image/aufs.old
	echo "End of docker images export"
	date
fi
exit 0

%post
# -g option moved to --data-root to manage image storage
perl -pi -e 's|-g |--data-root |' /etc/sysconfig/docker-storage
# If upgrade, try to import all saved images
# Deals with a change of format between mga8 (aufs) and mga9 (overlay2)
if [ $1 -ge 2 ];then
	# Get storage location
	storage=`grep -E '^DOCKER_STORAGE_OPTIONS' /etc/sysconfig/docker-storage | cut -d' ' -f2 | sed 's/"//g'`
	if [ ! -d "$storage/save" ]; then
		exit 0
	else
		echo "Restoring images from $storage/save"
	fi
	cd $storage/save
	echo "Starting Docker service"
	systemctl start docker
	echo "Importing Docker images from $storage/save"
	echo "This will again take time depending on the number of images saved but 10 times less !!"
	# Import images
	date
	for i in `ls *.xz`; do
		img=`echo $i | sed 's|.tar.xz$||'`
		echo "Importing image $img"
		xzcat $i | docker load
		while IFS=" " read -r repo tag imgid remainder
		do
			if [ $tag = "<none>" ]; then
				tag="latest"
			fi
			if [ $repo != "REPOSITORY" ]; then
				if [ $imgid = $img ] && [ $repo != "<none>" ] ; then
					echo "Tagging image $img ${repo}:${tag}"
					docker tag $img ${repo}:${tag}
				fi
			fi
		done < "$storage/save/tags.txt"
	done
	date
	echo "Purging now useless old and converted aufs based images"
	rm -rf $storage/aufs.old
	echo "Please purge $storage/oldsave once you checked all your Docker images are ok"
	mv $storage/save $storage/oldsave
	echo "Stopping Docker service"
	systemctl stop docker
fi
%systemd_post docker
exit 0

%preun
%systemd_preun docker

%postun
%systemd_postun_with_restart docker

%files
%license cli-LICENSE LICENSE
%doc AUTHORS CONTRIBUTING.md MAINTAINERS NOTICE README.md README.urpmi
%doc cli-MAINTAINERS cli-NOTICE cli-README.md
%config(noreplace) %{_sysconfdir}/sysconfig/%{origname}
%config(noreplace) %{_sysconfdir}/sysconfig/%{origname}-network
%config(noreplace) %{_sysconfdir}/sysconfig/%{origname}-storage
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man8/*.8*
%{_bindir}/%{origname}
%{_bindir}/%{origname}-proxy
%{_bindir}/%{origname}-init
%dir %{_var}/cache/%{origname}
%{_unitdir}/%{origname}.service
%{_unitdir}/%{origname}.socket
%{_sysconfdir}/bash_completion.d/%{origname}.bash
%dir %{_libdir}/%{origname}
%dir %{_libexecdir}/%{origname}/cli-plugins
%dir %{_udevrulesdir}
%{_udevrulesdir}/80-docker.rules
%{_sbindir}/%{origname}-network-cleanup
%{_sbindir}/%{origname}d

%files devel
%dir %{gopath}/src/%{newname}
%{gopath}/src/%{newname}/*

%files fish-completion
%dir %{_datadir}/fish/vendor_completions.d/
%{_datadir}/fish/vendor_completions.d/%{origname}.fish

%files logrotate
%doc README.%{origname}-logrotate
%{_sysconfdir}/cron.daily/%{origname}-logrotate

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{origname}

%files nano
%dir %{_datadir}/nano
%{_datadir}/nano/Dockerfile.nanorc
