# full parallel build seems to fail in Qt, so limite to -j4 level:
%global _smp_ncpus_max 4

%define bname		Dogecoin
%define consensus_major	0
%define libconsensus	%mklibname %{name}consensus %{consensus_major}
%define consensus_devel	%mklibname %{name}consensus -d

Summary:	%{bname} payment network
Name:		dogecoin
Version:	1.14.9
Release:	%mkrel 3
License:	MIT
Group:		Office/Finance
Url:		https://dogecoin.com/
Source0:	https://github.com/dogecoin/dogecoin/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		dogecoin-1.14.2-rename-bitcoinconsensus-to-dogecoinconsensus.patch
Patch1:		0001-add-compatibility-for-miniupnpc-2.2.8.patch
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	boost-devel
# db5.1 recommended for wallet portability, but 5.3 works:
BuildRequires:	db-devel >= 5.3.0
BuildRequires:	pkgconfig(miniupnpc)
BuildRequires:	pkgconfig(libevent)
BuildRequires:	pkgconfig(libqrencode)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	protobuf-compiler
BuildRequires:	pkgconfig(openssl)

%description
%{bname} is an innovative payment network and a new kind of money.

%package -n %{name}d
Summary:	%{bname} command line client
Group:		Office/Finance

%description -n %{name}d
%{name}d is the original %{bname} command line client.

%package qt
Summary:	%{bname} graphical Qt client
Group:		Office/Finance
Requires:	%{libconsensus} = %{version}

%description qt
%{bname}-Qt is the original %{bname} graphical client.

%package -n %{libconsensus}
Summary:	Shared libs for %{name}consensus
Group:		System/Libraries

%description -n %{libconsensus}
Shared libs for %{name}consensus.

%package -n %{consensus_devel}
Summary:	Development files for %{name}consensus
Group:		Development/C
Requires:	%{libconsensus} = %{version}
Provides:	%{name}-devel = %{version}

%description -n %{consensus_devel}
This package contains development files for the %{name}consensus
library.

%prep
%autosetup -p1

# At least C++14 is required by Boost
sed -i -e '/AX_CXX_COMPILE_STDCXX/s/\[1[0-3]\]/\[14\]/' configure.ac

%build
./autogen.sh
export CPPFLAGS="-I%{_includedir}/db53"
%configure \
    --disable-static \
    --disable-silent-rules \
    --disable-tests \
    --enable-c++17 \
    --with-incompatible-bdb \
    --with-gui=qt5

%make_build

%install
%make_install

install -d %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -m644 share/pixmaps/%{name}256.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

install -d %{buildroot}%{_datadir}/applications
install -m644 contrib/debian/%{name}-qt.desktop %{buildroot}%{_datadir}/applications
perl -pi -e 's/dogecoin128/dogecoin/g' %{buildroot}%{_datadir}/applications/%{name}-qt.desktop

install -d %{buildroot}%{_datadir}/kservices5
install -m644 contrib/debian/%{name}-qt.protocol %{buildroot}%{_datadir}/kservices5

install -d %{buildroot}%{_datadir}/bash-completion/completions
install -m644 contrib/dogecoind.bash-completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}d

find %{buildroot} -name '*.la' -delete

%files -n %{name}d
%{_bindir}/%{name}d
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-tx
%{_bindir}/bench_%{name}
%{_mandir}/man1/%{name}d.1%{_extension}
%{_mandir}/man1/%{name}-cli.1%{_extension}
%{_mandir}/man1/%{name}-tx.1%{_extension}
%{_datadir}/bash-completion/completions/%{name}d
%doc contrib/qos
%doc contrib/linearize


%files qt
%{_bindir}/%{name}-qt
%{_mandir}/man1/%{name}-qt.1%{_extension}
%{_iconsdir}/hicolor/*/apps/%{name}.svg
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/kservices5/%{name}-qt.protocol


%files -n %{libconsensus}
%{_libdir}/lib%{name}consensus.so.%{consensus_major}{,.*}


%files -n %{consensus_devel}
%{_includedir}/%{name}consensus.h
%{_libdir}/lib%{name}consensus.so
%{_libdir}/pkgconfig/lib%{name}consensus.pc

