%bcond_without pacemaker

%define drbd_api_ver	88

Name:		drbd-utils
Version:	9.27.0
Release:	%mkrel 1
Summary:	Utilities to manage DRBD devices
License:	GPLv2+
Group:		System/Kernel and hardware
URL:		https://www.drbd.org/
Source0:	https://pkg.linbit.com/downloads/drbd/utils/%{name}-%{version}.tar.gz
Patch0:		drbd-utils-9.12.2-disable_xsltproc_network_read.patch

ExclusiveArch: %{ix86} x86_64 aarch64

BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	po4a
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	pkgconfig(libkeyutils)
BuildRequires:	pkgconfig(udev)

Requires(post):	rpm-helper
Requires(preun):	rpm-helper
Requires(post):	initscripts
Requires:	drbd-api = %{drbd_api_ver}
Requires:	bash-completion

%if %{with pacemaker}
%package pacemaker
Summary:       Script to help integration with heartbeat
Group:         System/Kernel and hardware
Requires:      pacemaker
Requires:      %{name} = %{version}
%endif

%description
DRBD is a block device which is designed to build High Availability clusters.
This is done by mirroring a whole block device via (maybe dedicated) network.
You could see it as a network RAID 1. This package contains the tools to
manage DRBD devices.

%if %{with pacemaker}
%description pacemaker
Installs the datadisk script, designed to ease integration with pacemaker.
%endif

%prep
%autosetup -p1

# non-arch executable in datadir, fix conf file
sed -i 's,%{_libdir}/drbd/outdate-peer\.sh,%{_datadir}/drbd/outdate-peer.sh,g' scripts/drbd.conf

%build
%configure \
	--with-udev \
	--with-distro=generic \
	--with-initscripttype=systemd \
	--with-systemdunitdir=%{_unitdir} \
	--with-bashcompletion \
	--without-heartbeat \
%if %{with pacemaker}
	--with-pacemaker\
%else
	--without-pacemaker\
%endif
	--with-prebuiltman \
	--without-xen
%make_build

%install
%make_install

install -d %{buildroot}%{_var}/lib/drbd
install -d %{buildroot}{%{_bindir},%{_sbindir}}

mkdir -p %{buildroot}%{_datadir}/drbd
mkdir -p %{buildroot}%{_sysconfdir}/multipath/conf.d/

%post
%_post_service drbd

%preun
%_preun_service drbd

%files
%doc ChangeLog
%doc scripts/drbd.conf.example
%license COPYING
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/drbd.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/drbd.d/global_common.conf
%dir %{_var}/lib/drbd
%{_sysconfdir}/bash_completion.d/drbdadm
%{_sysconfdir}/multipath/conf.d/drbd.conf
%{_unitdir}/drbd.service
%{_unitdir}/drbd-graceful-shutdown.service
%{_unitdir}/drbd-lvchange@.service
%{_unitdir}/drbd-promote@.service
%{_unitdir}/drbd-demote-or-escalate@.service
%{_unitdir}/drbd-reconfigure-suspend-or-error@.service
%{_unitdir}/drbd-services@.target
%{_unitdir}/drbd-wait-promotable@.service
%{_unitdir}/drbd@.service
%{_unitdir}/drbd@.target
%{_unitdir}/ocf.ra@.service
%{_tmpfilesdir}/drbd.conf
%{_udevrulesdir}/65-drbd.rules
%{_sbindir}/drbdadm
%{_sbindir}/drbdmeta
%{_sbindir}/drbdsetup
%{_sbindir}/drbdmon
%dir %{_datadir}/drbd
%dir /lib/drbd
%dir /lib/drbd/scripts
%dir %{_prefix}/lib/drbd
/lib/drbd/scripts/drbd
/lib/drbd/scripts/drbd-service-shim.sh
/lib/drbd/scripts/drbd-wait-promotable.sh
/lib/drbd/scripts/ocf.ra.wrapper.sh
/lib/drbd/drbdadm-*
/lib/drbd/drbdsetup-*
%{_prefix}/lib/drbd/*.sh

%{_mandir}/man5/*
%{_mandir}/man8/*
%{_mandir}/ja/man5/*
%{_mandir}/ja/man8/*
%{_mandir}/man7/drbd*@.service.*
%{_mandir}/man7/drbd*@.target.*
%{_mandir}/man7/drbd.service.*
%{_mandir}/man7/ocf.ra@.service.*

%if %{with pacemaker}
%files pacemaker
%{_prefix}/lib/ocf/resource.d/linbit/
%{_mandir}/man7/ocf_linbit_drbd*

%endif
