%define major   1
%define libname %mklibname fdt %{major}
%define devname %mklibname fdt -d

%global with_mingw 0

%if 0%{?mageia}
%global with_mingw 1
%endif

Name:          dtc
Version:       1.7.2
Release:       %mkrel 5
Summary:       Device Tree Compiler
Group:         Development/Tools
License:       GPLv2+
URL:           https://devicetree.org/

Source0:       https://www.kernel.org/pub/software/utils/%{name}/%{name}-%{version}.tar.xz

BuildRequires: meson
BuildRequires: gcc make
BuildRequires: flex bison swig
BuildRequires: pkgconfig(yaml-0.1)
BuildRequires: pkgconfig(valgrind)
BuildRequires: python3-devel
BuildRequires: python3-pip
BuildRequires: python3-setuptools
BuildRequires: python3-setuptools_scm
BuildRequires: python3-wheel

%if %{with_mingw}
BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++
BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
%endif

%description
Devicetree is a data structure for describing hardware. Rather than hard coding
every detail of a device into an operating system, many aspects of the hardware
can be described in a data structure that is passed to the operating system at
boot time. The devicetree is used by OpenFirmware, OpenPOWER Abstraction Layer
(OPAL), Power Architecture Platform Requirements (PAPR) and in the standalone
Flattened Device Tree (FDT) form.

%package -n %{libname}
Summary: Device tree library
Group: System/Libraries

%description -n %{libname}
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n %{devname}
Summary: Development headers for device tree library
Group: Development/C
Requires: %{libname} = %{version}-%{release}
Provides: libfdt-devel = %{version}-%{release}

%description -n %{devname}
This package provides development files for libfdt

%package -n python3-libfdt
Summary: Python 3 bindings for device tree library
%{?python_provide:%python_provide python3-libfdt}
Requires: %{name} = %{version}-%{release}

%description -n python3-libfdt
This package provides python3 bindings for libfdt

%if %{with_mingw}
%package -n mingw32-libfdt
Summary: MinGW Device tree library
BuildArch: noarch

%description -n mingw32-libfdt
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n mingw32-libfdt-static
Summary: Static version of MinGW Device tree library
Requires: mingw32-libfdt = %{version}-%{release}
BuildArch: noarch

%description -n mingw32-libfdt-static
This package provides the static library of mingw32-libfdt

%package -n mingw64-libfdt
Summary: MinGW Device tree library
BuildArch: noarch

%description -n mingw64-libfdt
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n mingw64-libfdt-static
Summary: Static version of MinGW Device tree library
Requires: mingw64-libfdt = %{version}-%{release}
BuildArch: noarch

%description -n mingw64-libfdt-static
This package provides the static library of mingw64-libfdt

%{?mingw_debug_package}
%endif

%prep
%autosetup -p1
# to prevent setuptools from installing an .egg, we need to pass --root to setup.py install
# since $(PREFIX) already contains %%{buildroot}, we set root to /
# .eggs are going to be deprecated, see https://github.com/pypa/pip/issues/11501
sed -i 's@--prefix=$(PREFIX)@--prefix=$(PREFIX) --root=/@' pylibfdt/Makefile.pylibfdt


%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%meson
%meson_build

%if %{with_mingw}
%mingw_meson -Dtests=false -Dtools=false
%mingw_ninja
%endif

%install
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%meson_install

find %{buildroot} -type f -name "*.a" -delete

# we don't want ftdump and it conflicts with freetype-demos, so drop it (rhbz 797805)
rm -f %{buildroot}%{_bindir}/ftdump

%if %{with_mingw}
%mingw_ninja_install
%mingw_debug_install_post
%endif

%files
%license GPL
%doc Documentation/manual.txt
%{_bindir}/*

%files -n %{libname}
%license GPL
%{_libdir}/libfdt.so.%{version}
%{_libdir}/libfdt.so.%{major}

%files -n %{devname}
%{_libdir}/libfdt.so
%{_libdir}/pkgconfig/libfdt.pc
%{_includedir}/*

%files -n python3-libfdt
%{python3_sitearch}/libfdt-%{version}-py%{python3_version}.egg-info/
%{python3_sitearch}/_libfdt%{python3_ext_suffix}
%pycached %{python3_sitearch}/libfdt.py

%if %{with_mingw}
%files -n mingw32-libfdt
%license GPL
%{mingw32_bindir}/libfdt-1.dll
%{mingw32_includedir}/*fdt*.h
%{mingw32_libdir}/libfdt.dll.a
%{mingw32_libdir}/pkgconfig/libfdt.pc

%files -n mingw32-libfdt-static
%{mingw32_libdir}/libfdt.a

%files -n mingw64-libfdt
%license GPL
%{mingw64_bindir}/libfdt-1.dll
%{mingw64_includedir}/*fdt*.h
%{mingw64_libdir}/libfdt.dll.a
%{mingw64_libdir}/pkgconfig/libfdt.pc

%files -n mingw64-libfdt-static
%{mingw64_libdir}/libfdt.a
%endif

