%define		devel %mklibname %{name} -d

%global		__requires_exclude ^/bin/ksh$

# Use fewer cores on ix86
%ifarch %{ix86}
%global		_smp_ncpus_max 4
%endif

Name:		ecflow
Version:	5.13.7
Release:	%mkrel 2
Summary:	ecFlow is a work flow package
Group:		Monitoring
License:	ASL 2.0
URL:		https://confluence.ecmwf.int/display/ECFLOW
Source0:	https://confluence.ecmwf.int/download/attachments/8650755/ecFlow-%{version}-Source.tar.gz?api=v2#/%{name}-%{version}.tar.gz
Source1:	https://confluence.ecmwf.int/download/attachments/13207146/2017-01-19-ecFlowUI-for-ecFlow-training-course.pdf
Source2:	https://confluence.ecmwf.int/download/attachments/13207146/ecflowcourse2018.pdf#/ecflowcourse-20180122.pdf
Source3:	https://confluence.ecmwf.int/download/attachments/13207146/ecflowcourse2018_python.pdf#/ecflowcourse-20180122_python.pdf

Patch0:		ecflow-4.8.0-set-ecf-home.patch
# Patches from Debian
Patch1:		0001-perl-interpeter.patch
# Mageia patches

BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	boost-devel
BuildRequires:	boost-devel-static
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	libicu-devel
BuildRequires:	libstdc++-devel
BuildRequires:	m4
BuildRequires:	pkgconfig(libgcrypt)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-numpy-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(xpm)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(libpng16)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(graphite2)
BuildRequires:	pkgconfig(xau)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	git-core
BuildRequires:	pkgconfig(Qt6Core5Compat)
BuildRequires:	pkgconfig(Qt6Core)
BuildRequires:	pkgconfig(Qt6Charts)
BuildRequires:	pkgconfig(Qt6Gui)
BuildRequires:	pkgconfig(Qt6Network)
BuildRequires:	pkgconfig(Qt6Svg)
BuildRequires:	pkgconfig(Qt6Widgets)

Requires:	ksh
Requires:	git

%description
ecFlow is a work flow package that enables users to run a large number of
programs (with dependencies on each other and on time) in a controlled
environment. It provides reasonable tolerance for hardware and software
failures, combined with good restart capabilities.

ecFlow submits tasks (jobs) and receives acknowledgements from tasks when
they change status and when they send events, using child commands embedded
in the scripts. Ecflow stores the relationship between tasks, and is able to
submit tasks dependent on triggers.

%package -n	python3-%{name}
Summary:	Python 3 bindings for ecFlow
Requires:	%{name}-ui
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
ecFlow is a meteorological work flow package that enables
users to run a large number of programs ( with dependencies
on each other and on time) in a controlled environment.

This package contains Python3 modules used in writing ecflow scripts.

%package -n	%{name}-ui
Summary:	Graphical applications for ecFlow
Requires:	python3-%{name} = %{version}-%{release}
Requires(pre):	ksh

%description -n	%{name}-ui
ecFlow is a work flow package that enables users to run a large number of
programs (with dependencies on each other and on time) in a controlled
environment. It provides reasonable tolerance for hardware and software
failures, combined with good restart capabilities.

ecFlow submits tasks (jobs) and receives acknowledgements from tasks when
they change status and when they send events, using child commands embedded
in the scripts. Ecflow stores the relationship between tasks, and is able to
submit tasks dependent on triggers.

This package contains the client tools.

%package -n	%{name}-server
Summary:	The ecFlow server
Provides:	%{name} = %{version}-%{release}
Requires:	%{name}-ui = %{version}-%{release}
Requires(pre):	ksh

%description -n	%{name}-server
ecFlow is a work flow package that enables users to run a large number of
programs (with dependencies on each other and on time) in a controlled
environment. It provides reasonable tolerance for hardware and software
failures, combined with good restart capabilities.

ecFlow submits tasks (jobs) and receives acknowledgements from tasks when
they change status and when they send events, using child commands embedded
in the scripts. Ecflow stores the relationship between tasks, and is able to
submit tasks dependent on triggers.

%package -n	%{devel}
Summary:	The cmake files for ecFlow
Group:		Development/C++
Requires:	%{name}-ui = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devel}
The cmake development files for ecFlow.

%prep
%autosetup -p1 -n ecFlow-%{version}-Source

# Copy the documentation
cp %{SOURCE1} .
cp %{SOURCE2} .
cp %{SOURCE3} .

%py3_shebang_fix tools/ecflow_fuse.py

# There is a looping symlink in version 5.2.1. Remove to be safe.
rm -f cereal/cereal

%build
%cmake_qt6 -GNinja \
	-DCMAKE_POSITION_INDEPENDENT_CODE=ON \
	-DENABLE_STATIC_BOOST_LIBS=OFF \
	-DENABLE_SSL=ON \
	-DENABLE_UI_USAGE_LOG=OFF \
	-DENABLE_SECURE_USER=OFF \
	-DENABLE_PYTHON_PTR_REGISTER=ON \
	-DBOOST_ROOT=%{_prefix} \
	-DECFLOW_QT6=ON \
	-DENABLE_GUI=OFF \
	-DPYTHON_EXECUTABLE=%{python3} \
	-DPYTHON_MIN_VERSION=%{python3_version} \
	-DBoost_PYTHON_LIBRARY_RELEASE=%{_libdir}/libboost_python%{python3_pkgversion}.so \
	-DDISABLE_OS_CHECK=ON \
	-Decflow_FULL_INSTALL_CMAKE_DIR=%{_libdir}/cmake/%{name} \
	-Decflow_FULL_INSTALL_LIB_DIR=%{_libdir}
%cmake_build

%install
%cmake_install

install -Dpm 644 ./libs/server/server_environment.cfg %{buildroot}%{_var}/%{name}/server_environment.cfg

%files -n	%{name}-ui
%doc README.rst *.pdf
%{_bindir}/ecflow_client
%{_bindir}/ecflow_standalone
%{_bindir}/ecflow_ui
%{_bindir}/ecflow_ui.x
%{_bindir}/ecflow_udp_client
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/etc/

%files -n       python3-%{name}
%doc README.rst
%{_bindir}/ecflow_fuse.py
%{python3_sitelib}/%{name}/

%files -n	%{name}-server
%doc README.rst
%{_bindir}/%{name}_*.pl
%{_bindir}/*.sh
%{_bindir}/ecflow_server
%{_bindir}/ecflow_http
%{_bindir}/ecflow_udp
%{_var}/%{name}/

%files -n	%{devel}
%{_libdir}/cmake/%{name}/
