%define ecllibdir           %{_libdir}/%{name}-%{version}

Name:           ecl
Version:        24.5.10
Release:        %mkrel 1
Summary:        Embeddable Common-Lisp
Group:          Development/Other
License:        LGPLv2+
URL:            https://common-lisp.net/project/ecl/
Source0:        https://common-lisp.net/project/ecl/static/files/release/ecl-%{version}.tgz
# A modified version of src/util/ecl.svg with extra whitespace removed.  The
# extra whitespace made the icon appear very small and shoved into a corner.
Source2:        %{name}.svg
# Metainfo for ECL
Source3:        net.common-lisp.ecl.metainfo.xml
# This patch was sent upstream on 4 Feb 2012.  It fixes a few warnings
# from the C compiler that indicate situations that might be dangerous at
# runtime.
Patch0:         %{name}-24.5.10-warnings.patch
# GCC does not implement support for #pragma STDC FENV_ACCESS
Patch2:         %{name}-24.5.10-fenv-access.patch
# Avoid an infinite loop if there is a write error on stderr.  See
# build/pkgs/ecl/patches/write_error.patch in the sagemath distribution.
Patch3:         %{name}-20.4.24-write-error.patch
# Fix bogus test compromised by LTO.
Patch4:         %{name}-20.4.24-configure.patch

Patch21:        ecl-fix-doc-build.patch

BuildRequires:	appstream
BuildRequires:  emacs-common
BuildRequires:  info-install
BuildRequires:  m4
BuildRequires:  texi2html
BuildRequires:  texinfo
BuildRequires:  texlive
BuildRequires:  pkgconfig(atomic_ops)
BuildRequires:  pkgconfig(bdw-gc)
BuildRequires:  pkgconfig(gmp) 
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(x11)

# ECL permits to mix C code and Lisp, so users probably want gcc and
# devel packages of libraries used by ecl
Recommends:       gcc
Recommends:       libgc-devel
Recommends:       gmp-devel

%description
ECL (Embeddable Common-Lisp) is an interpreter of the Common-Lisp
language as described in the X3J13 Ansi specification, featuring CLOS
(Common-Lisp Object System), conditions, loops, etc, plus a translator
to C, which can produce standalone executables.

# no -devel package for header files is split off
# since they are required by the main package

%package doc
Summary:      Documentation for Embeddable Common-Lisp
Group:        Development/Other
Requires:     %{name} = %{version}-%{release}

%description doc
ECL (Embeddable Common-Lisp) is an interpreter of the Common-Lisp
language as described in the X3J13 Ansi specification, featuring CLOS
(Common-Lisp Object System), conditions, loops, etc, plus a translator
to C, which can produce standalone executables.

This package contains the documentation for ECL.

%prep
%setup -q
%autopatch -p0

# Remove spurious executable bits
find src/{c,h} -type f -perm /0111 -exec chmod a-x {} \+

# Temporary fix for missing braces in initializers, causes build failure
sed -i 's/{.*,.*,.*,.*,.*}/{&}/g' src/c/symbols_list.h

# Don't give the library a useless rpath
sed -i "/ECL_LDRPATH='-Wl,--rpath,~A'/d" src/configure

%build
%configure \
        --enable-manual=html \
        --enable-threads=yes \
        --with-sse=auto \
        --enable-c99complex \
        --disable-rpath \
        CFLAGS="%{build_cflags} -Wno-unused -Wno-return-type -Wno-unknown-pragmas"

# Parallel make does not work
make

# documentation build broken
#(cd build/doc; make)

%install
%make_install

# documentation build broken
#(cd build/doc; %%make_install)

# remove wrongly installed files
rm -rf %{buildroot}%{_docdir}/
rm -rf %{buildroot}%{_libdir}/ecl-%{version}/{Copyright,LGPL}
rm -rf %{buildroot}/%{ecllibdir}/BUILD-STAMP

mkdir -p %{buildroot}/%{_datadir}/applications/
cat <<EOF > %{buildroot}/%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=ECL
GenericName=Common Lisp
Comment=Embeddable Common Lisp
Exec=ecl
Icon=ecl
Terminal=true
Type=Application
Categories=Development;Building;
EOF

# Install the desktop icon
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
cp -p %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps

# Install the AppData file
mkdir -p %{buildroot}%{_metainfodir}
install -pm 644 %{SOURCE3} %{buildroot}%{_metainfodir}

find %{buildroot}%{ecllibdir} -name '*.lsp' -exec chmod 0644 {} \;

# Add missing executable bits
chmod a+x $RPM_BUILD_ROOT%{_libdir}/ecl-%{version}/dpp
chmod a+x $RPM_BUILD_ROOT%{_libdir}/ecl-%{version}/ecl_min

%files
%license COPYING LICENSE
%doc README*
%{_bindir}/ecl
%{_bindir}/ecl-config
%{ecllibdir}
%{_libdir}/libecl.so*
%{_includedir}/ecl
%{_mandir}/man*/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_metainfodir}/net.common-lisp.ecl.metainfo.xml

%files doc
%doc examples
