%define	major		2.4
%define	libname		%mklibname %{name} %{major}
%define	develname	%mklibname %{name} -d

%define date		0

%define rel		5

%if %{date}
%define release		%mkrel 13.git%{date}.%{rel}
%define tarballver	%{commit}
%define tarballdir	%{commit}
%define tarballgit	+git%{date}
%define commit		1e72256ac5e8fe6735f81bfbc3f9d90514ada578
%else
%define release		%mkrel %{rel}
%define tarballver	v%{version}
%define tarballdir	%{version}
%endif

# Upstream says:
# GTK+ UI is not supported anymore. Use it at own risk. As far as we know
# builds with GTK+ 3.x are almost unusable, but builds with GTK+ 2.x work
# more or less fine

# Optional features
%define	with_qt		1
%define	with_gtk	1
# This one needs also the above
%define	with_gtk3	1
%define	with_daemon	1
%define	with_devel	1

# filter out bogus auto-requires
%global __requires_exclude	^perl\\((cli*)

Name:		eiskaltdcpp
Version:	2.4.2
Release:	%{release}
License:	GPLv3+
Summary:	Cross-platform program that uses the Direct Connect and ADC protocol
Group:		Networking/File transfer
Url:		https://github.com/eiskaltdcpp/eiskaltdcpp
Source0:	https://github.com/eiskaltdcpp/eiskaltdcpp/archive/%{tarballver}/%{name}-%{version}%{?tarballgit}.tar.gz
Patch1:		0001-Update-miniupnpc-api-to-v18.patch
# Core requirements
BuildRequires:	attr-devel
BuildRequires:	gettext-devel
BuildRequires:	cmake >= 2.6.3
BuildRequires:	pkgconfig(libpcrecpp)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libidn)
BuildRequires:	pkgconfig(lua) >= 5.3
# When enabling miniupnpc in the cmake command line this is needed
BuildRequires:	pkgconfig(miniupnpc)
%if %{with_daemon}
# Requirements for eiskaltdcpp daemon
BuildRequires:	xmlrpc-c-devel >= 1.19
%endif
# Qt requirements
%if %{with_qt}
BuildRequires:	aspell-devel
BuildRequires:	gcc >= 4.5.0
BuildRequires:	pkgconfig(Qt5Concurrent)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Multimedia)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Script)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
%endif
# Gtk requirements
%if %{with_gtk}
BuildRequires:	pkgconfig(pango)
BuildRequires:	pkgconfig(glib-2.0) >= 2.24
%if %{with_gtk3}
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libcanberra-gtk3)
%else
BuildRequires:	pkgconfig(gtk+-2.0) >= 2.24
BuildRequires:	pkgconfig(libcanberra-gtk)
%endif
BuildRequires:	pkgconfig(libcanberra)
BuildRequires:	pkgconfig(libglade-2.0)
BuildRequires:	pkgconfig(libnotify)
%endif

%description
EiskaltDC++ is a cross-platform program that uses the Direct Connect and ADC
protocol. It is compatible with other DC clients, such as the original DC from
Neomodus, DC++ and derivatives. EiskaltDC++ also inter operates with all
common DC hub software. The minimum number of our patches to original DC++
kernel makes it easy to upgrade to new versions and ensures compatibility with
other clients.

%files -f lib%{name}.lang
%doc AUTHORS ChangeLog.txt README.md
%license COPYING LICENSE
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/sounds
%{_datadir}/%{name}/examples
%{_datadir}/%{name}/emoticons
%{_datadir}/%{name}/luascripts
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}.png

#-----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Dynamic library used by EiskaltDC++
Group:		System/Libraries

%description -n %{libname}
Dynamic library used by EiskaltDC++.

%files -n %{libname}
%doc COPYING
%{_libdir}/lib%{name}.so.%{major}{,.*}

#-----------------------------------------------------------------------------

%if %{with_qt}
%package qt
Summary:	Qt frontend for EiskaltDC++
Group:		Networking/File transfer
Requires:	%{name} = %{version}

%description qt
EiskaltDC++ is a cross-platform program that uses the Direct Connect and ADC
protocol. It is compatible with other DC clients, such as the original DC from
Neomodus, DC++ and derivatives. EiskaltDC++ also inter operates with all
common DC hub software. The minimum number of our patches to original DC++
kernel makes it easy to upgrade to new versions and ensures compatibility with
other clients. This is the Qt front end.

%files qt -f %{name}-qt.lang
%doc COPYING
%dir %{_datadir}/%{name}/qt
%{_datadir}/%{name}/qt/client-res
%{_datadir}/%{name}/qt/icons
%{_datadir}/%{name}/qt/qtscripts
%{_mandir}/man1/%{name}-qt.1.*
%{_datadir}/applications/%{name}-qt.desktop
%{_bindir}/%{name}-qt
%endif

#-----------------------------------------------------------------------------

%if %{with_gtk}
%package gtk
Summary:	GTK frontend for EiskaltDC++
Group:		Networking/File transfer
Requires:	%{name} = %{version}

%description gtk
EiskaltDC++ is a cross-platform program that uses the Direct Connect and ADC
protocol. It is compatible with other DC clients, such as the original DC from
Neomodus, DC++ and derivatives. EiskaltDC++ also inter operates with all
common DC hub software. The minimum number of our patches to original DC++
kernel makes it easy to upgrade to new versions and ensures compatibility with
other clients. This is the GTK front end.

%files gtk -f %{name}-gtk.lang
%doc COPYING
%{_datadir}/%{name}/gtk
%{_mandir}/man1/%{name}-gtk.1.*
%{_datadir}/applications/%{name}-gtk.desktop
%{_bindir}/%{name}-gtk
%endif

#-----------------------------------------------------------------------------

%if %{with_daemon}
%package daemon
Summary:	A simple EiskaltDC++ daemon
Group:		Networking/File transfer
Requires:	%{name} = %{version}
Requires:	perl(Term::UI)
Requires:	perl(JSON::RPC::Legacy::Client)

%description daemon
EiskaltDC++ is a cross-platform program that uses the Direct Connect and
ADC protocol. It is compatible with other DC clients, such as the original
DC from Neomodus, DC++ and derivatives. EiskaltDC++ also inter operates
with all common DC hub software. This is a simple daemon for running
EiskaltDC++ without any GUI; it can be controlled via XMLRPC or JSONRPC.

%files daemon
%{_datadir}/%{name}/cli/
%{_mandir}/man1/%{name}-daemon.1.*
%{_mandir}/man1/%{name}-cli-*.1.*
%{_bindir}/%{name}-daemon
%{_bindir}/%{name}-cli-*
%endif

#-----------------------------------------------------------------------------

%if %{with_devel}
%package -n %{develname}
Summary:	Development files for the main EiskaltDC++ library
Group:		Development/C++
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
EiskaltDC++ is a cross-platform program that uses the Direct Connect and
ADC protocol. It is compatible with other DC clients, such as the original
DC from Neomodus, DC++ and derivatives. EiskaltDC++ also inter operates
with all common DC hub software.
This package contains the header files needed to use the main EiskaltDC++
library.

%files -n %{develname}
%doc ChangeLog.txt
%license COPYING
%dir %{_includedir}/%{name}
%dir %{_includedir}/%{name}/dcpp
%{_includedir}/%{name}/dcpp/*.h
%endif

#-----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{tarballdir}

%build
%cmake	-DCMAKE_BUILD_TYPE=Release \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DLIB_INSTALL_DIR=%{_libdir} \
	-DLUA_SCRIPT=ON \
	-DUSE_IDNA=ON \
	-DPERL_REGEX=ON \
%if %{with_qt}
	-DUSE_QT=OFF \
	-DUSE_QT5=ON \
	-DUSE_QT_SQLITE=ON \
	-DUSE_QT_QML=OFF \
	-DUSE_JS=ON \
	-DUSE_ASPELL=ON \
	-DFREE_SPACE_BAR_C=ON \
	-DDBUS_NOTIFY=ON \
%else
	-DUSE_QT=OFF \
	-DUSE_QT5=OFF \
%endif
%if %{with_gtk}
%if %{with_gtk3}
	-DUSE_GTK=OFF \
	-DUSE_GTK3=ON \
%else
	-DUSE_GTK=ON \
	-DUSE_GTK3=OFF \
%endif
	-DUSE_LIBGNOME2=OFF \
	-DUSE_LIBNOTIFY=ON \
	-DUSE_LIBCANBERRA=ON \
%endif
%if %{with_daemon}
	-DNO_UI_DAEMON=ON \
	-DXMLRPC_DAEMON=OFF \
	-DJSONRPC_DAEMON=ON \
	-DUSE_CLI_XMLRPC=ON \
	-DUSE_CLI_JSONRPC=ON \
%else
	-DNO_UI_DAEMON=OFF \
	-DXMLRPC_DAEMON=OFF \
	-DJSONRPC_DAEMON=OFF \
	-DUSE_CLI_XMLRPC=OFF \
	-DUSE_CLI_JSONRPC=OFF \
%endif
%if %{with_devel}
	-DWITH_DEV_FILES=ON \
	-DEISKALTDCPP_INCLUDE_DIR="%{_includedir}/%{name}" \
%else
	-DWITH_DEV_FILES=OFF \
%endif
	-DWITH_EMOTICONS=ON \
	-DWITH_SOUNDS=ON \
	-DWITH_EXAMPLES=ON \
	-DWITH_LUASCRIPTS=ON \
	-DWITH_DHT=ON \
	-DUSE_MINIUPNP=ON \
	-DCREATE_MO=ON \
	-DINSTALL_RUNTIME_PATH=OFF
%cmake_build


%install
%cmake_install

# We don't want install php only for 3 example scripts (in russian moreover),
# nor we want remove all the example scripts,
# so removing the offenders and make find-provides happy
rm -f %{buildroot}%{_datadir}/%{name}/examples/*.php
rm -rf %{buildroot}%{_datadir}/%{name}/qt/qtscripts/gnome

%if %{with_gtk}
%find_lang %{name}-gtk
%endif

%if %{with_qt}
find %{buildroot} -name "*.qm" | sed 's:'%{buildroot}':: 
s:.*/\([a-zA-Z]\{2\}\).qm:%lang(\1) \0:' > %{name}-qt.lang
%endif

# The language files are named "libeiskaltdcpp.mo"
# and the filelist name is "libeiskaltdcpp.lang"
%find_lang lib%{name} lib%{name}.lang
