%define	upstream_name ess
%define	upstream_version %{version}

Summary:	Emacs Speaks Statistics package for Emacs
Name:		emacs-%{upstream_name}
Version:	17.11
Release:	%mkrel 4
# The ess license is GPLV+2, the license of julia-mode.el is MIT
License:	GPLv2+ and MIT
Group:		Editors
URL:		https://ess.r-project.org/
Source0:	https://ess.r-project.org/downloads/ess/%{upstream_name}-%{upstream_version}.tgz
BuildRequires:	emacs-X11
BuildRequires:	emacs-el
BuildRequires:	texinfo
BuildRequires:	R-base
Requires:	emacs
Requires:	emacs-el

Obsoletes:	xemacs-ess < 12.04.4-8

BuildArch:	noarch

%description
This package provides Emacs Speaks Statistics (ESS), which provides
Emacs-based front ends for popular statistics packages.

ESS provides an intelligent, consistent interface between the user and
the software.  ESS interfaces with S-PLUS, R, SAS, BUGS and other
statistical analysis packages under the Unix, Microsoft Windows, and
Apple Mac OS operating systems.  ESS is a package for the GNU Emacs
and XEmacs text editors whose features ESS uses to streamline the
creation and use of statistical software.  ESS knows the syntax and
grammar of statistical analysis packages and provides consistent
display and editing features based on that knowledge.  ESS assists in
interactive and batch execution of statements written in these
statistical analysis languages.

%package doc
Summary:	Emacs Speaks Statistics Documentation
Group:		Editors

%description doc
This package provides documentation for Emacs Speaks Statistics (ESS).

ESS provides an intelligent, consistent interface between the user and
the software.  ESS interfaces with S-PLUS, R, SAS, BUGS and other
statistical analysis packages under the Unix, Microsoft Windows, and
Apple Mac OS operating systems.  ESS is a package for the GNU Emacs
and XEmacs text editors whose features ESS uses to streamline the
creation and use of statistical software.  ESS knows the syntax and
grammar of statistical analysis packages and provides consistent
display and editing features based on that knowledge.  ESS assists in
interactive and batch execution of statements written in these
statistical analysis languages.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
chmod u+w doc/{html,info,refcard,dir.txt} # fix perms

%build
# disable parallel build, it seems broken
# anyway, build is very fast
%__make \
	PREFIX=%{_prefix} \
	LISPDIR=%{_datadir}/emacs/site-lisp/%{upstream_name} \
	ETCDIR=%{_datadir}/emacs/site-lisp/%{upstream_name}/etc \
	INFODIR=%{_infodir}

cat > %{name}.el <<"EOF"
;;; Set up %{upstream_name} for Emacs.
;;;
;;; This file is automatically loaded by emacs's site-start.el
;;; when you start a new emacs session.
(if (not (string-match "XEmacs" emacs-version)) (require 'ess-site))
EOF


%install

install -d %{buildroot}%{_sysconfdir}/emacs/site-start.d
install -d %{buildroot}%{_infodir}

%make_install \
	PREFIX=%{buildroot}%{_prefix} \
	LISPDIR=%{buildroot}%{_datadir}/emacs/site-lisp/%{upstream_name} \
	ETCDIR=%{buildroot}%{_datadir}/emacs/site-lisp/%{upstream_name}/etc \
	INFODIR=%{buildroot}%{_infodir} \
	DOCDIR=%{buildroot}%{_docdir}/%{name}-doc
install -m 0644 %{name}.el %{buildroot}%{_sysconfdir}/emacs/site-start.d/
# fix wrong link
ln -sf %{_datadir}/emacs/site-lisp/%{upstream_name}/ess-site.el %{buildroot}%{_datadir}/emacs/site-lisp/ess-site.el
rm -f %{buildroot}%{_datadir}/emacs/site-lisp/%{upstream_name}/etc/*.BAT
rm -f %{buildroot}%{_datadir}/emacs/site-lisp/%{upstream_name}/etc/*.sparc
rm -f %{buildroot}%{_docdir}/%{name}-doc/*.dvi
rm -f %{buildroot}%{_docdir}/%{name}-doc/*.html

%files
%doc ANNOUNCE ChangeLog README VERSION
%license COPYING
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/%{name}.el
%dir %{_datadir}/emacs/site-lisp
%{_datadir}/emacs/site-lisp/%{upstream_name}
%{_datadir}/emacs/site-lisp/ess-site.el
%{_infodir}/%{upstream_name}.info*

%files doc
%doc doc/ess-intro-graphs.pdf doc/readme.pdf doc/html
%doc %{_docdir}/%{name}-doc/ess.pdf
%doc %{_docdir}/%{name}-doc/refcard.pdf
