%define _localstatedir /var/lib
%define site_lisp %{_datadir}/emacs/site-lisp
%define site_start_d %{site_lisp}/site-start.d

%bcond_with xwidgets

Summary:	GNU Emacs text editor with X11 support
Name:		emacs
Version:	30.1
Release:	%mkrel 2
License:	GPLv3+
Group:		Editors
URL:		https://www.gnu.org/software/emacs/

Source0:	https://ftp.gnu.org/gnu/emacs/emacs-%{version}.tar.xz
Source5:	emacs-config
Source9:	emacs-pgtk.desktop
Source10:	emacs.appdata.xml

# rhbz#713600
Patch2:		emacs-system-crypto-policies.patch
Patch4:		emacs-libdir-vs-systemd.patch
Patch5:		emacs-CVE-2024-53920.patch

BuildRequires:	x11-server-common
BuildRequires:	pkgconfig(x11)
BuildRequires:	gcc
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	giflib-devel
BuildRequires:	texinfo
BuildRequires:	pkgconfig(xpm)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(ImageMagick)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(harfbuzz)
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	pkgconfig(libotf)
BuildRequires:	pkgconfig(m17n-flt)
BuildRequires:	pkgconfig(tree-sitter)
%if %{with xwidgets}
BuildRequires:	pkgconfig(webkit2gtk-4.1)
%endif
BuildRequires:	systemd-devel
BuildRequires:	gpm-devel
BuildRequires:	acl-devel

Requires(preun): update-alternatives
Requires(post):  update-alternatives

Requires:	%{name}-common = %{version}
Provides:	emacs = %{version}-%{release}
Provides:	emacs(bin) = %{version}-%{release}
Provides:	emacs-bin = %{version}-%{release}
Provides:	emacs-gtk = %{version}-%{release}
Provides:	emacs-X11 = %{version}-%{release}

Recommends:	hunspell

%description
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package provides an emacs binary with support for X Windows.

%package	el
Summary:	GNU Emacs Lisp source files
Group:		Editors
Requires:	%{name}-common = %{version}
BuildArch:	noarch

%description	el
The emacs-snapshot-el package contains the emacs elisp sources for
many of the elisp programs included with the main Emacs text editor
package.

You need to install this package only if you intend to modify any of
the Emacs packages or see some elisp examples.

%package	doc
Summary:	GNU Emacs documentation
Group:		Editors
Requires:	%{name}-common = %{version}
BuildArch:	noarch

%description	doc
Documentation for GNU Emacs.

%package	leim
Summary:	GNU Emacs Lisp code for international input methods
Group:		Editors
BuildArch:	noarch
Requires:	%{name}-common = %{version}

%description	leim
This package contains Emacs Lisp code for input methods for various
international character scripts.

%package	nox
Summary:	GNU Emacs text editor without support for X11
Group:		Editors
Requires:	%{name}-common = %{version}
Provides:	emacs(bin) = %{version}-%{release}
Provides:	emacs-bin = %{version}-%{release}
Requires(preun): update-alternatives
Requires(post):  update-alternatives

%description	nox
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package provides an emacs binary with no X Windows support for
running on a terminal.

%package	pgtk
Summary:	GNU Emacs text editor with support for Wayland only
Group:		Editors
Requires:	%{name}-common = %{version}
Provides:	emacs(bin) = %{version}-%{release}
Provides:	emacs-bin = %{version}-%{release}
Requires(preun): update-alternatives
Requires(post):  update-alternatives

%description	pgtk
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package provides an emacs binary with support for Wayland only.

%package	common
Summary:	Common files for GNU Emacs
Group:		Editors
Recommends:	enchant2

Provides:	gnus-emacs = 5.13
Provides:	emacs-cedet = 2.0
Provides:	emacs-speedbar = 1.0
Provides:	emacs-tramp = 2.4.5.27.2
Provides:	emacs-pcomplete = 21.1
Provides:	eshell-emacs = 2.4.2
Provides:	emacs-erc = %{version}

Conflicts:	emacs < 29.4-3
Conflicts:	emacs-pgtk < 29.4-3

%description	common
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package contains all of the common files needed by emacs-snapshot
emacs-snaphot-pgtk or emacs-snapshot-nox.

%prep
%autosetup -p1

perl -p -i -e 's/ctags/gctags/g' doc/man/etags.1

%build
autoreconf -fi -I m4

export CFLAGS="%{build_cflags} -fno-zero-initialized-in-bss"

# Build binary without X support
mkdir -p build-nox
pushd build-nox
export CONFIGURE_TOP=..
  %configure --with-x=no --with-gpm --with-tree-sitter
  %make_build bootstrap
  %make_build
popd

# Build pure GTK binary with Wayland only support
mkdir -p build-pgtk
pushd build-pgtk
  %configure --with-pgtk --with-tree-sitter
  %make_build bootstrap
  %make_build
popd

# Build binary with X support
mkdir -p build-gtk
pushd build-gtk
  %configure --with-x-toolkit=gtk3 %{?with_xwidgets:--with-xwidgets} --with-cairo --with-tree-sitter
  %make_build bootstrap
  %make_build
popd

# Create macros.emacs RPM macro file
cat > macros.emacs << EOF
%%_emacs_version %{version}
%%_emacs_ev %{?epoch:%{epoch}:}%{version}
%%_emacs_evr %{?epoch:%{epoch}:}%{version}-%{release}
%%_emacs_sitelispdir %{site_lisp}
%%_emacs_sitestartdir %{site_start_d}
%%_emacs_bytecompile /usr/bin/emacs -batch --no-init-file --no-site-file --eval '(progn (setq load-path (cons "." load-path)))' -f batch-byte-compile
EOF

%install
%make_install -C build-gtk

rm -f %{buildroot}%{_bindir}/emacs
rm -f %{buildroot}%{_infodir}/dir

# Remove emacs.pdmp from common
rm -f %{buildroot}%{_libexecdir}/emacs/%{version}/%{_target_platform}/emacs*.pdmp

# remove sun specific stuff
rm -f %{buildroot}%{_datadir}/emacs/%{version}/etc/{emacstool.1,emacs.1,ctags.1,etags.1,sex.6}

# rename ctags to gctags
mv %{buildroot}%{_mandir}/man1/ctags.1.gz %{buildroot}%{_mandir}/man1/gctags.1.gz
mv %{buildroot}%{_bindir}/ctags %{buildroot}%{_bindir}/gctags

mkdir -p %{buildroot}%{_sysconfdir}/emacs
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/emacs/site-start.el
ln -s %{_sysconfdir}/emacs/site-start.el %{buildroot}%{_datadir}/emacs/%{version}/lisp/site-start.el

install -d %{buildroot}%{_sysconfdir}/emacs/site-start.d

# Install app data
# Upstream ships its own appdata file, but it's quite terse.
rm -rf %{buildroot}%{_metainfodir}/emacs.appdata.xml
install -Dpm644 %{SOURCE10} %{buildroot}%{_metainfodir}/emacs.appdata.xml

# Install rpm macro definition file
mkdir -p %{buildroot}%{_rpmmacrodir}
install -p -m 0644 macros.emacs %{buildroot}%{_rpmmacrodir}/

install -p -m755 build-nox/src/emacs %{buildroot}%{_bindir}/emacs-nox
install -p -m644 build-nox/src/emacs.pdmp %{buildroot}%{_bindir}/emacs-nox.pdmp
install -p -m755 build-pgtk/src/emacs %{buildroot}%{_bindir}/emacs-pgtk
install -p -m644 build-pgtk/src/emacs.pdmp %{buildroot}%{_bindir}/emacs-pgtk.pdmp
mkdir -p %{buildroot}%{_datadir}/glib-2.0/schemas
install -p -m644 etc/org.gnu.emacs.defaults.gschema.xml %{buildroot}%{_datadir}/glib-2.0/schemas
install -p -m644 build-gtk/src/emacs.pdmp %{buildroot}%{_bindir}/emacs-%{version}.pdmp

chmod -t %{buildroot}%{_bindir}/emacs*

# Install a desktop entry for pgtk (Wayland)
install -p -m644 %{SOURCE9} %{buildroot}%{_datadir}/applications/emacs-pgtk.desktop

# Remove duplicate desktop-related files
rm -f %{buildroot}%{_datadir}/%{name}/%{version}/etc/%{name}.{desktop,service}


# create file lists

#
# emacs-doc file list
#
# 3.22MB of docs from emacs-common to emacs-doc to reduce size (tutorials, news, postscript files, ...)
# NB: etc/ps-prin{0,1}.ps are needed by ps-print
find %{buildroot}%{_datadir}/emacs/%{version}/etc/ -type f | \
  grep -E 'TUTORIAL\.|NEWS|ONEWS|.ps$'|fgrep -v /etc/ps-prin | \
  sed "s^%{buildroot}^^" > doc-filelist

#
# emacs-el file list
#

# take every .el and .el.gz which have a corresponding .elc
find %{buildroot}%{_datadir}/emacs -name '*.el' -o -name '*.el.gz' | \
  grep -v /leim/ | while read I; do
  f=`basename $I .gz`
  f=`basename $f .el`
  if [ -e `dirname $I`/$f.elc ]; then
    echo $I | sed "s^%{buildroot}^^"
  fi
done > el-filelist

#
# emacs-common file list
#

# everything not in previous filelists, and remove a few things listed in %%files
find %{buildroot}%{_datadir}/emacs/%{version} -type f -print -o -type d -printf "%%%%dir %%p\n" | \
  grep -v /leim/ | sed "s^%{buildroot}^^" > common-filelist.raw
while read I; do
  grep -qxF $I doc-filelist el-filelist || echo $I
done < common-filelist.raw > common-filelist

find %{buildroot}%{_libexecdir}/emacs -type f -print -o -type d -printf "%%%%dir %%p\n" | \
  grep -E -v 'movemail$|update-game-score$' | sed "s^%{buildroot}^^" >> common-filelist

# this conflicts with the info package
rm -f %{buildroot}%{_infodir}/info.info.gz

%define info_files  auth autotype bovine calc ccmode cl dbus dired-x ebrowse ede ediff edt efaq eglot eieio eintr elisp elisp_type_hierarchy.jpg elisp_type_hierarchy.txt emacs emacs-gnutls emacs-mime epa erc ert eshell eudc eww flymake forms gnus htmlfontify idlwave ido mairix-el message mh-e modus-themes newsticker nxml-mode octave-mode org pcl-cvs pgg rcirc reftex remember sasl sc semantic ses sieve smtpmail speedbar srecode todo-mode tramp transient url use-package vhdl-mode vip viper vtable widget wisent woman
have_info_files=$(echo $(ls %{buildroot}%{_infodir} | sed -e 's/\.info\.gz$//' | grep -E -v -- '-[0-9]+$' | LC_ALL=C sort))

[ "$have_info_files" = "%info_files" ] || {
  echo "you must modify the spec file, %%info_files should be: $have_info_files"
  exit 1
}


%post nox
update-alternatives --install %{_bindir}/emacs emacs %{_bindir}/emacs-nox 10

[[ ! -f %{_bindir}/emacs ]] && update-alternatives --auto emacs
:

%postun nox
[[ ! -f %{_bindir}/emacs-nox ]] && \
    /usr/sbin/update-alternatives --remove emacs %{_bindir}/emacs-nox
:

%post
/usr/sbin/update-alternatives --install %{_bindir}/emacs emacs %{_bindir}/emacs-%{version} 21

%postun
[[ ! -f %{_bindir}/emacs-%{version} ]] && \
    /usr/sbin/update-alternatives --remove emacs %{_bindir}/emacs-%{version}|| :

%post pgtk
update-alternatives --install %{_bindir}/emacs emacs %{_bindir}/emacs-pgtk 11

[[ ! -f %{_bindir}/emacs ]] && update-alternatives --auto emacs
:

%postun pgtk
[[ ! -f %{_bindir}/emacs-pgtk ]] && \
    /usr/sbin/update-alternatives --remove emacs %{_bindir}/emacs-pgtk
:

%files -f common-filelist common
%{_rpmmacrodir}/macros.emacs
%doc BUGS README src/COPYING
%dir %{_sysconfdir}/emacs/site-start.d
%dir %{_sysconfdir}/emacs
%config(noreplace) %{_sysconfdir}/emacs/site-start.el
%dir %{_datadir}/emacs
%dir %{_datadir}/emacs/site-lisp
%{_datadir}/emacs/%{version}/lisp/site-start.el
%attr(2755,root,mail) %{_libexecdir}/emacs/%{version}/%{_target_platform}/movemail
%{_bindir}/emacsclient
%{_bindir}/etags
%{_bindir}/ebrowse
%{_bindir}/gctags
%{_mandir}/*/*
%{_includedir}/emacs-module.h
%{_infodir}/*
%{_userunitdir}/emacs.service
%{_datadir}/applications/emacsclient.desktop
%{_datadir}/applications/emacsclient-mail.desktop
%{_datadir}/applications/emacs-mail.desktop
%{_iconsdir}/hicolor/*/apps/emacs*.png
%{_iconsdir}/hicolor/scalable/apps/emacs.svg
%{_iconsdir}/hicolor/scalable/mimetypes/emacs-document.svg
%{_iconsdir}/hicolor/scalable/mimetypes/emacs-document23.svg
%{_iconsdir}/hicolor/scalable/apps/emacs.ico
%{_metainfodir}/emacs.metainfo.xml
%{_metainfodir}/emacs.appdata.xml

%files -f doc-filelist doc

%files -f el-filelist el
%doc src/COPYING
%{_datadir}/emacs/%{version}/site-lisp/subdirs.el
%{_datadir}/emacs/site-lisp/subdirs.el
%{_datadir}/emacs/%{version}/lisp/leim/ja-dic/*.el.gz
%{_datadir}/emacs/%{version}/lisp/leim/quail/*.el.gz

%files leim
%doc src/COPYING
%{_datadir}/emacs/%{version}/lisp/leim/leim-list.el
%dir %{_datadir}/emacs/%{version}/lisp/leim/ja-dic
%{_datadir}/emacs/%{version}/lisp/leim/ja-dic/*.elc
%dir %{_datadir}/emacs/%{version}/lisp/leim/quail
%{_datadir}/emacs/%{version}/lisp/leim/quail/*.elc

%files nox
%doc src/COPYING
%{_bindir}/emacs-nox
%{_bindir}/emacs-nox.pdmp

%files pgtk
%doc src/COPYING
%{_bindir}/emacs-pgtk
%{_bindir}/emacs-pgtk.pdmp
%{_datadir}/applications/emacs-pgtk.desktop
%{_datadir}/glib-2.0/schemas/org.gnu.emacs.defaults.gschema.xml

%files
%doc src/COPYING
%{_bindir}/emacs-%{version}
%{_bindir}/emacs-%{version}.pdmp
%{_datadir}/applications/emacs.desktop
