%define pkgname		embree
%define api_version	3
%define libmajor	3
%define libname_orig	%mklibname %{pkgname} %{api_version}
%define libname		%mklibname %{pkgname} %{api_version} %{libmajor}
%define develname	%mklibname -d %{pkgname} %{api_version}
%define staticdevname	%mklibname -d -s %{pkgname} %{api_version}

# limit the maximum number of parallel building processes to avoid
# running out of memory during building
%global		_smp_ncpus_max 2

Name:		%{pkgname}%{api_version}
Version:	3.13.5
Release:	%mkrel 2
Summary:	A collection of high-performance ray tracing kernels
Group:		Graphics/3D
License:	ASL 2.0
URL:		https://embree.github.io
Source:		https://github.com/%{pkgname}/%{pkgname}/archive/v%{version}/%{pkgname}-%{version}.tar.gz
Patch0:		embree-3.13.5-dont-force-std.patch
Patch1:		embree-fix-aarch64.patch

BuildRequires:	cmake
BuildRequires:	gcc-c++
%ifarch x86_64
# (akien) Current ISPC version doesn't support aarch64, and it's an optional dependency.
# Don't enable it for aarch64 without confirming that the above comment is solved!
BuildRequires:	ispc
%endif
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(glfw3)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(xmu)

# Use 64bit architectures because of SSE2 and up
ExclusiveArch:	x86_64 aarch64

%description
A collection of high-performance ray tracing kernels intended to
graphics application engineers that want to improve the performance of
their photo-realistic rendering applications.

%package -n %{libname}
Summary:	A collection of high-performance ray tracing kernels
Group:		System/Libraries
Provides:	%{libname_orig} = %{version}-%{release}
Provides:	%{pkgname}%{api_version} = %{version}-%{release}

%description -n %{libname}
A collection of high-performance ray tracing kernels intended to
graphics application engineers that want to improve the performance of
their photo-realistic rendering applications.

This package contains the library needed to run programs dynamically
linked with embree.

%package -n %{develname}
Summary:	Headers and development files of the embree library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{pkgname}%{api_version}-devel = %{version}-%{release}
Provides:	%{libname_orig}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the embree library. Install this package if you
want to compile applications using the embree library.

%prep
%autosetup -p1 -n %{pkgname}-%{version}

%build
%cmake \
	-DEMBREE_IGNORE_CMAKE_CXX_FLAGS:BOOL=OFF \
	-DCMAKE_CXX_FLAGS:STRING="%{optflags}" \
	-DCMAKE_C_FLAGS:STRING="%{optflags}" \
%ifnarch x86_64
	-DEMBREE_ISPC_SUPPORT:BOOL=OFF \
%endif
	-DEMBREE_RAY_MASK:BOOL=ON \
	-DEMBREE_BACKFACE_CULLING:BOOL=OFF \
	-DEMBREE_FILTER_FUNCTION:BOOL=ON \
	-DEMBREE_TUTORIALS:BOOL=OFF

%cmake_build

%install
%cmake_install

# Remove installed doc files
rm -rf %{buildroot}%{_docdir}/%{name}

%files -n %{libname}
%{_libdir}/*.so.%{libmajor}{,.*}

%files -n %{develname}
%license LICENSE.txt
%doc README.md CHANGELOG.md readme.pdf
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/cmake/%{pkgname}-%{version}/
%{_mandir}/man3/*
