#
# spec file for package ESO-MIDAS (Version 12FEBpl1.3)
#
# Copyright (c) 2007-2012 Matwey V. Kornilov
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Modified for Mageia by joequant@gmail.com

%global        _legacy_common_support 1

%global __brp_check_rpaths %{nil}
%define debug_package %{nil}

%define prefix %{_datadir}/eso-midas

Name:           eso-midas
License:        GPLv2+
Group:          Sciences/Astronomy
Version:        23FEBpl1.0
Release:        %mkrel 2
Summary:        European Southern Observatory Munich Image Data Analysis System
URL:            https://www.eso.org/sci/software/esomidas/

Source0:        ftp://ftp.eso.org/pub/midaspub/13SEP/sources/%{version}.tar.gz
Source1:        calib_src.tar.gz
Source3:        agldoc.tar.bz2
Source4:        daophot.ps.bz2
Source5:        env.ps.bz2
Source6:        ididoc.ps.bz2
Source7:        installunix.ps.bz2
Source8:        installvms.ps.bz2
Source9:        midas-faq.doc.bz2
Source10:       README.doc
Source11:       volume_a.html.tar.bz2
Source12:       volume_a.ps.bz2
Source13:       volume_b.html.tar.bz2
Source14:       volume_b.ps.bz2
Patch0:         23FEBpl1.0-flags.patch
Patch1:         23FEBpl1.0-fixbuild.patch

BuildRequires:  binutils
BuildRequires:  bzip2
BuildRequires:  chrpath
BuildRequires:  dos2unix
BuildRequires:  gcc
BuildRequires:  gcc-gfortran
BuildRequires:  pkgconfig(libnsl)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  motif-devel
BuildRequires:  procmail
BuildRequires:  tar
BuildRequires:  vim
BuildRequires:  fdupes

%description
The ESO-MIDAS(tm) system provides general tools for image processing and data
reduction with emphasis on astronomical applications including imaging and
special reduction packages for ESO instrumentation at La Silla and the VLT at
Paranal. In addition it contains applications packages for stellar and surface
photometry, image sharpening and decomposition, statistics and various others.

%package -n eso-midas-doc
Summary:        Documentation for ESO-MIDAS(tm)
Group:          Sciences/Astronomy

%description -n eso-midas-doc
This package contains the documentation for ESO-MIDAS(tm):

 * ASTRONET Graphics library
 * DAOPHOT II
 * MIDAS Environment
 * Image Display Interface
 * Installation of MIDAS on UNIX Systems
 * Installation of MIDAS on VMS Systems
 * MIDAS FAQ
 * MIDAS User Guide Volume A
 * MIDAS User Guide Volume B

%package -n eso-midas-calib
Summary:        Calibration data for ESO-MIDAS(tm)
Group:          Sciences/Astronomy
Requires:       eso-midas = %{version}
AutoReqProv:    on

%description -n eso-midas-calib
This package contains the calibration data for ESO-MIDAS(tm).

%package -n eso-midas-devel
Summary:        ESO-MIDAS(tm) - development files
Group:          Sciences/Astronomy
Requires:       eso-midas = %{version}
AutoReqProv:    on

%description -n eso-midas-devel
This package contains the headers, static libraries for ESO-MIDAS(tm).

# Note that it will mention AMD when using 64-bit

%prep
%setup -q -c -n midas -a 1
%autopatch -p1

# Some command like linking final .so get redirected to /dev/null
# making it very hard to debug things like missing -fPIC
find -name makefile -exec sed -i 's/DEV_NULL =.*/DEV_NULL =/' {} \;

%build

##
## MIDAS
##
# Installation of MIDAS on UNIX Systems
# 2.4 The Config Script
export MIDVERS=%{version}
export MIDASHOME=`pwd`

#(eatdirt) at some point, $(MGAFLAGS) is otherwise interpreted as a command!?
sed -i 's|$(MGAFLAGS)|%{optflags} -fPIC -Wno-implicit|g' %{_builddir}/midas/23FEBpl1.0/install/unix/systems/Linux/make_options
sed -i 's|$(MGAFLAGS)|%{optflags} -fPIC -Wno-implicit|g' %{_builddir}/midas/23FEBpl1.0/install/unix/systems/Linux_AMD64/make_options

#ifarch armv7hl
#export MGAFLAGS="#{optflags} -fPIC -Wno-implicit"
#else
#export MGAFLAGS="#{optflags} -Wno-implicit"
#endif

pushd %{version}/install/unix
# 2.5 Preinstallation of MIDAS
./preinstall -a
# 2.6 Selection of optional packages
./select all
# 2.7 Installation of MIDAS
./install1 -a
# printout install log
cat ../../tmp/install.*
# 2.9 Setup of MIDAS
./setup -a
# 2.10 Running MIDAS for the first time
mkdir tmp
pushd tmp
cat <<EOF | ../../../system/unix/inmidas
@ compile.all

EOF
cat <<EOF | ../../../system/unix/gomidas
@ ascii_bin
bye

EOF
# 2.11 Verifying MIDAS
cat <<EOF | ../../../system/unix/inmidas
@ vericopy
@@ veriall

EOF

popd
rm -rf tmp

##
## Calib
##
pushd %{_builddir}/midas/calib/install
source ./dbassign.sh
cat <<EOF | %{_builddir}/midas/%{version}/system/unix/inmidas
@@ caldb
@@ filters
bye
EOF
popd
rm -rf %{_builddir}/midas/calib/raw %{_builddir}/midas/calib/install

# 2.12 Cleaning MIDAS
cat <<EOF | ./cleanm
2
y
y
q
EOF
cat <<EOF | ../../system/unix/cleanmidas
y
EOF

# Black magic
for F in inmidas helpmidas drs
do
        cat ../../system/unix/$F | sed -e 's|'%{_builddir}'/midas|%{prefix}|g' > $F.t
        chmod 0755 $F.t
        mv $F.t ../../system/unix/$F
done

# Black magic
rm -rf %{_builddir}/midas/calib/data/emos
rm -rf %{_builddir}/midas/calib/data/inst/uves/stisanneal # elf32-sparc precompiled binary
ln -snf ./ftoc-new ../../system/good-ftoc
ln -snf ./ftoc-new ../../libsrc/ftoc
find %{_builddir}/midas/%{version} -perm 0666 -exec chmod 0644 '{}' \;
find %{_builddir}/midas/%{version} -perm 0664 -exec chmod 0644 '{}' \;
find %{_builddir}/midas/%{version} -perm 0775 -exec chmod 0755 '{}' \;
dos2unix %{_builddir}/midas/%{version}/prim/proc/bbmod.pl
find %{_builddir}/midas/%{version} -name *.exe -exec chrpath -r %{prefix}/%{version}/lib '{}' \;
find %{_builddir}/midas/%{version} -name *.exe -exec strip '{}' \;
find %{_builddir}/midas/%{version} -name .cvsignore -exec rm '{}' \;
popd

##
## Documentation
##
mkdir agldoc
tar -jxf   %{S:3} -C agldoc         # ASTRONET Graphics library
bunzip2 -c %{S:4}  > daophot.ps     # DAOPHOT II
bunzip2 -c %{S:5}  > env.ps         # MIDAS Environment
bunzip2 -c %{S:6}  > ididoc.ps      # Image Display Interface
bunzip2 -c %{S:7}  > installunix.ps # Installation of MIDAS on UNIX Systems
bunzip2 -c %{S:8}  > installvms.ps  # Installation of MIDAS on VMS Systems
bunzip2 -c %{S:9}  > midas-faq.doc  # MIDAS FAQ
cp         %{S:10} README.doc
mkdir html
tar -jxf   %{S:11} -C html          # MIDAS User Guide Volume A
bunzip2 -c %{S:12} > volume_a.ps    #
tar -jxf   %{S:13} -C html          # MIDAS User Guide Volume B
bunzip2 -c %{S:14} > volume_b.ps    #
# Black magic
find html/volb -name '*.html.bak' -exec rm '{}' \;
chmod 0644 html/vola/IMG_PARAMS.pag html/vola/IMG_PARAMS.dir html/volb/IMG_PARAMS.pag html/volb/IMG_PARAMS.dir
mv %{_builddir}/midas/calib/README.calib .

%install
# Install MIDAS
mkdir -p %{buildroot}%{prefix}
cp -pr %{_builddir}/midas/%{version} %{buildroot}%{prefix}

# Install calib
cp -pr %{_builddir}/midas/calib %{buildroot}%{prefix}
rm -rf %{buildroot}%{prefix}/%{version}/system/vms
chmod a+x %{buildroot}%{prefix}/%{version}/system/unix/*

# Install binaries
mkdir -p %{buildroot}/usr/bin
ln -s %{prefix}/%{version}/system/unix/{inmidas,gomidas,helpmidas,drs} \
  %{buildroot}/usr/bin

# Install man pages
mkdir -p %{buildroot}%{_mandir}/man1
cp -p %{buildroot}%{prefix}/%{version}/system/unix/man1/*.1 \
  %{buildroot}%{_mandir}/man1

( find %{buildroot}%{prefix}/%{version} -name *.h ;
find %{buildroot}%{prefix}/%{version} -name *.a ;
find %{buildroot}%{prefix}/%{version} -name makefile ;
find %{buildroot}%{prefix}/%{version} -name *.mk ;
find %{buildroot}%{prefix}/%{version}/libsrc ! -type d;
find %{buildroot}%{prefix}/%{version}/libsrc -type d -printf '%%%%dir %p\n' ;
echo %{buildroot}%{prefix}/%{version}/lib/libgmidas.so ;
echo %{buildroot}%{prefix}/%{version}/lib/libmidas.so ;
echo %{buildroot}%{prefix}/calib/data/datatrans/efosc2/save/read.c ; ) | sed -e 's|'%{buildroot}'||g' | sort | uniq > ./eso-midas-devel.manifest

( find %{buildroot}%{prefix}/%{version} ! -type d ;
find %{buildroot}%{prefix}/%{version} -type d -printf '%%%%dir %p\n' ; ) | sed -e 's|'%{buildroot}'||g' | sort | uniq > ./eso-midas.manifest

diff ./eso-midas-devel.manifest ./eso-midas.manifest | grep '^>' | cut -c3- > ./eso-midas.manifest.t; mv ./eso-midas.manifest.t ./eso-midas.manifest

%fdupes %{buildroot}%{prefix}/%{version}
%fdupes %{buildroot}%{prefix}/calib
%fdupes -s html

%files -f eso-midas.manifest
%{_bindir}/drs
%{_bindir}/gomidas
%{_bindir}/helpmidas
%{_bindir}/inmidas
%{_mandir}/man1/*.1.*
%dir %{prefix}

%files -n eso-midas-doc
%doc agldoc
%doc daophot.ps
%doc env.ps
%doc ididoc.ps
%doc installunix.ps
%doc installvms.ps
%doc midas-faq.doc
%doc README.doc
%doc html/vola
%doc volume_a.ps
%doc html/volb
%doc volume_b.ps

%files -n eso-midas-calib
%doc README.calib
%dir %{prefix}/calib
%{prefix}/calib/*

%files -n eso-midas-devel -f eso-midas-devel.manifest
