%define oname	Eterm

%define major	%{version}
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

Summary:	Terminal emulator
Name:		eterm
Version:	0.9.7
Release:	%mkrel 8
License:	BSD
Group:		Terminals
URL:		https://git.enlightenment.org/apps/eterm.git
Source0:	%{oname}-%{version}.tar.gz
Source5:	http://www.eterm.org/download/%{oname}-bg-0.9.6.tar.gz
Patch0:		CVE-2021-33477.patch
#  with Fix for graphics/imlib2 update 
# imlib_strerror() has been introduced to imlib2; mangle local version.
# from http://cvsweb.netbsd.org/bsdweb.cgi/pkgsrc/x11/eterm/patches/patch-src_pixmap.c
Patch1:		patch-src_pixmap.c
Patch2:		patch-src_pixmap.h
Patch3:		eterm-0.9.6-gcc10.patch
Patch4:		eterm-0.9.6-gcc14.patch
Patch5:		eterm-c99-headers.patch
BuildRequires:	pkgconfig(imlib2)
BuildRequires:	libast-devel >= 0.5
BuildRequires:	utempter-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	twin-devel
BuildRequires:	pkgconfig(xres)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xmu)
BuildRequires:  groff-for-man
BuildRequires:	man
BuildRequires:	gdb
BuildRequires:	chrpath
Requires(pre):	ncurses
# needed by Etbg_update_list script
Requires(post):	diffutils
Provides:	%{oname} = %{version}-%{release}
Obsoletes:	%{oname} < %{version}-%{release}

%description
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

%package -n	%{libname}
Summary:	Library from Eterm (Enlightened Terminal Emulator)
Group:		Terminals

%description -n	%{libname}
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

This library is essential for Eterm to work.

%package -n %{devname}
Summary:	Devel files for Eterm
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%{oname}-devel < %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}

%description -n %{devname}
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

This package provides the necessary development libraries and include files
to allow you to develop or compile programs that needs Eterm, though no such
program has existed so far.

%prep
%setup -q -a5 -n %{oname}-%{version}
%patch -P 0 -p1
%patch -P 1 -p0
%patch -P 2 -p0
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

# fix rpmlint warning
# change character encoding
mv ChangeLog ChangeLog.old
iconv -f ISO-8859-1 -t UTF8 -o ChangeLog ChangeLog.old

# patch1 also sets $TERM = xterm for all themes,
# do that here since patch1 is not applied
find themes/ -name 'theme.cfg.in' -print0 | xargs -0 -r perl -pi -e 's/term_name Eterm/term_name xterm/'

%build
autoreconf -fi
%configure \
  --enable-etwin \
  --enable-escreen-fx \
  --enable-profile \
  --enable-trans \
  --with-backspace=bs \
  --disable-mmx \
  --enable-utmp \
  --with-delete=execute \
  --enable-auto-encoding \
  --enable-multi-charset \
  --enable-xim \
  --enable-greek \
  --disable-static

%make_build

%install
%make_install

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Eterm
Comment=Enlightened Terminal Emulator
Exec=%{oname}
Icon=terminals_section
Terminal=false
Type=Application
Categories=System;TerminalEmulator;
EOF

#for %%ghost file
touch %{buildroot}%{_datadir}/%{oname}/pix/pixmaps.list.old

# fiw rpmlint warning
# remove rpath
chrpath -d %{buildroot}%{_bindir}/{Esetroot,Eterm}

#we don't want these
rm -rf %{buildroot}%{_libdir}/*.la

%post
%{_bindir}/Etbg_update_list %{_datadir}/%{oname}/pix/

%files
%defattr(-, root, root,0755)
%doc ChangeLog README ReleaseNotes doc/Eterm_reference.html doc/README.Escreen
%{_bindir}/*
%dir %{_datadir}/%{oname}
%{_datadir}/%{oname}/gdb.scr
%config(noreplace) %{_datadir}/%{oname}/themes
%dir %{_datadir}/%{oname}/pix
%ghost %{_datadir}/%{oname}/pix/pixmaps.list.old
%{_datadir}/%{oname}/pix/tile
%{_datadir}/%{oname}/pix/scale
%{_datadir}/%{oname}/pix/*.png
%{_datadir}/%{oname}/pix/pixmaps.list
%{_mandir}/man1/Eterm.1.*
%{_datadir}/applications/%{name}.desktop

%files -n %{libname}
%{_libdir}/lib%{oname}-%{major}.so

%files -n %{devname}
%{_libdir}/lib%{oname}.so
