%define major	28
%define libname	%mklibname exiv2_ %{major}
%define libdev	%mklibname exiv2 -d

Summary:	Command line tool to access EXIF data in image files
Name:		exiv2
Version:	0.28.5
Release:	%mkrel 1
License:	GPLv2+
Group:		Graphics/Utilities
Url:		https://exiv2.org/
#Source0:	https://github.com/Exiv2/exiv2/releases/download/v%%{version}/%%{name}-%%{version}-Source.tar.gz
Source0:	https://github.com/Exiv2/exiv2/archive/v%{version}/%{name}-%{version}.tar.gz
Patch3:		mga-fix-check-rpaths-errors.patch

BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	python3
BuildRequires:	libxslt-proc
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(gtest)
BuildRequires:	pkgconfig(inih)
BuildRequires:	pkgconfig(libbrotlidec)
BuildRequires:	pkgconfig(zlib)

BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libssh)

%description
Exiv2 is a command line utility to access image metadata:
* print the Exif metadata of JPEG, TIFF and several RAW image formats as
  summary info, interpreted values, or the plain data for each tag
* print the IPTC metadata of JPEG images
* print, set and delete the JPEG comment of JPEG images
* set, add and delete Exif and IPTC metadata of JPEG images
* adjust the Exif timestamp (that's how it all started...)
* rename Exif image files according to the Exif timestamp
* extract, insert and delete Exif metadata, IPTC metadata and JPEG comments
* extract, insert and delete the thumbnail image embedded in the Exif metadata
* fix the Exif ISO setting of picture taken with Nikon cameras

%package -n	%{libname}
Summary:	Library to access EXIF data in image files
Group:		Graphics/Utilities

%description -n	%{libname}
libexiv2 is a C++ library to access image metadata. libexiv2 is free
software.

The Exiv2 library provides:
* full read and write access to the Exif and IPTC metadata of
  an image through Exiv2 keys and standard C++ iterators
* a smart IPTC implementation that does not affect data that
  programs like Photoshop store in the same image segment
* Exif MakerNote support:
      o MakerNote tags can be accessed just like any other Exif metadata
      o a sophisticated write algorithm avoids corrupting the MakerNote:
          1) the MakerNote is not re-located if possible at all, and
          2) MakerNote Ifd offsets are re-calculated if the MakerNote 
             needs to be moved (for known Ifd MakerNotes)
* extract and delete methods for Exif thumbnails (both, JPEG and TIFF
  thumbnails)
* set methods for Exif thumbnails (JPEG only, TIFF thumbnails can be
  set from individual tags)
* complete API documentation (by Doxygen)

%package -n	%{libdev}
Summary: 	Headers and links to compile against the "%{libname}" library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	libexiv-devel = %{version}-%{release}
Provides:	libexiv2-devel = %{version}-%{release}
Provides:	exiv2-devel = %{version}-%{release}

%description -n	%{libdev}
This package contains all files which one needs to compile programs using
the "%{libname}" library.

%package	doc
Summary:	Exiv2 library documentation
Group:		Documentation
BuildArch:	noarch

%description	doc
Exiv2 library documentation.

%prep
%autosetup -p1

# remove Apple filesystem cruft
find . -type f -name "._*" -delete

%build
# exiv2: embedded copy of exempi should be compiled with BanAllEntityUsage
# https://bugzilla.redhat.com/show_bug.cgi?id=888769
export CPPFLAGS="-DBanAllEntityUsage=1"
export MAKEFILES_TYPE='Unix Makefiles'
%cmake -G "$MAKEFILES_TYPE" \
      -DEXIV2_BUILD_SAMPLES=OFF \
      -DEXIV2_BUILD_UNIT_TESTS=ON \
      -DEXIV2_ENABLE_XMP=ON \
      -DEXIV2_ENABLE_PNG=ON \
      -DEXIV2_ENABLE_NLS=ON \
      -DEXIV2_ENABLE_LENSDATA=ON \
      -DEXIV2_ENABLE_VIDEO=ON \
      -DEXIV2_ENABLE_WEBREADY=ON \
      -DEXIV2_ENABLE_CURL=ON \
      -DEXIV2_ENABLE_BMFF=ON
%cmake_build

%install
%cmake_install

%find_lang %{name}

%check
build/bin/unit_tests

%files -f %{name}.lang
%doc COPYING README.md
%{_bindir}/*
%{_mandir}/man1/*.1*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}.so.%{version}{,.*}

%files -n %{libdev}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*
%{_libdir}/cmake/%{name}/
%{_includedir}/*

%files doc
%doc doc/ChangeLog doc/cmd.txt
