%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libvtkext

%define major 3
%define libnamedev %mklibname %name -d

%bcond_without draco
%bcond_without java

Name:           f3d
Version:        3.0.0
Release:        %mkrel 2
Summary:        Fast and minimalist 3D viewer
License:        BSD-3-Clause
Group:          Graphics/Viewers
URL:            https://f3d.app/
Source0:        https://github.com/f3d-app/f3d/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  hdf5-devel
BuildRequires:  libstdc++-static-devel
BuildRequires:  cmake(Alembic)
BuildRequires:  cmake(Imath)
BuildRequires:  cmake(OpenCASCADE)
BuildRequires:  cmake(double-conversion)
BuildRequires:  cmake(pybind11)
BuildRequires:  cmake(utf8cpp)
BuildRequires:  cmake(vtk) >= 9.0
BuildRequires:  pkgconfig(assimp)
%if %{with draco}
BuildRequires:  pkgconfig(draco)
%endif
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(opengl)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3dist(pybind11)

%description
F3D is a VTK-based 3D viewer following the KISS principle, so it is
minimalist, efficient, has no GUI, has simple interaction mechanisms
and is fully controllable using arguments in the command line.

%package        python3
Summary:        Python 3 bindings for the %{name}
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       python3-%{name} = %{version}-%{release}

%description    python3
The python3-%{name} package contains Python 3 bindings for %{name}.

%package        bash-completion
Summary:        Bash completion for %{name}
Group:          Shells
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description    bash-completion
Bash command line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          Shells
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description    fish-completion
Fish command line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Shells
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description    zsh-completion
ZSH command line completion support for %{name}.

%if %{with java}
%package        java
Summary:        Java bindings for the %{name}
Group:          Development/Java
BuildRequires:  javapackages-tools
BuildRequires:  java-devel
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    java
This package contains Java bindings for %{name}.
%endif

%package     -n %{libnamedev}
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n %{libnamedev}
This package contains development files for %{name}.

%prep
%autosetup -p1

# fix install location for -java sub-package
sed -i 's|share/java|%{_jnidir}|' java/CMakeLists.txt

%build
%cmake \
    -DCMAKE_SKIP_INSTALL_RPATH=ON \
    -DBUILD_TESTING=OFF \
    -DF3D_BINDINGS_JAVA:BOOL=%{?with_java:ON}%{?!with_java:OFF} \
    -DF3D_BINDINGS_PYTHON=ON \
    -Dpybind11_DIR=%{python3_sitelib}/pybind11/share/cmake/pybind11 \
    -DF3D_LINUX_GENERATE_MAN=ON \
    -DF3D_LINUX_INSTALL_DEFAULT_CONFIGURATION_FILE_IN_PREFIX=ON \
    -DF3D_USE_EXTERNAL_NLOHMANN_JSON=ON \
    -DF3D_MODULE_EXTERNAL_RENDERING=OFF \
    -DF3D_MODULE_RAYTRACING=OFF \
    -DF3D_PLUGINS_STATIC_BUILD=OFF \
    -DF3D_PLUGIN_BUILD_ALEMBIC=ON \
    -DF3D_PLUGIN_BUILD_ASSIMP=ON \
    -DF3D_PLUGIN_BUILD_DRACO=%{?with_draco:ON}%{?!with_draco:OFF} \
    -DF3D_PLUGIN_BUILD_EXODUS=ON \
    -DF3D_PLUGIN_BUILD_OCCT=ON
%cmake_build

%install
%cmake_install

rm -rfv %{buildroot}%{_datadir}/doc/F3D
rm -rfv %{buildroot}%{_libdir}/libvtk*.a

%files
%doc README.md
%license LICENSE.md doc/THIRD_PARTY_LICENSES.md
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}-plugin-*.so
%{_libdir}/libvtkext.so
%{_libdir}/vtk/hierarchy/f3d_vtkext/vtkext-hierarchy.txt
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-plugin-*.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/*.json
%{_iconsdir}/hicolor/*/apps/%{name}.??g
%{_iconsdir}/HighContrast/*/apps/%{name}.??g
%{_metainfodir}/app.%{name}.F3D.metainfo.xml
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}*.thumbnailer
%{_mandir}/man1/%{name}.1.*

%files python3
%{python3_sitearch}/f3d/

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{name}

%if %{with java}
%files java
%{_libdir}/libf3d-java.so
%{_jnidir}/f3d.jar
%endif

%files -n %{libnamedev}
%{_libdir}/libf3d.so
%dir %{_includedir}/f3d
%{_includedir}/f3d/*.h
%dir %{_libdir}/cmake/f3d_vtkext
%{_libdir}/cmake/f3d_vtkext/*.cmake
