#
# Please do not update/rebuild/touch this package before asking first
# to the KDE Team
# This package is part of the KDE Stack.
#

%global toolchain clang

# build Python plugins
%bcond_without python

%define		oname		Falkon
%define		major		3
%define		libname		%mklibname %{name}private %{major}

%define rel 1

Name:		falkon
Summary:	Cross-platform Qt Web Browser based on QtWebEngine
Version: 25.04.0
Release:        %mkrel %{rel}
Group:		Networking/WWW
License:	GPLv3+ and BSD and LGPLv2+ and GPLv2+ and MPL
URL:		https://apps.kde.org/falkon/
Source0:	https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
# reenable native scrollbars by default (upstream disabled them in 2.1.2)
Patch0:		falkon-3.1.0-native-scrollbars.patch
# FIXME use/update qt6_qtwebengine_arches
# 32-bit arches not supported (https://bugreports.qt.io/browse/QTBUG-102143)
ExclusiveArch:	aarch64 x86_64

BuildRequires:	kf6-rpm-macros

BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Qml)
BuildRequires:	cmake(Qt6QuickWidgets)
BuildRequires:	cmake(Qt6Sql)
BuildRequires:	cmake(Qt6PrintSupport)
BuildRequires:	cmake(Qt6WebChannel)
BuildRequires:	cmake(Qt6WebEngineCore)
BuildRequires:	cmake(Qt6WebEngineWidgets)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Test)

BuildRequires:	qttools6
BuildRequires:	dos2unix
BuildRequires:	pkgconfig(xcb-util)

%if 0%{?with_python}
BuildRequires:	cmake(PySide6)
BuildRequires:	cmake(Shiboken6)
BuildRequires:	cmake(Shiboken6Tools)
BuildRequires:	cmake(KF6I18n)
BuildRequires:	pkgconfig(python3)
%if "%{toolchain}" == "clang"
BuildRequires:	clang
%endif
%endif

Requires:	%{name}-core	= %{version}-%{release}
Requires:	%{name}-plugins	= %{version}-%{release}

Provides:	qupzilla = %{version}-%{release}

# forked version that uses D-Bus instead of lock files (see also #1551678)
Provides:	bundled(qtsingleapplication-qt6)

%description
Falkon is a new KDE web browser, previously known as QupZilla.
Following this release, there will only be one last final QupZilla
release.

Falkon is a new and very fast QtWebEngine browser. It aims to be a lightweight
web browser available through all major platforms. This project has been
originally started only for educational purposes. But from its start, Falkon
has grown into a feature-rich browser.

Falkon has all standard functions you expect from a web browser. It includes
bookmarks, history (both also in sidebar) and tabs. Above that, you can manage
RSS feeds with an included RSS reader, block ads with a builtin AdBlock plugin,
block Flash content with Click2Flash and edit the local CA Certificates
database with an SSL Manager.

Falkon's main aim is to be a very fast and very stable QtWebEngine browser
available to everyone. There are already a lot of QtWebEngine browsers available,
but they are either bound to the KDE environment (rekonq), are not actively
developed or very unstable and miss important features. But there is missing
a multiplatform, modern and actively developed browser. Falkon is trying
to fill this gap by providing a very stable browsing experience.

If you were previously using QupZilla, you can manually migrate
your profiles to Falkon by moving the config directory (usually
in ~/.config/qupzilla/).
There is no automatic migration.

%package core
Summary:	%{oname} web browser core package
Group:		Networking/WWW
Provides:	webclient
Requires:	%{libname} = %{version}-%{release}
Requires:	qtbase6-database-plugin-sqlite
Requires:	qtwebengine6

Provides:	qupzilla-core = %{version}-%{release}

%description core
Falkon is a new KDE web browser, previously known as QupZilla.
Following this release, there will only be one last final QupZilla
release.

Falkon is a new and very fast QtWebEngine browser. It aims to be a lightweight
web browser available through all major platforms. This project has been
originally started only for educational purposes. But from its start, Falkon
has grown into a feature-rich browser.

Falkon has all standard functions you expect from a web browser. It includes
bookmarks, history (both also in sidebar) and tabs. Above that, you can manage
RSS feeds with an included RSS reader, block ads with a builtin AdBlock plugin,
block Flash content with Click2Flash and edit the local CA Certificates
database with an SSL Manager.

Falkon's main aim is to be a very fast and very stable QtWebEngine browser
available to everyone. There are already a lot of QtWebEngine browsers available,
but they are either bound to the KDE environment (rekonq), are not actively
developed or very unstable and miss important features. But there is missing
a multiplatform, modern and actively developed browser. Falkon is trying
to fill this gap by providing a very stable browsing experience.

If you were previously using QupZilla, you can manually migrate
your profiles to Falkon by moving the config directory (usually
in ~/.config/qupzilla/).
There is no automatic migration.

%package plugins
Summary:	Various plugins for %{oname} web browser
Group:		Networking/WWW
Requires:	%{name}-core = %{version}

Provides:	qupzilla-plugins = %{version}-%{release}

%description plugins
Falkon Plugins are dynamically loaded shared libraries (*.so) that can extend
application in almost any way. This package contains the following plugins:

* Mouse Gestures
* Access Keys Navigation
* Personal Information Manager
* GreaseMonkey

%package gnome-keyring
Summary:	GNOME keyring plugin for %{oname} web browser
Group:		Networking/WWW
BuildRequires:	pkgconfig(gnome-keyring-1)
Requires:	%{name}-core = %{version}-%{release}

Provides:	qupzilla-gnome-keyring = %{version}-%{release}

%description gnome-keyring
Plugin for %{oname} web browser that allows to store passwords in
GNOME Keyring.

%package kde
Summary:	KDE Frameworks Integration plugin for %{oname} web browser
Group:		Networking/WWW
BuildRequires:	cmake(KF6Archive)
BuildRequires:	cmake(KF6I18n)
BuildRequires:	cmake(KF6Wallet)
BuildRequires:	cmake(KF6KIO)
BuildRequires:	cmake(KF6Crash)
BuildRequires:	cmake(KF6CoreAddons)
BuildRequires:	cmake(KF6Purpose)
BuildRequires:	cmake(KF6JobWidgets)
Requires:	%{name}-core = %{version}-%{release}

Provides:	qupzilla-kwallet = %{version}-%{release}
Provides:	falkon-kwallet = %{version}-%{release} 

%description kde
Plugin for Falkon adding support for:

* storing passwords securely in KWallet,
* additional URL protocols using KIO (e.g., man:, info:, gopher:, etc.),
* a "Share page" menu using the KDE Purpose Framework,
* intercepting crashes with KCrash, bringing up the DrKonqi crash handler.

%package -n %{libname}
Summary:	%{oname} shared library
Group:		System/Libraries

%description -n %{libname}
Shared library used by %{oname} web browser.

%prep
%autosetup -p1

dos2unix README.md

%build
export LLVM_INSTALL_DIR="%{_prefix}"
%cmake_kf6
%cmake_build

%install
%cmake_install

%find_lang falkon_hellopython
%find_lang falkon_helloqml
%find_lang falkon_middleclickloader
%find_lang falkon_runaction
%find_lang_kf6 falkon_qt
%find_lang_kf6 falkon_autoscroll_qt
%find_lang_kf6 falkon_flashcookiemanager_qt
%find_lang_kf6 falkon_gnomekeyringpasswords_qt
%find_lang_kf6 falkon_greasemonkey_qt
%find_lang_kf6 falkon_kdeframeworksintegration_qt
%find_lang_kf6 falkon_kwalletpasswords_qt
%find_lang_kf6 falkon_mousegestures_qt
%find_lang_kf6 falkon_pim_qt
%find_lang_kf6 falkon_sitesettingsview_qt
%find_lang_kf6 falkon_statusbaricons_qt
%find_lang_kf6 falkon_tabmanager_qt
%find_lang_kf6 falkon_testplugin_qt
%find_lang_kf6 falkon_verticaltabs_qt
cat *_qt.lang falkon_hellopython.lang falkon_helloqml.lang \
falkon_middleclickloader.lang falkon_runaction.lang > %{name}.lang

%files

%files core -f %{name}.lang
%doc CHANGELOG README.md
%license COPYING
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/themes
%{_iconsdir}/hicolor/*/apps/*.png
%{_iconsdir}/hicolor/*/apps/*.svg
%{_datadir}/applications/org.kde.%{name}.desktop
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/metainfo/org.kde.%{name}.appdata.xml
%dir %{_qt6_plugindir}/%{name}

%files plugins
%{_qt6_plugindir}/%{name}/AutoScroll.so
%{_qt6_plugindir}/%{name}/FlashCookieManager.so
%{_qt6_plugindir}/%{name}/GreaseMonkey.so
%{_qt6_plugindir}/%{name}/MouseGestures.so
%{_qt6_plugindir}/%{name}/PIM.so
%{_qt6_plugindir}/%{name}/StatusBarIcons.so
%{_qt6_plugindir}/%{name}/TabManager.so
%{_qt6_plugindir}/%{name}/VerticalTabs.so
%if 0%{?with_python}
%{_qt6_plugindir}/%{name}/PyFalkon.so
%{_qt6_plugindir}/%{name}/middleclickloader/
%{_qt6_plugindir}/%{name}/runaction/
%endif

%files gnome-keyring
%{_qt6_plugindir}/%{name}/GnomeKeyringPasswords.so

%files kde
%{_qt6_plugindir}/%{name}/KDEFrameworksIntegration.so

%files -n %{libname}
%{_libdir}/libFalkonPrivate.so.%{major}
%{_libdir}/libFalkonPrivate.so.%{version}
