%define         enable_checks            0

%define         major                    3
%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d
%define         staticdevelname          %mklibname %{name} -d -s

%define         libmpiname               %mklibname %{name}mpi %{major}
%define         libompname               %mklibname %{name}omp %{major}

# No openmpi on 32bits with openmpi 5 in Mageia 10+
%ifnarch %arm32 %ix86
%bcond_without  mpi
%else
%bcond_with     mpi
%endif

Summary:        Fast Fourier transform library
Name:           fftw
Version:        3.3.10
Release:        %mkrel 7
License:        GPLv2+
Group:          System/Libraries

URL:            https://www.fftw.org/
Source0:        ftp://ftp.fftw.org/pub/fftw/%{name}-%{version}.tar.gz
BuildRequires:  gcc-gfortran
%ifarch %{ix86} x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel
BuildRequires:  perl
BuildRequires:  cmake
%if %{with mpi}
BuildRequires:  pkgconfig(ompi)
BuildRequires:  openmpi
%endif




%description
FFTW is a collection of fast C routines for computing the Discrete
Fourier Transform in one or more dimensions. It includes complex,
real, and parallel transforms, can handle arbitrary array sizes
efficiently and can be called from Fortran.

%package wisdom
Summary:        FFTW-wisdom file generator
Group:          Development/Other

%description wisdom
This package contains a wisdom file generator to be used with the FFTW
Fourier transform library. These files contain saved information about how
to optimally compute transforms of various sizes.



%package -n %{libname}
Summary:        Fast Fourier transform library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
FFTW is a collection of fast C routines for computing the Discrete Fourier
Transform in one or more dimensions.  It includes complex, real, and
parallel transforms, and can handle arbitrary array sizes efficiently.


%if %{with mpi}
%package -n %{libmpiname}
Summary:        MPI-parallel fast Fourier transform library
Group:          System/Libraries
Provides:       %{name}-mpi = %{version}-%{release}

%description -n %{libmpiname}
MPI-parallel fast Fourier transform library.
%endif


%package -n %{libompname}
Summary:        OpenMP-parallel fast Fourier transform library
Group:          System/Libraries
Provides:       %{name}-openmp = %{version}-%{release}
Provides:       %{name}-omp = %{version}-%{release}

%description -n %{libompname}
OpenMP-parallel fast Fourier transform library.



%package -n %{develname}
Summary:        Headers, libraries, & docs for the FFTW fast Fourier transform library
Group:          Development/C
%if %{with mpi}
Requires:       pkgconfig(ompi)
Requires:       %{libmpiname} = %{version}-%{release}
%endif
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libompname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}%{major}-devel = %{version}-%{release}
Obsoletes:      %{libname}-devel < 3.3
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the additional header files, documentation, and
libraries you need to develop programs using the FFTW fast Fourier
transform library.



%package -n %{staticdevelname}
Summary:        Static development files for the FFTW fast Fourier transform library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       lib%{name}-devel = %{version}-%{release}
Provides:       lib%{name}-static-devel = %{version}-%{release}
Obsoletes:      %{libname}-static-devel < 3.3

%description -n %{staticdevelname}
Static development files for the FFTW fast Fourier transform library.


%prep
%autosetup -p1

# FIXME daviddavid
# fix wrong soname in FFTW3LibraryDepends.cmake
sed -e 's/3.6.9/3.6.10/' -i CMakeLists.txt

%build
export F77="gfortran"
export MPILIBS="-lmpi"
if [ ! -d build-std ]; then
        mkdir build-std
fi
pushd build-std
CONFIGURE_TOP=.. %configure \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
		    %if %{with mpi}
		    --enable-mpi \
		    %endif		    
                    --enable-fortran \
		    %ifarch x86_64
                    --enable-sse2 \
                    --enable-avx \
		    %endif
                    --infodir=%{_infodir}

%make_build
popd

if [ ! -d build-float ]; then
        mkdir build-float
fi
pushd build-float
CONFIGURE_TOP=.. %configure \
                    --enable-float \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
		    %if %{with mpi}
		    --enable-mpi \
		    %endif
                    --enable-fortran \
                    %ifarch x86_64
                    --enable-sse2 \
                    --enable-avx \
                    %endif
                    --infodir=%{_infodir}
%make_build
popd

#SSE2 and AVX do not work with long-double
if [ ! -d build-long-double ]; then
        mkdir build-long-double
fi
pushd build-long-double
CONFIGURE_TOP=.. %configure \
                    --enable-long-double \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
    		    %if %{with mpi}
		    --enable-mpi \
		    %endif
                    --enable-fortran \
                    --infodir=%{_infodir}
%make_build
popd

%ifarch %{ix86} x86_64
#SSE2,AVX, and MPI do not work with quad-precision
mkdir build-quad-precision
pushd build-quad-precision
CONFIGURE_TOP=.. %configure \
                    --enable-quad-precision \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-fortran \
                    --infodir=%{_infodir}
%make_build
popd
%endif


# FIXME daviddavid
# create missing FFTW3LibraryDepends.cmake (needed now by krita >= 5.2.0)
# https://bugs.archlinux.org/task/67604
# https://github.com/FFTW/fftw3/issues/130
%cmake \
                    -D ENABLE_OPENMP=ON         \
                    -D ENABLE_THREADS=ON        \
                    -D ENABLE_FLOAT=ON          \
                    -D ENABLE_LONG_DOUBLE=ON    \
                    -D ENABLE_QUAD_PRECISION=ON \
                    -D ENABLE_SSE=ON            \
                    -D ENABLE_SSE2=ON           \
                    -D ENABLE_AVX=ON            \
                    -D ENABLE_AVX2=ON

# fix broken IMPORTED_LOCATION:
# https://github.com/FFTW/fftw3/issues/130#issuecomment-1030280157
sed -e 's|\(IMPORTED_LOCATION_RELWITHDEBINFO\).*|\1 "%{_libdir}/libfftw3.so.3"|' -i build/FFTW3LibraryDepends.cmake


%check
%if %enable_checks
make check -C build-std
make check -C build-float
make check -C build-long-double
make check -C build-quad-precision
%endif

%install
pushd build-std
%make_install
popd
pushd build-float
%make_install
popd
pushd build-long-double
%make_install
popd
%ifarch %{ix86} x86_64
pushd build-quad-precision
%make_install
popd
%endif

rm -fr %{buildroot}%{_docdir}/Make*
find %{buildroot}%{_libdir} -name *.la -delete

# FIXME daviddavid
# Compatibility with old versions -- some 3rd party cmake files (e.g. krita)
# install missing FFTW3LibraryDepends.cmake
install -vDm 644 build/FFTW3LibraryDepends.cmake -t %{buildroot}%{_libdir}/cmake/fftw3/

%files -n %{name}-wisdom
%{_bindir}/fftw*-wisdom
%{_bindir}/fftw-wisdom-to-conf
%{_mandir}/man1/fftw-wisdom-to-conf.*
%{_mandir}/man1/fftw*-wisdom.*


%files -n %{libname}
%doc AUTHORS CO* NEWS README TODO 
%{_libdir}/libfftw3.so.%{major}{,.*}
%{_libdir}/libfftw3f.so.%{major}{,.*}
%{_libdir}/libfftw3l.so.%{major}{,.*}
%ifarch %{ix86} x86_64
%{_libdir}/libfftw3q.so.%{major}{,.*}
%endif
%{_libdir}/libfftw3*_threads.so.%{major}{,.*}

%if %{with mpi}
%files -n %{libmpiname}
%{_libdir}/libfftw3*_mpi.so.%{major}{,.*}
%endif

%files -n %{libompname}
%{_libdir}/libfftw3*_omp.so.%{major}{,.*}


%files -n %{develname}
%doc ChangeLog doc/*
%{_includedir}/*fftw*.h
%{_includedir}/fftw3*.f*
%{_infodir}/fftw%{major}.info*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libfftw*.so
%{_libdir}/cmake/fftw3/


%files -n %{staticdevelname}
%{_libdir}/libfftw*.a
