# This package is loosely synced with FC

%global debug_build       0
%global build_with_clang  0

ExclusiveArch:	x86_64

# Place rpm-macros into proper location
%global rpm_macros_dir %(d=%{_rpmconfigdir}/macros.d; [ -d $d ] || d=%{_sysconfdir}/rpm; echo $d)

%global system_nss        0
%global system_libicu     0
%global disable_elfhack   0
# Bundled cbindgen makes build slow.
# Enable only if system cbindgen is not available.
%global use_bundled_cbindgen    1
%ifarch x86_64 aarch64
#global build_with_clang  1
%endif
%global build_with_pgo    0

# (tpg) MOZILLA_FIVE_HOME
%global mozappdir %{_libdir}/%{name}
%global pluginsdir %{_libdir}/mozilla/plugins
%global firefox_channel beta

%define prerel  b7

# exclude libnss from provides (eg: when system_nss is disabled)
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^libnss|^libnspr|^libsmime3|^libssl3|^libsoftokn3|^libfreeblpriv3|^libplc4|^libplds4
# exclude libnss from requires when system_nss is disabled (requires on ourselves):
%if !%{?system_nss}
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^libnss|^libnspr|^libsmime3|^libssl3|^libsoftokn3|^libfreeblpriv3|^libplc4|^libplds4
%endif

# Minimal required versions
%global cairo_version 1.13.1
%global freetype_version 2.1.9
%global libnotify_version 0.7.0
%global libvpx_version 1.10.0

# this seems fragile, so require the exact version or later (#58754)
%global nspr_version 4.25
%global nspr_build_version %(pkg-config --silence-errors --modversion nspr 2>/dev/null || echo 65536)
%global nss_version 3.78
%global nss_build_version %(pkg-config --silence-errors --modversion nss 2>/dev/null || echo 65536)
%global sqlite_version 3.31.1
# The actual sqlite version (see #480989):
%global sqlite_build_version %(pkg-config --silence-errors --modversion sqlite3 2>/dev/null || echo 65536)

%global mozappdir     %{_libdir}/%{name}

Summary:	Mozilla Firefox Web browser
Name:		firefox-beta
Version:	138.0
Release:	%mkrel 0.%{prerel}
Provides:	%{name} = %{version}-0.%{prerel}
URL:            https://www.mozilla.org/firefox/
License:	MPLv1.1 or GPLv2+ or LGPLv2+
Group:		Networking/WWW
Source0:	https://ftp.mozilla.org/pub/firefox/releases/%{version}%prerel/source/firefox-%{version}%prerel.source.tar.xz
Source2:        cbindgen-vendor.tar.xz
Source4:	%{name}.desktop
Source8:	firefox-searchengines-duckduckgo.xml
# From Fedora:
Source10:       firefox-mozconfig
Source12:       firefox-mageia-default-prefs.js
Source24:       mozilla-api-key
Source26:       distribution.ini
Source27:       google-api-key
# To generate cbindgen-vendor.tar.xz
Source100:      gen_cbindgen-vendor.sh
# Fedora patches:
# Build patches
Patch40:        build-aarch64-skia.patch
Patch41:        build-disable-elfhack.patch
Patch44:        build-arm-libopus.patch
Patch53:        firefox-gcc-build.patch
Patch71:        0001-GLIBCXX-fix-for-GCC-12.patch
Patch79:        firefox-gcc-13-build.patch

#ARM run-time patch
Patch226:        rhbz-1354671.patch

# Upstream patches

# Mageia patches:
Patch1000:		firefox-lang.patch
Patch1002:		firefox-vendor.patch
Patch1003:		firefox-disable-check-default-browser.patch
# (OpenSuse) add patch to make firefox always use /usr/bin/firefox when "make firefox
# the default web browser" is used fix mdv bug#58784
Patch1005:		firefox-38.0-appname.patch
Patch1009:		fix-build.diff

Patch1042:      typenum-fix-cargo-checksum.patch
# Patch by Martin Whitaker to fix building i586 with rust
Patch1043:      force-i586-host.patch
# (martinw) don't check for cmov support when running on older CPUs
Patch1044:      bypass-cmov-assert-on-i586.patch

BuildRequires:	pkgconfig(nspr) >= %{nspr_version}
%if %{?system_nss}
BuildRequires:	pkgconfig(nss) >= %{nss_version}
BuildRequires:	nss-static-devel >= %{nss_version}
%endif
BuildRequires:	pkgconfig(libpng)
BuildRequires:	libjpeg-devel
BuildRequires:	zip
BuildRequires:	bzip2-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(freetype2) >= %{freetype_version}
BuildRequires:	pkgconfig(xt)
BuildRequires:  pkgconfig(xrender)
BuildRequires:	pkgconfig(libstartup-notification-1.0)
BuildRequires:	pkgconfig(libnotify) >= %{libnotify_version}
BuildRequires:	pkgconfig(dri)
BuildRequires:  dbus-glib-devel
BuildRequires:	pkgconfig(vpx) >= %{libvpx_version}
BuildRequires:	autoconf2.1
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(icu-i18n) >= 58.0
#BuildRequires:	valgrind-devel
BuildRequires:	yasm
BuildRequires:	libatomic-devel
BuildRequires:  llvm
BuildRequires:  llvm-devel
BuildRequires:  clang
BuildRequires:  clang-devel
%if 0%{?build_with_clang}
BuildRequires:  lld
%endif
%if !0%{?use_bundled_cbindgen}
BuildRequires:  cbindgen
%endif
BuildRequires:  nodejs
BuildRequires:	nasm >= 1.13
%if %{?system_nss}
Requires:	%{mklibname nss 3} >= 2:%{nss_build_version}
Requires:	%{mklibname nspr 4} >= 2:%{nspr_build_version}
%endif
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	python3-devel
BuildRequires:	pkgconfig(sqlite3) >= %{sqlite_version}
Requires:	%{mklibname sqlite3_ 0} >= %{sqlite_build_version}
BuildRequires:	pkgconfig(libffi)
BuildRequires:	rootcerts >= 1:20130411.00
BuildRequires:	doxygen
BuildRequires:	libiw-devel
BuildRequires:  python3-setuptools
BuildRequires:	python3-virtualenv
BuildRequires:	pkgconfig(libproxy-1.0)

BuildRequires:  rust >= 1.43.0
BuildRequires:  cargo >= 1.43.0
BuildRequires:  libstdc++-static-devel

Provides:	webclient

#Requires:	indexhtml
Requires:	xdg-utils
# fixes bug #42096
Requires:	mailcap
Recommends:	hunspell-en
Requires:	%{_lib}notify4
# make sure our default bookmarks are present
Requires:	desktop-common-data
Recommends:	%{_lib}canberra0
Recommends:	%{_lib}cups2
%define ff_deps myspell-en_US
Recommends:	%{ff_deps}

%description
Mozilla Firefox is an open-source web browser, designed for standards
compliance, performance and portability.

%package	devel
Summary:	Development files for %{name}
Group:		Development/Other

%description	devel
Files and macros mainly for building Firefox extensions.

%prep
%setup -qn firefox-%{version}
# Fedora patches:
#patch -P 40 -p1 -b .aarch64-skia
%if 0%{?disable_elfhack}
%patch -P 41 -p1 -b .disable-elfhack
%endif
%patch -P 44 -p1 -b .build-arm-libopus
%patch -P53 -p1 -b .firefox-gcc-build
%patch -P 71 -p1 -b .0001-GLIBCXX-fix-for-GCC-12
%ifarch aarch64
#patch -P 226 -p1 -b .1354671
%endif
%patch -P79 -p1 -b .firefox-gcc-13-build


# Mageia patches:
%patch -P 1000 -p1 -b .lang
#patch -P 1002 -p1 -b .vendor
%patch -P 1003 -p1 -b .defaultbrowser
%patch -P 1009 -p1 -b .fbts

#patch -P 1042 -p1 -b .typenum

%patch -P 1043 -p0
%patch -P 1044 -p1

%{__rm} -f .mozconfig
%{__cp} %{SOURCE10} .mozconfig
# Mageia specific options:
cat << EOF >> .mozconfig
ac_add_options --enable-libproxy
ac_add_options --with-system-png
ac_add_options --with-distribution-id=org.mageia
#ac_add_options --with-valgrind
EOF

# Options shared with FC:
echo "ac_add_options --enable-default-toolkit=cairo-gtk3-wayland" >> .mozconfig
echo "ac_add_options --enable-official-branding" >> .mozconfig

%{__cp} %{SOURCE24} mozilla-api-key
%{__cp} %{SOURCE27} google-api-key

echo "ac_add_options --prefix=\"%{_prefix}\"" >> .mozconfig
echo "ac_add_options --libdir=\"%{_libdir}\"" >> .mozconfig

%if %{?system_nss}
echo "ac_add_options --with-system-nspr" >> .mozconfig
echo "ac_add_options --with-system-nss" >> .mozconfig
%else
echo "ac_add_options --without-system-nspr" >> .mozconfig
echo "ac_add_options --without-system-nss" >> .mozconfig
%endif

echo "ac_add_options --enable-system-ffi" >> .mozconfig

%ifarch %{arm}
echo "ac_add_options --disable-elf-hack" >> .mozconfig
%endif

%if %{?debug_build}
echo "ac_add_options --enable-debug" >> .mozconfig
echo "ac_add_options --disable-optimize" >> .mozconfig
%else
%global optimize_flags "none"
%ifarch ppc64le aarch64
%global optimize_flags "-g -O2"
%endif
%if %{optimize_flags} != "none"
echo 'ac_add_options --enable-optimize=%{?optimize_flags}' >> .mozconfig
%else
echo 'ac_add_options --enable-optimize' >> .mozconfig
%endif
echo "ac_add_options --disable-debug" >> .mozconfig
%endif

# Second arches fail to start with jemalloc enabled
%ifnarch %{ix86} x86_64
echo "ac_add_options --disable-jemalloc" >> .mozconfig
%endif

%ifnarch %{ix86} x86_64 ppc64le
echo "ac_add_options --disable-webrtc" >> .mozconfig
%endif

echo "ac_add_options --disable-crashreporter" >> .mozconfig

echo "ac_add_options --with-system-jpeg" >> .mozconfig

echo "ac_add_options --without-system-libvpx" >> .mozconfig

%if %{?system_libicu}
echo "ac_add_options --with-system-icu" >> .mozconfig
%else
echo "ac_add_options --without-system-icu" >> .mozconfig
%endif

%ifarch i586
# Rust seems to default to i686 otherwise
echo "ac_add_options --host=i586-mageia-linux-gnu" >> .mozconfig
echo "ac_add_options --target=i586-mageia-linux-gnu" >> .mozconfig
%endif

# api keys full path
echo "ac_add_options --with-mozilla-api-keyfile=`pwd`/mozilla-api-key" >> .mozconfig
# It seems that the api key we have is for the safe browsing only
#echo "ac_add_options --with-google-location-service-api-keyfile=`pwd`/google-api-key" >> .mozconfig
echo "ac_add_options --with-google-safebrowsing-api-keyfile=`pwd`/google-api-key" >> .mozconfig

# https://bugzilla.redhat.com/show_bug.cgi?id=2239046
# with clang 17 upstream's detection fails, so let's just tell it
# where to look
echo "ac_add_options --with-libclang-path=`llvm-config --libdir`" >> .mozconfig

# Remove executable bit to make brp-mangle-shebangs happy.
chmod -x third_party/rust/itertools/src/lib.rs
#chmod a-x third_party/rust/gfx-backend-vulkan/src/*.rs
#chmod a-x third_party/rust/gfx-hal/src/*.rs
chmod a-x third_party/rust/ash/src/extensions/ext/*.rs
chmod a-x third_party/rust/ash/src/extensions/khr/*.rs
chmod a-x third_party/rust/ash/src/extensions/nv/*.rs 
find -name lib.rs | xargs chmod -x

#---------------------------------------------------------------------

%build
%if 0%{?use_bundled_cbindgen}

mkdir -p my_rust_vendor
cd my_rust_vendor
%{__tar} xf %{SOURCE2}
mkdir -p .cargo
cat > .cargo/config <<EOL
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "`pwd`"
EOL

env CARGO_HOME=.cargo cargo install cbindgen
export PATH=`pwd`/.cargo/bin:$PATH
cd -
%else
export CBINDGEN=/usr/bin/cbindgen
%endif


MOZ_OPT_FLAGS=$(echo "%{optflags}" | sed -e 's/-Wall//')
#rhbz#1037063
# -Werror=format-security causes build failures when -Wno-format is explicitly given
# for some sources
# Explicitly force the hardening flags for Firefox so it passes the checksec test;
# See also https://fedoraproject.org/wiki/Changes/Harden_All_Packages
# Workaround for mozbz#1531309
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-Werror=format-security//')
MOZ_OPT_FLAGS="$MOZ_OPT_FLAGS -fpermissive"
%if %{?debug_build}
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-O2//')
%endif
# If MOZ_DEBUG_FLAGS is empty, firefox's build will default it to "-g" which
# overrides the -g1 from line above and breaks building on s390/arm
# (OOM when linking, rhbz#1238225)
%ifarch %{ix86} ppc64le %{arm}
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-g/-g0/')
%else
# this reduces backtrace quality substantially, but seems to be needed
# to prevent various OOM conditions during build
# https://bugzilla.redhat.com/show_bug.cgi?id=2241690
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-g/-g1/')
%endif
export MOZ_DEBUG_FLAGS=" "
MOZ_LINK_FLAGS="%{build_ldflags}"
%if !0%{?build_with_clang}
%ifarch aarch64 %{ix86} ppc64le x86_64
MOZ_LINK_FLAGS="$MOZ_LINK_FLAGS -Wl,--no-keep-memory -Wl,--reduce-memory-overheads"
%endif
%ifarch %{arm}
MOZ_LINK_FLAGS="$MOZ_LINK_FLAGS -Wl,--no-keep-memory -Wl,--strip-debug"
echo "ac_add_options --enable-linker=gold" >> .mozconfig
%endif
%endif
%ifarch %{arm} %{ix86}
export RUSTFLAGS="-Cdebuginfo=0"
%endif

echo "export CFLAGS=\"$MOZ_OPT_FLAGS\"" >> .mozconfig
echo "export CXXFLAGS=\"$MOZ_OPT_FLAGS\"" >> .mozconfig
echo "export LDFLAGS=\"$MOZ_LINK_FLAGS\"" >> .mozconfig

%if 0%{?build_with_clang}
echo "export LLVM_PROFDATA=\"llvm-profdata\"" >> .mozconfig
echo "export AR=\"llvm-ar\"" >> .mozconfig
echo "export NM=\"llvm-nm\"" >> .mozconfig
echo "export RANLIB=\"llvm-ranlib\"" >> .mozconfig
echo "ac_add_options --enable-linker=lld" >> .mozconfig
%else
echo "export CC=gcc" >> .mozconfig
echo "export CXX=g++" >> .mozconfig
echo "export AR=\"gcc-ar\"" >> .mozconfig
echo "export NM=\"gcc-nm\"" >> .mozconfig
echo "export RANLIB=\"gcc-ranlib\"" >> .mozconfig
%endif
%if 0%{?build_with_pgo}
#echo "ac_add_options --enable-lto" >> .mozconfig
echo "ac_add_options MOZ_PGO=1" >> .mozconfig
%endif

MOZ_SMP_FLAGS=-j1
# On x86_64 architectures, Mozilla can build up to 4 jobs at once in parallel,
# however builds tend to fail on other arches when building in parallel.
%ifarch %{ix86}
[ -z "$RPM_BUILD_NCPUS" ] && \
     RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"
[ "$RPM_BUILD_NCPUS" -ge 2 ] && MOZ_SMP_FLAGS=-j2
%endif
%ifarch x86_64 ppc ppc64 ppc64le aarch64
[ -z "$RPM_BUILD_NCPUS" ] && \
     RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"
[ "$RPM_BUILD_NCPUS" -ge 2 ] && MOZ_SMP_FLAGS=-j2
[ "$RPM_BUILD_NCPUS" -ge 4 ] && MOZ_SMP_FLAGS=-j4
[ "$RPM_BUILD_NCPUS" -ge 8 ] && MOZ_SMP_FLAGS=-j8
%endif

echo "export MOZ_MAKE_FLAGS=\"$MOZ_SMP_FLAGS\"" >> .mozconfig
echo "export MOZ_SERVICES_SYNC=1" >> .mozconfig
echo "export STRIP=/bin/true" >> .mozconfig
echo "export MACH_USE_SYSTEM_PYTHON=1" >> .mozconfig
export MACH_USE_SYSTEM_PYTHON=1
./mach build

%install
make -C objdir/browser/installer STRIP=/bin/true MOZ_PKG_FATAL_WARNINGS=0

# Copy files to buildroot
%{__mkdir_p} %{buildroot}%{mozappdir}
cp -rf objdir/dist/firefox/* %{buildroot}%{mozappdir}

%{__mkdir_p}  %{buildroot}%{_bindir}
ln -sf %{mozappdir}/firefox %{buildroot}%{_bindir}/firefox-%{firefox_channel}
mkdir -p %{buildroot}%{mozappdir}/browser/defaults/preferences/

# (tpg) desktop entry
%{__mkdir_p} %{buildroot}%{_datadir}/applications
install -m 644 %{SOURCE4} %{buildroot}%{_datadir}/applications/firefox-%{firefox_channel}.desktop

# (tpg) icons
#cp %{buildroot}%{mozappdir}/browser/chrome/icons/default/default16.png %{buildroot}/%{mozappdir}/browser/icons/
for i in 16 22 24 32 48 256; do
%{__mkdir_p} %{buildroot}%{_iconsdir}/hicolor/"$i"x"$i"/apps
%{__install} -m 644 browser/branding/official/default$i.png %{buildroot}%{_iconsdir}/hicolor/"$i"x"$i"/apps/firefox-%{firefox_channel}.png ;
done

# exclusions
rm -f %{buildroot}%{mozappdir}/README.txt
rm -f %{buildroot}%{mozappdir}/removed-files
rm -f %{buildroot}%{mozappdir}/precomplete

# Default
%{__cp} %{SOURCE12} %{buildroot}%{mozappdir}/browser/defaults/preferences

# display icon for Firefox button
%{__mkdir_p} %{buildroot}%{mozappdir}/browser/defaults/profile/chrome
cat << EOF > %{buildroot}%{mozappdir}/browser/defaults/profile/chrome/userChrome.css
#appmenu-toolbar-button {
  list-style-image: url("chrome://branding/content/icon16.png");
}
EOF

# files in this directory are read on every startup, and can change/add
# preferences for existing profiles
# extensions.autoDisableScopes is a new preference added in firefox 8
# it defines "scopes" where newly installed addons are disabled by default
# this is an additive bit field, and the value defaults to 15 (1+2+4+8)
# we need to remove system scope (8) from it so language packs and other addons
# which are installed systemwide won't get marked as 3rd party and disabled
# documentation: http://kb.mozillazine.org/About:config_entries#Extensions.
# or in toolkit/mozapps/extensions/AddonManager.jsm
# we also need to disable the "disable addon selection dialog"
%{__mkdir_p} %{buildroot}%{mozappdir}/browser/defaults/preferences
cat << EOF > %{buildroot}%{mozappdir}/browser/defaults/preferences/mga.js
pref("general.useragent.locale", "chrome://global/locale/intl.properties");
pref("extensions.autoDisableScopes", 0);
pref("extensions.shownSelectionUI", true);
EOF
# FIXME: Add it back in mga.js when this search engine will be used by default.
# user_pref("browser.search.selectedEngine","duckduckgo.com");

# Use the system hunspell dictionaries
rm -fr %{buildroot}%{mozappdir}/dictionaries
ln -s %{_datadir}/hunspell %{buildroot}%{mozappdir}/dictionaries

# Add distribution.ini
%{__mkdir_p} %{buildroot}%{mozappdir}/distribution
%{__cp} %{SOURCE26} %{buildroot}%{mozappdir}/distribution

# (lm) touch and %ghost bookmarks.html to a proper uninstall
touch %{buildroot}%{mozappdir}/browser/defaults/profile/bookmarks.html

mkdir -p %{buildroot}%{rpm_macros_dir}
cat <<FIN >%{buildroot}%{rpm_macros_dir}/macros.%{name}
# Macros from %{name} package
%%firefox_major              %{version}
%%firefox_version            %{version}
%%firefox_mozillapath        %{mozappdir}
%%firefox_pluginsdir         %{pluginsdir}
%%firefox_appid              \{ec8030f7-c20a-464f-9b0e-13a3a9e97384\}
%%firefox_extdir             %%(if [ "%%_target_cpu" = "noarch" ]; then echo %%{_datadir}/mozilla/extensions/%%{firefox_appid}; else echo %%{_libdir}/mozilla/extensions/%%{firefox_appid}; fi)
FIN
# temp build fix:
mkdir -p %{buildroot}%{mozappdir}/browser/searchplugins
cp -f %{SOURCE8} %{buildroot}%{mozappdir}/browser/searchplugins/duckduckgo.xml

%post
if [ ! -r /etc/sysconfig/oem ]; then
  case `grep META_CLASS /etc/sysconfig/system` in
    *powerpack) bookmark="mozilla-powerpack.html" ;;
    *desktop) bookmark="mozilla-one.html";;
    *) bookmark="mozilla-download.html";;
  esac
  ln -s -f %{_prefix}/share/mga/bookmarks/mozilla/$bookmark  %{mozappdir}/browser/defaults/profile/bookmarks.html
fi

%files
%{_bindir}/firefox-%{firefox_channel}
%{_iconsdir}/hicolor/*/apps/*.png
%{_datadir}/applications/*.desktop
%{_libdir}/%{name}{,.*}
%ghost %{mozappdir}/browser/defaults/profile/bookmarks.html

%files devel
%{rpm_macros_dir}/macros.%{name}
