%bcond_with tests

%define major     %{version}
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           flatbuffers
Version:        25.2.10
Release:        %mkrel 1
Summary:        Memory efficient serialization library
URL:            https://google.github.io/flatbuffers
Group:          Development/Other

# The entire source code is ASL 2.0 except grpc/ which is BSD (3 clause)
License:        ASL 2.0 and BSD

Source0:        https://github.com/google/flatbuffers/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        flatc.1
Source2:        flatbuffers.7

BuildRequires:  cmake
BuildRequires:  git-core
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel

# The library contains pieces of gRPC project, with some additions.
# It is not easy to identify the version, which was used to take the code,
# but it should be something after version 1.3.2. See this discussion for
# details: https://github.com/google/flatbuffers/pull/4305
Provides:       bundled(grpc) = 1.49.0

%description
FlatBuffers is a serialization library for games and other memory constrained
apps. FlatBuffers allows you to directly access serialized data without
unpacking/parsing it first, while still having great forwards/backwards
compatibility.

#------------------------------------------------

%package -n     %{libname}
Summary:        Memory efficient serialization library
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description -n %{libname}
FlatBuffers is a serialization library for games and other memory constrained
apps. FlatBuffers allows you to directly access serialized data without
unpacking/parsing it first, while still having great forwards/backwards
compatibility.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}

%description -n python3-%{name}
This package contains python 3 bindings for %{name}.

#------------------------------------------------

%prep
%autosetup -p1
# cleanup distribution
rm -rf js net php docs go java js biicode {samples/,}android

%build
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DFLATBUFFERS_BUILD_SHAREDLIB=ON \
       -DFLATBUFFERS_BUILD_FLATLIB=OFF \
       -DFLATBUFFERS_BUILD_FLATC=ON \
       -DFLATBUFFERS_BUILD_TESTS=%{?with_tests:ON}%{!?with_tests:OFF}

%cmake_build

pushd python
%pyproject_wheel
popd

%install
%cmake_install

pushd python
%pyproject_install
%pyproject_save_files flatbuffers
popd

mkdir -p %{buildroot}%{_mandir}/man{1,7}
cp -p %{SOURCE1} %{buildroot}%{_mandir}/man1/flatc.1
cp -p %{SOURCE2} %{buildroot}%{_mandir}/man7/flatbuffers.7

%check
%if %{with tests}
%__make test -C %{_vpath_builddir}
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/flatc
%{_mandir}/man1/flatc.1*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_mandir}/man7/%{name}.7*
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files -n python3-%{name} -f %{pyproject_files}
%license LICENSE
%doc README.md
