# Warning: this package is synchronized with Fedora!

%global libmajor 0
%global girapi 1.0
%global girlib %mklibname %{name}-gir %{girapi}
%global libname %mklibname %{name} %{libmajor}
%global devname %mklibname %{name} -d

# Minimum dependent components
%global appstream_version 1.0.0
%global bubblewrap_version 0.8.0
%global glib_version 2.46.0
%global gpgme_version 1.8.0
%global libcurl_version 7.29.0
%global ostree_version 2020.8
%global wayland_protocols_version 1.32
%global wayland_scanner_version 1.15

%{?!_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}}

Version:        1.15.8
Release:        %mkrel 2
# (ovitters) this warnings is NOT in Fedora
# If the patch version increases, please rebuild the dependant packages
# See/read the error message for the specifics
%define patch_ver %(echo %{version}|cut -d. -f1,2)
%global patch_ver_dependant 1.15

# This handles printing the error
%if "%patch_ver" != "%patch_ver_dependant"
%{error:%dnl
Make sure to rebuild the packages depending on flatpak: discover, %dnl
%gnome-software and the various portals. To silence this error please increase %dnl
%the patch_ver_dependant to the current minor version (%patch_ver)} %dnl
%endif

Name:           flatpak
Summary:        Application deployment framework for desktop apps

Group:          System/Packaging
License:        LGPLv2+
URL:            https://flatpak.org/
Source0:        https://github.com/flatpak/flatpak/releases/download/%{version}/%{name}-%{version}.tar.xz
Patch0:         flatpak-1.15.2-compile.patch
#
# Security patches
# P100 -> ...
#

BuildRequires:  pkgconfig(appstream) >= %{appstream_version}
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.40.0
BuildRequires:  pkgconfig(gpgme) >= %{gpgme_version}
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libarchive) >= 2.8.0
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(libcurl) >= %{libcurl_version}
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4
BuildRequires:  pkgconfig(libzstd) >= 0.8.1
BuildRequires:  pkgconfig(ostree-1) >= %{ostree_version}
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= %{wayland_protocols_version}
BuildRequires:  pkgconfig(wayland-scanner) >= %{wayland_scanner_version}
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(malcontent-0)
BuildRequires:  bison
BuildRequires:  bubblewrap >= %{bubblewrap_version}
BuildRequires:  chrpath
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-xsl
BuildRequires:  gettext
BuildRequires:  libcap-devel
BuildRequires:  meson
BuildRequires:  python3dist(pyparsing)
BuildRequires:  systemd-devel
BuildRequires:  socat
BuildRequires:  xdg-dbus-proxy
BuildRequires:  xmlto-notex
BuildRequires:  xsltproc
BuildRequires:  selinux-policy-devel

# Needed for the document portal.
Requires:       fuse3

# Needed for confinement
Requires:       bubblewrap%{?_isa} >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}
Requires:       xdg-dbus-proxy%{?_isa}
Recommends:     xdg-desktop-portal > 0.10
Conflicts:      xdg-desktop-portal <= 0.10

# For supporting exporting SVG icons from flatpaks
Requires:       %{mklibname rsvg2 _2}%{?_isa}

# Required to ensure flatpak functions
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}
Requires(pre):  shadow-utils

Recommends:     xdg-desktop-portal

%description
flatpak is a system for building, distributing and running sandboxed desktop
applications on Linux. See https://wiki.gnome.org/Projects/SandboxedApps for
more information.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C
License:        LGPLv2+
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package contains the pkg-config file and development headers for %{name}.

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          System/Libraries
License:        LGPLv2+
Requires:       bubblewrap%{?_isa} >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}

%description -n %{libname}
This package contains libflatpak.

%package -n %{girlib}
Summary:        GObject Introspection Libraries for %{name}
Group:          System/Libraries
License:        LGPLv2+
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{girlib}
This package contains libflatpak GObject libraries.

%package selinux
Summary:        SELinux policy module for %{name}
Group:          System/Libraries
BuildRequires:  selinux-policy-devel
BuildRequires:  make
BuildArch:      noarch
%{?selinux_requires}

%description selinux
This package contains the SELinux policy module for %{name}.

%package session-helper
Summary:        User D-Bus service used by %{name} and others
Group:          System/Libraries
Conflicts:      flatpak < 1.14.4-3
Requires:       systemd

%description session-helper
This package contains the org.freedesktop.Flatpak user D-Bus service
that's used by %{name} and other packages.

%package tests
Summary:        Tests for %{name}
Group:          Development/Other
License:        LGPLv2+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}
Requires:       bubblewrap >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}

%description tests
This package contains installed tests for %{name}.


%prep
%autosetup -p1

%build
%meson \
    -Dinstalled_tests=true \
    -Dsystem_bubblewrap=%{_bindir}/bwrap \
    -Dsystem_dbus_proxy=%{_bindir}/xdg-dbus-proxy \
    -Dtmpfilesdir=%{_tmpfilesdir} \
    -Dmalcontent=enabled \
    -Dwayland_security_context=enabled \
    %{nil}
%meson_build


%install
%meson_install

install -pm 644 NEWS README.md %{buildroot}/%{_pkgdocdir}
# The system repo is not installed by the flatpak build system.
install -d %{buildroot}%{_localstatedir}/lib/flatpak
install -d %{buildroot}%{_sysconfdir}/flatpak/remotes.d

chrpath -d %{buildroot}%{_libexecdir}/installed-tests/Flatpak/testlibrary

%find_lang %{name}

%pre
getent group flatpak >/dev/null || groupadd -r flatpak
getent passwd flatpak >/dev/null || \
    useradd -r -g flatpak -d / -s /sbin/nologin \
     -c "User for flatpak system helper" flatpak
exit 0


%post
# Create an (empty) system-wide repo.
flatpak remote-list --system &> /dev/null || :

%post selinux
%selinux_modules_install %{_datadir}/selinux/packages/flatpak.pp.bz2

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall %{_datadir}/selinux/packages/flatpak.pp.bz2
fi

%files -f %{name}.lang
%license COPYING
%doc %{_pkgdocdir}
%{_bindir}/flatpak
%{_bindir}/flatpak-bisect
%{_bindir}/flatpak-coredumpctl
%{_datadir}/bash-completion
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Flatpak.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Flatpak.Authenticator.xml
%{_datadir}/dbus-1/services/org.flatpak.Authenticator.Oci.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Flatpak.service
%{_datadir}/dbus-1/system-services/org.freedesktop.Flatpak.SystemHelper.service
%{_datadir}/fish/vendor_conf.d/flatpak.fish
%{_datadir}/fish/vendor_completions.d/flatpak.fish
%{_datadir}/%{name}/
%{_datadir}/polkit-1/actions/org.freedesktop.Flatpak.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.Flatpak.rules
%{_datadir}/zsh/site-functions
%{_libexecdir}/flatpak-oci-authenticator
%{_libexecdir}/flatpak-portal
%{_libexecdir}/flatpak-system-helper
%{_libexecdir}/flatpak-validate-icon
%{_libexecdir}/revokefs-fuse
%dir %{_localstatedir}/lib/flatpak
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}-metadata.5*
%{_mandir}/man5/flatpakref.5*
%{_mandir}/man5/flatpak-flatpakref.5*
%{_mandir}/man5/flatpakrepo.5*
%{_mandir}/man5/flatpak-flatpakrepo.5*
%{_mandir}/man5/flatpak-installation.5*
%{_mandir}/man5/flatpak-remote.5*
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.Flatpak.SystemHelper.conf
%dir %{_sysconfdir}/flatpak
%{_sysconfdir}/flatpak/remotes.d
%{_sysconfdir}/profile.d/flatpak.sh
%{_sysusersdir}/%{name}.conf
%{_unitdir}/flatpak-system-helper.service
%{_userunitdir}/flatpak-oci-authenticator.service
%{_userunitdir}/flatpak-portal.service
%{_systemd_system_env_generator_dir}/60-flatpak-system-only
%{_systemd_user_env_generator_dir}/60-flatpak
%{_tmpfilesdir}/%{name}.conf

%files -n %{devname}
%{_datadir}/gir-1.0/Flatpak-%{girapi}.gir
%doc %{_datadir}/gtk-doc/html/%{name}/
%{_includedir}/%{name}/
%{_libdir}/libflatpak.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{libname}
%license COPYING
%{_libdir}/libflatpak.so.%{libmajor}{,.*}

%files -n %{girlib}
%{_libdir}/girepository-1.0/Flatpak-%{girapi}.typelib

%files selinux
%{_datadir}/selinux/packages/flatpak.pp.bz2
%{_datadir}/selinux/devel/include/contrib/flatpak.if

%files session-helper
%license COPYING
%{_datadir}/dbus-1/interfaces/org.freedesktop.Flatpak.xml
%{_datadir}/dbus-1/services/org.freedesktop.Flatpak.service
%{_libexecdir}/flatpak-session-helper
%{_userunitdir}/flatpak-session-helper.service

%files tests
%{_datadir}/installed-tests
%{_libexecdir}/installed-tests

