%define major   1.3
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

%bcond_without mingw

Name:           fltk
Version:        1.3.11
Release:        %mkrel 1
Summary:        Fast Light Toolkit (FLTK)
Group:          System/Libraries
License:        LGPLv2+
URL:            https://www.fltk.org
Source0:        https://github.com/fltk/fltk/releases/download/release-%{version}/%{name}-%{version}-source.tar.gz
Patch0:         fltk-1.3.6-libdir-prefix.patch
Patch1:         fltk-1.3.6-remove-shared-in-libnames.patch
# Fix cmake install location for legacy build
Patch2:         fltk-cmake.patch
# Fix cmake install location for MinGW build
Patch3:         mingw-fltk-cmake.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  xprop

%if %{with mingw}
# MinGW
BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-gettext
BuildRequires:  mingw32-win-iconv
BuildRequires:  mingw32-zlib
# Libraries
BuildRequires:  mingw32-libpng
BuildRequires:  mingw32-libjpeg

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-gettext
BuildRequires:  mingw64-win-iconv
BuildRequires:  mingw64-zlib
# Libraries
BuildRequires:  mingw64-libpng
BuildRequires:  mingw64-libjpeg
%endif

%description
The Fast Light Toolkit ("FLTK", pronounced "fulltick") is a LGPL'd
C++ graphical user interface toolkit for X (UNIX(r)), OpenGL(r),
and Microsoft(r) Windows(r) NT 4.0, 95, or 98. It was originally
developed by Mr. Bill Spitzak and is currently maintained by a
small group of developers across the world with a central
repository in the US.

#---------------------------------------------------------------------------

%package -n %{libname}
Summary:        Fast Light Toolkit (FLTK) - main library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
The Fast Light Toolkit ("FLTK", pronounced "fulltick") is a LGPL'd
C++ graphical user interface toolkit for X (UNIX(r)), OpenGL(r),
and Microsoft(r) Windows(r) NT 4.0, 95, or 98. It was originally
developed by Mr. Bill Spitzak and is currently maintained by a
small group of developers across the world with a central
repository in the US.

%files -n %{libname}
%license COPYING COPYING.xutf8
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}_forms.so.%{major}{,.*}
%{_libdir}/lib%{name}_gl.so.%{major}{,.*}
%{_libdir}/lib%{name}_images.so.%{major}{,.*}

#---------------------------------------------------------------------------

%package -n %{devname}
Summary:        Fast Light Toolkit (FLTK) - development environment
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{name}-fluid = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development headers and libraries for FLTK.

%files -n %{devname}
%doc README CHANGES
%doc README.CMake.txt README.Unix.txt
%{_bindir}/%{name}-config
%{multiarch_bindir}/%{name}-config
%{_libdir}/cmake/%{name}/
%{_includedir}/FL/
%{_libdir}/lib%{name}*.so
%{_mandir}/man1/%{name}-config.1*
%{_mandir}/man3/%{name}.3*

#---------------------------------------------------------------------------

%package fluid
Summary:        Fast Light User Interface Designer: GUI builder for FLTK
Group:          Development/Tools

%description fluid
FLUID (Fast Light User Interface Designer) is a graphical editor and GUI
builder that is used to produce FLTK source code. FLUID edits and saves its
state in text .fl files, which can be edited in a text editor for finer
control over display and behavior.

%files fluid
%{_bindir}/fluid
%{_datadir}/mime/packages/fluid.xml
%{_datadir}/applications/fluid.desktop
%{_iconsdir}/hicolor/*/apps/fluid.png
%{_mandir}/man1/fluid.1*

#---------------------------------------------------------------------------

%if %{with mingw}
%package -n mingw32-fltk
Summary:       MinGW compiled fltk for the Win32 target

%description -n mingw32-fltk
%{_description}.

%files -n mingw32-fltk
%license COPYING COPYING.xutf8
%{mingw32_bindir}/fltk-config
%{mingw32_bindir}/libfltk.dll
%{mingw32_libdir}/libfltk.dll.a
%{mingw32_bindir}/libfltk_forms.dll
%{mingw32_libdir}/libfltk_forms.dll.a
%{mingw32_bindir}/libfltk_images.dll
%{mingw32_libdir}/libfltk_images.dll.a
%{mingw32_bindir}/libfltk_gl.dll
%{mingw32_libdir}/libfltk_gl.dll.a
%{mingw32_includedir}/FL/
%{mingw32_datadir}/cmake/fltk/
%exclude %{mingw32_datadir}/man/*

# Win64
%package -n mingw64-fltk
Summary:       MinGW compiled fltk for the Win64 target

%description -n mingw64-fltk
%{_description}.

%files -n mingw64-fltk
%license COPYING COPYING.xutf8
%{mingw64_bindir}/fltk-config
%{mingw64_bindir}/libfltk.dll
%{mingw64_libdir}/libfltk.dll.a
%{mingw64_bindir}/libfltk_forms.dll
%{mingw64_libdir}/libfltk_forms.dll.a
%{mingw64_bindir}/libfltk_images.dll
%{mingw64_libdir}/libfltk_images.dll.a
%{mingw64_bindir}/libfltk_gl.dll
%{mingw64_libdir}/libfltk_gl.dll.a
%{mingw64_includedir}/FL/
%{mingw64_datadir}/cmake/fltk/
%exclude %{mingw64_datadir}/man/*

%package -n mingw32-fltk-static
Summary:       MinGW compiled fltk for the Win32 static target

%description -n mingw32-fltk-static
%{_description}.

%files -n mingw32-fltk-static
%{mingw32_libdir}/libfltk.a
%{mingw32_libdir}/libfltk_forms.a
%{mingw32_libdir}/libfltk_images.a
%{mingw32_libdir}/libfltk_gl.a

# Win64
%package -n mingw64-fltk-static
Summary:       MinGW compiled fltk for the Win64 static target

%description -n mingw64-fltk-static
%{_description}.

%files -n mingw64-fltk-static
%{mingw64_libdir}/libfltk.a
%{mingw64_libdir}/libfltk_forms.a
%{mingw64_libdir}/libfltk_images.a
%{mingw64_libdir}/libfltk_gl.a

%{?mingw_debug_package}
%endif

#---------------------------------------------------------------------------

%prep
%autosetup -p1

%build
%cmake \
    -DFLTK_CONFIG_PATH:PATH=%{_libdir}/cmake/fltk \
    -DOPTION_BUILD_SHARED_LIBS=ON \
    -DOPTION_USE_SYSTEM_ZLIB=ON \
    -DOPTION_USE_SYSTEM_LIBJPEG=ON \
    -DOPTION_USE_SYSTEM_LIBPNG=ON \
    -DFLTK_BUILD_EXAMPLES=OFF
%cmake_build

%if %{with mingw}
%mingw_cmake \
    -DOPTION_BUILD_SHARED_LIBS=TRUE \
    -DFLTK_BUILD_TEST=FALSE
%mingw_make_build
%endif

%install
%cmake_install

# We don't want static libraries
find %{buildroot} -name "*.a" -delete

%if %{with mingw}
%mingw_make_install
%mingw_debug_install_post
%endif

# Demos man pages
rm -rf %{buildroot}%{_mandir}/man6

# Deal with license file of same name
mv src/xutf8/COPYING ./COPYING.xutf8

%multiarch_binaries %{buildroot}%{_bindir}/%{name}-config
