%define fontconfig_major 1
%define lib_name %mklibname %{name} %{fontconfig_major}
%define develname %mklibname %{name} -d

%define freetype_version 2.3.5

%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}
%define rebuild_doc	1
%if %{bootstrap}
%define rebuild_doc 0
%endif

Summary: Font configuration library
Name: fontconfig
Version: 2.16.0
Release: %mkrel 2
License: MIT and Public Domain and UCD
Group: System/X11
URL: https://fontconfig.org/
Source0: https://fontconfig.org/release/fontconfig-%{version}.tar.xz
# (fc) 2.3.2-3mdk prefer urw fonts
Source1: 30-mdv-urwfonts.conf
# (fc) 2.3.2-3mdk disable antialiasing for some fonts
Source3: 20-mdv-disable-antialias.conf
# (fc) 2.3.2-3mdk  Avoid KDE/QT uses some bitmapped fonts (guisseppe)
Source5: 30-mdv-avoid-bitmap.conf
# (fc) 2.4.2-1mdv disable embedded bitmap for big size (Mdv bug #25924)
Source8: 26-mdv-no-embeddedbitmap.conf
# (fc) 2.4.92-1mdv enable embeddedbitmap on some CJK fonts (Fedora)
Source101: 25-no-bitmap-fedora.conf
# (ovitters) 2.13.90-1mga fc-cache per arch bits (32/64) (Fedora)
Source102: fc-cache
# (ns80) fix PDF rendering in Firefox and Thunderbird (mga bug #32525)
Source103: 70-mga-no-bitmaps-firefox-thunderbird.conf
# (fc) 2.1-4mdk change order of default fonts
Patch50: fontconfig-mdvconfig.patch

# From Fedora as well as upstream:
Patch0: %{name}-sleep-less.patch
Patch5: %{name}-disable-network-required-test.patch
Patch7: %{name}-meson-cachedir.patch

Requires: fonts-filesystem
# Register DTD system-wide to make validation work by default
# (used by fonts-rpm-macros)
Requires(pre):    libxml2-utils
Requires(postun): libxml2-utils

Requires(post): %{lib_name}  >= %{version}-%{release}
Requires(post): grep
Requires(post): coreutils

BuildRequires: pkgconfig(freetype2) >= %{freetype_version}
BuildRequires: pkgconfig(uuid)

BuildRequires: ed
%if %{rebuild_doc}
BuildRequires: docbook-utils
BuildRequires: docbook-utils-pdf
BuildRequires: docbook-dtd31-sgml
BuildRequires: docbook-dtd41-sgml
%endif
BuildRequires: lynx
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: libxml2-utils
BuildRequires: gperf
BuildRequires: docbook-utils
BuildRequires: docbook-utils-pdf
BuildRequires: meson

%description
Fontconfig is designed to locate fonts within the
system and select them according to requirements specified by
applications.

%package -n %{lib_name}
Summary: Font configuration and customization library
Group: System/Libraries
Requires: %{name} >= %{version}-%{release}
Provides: lib%{name} = %{version}-%{release}
Provides: %{name}-libs = %{version}-%{release}

%description -n %{lib_name}
Fontconfig is designed to locate fonts within the
system and select them according to requirements specified by
applications.

%package -n %{develname}
Summary: Font configuration and customization library
Group: Development/C
Provides: lib%{name}-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Requires: %{name} = %{version}-%{release}
Requires: %{lib_name} = %{version}-%{release}
Requires: pkgconfig(freetype2) >= %{freetype_version}

%description -n %{develname}
The fontconfig-devel package includes the header files,
and developer docs for the fontconfig package.

Install fontconfig-devel if you want to develop programs which
will use fontconfig.

%prep
%autosetup -p1

%build
%if !%{rebuild_doc}
# We don't want to rebuild the docs, but we want to install the included ones.
export HASDOCBOOK=no

for i in doc/*.fncs; do
  touch -r $i ${i//.fncs/.sgml}
done
%endif

%meson --default-library=shared \
       -D doc-pdf=disabled \
       -D cache-build=disabled \
       -D xml-backend=libxml2 \
       -D additional-fonts-dirs="/usr/share/fonts,/usr/share/X11/fonts/Type1,/usr/share/X11/fonts/TTF,/usr/local/share/fonts,/usr/lib/X11/fonts,/opt/ttfonts" \
       -D cache-dir=/usr/lib/fontconfig/cache
%meson_build

%install
%meson_install

install -p -m 0644 %{SOURCE1} %{SOURCE3} %{SOURCE5} %{SOURCE8} %{SOURCE101} %{SOURCE103} %{buildroot}%{_sysconfdir}/fonts/conf.d

# needed in case main config files isn't up to date
cat << EOF > %{buildroot}%{_sysconfdir}/fonts/conf.d/00-cache.conf
<?xml version="1.0"?>
<!DOCTYPE fontconfig SYSTEM "urn:fontconfig:fonts.dtd">
<fontconfig>
<!-- Font cache directory list -->

        <cachedir>/usr/lib/fontconfig/cache</cachedir>
        <cachedir>~/.fontconfig</cachedir>

</fontconfig>
EOF

ln -s %{_datadir}/fontconfig/conf.avail/25-unhint-nonlatin.conf %{buildroot}%{_sysconfdir}/fonts/conf.d

# rename fc-cache binary
mv %{buildroot}%{_bindir}/fc-cache %{buildroot}%{_bindir}/fc-cache-%{__isa_bits}

# create link to man page
echo ".so man1/fc-cache.1" > %{buildroot}%{_mandir}/man1/fc-cache-%{__isa_bits}.1

install -p -m 0755 %{SOURCE102} %{buildroot}%{_bindir}/fc-cache

# remove unpackaged files
rm -rf %{buildroot}%{_datadir}/doc/fontconfig

%find_lang %{name}
%find_lang %{name}-conf

%check
#meson_test

%post
umask 0022

mkdir -p /usr/lib/fontconfig/cache

[[ -d %{_localstatedir}/cache/fontconfig ]] && rm -rf %{_localstatedir}/cache/fontconfig/* 2> /dev/null || :

# Force regeneration of all fontconfig cache files
# The check for existance is needed on dual-arch installs (the second
#  copy of fontconfig might install the binary instead of the first)
# The HOME setting is to avoid problems if HOME hasn't been reset
if [ -x /usr/bin/fc-cache ] && /usr/bin/fc-cache --version 2>&1 | grep -q %{version} ; then
  HOME=/root /usr/bin/fc-cache -f
fi


%triggerprein -- fontconfig < 2.4.0
rm -f %{_var}/cache/fontconfig/*.cache-2

# rpm filetriggers to update cache
%transfiletriggerin     --  /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts /usr/lib/X11/fonts /opt/ttfonts
HOME=/root /usr/bin/fc-cache -s

%transfiletriggerpostun --  /usr/share/fonts /usr/share/X11/fonts/Type1 /usr/share/X11/fonts/TTF /usr/local/share/fonts /usr/lib/X11/fonts /opt/ttfonts
HOME=/root /usr/bin/fc-cache -s

%posttrans
if [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --add system \
                        "urn:fontconfig:fonts.dtd" \
                        "file://%{_datadir}/xml/fontconfig/fonts.dtd" \
                        %{_sysconfdir}/xml/catalog
fi

%postun
if [ $1 == 0 ] && [ -e %{_sysconfdir}/xml/catalog ]; then
  %{_bindir}/xmlcatalog --noout --del "urn:fontconfig:fonts.dtd"
fi

%files -f %{name}.lang -f %{name}-conf.lang
%doc README.md AUTHORS doc/fontconfig-user.html doc/fontconfig-user.txt
%license COPYING
%{_bindir}/*
%dir %{_sysconfdir}/fonts
%dir %{_sysconfdir}/fonts/conf.d
# those files must NOT have noreplace option
%config %{_sysconfdir}/fonts/fonts.conf
%config %{_sysconfdir}/fonts/conf.d/*.conf
%config %{_sysconfdir}/fonts/conf.d/README
%{_datadir}/fontconfig/
%{_datadir}/gettext/its/*
%{_datadir}/xml/fontconfig/fonts.dtd
%{_mandir}/man1/*
%{_mandir}/man5/*
%dir /usr/lib/fontconfig/cache

%files -n %{lib_name}
%{_libdir}/*.so.%{fontconfig_major}{,.*}

%files -n %{develname}
%doc doc/fontconfig-devel.txt doc/fontconfig-devel.html
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_mandir}/man3/*
