# Attempt to fix https://ml.mageia.org/l/arc/dev/2014-10/msg00662.html
%global __requires_exclude pear\\(source/objp\\.php\\)

%ifarch aarch64
# Bootstrap the aarch64-compiler. Set this to 0 after we've bootstrapped.
%{!?_with_bootstrap: %global bootstrap 0}
%else
%{!?_with_bootstrap: %global bootstrap 0}
%endif

# debuginfo seems to be broken on i586 and arm
%ifarch %{ix86} %{arm}
%define debug_package %{nil}
%endif

Name:           fpc
Version:        3.2.2
Release:        %mkrel 4
Summary:        Free Pascal Compiler

Group:          Development/Other
License:        GPLv2+ and LGPLv2+ with exceptions
URL:            https://www.freepascal.org/
Source0:        https://mirror.freemirror.org/pub/fpc/dist/%{version}/source/fpcbuild-%{version}.tar.gz

# This is only needed when we're bootstrapping.
# But it's not in an 'if defined' block, since the file has to be included in the srpm
# Thus you should enable this line when we're bootstrapping for any target
#
# Last used for aarch64 bootstrap, for the aarch64 boostrap, a compiler has been used that has
# been cross-compiled on a x86_64 system using
#  make all CPU_TARGET=aarch64 OS_TARGET=linux BINUTILSPREFIX=aarch64-linux-gnu-
# in the fpcsrc directory of fpcbuild-3.0.4.tar.gz. The compiler is then copied from
# fpcsrc/compiler/ppca64 to SOURCES dir.
#Source1:        ppca64-3.0.4
# Configuration templates:
Source10:        fpc.cft
Source11:        fppkg.cfg
Source12:        default.cft

# We do not want stabs debug-information. (even on 32 bit platforms)
# https://bugzilla.redhat.com/show_bug.cgi?id=1475223
Patch0:         fpc-3.2.0--dwarf-debug.patch

# Allow for reproducible builds
# https://bugzilla.redhat.com/show_bug.cgi?id=1778875
Patch1:         fpc-3.2.0--honor_SOURCE_DATE_EPOCH_in_date.patch

# Upstream assumes /usr/lib/ for aarch64, but we use /usr/lib64/
Patch2:         fpc-3.2.0--fix-lib-paths-on-aarch64.patch

# Update for new glibc >= 2.34
# https://bugzilla.redhat.com/show_bug.cgi?id=2005910
Patch3:         fpc-3.2.0--glibc-2.34.patch

# The "pas2jni" util program shipped with FPC uses threads,
# but is compiled without thread support and fails to actually do anything useful when run.
# Submitted upstream: https://gitlab.com/freepascal.org/fpc/source/-/merge_requests/185
Patch5:         0001-Make-pas2jni-use-cthreads-on-Unices.patch

# FPC's LaTeX docs use the \htmladdnormallink command, which has been removed in recent TexLive versions.
# Alias the command to \href.
#
# Taken from OpenSUSE: https://build.opensuse.org/package/view_file/openSUSE:Leap:15.5:Update/fpc/hyperref-2022.patch
Patch10:        hyperref-2022.patch

Requires:       binutils
Requires:       gpm
Requires:       ncurses

%if ! 0%{?bootstrap}
BuildRequires:  fpc
%endif
BuildRequires:  texlive-dist
BuildRequires:  mysql-devel
BuildRequires:  postgresql-devel

# Fix bug 8805 - needed for ptcGraph
Requires:       glibc-devel
Requires:       gcc
Requires:       libx11-devel
Requires:       libxext-devel
Requires:       libxrandr-devel
Requires:       libxxf86vm-devel
Requires:       libxxf86dga-devel

ExclusiveArch:  %{arm} aarch64 %{ix86} x86_64

%description
Free Pascal is a free 32/64bit Pascal Compiler. It comes with a run-time
library and is fully compatible with Turbo Pascal 7.0 and nearly Delphi
compatible. Some extensions are added to the language, like function
overloading and generics. Shared libraries can be linked. This package
contains the command-line compiler and utilities. Provided units are the
runtime library (RTL), free component library (FCL) and packages.

%package doc
Summary: Free Pascal Compiler - documentation and examples
Group: Documentation

%description doc
The fpc-doc package contains the documentation (in pdf format) and examples
of Free Pascal.

%package src
Summary:   Free Pascal Compiler - sources
BuildArch: noarch
Group: Development/Other

%description src
The fpc-src package contains the sources of Free Pascal, for documentation or
automatic code generation purposes.

%global smart _smart
%global fpcopt -k"--build-id"
%global fpcdebugopt -gl
%ifarch %{arm}
  %global fpcopt -dFPC_ARMHF -k"--build-id"
  %global ppcname ppcarm
  %global fpcarchname arm
%endif

%ifarch aarch64
%global ppcname ppca64
%global fpcarchname aarch64
%endif

%ifarch %{ix86}
%global ppcname ppc386
%global fpcarchname i386
%endif

%ifarch x86_64
%global ppcname ppcx64
%global fpcarchname x86_64
%endif

%prep
%setup -n fpcbuild-%{version} -q

%if 0%{bootstrap}
install -Dpm755 %{_sourcedir}/%{ppcname}-3.0.4 bootstrap-bin/%{ppcname}-3.0.4
%endif

pushd fpcsrc
%patch -P 0
%patch -P 1
%patch -P 2
%patch -P 3 -p1
%patch -P 5 -p1
popd

pushd fpcdocs
%patch -P 10 -p1
popd

%build
# The source-files:
mkdir -p fpc_src
cp -a fpcsrc/rtl fpc_src
cp -a fpcsrc/packages fpc_src
rm -rf fpc_src/packages/extra/amunits
rm -rf fpc_src/packages/extra/winunits

%if 0%{?bootstrap}
STARTPP=$(pwd)/bootstrap-bin/%{ppcname}-3.0.4
%else
STARTPP=%{ppcname}
%endif

pushd fpcsrc
NEWPP=$(pwd)/compiler/%{ppcname}
DATA2INC=$(pwd)/utils/data2inc
# FIXME: -j1 as there is a race on armv7hl - seen on "missing" `prt0.o' and 'dllprt0.o'.
make -j1 compiler_cycle FPC=${STARTPP} OPT='%{fpcopt} %{fpcdebugopt}'
make %{?_smp_mflags} rtl_clean rtl%{smart} FPC=${NEWPP} OPT='%{fpcopt}'
make %{?_smp_mflags} packages%{smart} FPC=${NEWPP} OPT='%{fpcopt}'
make %{?_smp_mflags} utils_all FPC=${NEWPP} DATA2INC=${DATA2INC} OPT='%{fpcopt} %{fpcdebugopt}'
popd

# FIXME: -j1 as there is a race - seen on "missing" `rtl.xct'.
make -j1 -C fpcdocs pdf FPC=${NEWPP}

%install
pushd fpcsrc
NEWPP=$(pwd)/compiler/%{ppcname}
NEWFPCMAKE=$(pwd)/utils/fpcm/bin/%{fpcarchname}-linux/fpcmake
INSTALLOPTS="-j1 FPC=${NEWPP} FPCMAKE=${NEWFPCMAKE} \
                INSTALL_PREFIX=%{buildroot}%{_prefix} \
                INSTALL_LIBDIR=%{buildroot}%{_libdir} \
                INSTALL_BASEDIR=%{buildroot}%{_libdir}/%{name}/%{version} \
                CODPATH=%{buildroot}%{_libdir}/%{name}/lexyacc \
                INSTALL_DOCDIR=%{buildroot}%{_defaultdocdir}/%{name} \
                INSTALL_BINDIR=%{buildroot}%{_bindir}
                INSTALL_EXAMPLEDIR=%{buildroot}%{_defaultdocdir}/%{name}/examples"
make compiler_distinstall ${INSTALLOPTS}
make rtl_distinstall ${INSTALLOPTS}
make packages_distinstall ${INSTALLOPTS}
make utils_distinstall ${INSTALLOPTS}
popd

pushd install
make -C doc ${INSTALLOPTS}
make -C man ${INSTALLOPTS} INSTALL_MANDIR=%{buildroot}%{_mandir}
popd

make -C fpcdocs pdfinstall ${INSTALLOPTS}

# create link
ln -sf ../%{_lib}/%{name}/%{version}/%{ppcname} %{buildroot}%{_bindir}/%{ppcname}

# Remove the version-number from the documentation-directory
mv %{buildroot}%{_defaultdocdir}/%{name}-%{version}/* %{buildroot}%{_defaultdocdir}/%{name}
rmdir %{buildroot}%{_defaultdocdir}/%{name}-%{version}

# Create a version independent compiler-configuration file with build-id
# enabled by default
# For this purpose some non-default templates are used. So the samplecfg
# script could not be used and fpcmkcfg is called directly.
%{buildroot}%{_bindir}/fpcmkcfg -p -t %{SOURCE10} -d "basepath=%{_exec_prefix}" -o %{buildroot}%{_sysconfdir}/fpc.cfg
# Create the IDE configuration files
%{buildroot}%{_bindir}/fpcmkcfg -p -1 -d "basepath=%{_libdir}/%{name}/\$fpcversion" -o %{buildroot}%{_libdir}/%{name}/%{version}/ide/text/fp.cfg
%{buildroot}%{_bindir}/fpcmkcfg -p -2 -o %{buildroot}%{_libdir}/%{name}/%{version}/ide/text/fp.ini
# Create the fppkg configuration files
%{buildroot}%{_bindir}/fpcmkcfg -p -t %{SOURCE11} -d CompilerConfigDir=%{_sysconfdir}/fppkg -d arch=%{_arch} -o %{buildroot}%{_sysconfdir}/fppkg.cfg
%{buildroot}%{_bindir}/fpcmkcfg -p -t %{SOURCE12} -d fpcbin=%{_bindir}/fpc -d GlobalPrefix=%{_exec_prefix} -d lib=%{_lib} -o %{buildroot}%{_sysconfdir}/fppkg/default_%{_arch}

# Include the COPYING-information for the compiler/rtl/fcl in the documentation
cp -a fpcsrc/compiler/COPYING.txt %{buildroot}%{_defaultdocdir}/%{name}/COPYING
cp -a fpcsrc/rtl/COPYING.txt %{buildroot}%{_defaultdocdir}/%{name}/COPYING.rtl
cp -a fpcsrc/rtl/COPYING.FPC %{buildroot}%{_defaultdocdir}/%{name}/COPYING.FPC

# The source-files:
mkdir -p %{buildroot}%{_datadir}/fpcsrc
cp -a fpc_src/* %{buildroot}%{_datadir}/fpcsrc/

# Workaround:
# newer rpm versions do not allow garbage
# delete lexyacc (The hardcoded library path is necessary because 'make
# install' places this file hardcoded at usr/lib)
rm -rf %{buildroot}/usr/lib/%{name}/lexyacc


%files
%{_bindir}/*
%{_libdir}/%{name}
%{_libdir}/libpas2jslib.so*
%config(noreplace) %{_sysconfdir}/%{name}.cfg
%config(noreplace) %{_sysconfdir}/fppkg.cfg
%dir %{_sysconfdir}/fppkg/
%config(noreplace) %{_sysconfdir}/fppkg/default_%{_arch}
%dir %{_defaultdocdir}/%{name}/
%doc %{_defaultdocdir}/%{name}/NEWS
%doc %{_defaultdocdir}/%{name}/README
%doc %{_defaultdocdir}/%{name}/faq*
%license %{_defaultdocdir}/%{name}/COPYING*
%{_mandir}/*/*

%files doc
%dir %{_defaultdocdir}/%{name}/
%doc %{_defaultdocdir}/%{name}/*.pdf
%doc %{_defaultdocdir}/%{name}/*/*

%files src
%{_datadir}/fpcsrc
