# Maintainers:  keep this list of plugins up to date
# List plugins in %%{_libdir}/freecad/lib, less '.so' and 'Gui.so', here
%global plugins Drawing Fem FreeCAD Image Import Inspection Mesh MeshPart Part Points QtUnit Raytracing ReverseEngineering Robot Sketcher Start Web _PartDesign Path Spreadsheet area DraftUtils libDriver libDriverDAT libDriverSTL libDriverUNV libE57Format libMEFISTO2 libSMDS libSMESH libSMESHDS libStdMeshers Measure TechDraw libarea-native Surface PathSimulator flatmesh libFreeCADApp libFreeCADBase PathApp

# Some plugins go in the Mod folder instead of lib. Deal with those here:
%global mod_plugins Mod/PartDesign

%define srcname FreeCAD

# (daviddavid) re-enable system PyCXX
# https://forum.freecadweb.org/viewtopic.php?f=4&t=35109
%bcond_without pycxx
# (daviddavid) use bundled Zipios for now (upstream still use an old zipios copy)
%bcond_with zipios

%ifarch aarch64 x86_64
%bcond_without web
%else
%bcond_with web
%endif

# No openmpi on 32bits with openmpi 5 in Mageia 10+
%ifarch %{ix86} %{arm32}
%bcond_with openmpi
%else
%bcond_without openmpi
%endif

# comment out when not a pre-release
#define prerel  rc2

Name:           freecad
Version:        1.0.0
Release:        %mkrel %{?prerel:0.%prerel.}4
Summary:        A general purpose 3D CAD modeler
Group:          Graphics/3D

License:        GPLv2+
URL:            https://www.freecadweb.org/
Source0:        https://github.com/FreeCAD/FreeCAD/archive/%{version}%{?prerel:%prerel}/%{srcname}-%{version}%{?prerel:%prerel}.tar.gz
Source102:      freecad.1

Patch2:         freecad-unbundled-pycxx.patch
#
# # Patches from Debian
#
# # Mageia patches
#
# # Gentoo patches

# # Archlinux patches

# # Upstream patches

# Utilities
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  swig
BuildRequires:  graphviz
BuildRequires:  gettext
BuildRequires:  dos2unix
BuildRequires:  desktop-file-utils
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  git-core

# Development Libraries
BuildRequires:  glibc-devel
BuildRequires:  boost-devel
BuildRequires:  freeimage-devel
BuildRequires:  med-devel >= 4.0.0
BuildRequires:  hdf5-devel >= 1.12.2
BuildRequires:  opencascade-devel
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6SvgWidgets)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6UiTools)
%if %{with web}
BuildRequires:  cmake(Qt6WebEngineWidgets)
%endif
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
# We use the internal smesh version with fixes atm
#BuildRequires:  smesh-devel
BuildRequires:  spnav-devel
BuildRequires:  vtk-devel
BuildRequires:  utf8cpp-devel
%if %{with zipios}
BuildRequires:  zipios++-devel
%endif
BuildRequires:  cmake(double-conversion)
BuildRequires:  cmake(Microsoft.GSL)
BuildRequires:  cmake(pybind11)
BuildRequires:  cmake(yaml-cpp)
BuildRequires:  pkgconfig(Coin)
BuildRequires:  pkgconfig(OndselSolver)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(nlohmann_json)
%if %{with openmpi}
BuildRequires:  pkgconfig(ompi-cxx)
%endif
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(pyside6)
BuildRequires:  pkgconfig(shiboken6)
BuildRequires:  pkgconfig(freeglut)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(xmu)
%if %{with pycxx}
BuildRequires:  python3dist(cxx)
%endif
BuildRequires:  python3dist(matplotlib)
BuildRequires:  python3dist(pivy)

# Packages separated because they are noarch, but not optional so require them
# here.
Requires:       %{name}-data = %{version}-%{release}

Requires:       python3dist(pivy)
Requires:       python3dist(matplotlib)
Requires:       python3dist(pycollada)
Requires:       python3-pyside6
Requires:       python3-shiboken6
Requires:       openscad

Provides:       bundled(smesh)

%description
FreeCAD is a general purpose Open Source 3D CAD/MCAD/CAx/CAE/PLM modeler, aimed
directly at mechanical engineering and product design but also fits a wider
range of uses in engineering, such as architecture or other engineering
specialties. It is a feature-based parametric modeler with a modular software
architecture which makes it easy to provide additional functionality without
modifying the core system.


%package data
Summary:        Data files for FreeCAD
Group:          Graphics/3D
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}
Requires:       qttools6-assistant

%description data
Data files for FreeCAD.


%prep
%autosetup -p1 -n %{srcname}-%{version}%{?prerel:%prerel}

# Removed bundled libraries
#rm -rf src/3rdParty
%if %{with zipios}
rm -rf src/zipios++
%endif
%if %{with pycxx}
rm -rf src/CXX
%endif


%build
%cmake -DENABLE_DEVELOPER_TESTS=OFF \
       -DCMAKE_INSTALL_PREFIX=%{_libdir}/%{name} \
       -DCMAKE_INSTALL_LIBDIR=%{_libdir}/%{name}/lib \
       -DCMAKE_INSTALL_DATADIR=%{_datadir}/%{name} \
       -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
       -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir} \
       -DRESOURCEDIR=%{_datadir}/%{name} \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DCOIN3D_INCLUDE_DIRS=%{_includedir}/Coin4 \
       -DCOIN3D_DOC_PATH=%{_docdir}/Coin4/html \
       -DFREECAD_USE_PYBIND11=TRUE \
       -DFREECAD_USE_EXTERNAL_PIVY=TRUE \
       -DUSE_OCC=TRUE \
       -DFREECAD_USE_EXTERNAL_SMESH=FALSE \
       -DSMESH_INCLUDE_DIR=%{_includedir}/smesh \
       -DFREECAD_USE_EXTERNAL_ONDSELSOLVER=TRUE \
       %if %{with zipios}
       -DFREECAD_USE_EXTERNAL_ZIPIOS=TRUE \
       %else
       -DFREECAD_USE_EXTERNAL_ZIPIOS=FALSE \
       %endif
       %if %{with pycxx}
       -DPYCXX_INCLUDE_DIR=$(pkg-config --variable=includedir PyCXX) \
       -DPYCXX_SOURCE_DIR=$(pkg-config --variable=srcdir PyCXX) \
       %endif
       %{!?with_web:-DBUILD_WEB:BOOL=OFF} \
       -DMEDFILE_INCLUDE_DIRS=%{_includedir}/med \
       -DOPENMPI_INCLUDE_DIRS=%{_includedir} \
       -DBUILD_QT5=OFF \
       -DFREECAD_QT_VERSION=6 \
       -DPYTHON_EXECUTABLE=%{__python3} \
       -DSHIBOKEN_INCLUDE_DIR=%{_includedir}/shiboken6/ \
       -DSHIBOKEN_LIBRARY=%{_libdir}/libshiboken6.abi3.so \
       -DPYSIDE_INCLUDE_DIR=%{_includedir}/PySide6/ \
       -DPYSIDE_LIBRARY=%{_libdir}/libpyside6.abi3.so \
       -DBUILD_ENABLE_CXX_STD="C++17"

%cmake_build


%install
%cmake_install

# Launchers in /usr/bin
mkdir -p %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/FreeCAD << EOF
#!/bin/bash
LD_LIBRARY_PATH=%{_libdir}/freecad/lib %{_libdir}/freecad/bin/FreeCAD "\$@"
EOF

cat > %{buildroot}%{_bindir}/FreeCADCmd << EOF
#!/bin/bash
LD_LIBRARY_PATH=%{_libdir}/freecad/lib %{_libdir}/freecad/bin/FreeCADCmd "\$@"
EOF

chmod a+rx %{buildroot}%{_bindir}/FreeCAD
chmod a+rx %{buildroot}%{_bindir}/FreeCADCmd

# Move mis-installed files to the right location
# Need to figure out if FreeCAD can install correctly at some point.
mkdir -p %{buildroot}%{_datadir}
mv %{buildroot}%{_libdir}/%{name}/share/* \
   %{buildroot}%{_datadir}

# Install man page
install -pD -m 0644 %{SOURCE102} \
    %{buildroot}%{_mandir}/man1/%{name}.1

# Symlink manpage to other binary names
pushd %{buildroot}%{_mandir}/man1
ln -sf %{name}.1.gz FreeCAD.1.xz
ln -sf %{name}.1.gz FreeCADCmd.1.xz
popd

rm -f %{buildroot}%{_datadir}/pixmaps/freecad.xpm

%files
%license LICENSE
%doc README.md
%{_bindir}/*
%{_metainfodir}/org.%{name}.%{srcname}.metainfo.xml
%{_datadir}/applications/org.%{name}.%{srcname}.desktop
%{_iconsdir}/hicolor/*/apps/org.%{name}.%{srcname}.png
%{_iconsdir}/hicolor/scalable/apps/org.%{name}.%{srcname}.svg
%{_iconsdir}/hicolor/scalable/mimetypes/application-x-extension-fcstd.svg
%{_datadir}/mime/packages/org.%{name}.%{srcname}.xml
%{_datadir}/thumbnailers/%{srcname}.thumbnailer
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/bin/
%{_libdir}/%{name}/include/E57Format/E57Export.h
%{_libdir}/%{name}/lib/
%{_libdir}/%{name}/Ext/
%{_libdir}/%{name}/Mod/
%{_mandir}/man1/*.1.*
%pycached %{python3_sitelib}/freecad/*.py

%files data
%{_datadir}/%{name}/
%{_docdir}/%{name}/{LICENSE.html,ThirdPartyLibraries.html}
