%define oname       FreeImage
%define srcver      %(echo %{version} | tr -d .)

%define major       3
%define libname     %mklibname %{name} %{major}
%define libname_fip %mklibname %{name}plus %{major}
%define develname   %mklibname %{name} -d

Name:           freeimage
# (akien) We used to have version 3.15.4 badly named 3.154,
# so an epoch was needed to transition to 3.17.0.
Epoch:          1
Version:        3.18.0
Release:        %mkrel 12
Summary:        Multi-format image decoder library
# freeimage is triple-licensed, see
# https://freeimage.sourceforge.net/license.html
# https://lists.fedoraproject.org/pipermail/legal/2013-October/002271.html
License:        GPLv2 or GPLv3 or MPLv1.0
Group:          System/Libraries
URL:            https://freeimage.sourceforge.net/
Source0:        https://downloads.sourceforge.net/freeimage/%{oname}%{srcver}.zip

# Patches synced with Debian (they do a better job than Fedora on freeimage)
Patch0:         Disable-vendored-dependencies.patch
Patch1:         Use-system-dependencies.patch
Patch2:         Fix-macro-redefinition-for-64-bit-integer-types.patch
Patch3:		Fix-compatibility-with-system-libpng.patch
Patch4:		Disable-usage-of-HTML-timestamps-in-doxygen.patch
Patch5:		Disable-testing-of-JPEG-transform.patch
Patch6:		Disable-testing-of-JXR-MemIO.patch
Patch7:         Fix-encoding-of-fi-header.patch
Patch8:		Fix-libraw-compilation.patch
Patch9:         freeimage-libraw-0.21.patch

# Fix trying to change file ownership
Patch10:        FreeImage-3.17.0-mga-makeinstall.patch

# Patch from Gentoo to fix build error in JPEG plugin
Patch11:	freeimage-3.15.4-rename-static.patch

# Backport fixes for CVE-2019-12211 and 2019-12213
# https://sourceforge.net/p/freeimage/svn/1825/tree//FreeImage/trunk/Source/FreeImage/PluginTIFF.cpp?diff=5a0ca8dd5a4a1f6b3942a079:1824
Patch12:	CVE-2019-12211_2019-12213.patch

Patch13:	freeimage-openexr3.patch
Patch14:	freeimage-libtiff44.patch
# Proposed fix for CVE-2021-33367
Patch15:	CVE-2021-33367.patch
Patch16:	CVE-2023-47995.patch
Patch17:	CVE-2023-47997.patch
Patch18:	mga-fix-linking-with-libwebp-1.3.2.patch

BuildRequires:  jxrlib-devel
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmng)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(OpenEXR)

%description
FreeImage is an Open Source library project for developers who would
like to support popular graphics image formats like PNG, BMP, JPEG,
TIFF and others as needed by today's multimedia applications.
FreeImage is easy to use, fast, multithreading safe and cross-platform.

#----------------------------------------------------------------------

%package -n %{libname}
Summary:        Multi-format image decoder library
Group:          System/Libraries

%description -n %{libname}
FreeImage is an Open Source library project for developers who would
like to support popular graphics image formats like PNG, BMP, JPEG,
TIFF and others as needed by today's multimedia applications.
FreeImage is easy to use, fast, multithreading safe, compatible with
all 32-bit versions of Windows, and cross-platform (works both with
Linux and Mac OS X).

#----------------------------------------------------------------------

%package -n %{libname_fip}
Summary:        Multi-format image decoder library
Group:          System/Libraries

%description -n %{libname_fip}
FreeImage is an Open Source library project for developers who would
like to support popular graphics image formats like PNG, BMP, JPEG,
TIFF and others as needed by today's multimedia applications.
FreeImage is easy to use, fast, multithreading safe, compatible with
all 32-bit versions of Windows, and cross-platform (works both with
Linux and Mac OS X).

#----------------------------------------------------------------------

%package -n %{develname}
Summary:        Development tools for programs using FreeImage
Group:          Development/C
Requires:       %{libname} = %{epoch}:%{version}-%{release}
Requires:       %{libname_fip} = %{epoch}:%{version}-%{release}
Provides:       %{name}-devel = %{epoch}:%{version}-%{release}
Provides:       %{name}plus-devel = %{epoch}:%{version}-%{release}

%description -n %{develname}
This package contains the header files and libraries needed for
developing programs using the FreeImage library.

#----------------------------------------------------------------------

%prep
%autosetup -p1 -n %{oname}

# Remove included libs to make sure these don't get used during compilation
rm -rf Source/Lib* Source/OpenEXR Source/ZLib

%build
%global optflags %{optflags} -fPIC
%set_build_flags

sh ./gensrclist.sh
sh ./genfipsrclist.sh
%make_build -f Makefile.gnu
%make_build -f Makefile.fip

%install
%make_install -f Makefile.gnu \
  INCDIR=%{buildroot}%{_includedir} \
  INSTALLDIR=%{buildroot}%{_libdir}

%make_install -f Makefile.fip \
  INCDIR=%{buildroot}%{_includedir} \
  INSTALLDIR=%{buildroot}%{_libdir}

# We don't package static libs
find %{buildroot}%{_libdir} -name '*.a' -delete

%files -n %{libname}
%doc Whatsnew.txt README.linux
%license license-*.txt
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}-%{version}.so

%files -n %{libname_fip}
%doc Whatsnew.txt README.linux
%license license-*.txt
%{_libdir}/lib%{name}plus.so.%{major}
%{_libdir}/lib%{name}plus-%{version}.so

%files -n %{develname}
%{_includedir}/%{oname}.h
%{_includedir}/%{oname}Plus.h
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}plus.so
