# The fritzing-app repo does not contain a tag for v1.0.4
# The app commit we're using is dated 2024-10-07
%define git      a8c6ef7cf66f7a42b9b233d6137f1b70a9573a25
%define gitparts 76235099ed556e52003de63522fdd74e61d53a36

Name:           fritzing
Version:        1.0.4
Release:        %mkrel 1
Summary:        Electronic Design Automation software; from prototype to product
License:        GPLv3+, CC-BY-SA
Group:          Sciences/Other
Url:            https://fritzing.org/
Source0:        https://github.com/fritzing/fritzing-app/archive/%{git}/%{name}-app-%{git}.tar.gz
# The fritzing-parts repository no longer uses git tags for marking releases.
# There is a "release_0.9.6" branch in the repository, though.
# Take the latest commit from that branch (as of 2023-12-20).
Source1:        https://github.com/fritzing/fritzing-parts/archive/%{gitparts}/%{name}-parts-%{gitparts}.tar.gz
Source2:        https://github.com/svgpp/svgpp/archive/v1.3.1/svgpp-1.3.1.tar.gz
# Taken from fedora until a fix for issue 3796
Source3:        parts.db
# Mageia-specific patch to disable internal auto-updating feature
Patch0:         0000-disable-autoupdate.patch
# Use the system quazip library instead of the bundled one and
# upgrade to Quazip Qt6 V1.x
Patch1:         0001-unbundle-quazip.patch
# Remove references to example sketches that use twitter4j library
Patch2:         0002-remove-twitter4j.patch
# use system libgit2
Patch3:         fritzing-0.9.10-use-system-libgit2.patch
# use system polyclipping (clipper)
Patch4:         0003-unbundle-clipper.patch

BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(ngspice)
BuildRequires:  pkgconfig(polyclipping)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6SerialPort)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6SvgWidgets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(QuaZip-Qt6)
BuildRequires:  boost-devel
BuildRequires:  desktop-file-utils
BuildRequires:  qttools6

# mga#24115
Requires:       qt6-database-plugin-sqlite

%description
Fritzing is an open-source initiative to support designers, artists,
researchers and hobbyists to take the step from physical prototyping
to actual product. It is in the spirit of Processing and Arduino which
allows users to document their Arduino and other electronic-based
prototypes, and to create a PCB layout for manufacturing.

%prep
%setup -q -n %{name}-app-%{git}
tar -xf %{SOURCE1}
mv %{name}-parts-%{gitparts}/ parts/

tar -xf %{SOURCE2}

# Remove some GitHub-specific files
rm -rf .github || true
rm -rf parts/.github || true

# The TwitterSaurus examples use (a bundled) twitter4j library, whose license
# is incompatible with Mageia.
rm -f sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Fritzing/TwitterSaurus.fzz
rm -f sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Processing/twitter4j-core-2.2.5.jar
rm -rf sketches/core/Fritzing\ Creator\ Kit\ DE+EN/creator-kit-*/Processing/TwitterSaurus*
rm -f sketches/core/obsolete/TwitterSaurus.fzz

# Remove a <url> entry which causes the appstream file to fail validation.
sed -e '/<url type="forum">/d' -i 'org.fritzing.Fritzing.appdata.xml'

# Detect system ngspice header library
sed -i 's|NGSPICEPATH = ../../ngspice-42|NGSPICEPATH = %{_includedir}/ngspice|' pri/spicedetect.pri
# Detect bundled svgpp header-only library
sed -i 's|$$PWD/../../svgpp-1.3.1|$$PWD/../svgpp-1.3.1|g' pri/svgppdetect.pri

# Fix qt version check (upstream recommend 6.5.3 at use, why???)
sed -i 's|QT_MOST=6.5.10|QT_MOST=6.8.10|' phoenix.pro

%autopatch -p1

%build
# build translations
%{_qt6_libexecdir}/lrelease-pro phoenix.pro

CXXFLAGS="%{optflags}"
%qmake_qt6
%make_build

./Fritzing -platform minimal -f ./parts -db ./parts/parts.db

%install
%make_install INSTALL_ROOT=%{buildroot}

ln -s %{_bindir}/Fritzing %{buildroot}%{_bindir}/%{name}
cp -f %{buildroot}%{_mandir}/man1/Fritzing.1 %{buildroot}%{_mandir}/man1/fritzing.1

%files
%doc README.md
%license LICENSE.GPL2 LICENSE.GPL3 LICENSE.CC-BY-SA
%{_bindir}/Fritzing
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.%{name}.Fritzing.desktop
%{_metainfodir}/org.%{name}.Fritzing.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/*
