#
# Please do not update/rebuild/touch this package before asking first
# to neoclust and/or daviddavid
# This package is part of the KDE Stack.
#

%define rel 1

%bcond_without qt5
%bcond_without qt6

Name:           futuresql
Version:        0.1.1
Release:        %mkrel 2
Summary:        Non-blocking database framework for Qt
License:        LGPL-2.1 or LGPL-3.0
Group:          Graphical desktop/KDE
URL:            https://api.kde.org/futuresql/html/index.html
Source0:        https://download.kde.org/stable/futuresql/%{name}-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  cmake(ECM)

### Qt5 build dependencies
%if %{with qt5}
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(QCoro5Core)
BuildRequires:  cmake(QCoro5)
%endif
### Qt6 build dependencies
%if %{with qt6}
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(QCoro6Core)
BuildRequires:  cmake(QCoro6)
%endif

%description
A non-blocking database framework for Qt.

FutureSQL was in part inspired by Diesel, and provides a higher level of
abstraction than QtSql. Its features include non-blocking database access
by default, relatively boilderplate-free queries, automatic database
migrations and simple mapping to objects.

In order to make FutureSQL's use of templates less confusing, FutureSQL
uses C++20 concepts, and requires a C++20 compiler.

#--------------------------------------------------------------------
%if %{with qt5}

%define major_qt5   0
%define libname_qt5 %mklibname futuresql5_ %{major_qt5}

%package -n %{libname_qt5}
Summary:        Non-blocking database framework for Qt5
Group:          System/Libraries

%description -n %{libname_qt5}
A non-blocking database framework for Qt5.

FutureSQL was in part inspired by Diesel, and provides a higher level of
abstraction than QtSql. Its features include non-blocking database access
by default, relatively boilderplate-free queries, automatic database
migrations and simple mapping to objects.

In order to make FutureSQL's use of templates less confusing, FutureSQL
uses C++20 concepts, and requires a C++20 compiler.

%files -n %{libname_qt5}
%{_libdir}/libfuturesql5.so.%{major_qt5}{,.*}

#--------------------------------------------------------------------

%define devname_qt5 %mklibname futuresql5 -d

%package -n %{devname_qt5}
Summary:        Development files for Qt5 %{name}
Group:          Development/KDE and Qt
Requires:       %{libname_qt5} = %{version}-%{release}
Provides:       qt5-%{name}-devel = %{version}-%{release}

%description -n %{devname_qt5}
This package contains development files for Qt5 %{name}.

%files -n %{devname_qt5}
%{_includedir}/FutureSQL5/
%{_libdir}/libfuturesql5.so
%{_libdir}/cmake/FutureSQL5/

%endif
#--------------------------------------------------------------------
%if %{with qt6}

%define major_qt6   0
%define libname_qt6 %mklibname futuresql6_ %{major_qt6}

%package -n %{libname_qt6}
Summary:        Non-blocking database framework for Qt6
Group:          System/Libraries

%description -n %{libname_qt6}
A non-blocking database framework for Qt6.

FutureSQL was in part inspired by Diesel, and provides a higher level of
abstraction than QtSql. Its features include non-blocking database access
by default, relatively boilderplate-free queries, automatic database
migrations and simple mapping to objects.

In order to make FutureSQL's use of templates less confusing, FutureSQL
uses C++20 concepts, and requires a C++20 compiler.

%files -n %{libname_qt6}
%{_libdir}/libfuturesql6.so.%{major_qt6}{,.*}

#--------------------------------------------------------------------

%define devname_qt6 %mklibname futuresql6 -d

%package -n %{devname_qt6}
Summary:        Development files for Qt6 %{name}
Group:          Development/KDE and Qt
Requires:       %{libname_qt6} = %{version}-%{release}
Provides:       qt6-%{name}-devel = %{version}-%{release}

%description -n %{devname_qt6}
This package contains development files for Qt6 %{name}.

%files -n %{devname_qt6}
%{_includedir}/FutureSQL6/
%{_libdir}/libfuturesql6.so
%{_libdir}/cmake/FutureSQL6/

%endif
#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
### Build Qt5 ###
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_qt5 -DQT_MAJOR_VERSION:STRING=5
%cmake_build
%endif

### Build Qt6 ###
%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_qt6 -DQT_MAJOR_VERSION:STRING=6
%cmake_build
%endif

%install
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_install
%endif
