%define rel		4
%define fwsnortlibdir	%{_prefix}/lib/%{name}
%define fwsnortlogdir	/var/log/fwsnort

### get the first @INC directory that includes the string "linux".
### This may be 'i386-linux', or 'i686-linux-thread-multi', etc.
%define fwsnortmoddir	`perl -e '$path=q|i386-linux|; for (@INC) { if($_ =~ m|.*/(.*linux.*)|) {$path = $1; last; }} print $path'`

Name:		fwsnort
Version:	1.6.8
Release:	%mkrel %{rel}
Summary:	Translates Snort rules into equivalent iptables rules
License:	GPLv2+
Group:		System/Servers
Url:		https://www.cipherdyne.org/fwsnort/
Source0:	https://www.cipherdyne.org/fwsnort/download/%{name}-%{version}.tar.bz2
Source1:	logrotate.fwsnort
BuildArch:	noarch
Requires:	iptables
BuildRequires:	perl-devel

%description
fwsnort translates Snort rules into equivalent iptables rules and generates
a Bourne shell script that implements the resulting iptables commands. This
ruleset allows network traffic that exhibits Snort signatures to be logged
and/or dropped by iptables directly without putting any interface into
promiscuous mode or queuing packets from kernel to user space. In addition,
fwsnort (optionally) uses the IPTables::Parse module to parse the iptables
ruleset on the machine to determine which Snort rules are applicable to the
specific iptables policy.  After all, if iptables is blocking all inbound
http traffic from external addresses, it is probably not of much use to try
detecting inbound attacks against against tcp/80. By default fwsnort
generates iptables rules that log Snort sid's with --log-prefix to klogd
where the messages can be analyzed with a log watcher such as logwatch or
psad (see https://www.cipherdyne.org/psad). fwsnort relies on the iptables
string match extension to match Snort content fields in the application portion
of ip traffic. Since Snort rules can contain hex data in content fields,
fwsnort implements a patch against iptables-1.2.7a which adds a
"--hex-string" option which will accept content fields such as
"|0d0a5b52504c5d3030320d0a|". fwsnort bundles the latest rule set from
Emerging Threats (https://www.emergingthreats.net/) and also includes all rules
from the Snort-2.3.3 IDS - the final Snort rule set that was released under
the GPL.  fwsnort is able to translate well over 60% of all bundled rules.
For more information about the translation strategy as well as
advantages/disadvantages of the method used by fwsnort to obtain intrusion
detection data, see the README included with the fwsnort sources or browse
to: https://www.cipherdyne.org/fwsnort/

%prep

%setup -q

cp -p %{SOURCE1} .

cd deps
cd IPTables-Parse && perl Makefile.PL PREFIX=%{fwsnortlibdir} LIB=%{fwsnortlibdir}
cd ..
cd NetAddr-IP && perl Makefile.PL PREFIX=%{fwsnortlibdir} LIB=%{fwsnortlibdir}
cd ../..

%build
### build perl modules used by fwsnort
cd deps
make OPTS="%{optflags}" -C IPTables-Parse
make OPTS="%{optflags}" -C NetAddr-IP
cd ..

%install
### config directory
### log directory
mkdir -p %{buildroot}%{fwsnortlogdir}

### fwsnort module dirs
mkdir -p %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/IPTables/Parse
mkdir -p %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/Util
mkdir -p %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP
mkdir -p %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase
mkdir -p %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/NetAddr/IP
mkdir -p %{buildroot}%{fwsnortlibdir}/IPTables

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man8
mkdir -p %{buildroot}%{_sbindir}

### fwsnort config
mkdir -p %{buildroot}%{_sysconfdir}/%{name}

install -m 755 fwsnort %{buildroot}%{_sbindir}/
install -m 644 fwsnort.conf %{buildroot}%{_sysconfdir}/%{name}/
install -m 644 fwsnort.8 %{buildroot}%{_mandir}/man8/

### install perl modules used by fwsnort
cd deps
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/hostenum.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/hostenum.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/compactref.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/compactref.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/nprefix.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/nprefix.al
[ -e NetAddr-IP/blib/lib/auto/NetAddr/IP/.packlist ] && install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/.packlist %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/.packlist
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/re.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/re.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/prefix.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/prefix.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/do_prefix.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/do_prefix.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/wildcard.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/wildcard.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/_compact_v6.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/_compact_v6.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/autosplit.ix %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/autosplit.ix
[ -e NetAddr-IP/blib/lib/auto/NetAddr/IP/Util/Util.so ] && install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/Util/Util.so %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/Util/Util.so
[ -e NetAddr-IP/blib/lib/auto/NetAddr/IP/Util/Util.bs ] && install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/Util/Util.bs %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/Util/Util.bs
[ -e NetAddr-IP/blib/lib/auto/NetAddr/IP/Util/autosplit.ix ] && install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/Util/autosplit.ix %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/Util/autosplit.ix
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/shiftleft.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/shiftleft.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/ipv4to6.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/ipv4to6.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/maskanyto6.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/maskanyto6.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/comp128.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/comp128.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/_deadlen.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/_deadlen.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/sub128.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/sub128.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/notcontiguous.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/notcontiguous.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/bcdn2bin.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/bcdn2bin.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/add128.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/add128.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/ipv6to4.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/ipv6to4.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/_bcdcheck.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/_bcdcheck.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/mask4to6.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/mask4to6.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/_128x2.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/_128x2.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/ipanyto6.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/ipanyto6.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/hasbits.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/hasbits.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/bcdn2txt.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/bcdn2txt.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/slowadd128.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/slowadd128.al
[ -e NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/autosplit.ix ] && install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/autosplit.ix %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/autosplit.ix
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/simple_pack.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/simple_pack.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/bcd2bin.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/bcd2bin.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/bin2bcdn.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/bin2bcdn.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/_bin2bcdn.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/_bin2bcdn.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/bin2bcd.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/bin2bcd.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/_sa128.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/_sa128.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/_bcd2bin.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/_bcd2bin.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/addconst.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/addconst.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/UtilPP/_128x10.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/UtilPP/_128x10.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/mod_version.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/mod_version.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/_splitref.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/_splitref.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/_compV6.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/_compV6.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/inet_any2n.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/inet_any2n.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/_inet_ntop.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/_inet_ntop.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/inet_n2ad.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/inet_n2ad.al
[ -e NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/autosplit.ix ] && install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/autosplit.ix %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/autosplit.ix
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/_packzeros.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/_packzeros.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/inet_n2dx.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/inet_n2dx.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/ipv6_aton.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/ipv6_aton.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/ipv6_ntoa.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/ipv6_ntoa.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/inet_ntoa.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/inet_ntoa.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/InetBase/_inet_pton.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/InetBase/_inet_pton.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/coalesce.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/coalesce.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/re6.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/re6.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/short.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/short.al
install -m 444 NetAddr-IP/blib/lib/auto/NetAddr/IP/_splitplan.al %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/auto/NetAddr/IP/_splitplan.al
install -m 444 NetAddr-IP/blib/lib/NetAddr/IP/InetBase.pm %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/NetAddr/IP/InetBase.pm
install -m 444 NetAddr-IP/blib/lib/NetAddr/IP/UtilPP.pm %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/NetAddr/IP/UtilPP.pm
install -m 444 NetAddr-IP/blib/lib/NetAddr/IP/Util.pm %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/NetAddr/IP/Util.pm
install -m 444 NetAddr-IP/blib/lib/NetAddr/IP/Lite.pm %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/NetAddr/IP/Lite.pm
install -m 444 NetAddr-IP/blib/lib/NetAddr/IP/Util_IS.pm %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/NetAddr/IP/Util_IS.pm
install -m 444 NetAddr-IP/blib/lib/NetAddr/IP.pm %{buildroot}%{fwsnortlibdir}/%{fwsnortmoddir}/NetAddr/IP.pm
install -m 444 IPTables-Parse/blib/lib/IPTables/Parse.pm %{buildroot}%{fwsnortlibdir}/IPTables/Parse.pm
cd ..

### install snort rules files
cp -r deps/snort_rules %{buildroot}%{_sysconfdir}/%{name}

### install fwsnort logrotate files
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 logrotate.fwsnort %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%pre
### not used

%post
### not used

%preun
### not used

%files
%doc ChangeLog VERSION README CREDITS TODO
%license LICENSE
%dir %{fwsnortlogdir}
%{_sbindir}/*
%{_mandir}/man8/*

%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/fwsnort.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}

%dir %{_sysconfdir}/%{name}/snort_rules
%config(noreplace) %{_sysconfdir}/%{name}/snort_rules/*

%{_prefix}/lib/%{name}
