%define _mariadb_ver	11.7.2

Name:		galera
Version:	26.4.21
Release:	%mkrel 1
Summary:	Synchronous multi-master wsrep provider (replication engine)
Group:		System/Servers
License:	GPLv2
URL:		https://galeracluster.com/
# Actually, the truth is, we do use galera source tarball provided by MariaDB on
# following URL (without macros):
# https://mirror.vpsfree.cz/mariadb/mariadb-%%{_mariadb_ver}/galera-26.4.21/src/galera-26.4.21.tar.gz
Source0:	https://mirror.vpsfree.cz/mariadb/mariadb-%{_mariadb_ver}/%{name}-%{version}/src/%{name}-%{version}.tar.gz
Source1:	garbd.service
Source2:	garbd-wrapper
Patch0:		cmake_paths.patch
BuildRequires:	gcc-c++
BuildRequires:	cmake
BuildRequires:	systemd
BuildRequires:	asio-devel
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(check)
BuildRequires:	pkgconfig(openssl) >= 1.1
Requires:	nmap
Requires:	procps-ng

Requires(post):		systemd
Requires(preun):	systemd

%description
Galera is a fast synchronous multi-master wsrep provider (replication engine)
for transactional databases and similar applications. For more information
about wsrep API see https://launchpad.net/wsrep. For a description of Galera
replication engine see http://www.codership.com.

%prep
%autosetup -p1

%build
%cmake \
       -DINSTALL_LAYOUT=RPM \
       -DCMAKE_RULE_MESSAGES=OFF \
       -DINSTALL_DOCDIR="share/doc/%{name}/" \
       -DINSTALL_GARBD="sbin" \
       -DINSTALL_GARBD-SYSTEMD="sbin" \
       -DINSTALL_CONFIGURATION="/etc/sysconfig/" \
       -DINSTALL_SYSTEMD_SERVICE="lib/systemd/system" \
       -DINSTALL_LIBDIR="%{_lib}/%{name}" \
       -DINSTALL_MANPAGE="share/man/man8"

%cmake_build

%install
%cmake_install

# PATCH 1:
#   Change the Systemd service name from "garb" to "garbd"
#
#   The Galera upstream uses name "garb" for the service while providing "garbd" alias
#   Mageia downstream packaging historically used "garbd" name for the service.
#
#   Let's stick with the Mageia legacy naming, AND provide an alias to the Galera upstream name
mv %{buildroot}%{_unitdir}/garb.service %{buildroot}%{_unitdir}/garbd.service
sed -i 's/Alias=garbd.service/Alias=garb.service/g' %{buildroot}%{_unitdir}/garbd.service

# PATCH 2:
#   Fix the hardcoded paths
#     In the Systemd service file:
sed -i 's;/usr/bin/garb-systemd;/usr/sbin/garb-systemd;g' %{buildroot}%{_unitdir}/garbd.service
#     In the wrapper script:
sed -i 's;/usr/bin/garbd;/usr/sbin/garbd;g' %{buildroot}%{_sbindir}/garb-systemd

# PATCH 4:
#  Use a dedicated user for the Systemd service
#  To fix an security issue reported by Systemd:
#
## systemd[1]: /usr/lib/systemd/system/garb.service:14: Special user nobody configured, this is not safe!
##   Subject: Special user nobody configured, this is not safe!
##   Defined-By: systemd
##   Support: https://lists.freedesktop.org/mailman/listinfo/systemd-devel
##   Documentation: https://systemd.io/UIDS-GIDS
##
##   The unit garb.service is configured to use User=nobody.
##
##   This is not safe. The nobody user's main purpose on Linux-based
##   operating systems is to be the owner of files that otherwise cannot be mapped
##   to any local user. It's used by the NFS client and Linux user namespacing,
##   among others. By running a unit's processes under the identity of this user
##   they might possibly get read and even write access to such files that cannot
##   otherwise be mapped.
##
##   It is strongly recommended to avoid running services under this user identity,
##   in particular on systems using NFS or running containers. Allocate a user ID
##   specific to this service, either statically via systemd-sysusers or dynamically
##   via the DynamicUser= service setting.
sed -i 's/User=nobody/User=garb/g' %{buildroot}/usr/lib/systemd/system/garbd.service

%post
%_post_service garbd

%preun
%_preun_service garbd

%files
%doc %{_docdir}/%{name}/
%config(noreplace,missingok) %{_sysconfdir}/sysconfig/garb
%{_sbindir}/garbd
#{_sbindir}/garbd-wrapper
# PATCH 3:
#   Make sure the wrapper script is executable
%attr(755, -, -) %{_sbindir}/garb-systemd
%{_unitdir}/garbd.service
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}_smm.so
%{_mandir}/man8/garbd.8*
