%bcond_with pcre
%bcond_with python

%define lib_major	0
%define lib_api 	3.7.2
%define lib_name	%mklibname %{name} %{lib_api} %{lib_major}
%define dev_name	%mklibname %{name} -d

%define script_version 0.3

Name:		ganglia
License:	BSD
Version:	3.7.2
Release:	%mkrel 9
Group:		Monitoring
Summary:	Cluster Toolkit
URL:		https://ganglia.sourceforge.net/
Source:		https://downloads.sourceforge.net/ganglia/%{name}-%{version}.tar.gz
Requires(post):	rpm-helper
Requires(preun): rpm-helper
#Source1:	gmond.conf
Source2:	%{name}-monitor-script-%{script_version}.tar.bz2
Source3:	%{name}-monitor-script.d
Source4:	ganglia-script
Source5:	README.script
Source6:	ganglia-monitor-logrotate.d
Source7:	gmond.service
Source8:	gmetad.service
Patch3:         ganglia-3.7.2-tirpc-hack.patch
Patch4:         ganglia-3.7.2-gcc14-cast.patch
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre)
%endif
BuildRequires:	rpcgen
BuildRequires:	libtirpc-devel
BuildRequires:	pkgconfig(apr-1)
BuildRequires:	pkgconfig(libconfuse)
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	gettext-devel
%if %{with python}
BuildRequires:	pkgconfig(python3)
%endif
BuildRequires:	pkgconfig(librrd)

%description
Ganglia is a scalable, real-time cluster monitoring and execution environment
with all execution requests and cluster statistics expressed in an open
well-defined XML format.

%package 	core
Group:		Monitoring
Summary:	Cluster Core
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description	core
The core package of Ganglia Monitor.

%package	gmetad
Group:		Monitoring
Summary:	Meta daemon
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires:	%name-core = %{version}-%{release}

%description gmetad
Ganglia is a scalable, real-time monitoring and execution environment
with all execution requests and statistics expressed in an open
well-defined XML format.

This gmetad daemon can aggregate monitoring data from several clusters
to form a monitoring grid. It also keeps metric history using the RRD tool.

%package	-n %{dev_name}
Group:		Development/Other
Summary:	Cluster Toolkit Library
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Conflicts:	%{lib_name} < 3.1.7-3
Obsoletes:	%{_lib}ganglia1-devel < 3.6.0-2
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description 	-n %{dev_name}
The Ganglia Monitoring Core library provides a set of
functions that programmers can use to build scalable
cluster or grid applications.

%package 	-n %{lib_name}
Group:		Development/Other
Summary:	Cluster Toolkit Library
Provides:	lib%name = %{version}-%{release}
# Obsolete old wrongly named lib for smooth upgrades
Obsoletes:	%{_lib}ganglia1 < 3.6.0-2
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description	-n %{lib_name}
The Ganglia Monitoring Core library provides a set of
functions that programmers can use to build scalable
cluster or grid applications.

%package	script
Group:		Monitoring
Summary:	Cluster Script
Provides:	%{name}-script = %{version}-%{release}
Requires:	%{name}-core
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description	script
Ganglia Monitor Script is an extrension for Ganglia Monitor.
It's a easy way to add value to monitor for your
Ganglia Monitor.

%prep
%setup -q -T -n %{name}-monitor-script-%{script_version} -b 2
%setup -q -T -n %{name}-%{version} -b 0
%patch -P 3 -p1
%patch -P 4 -p1

%build
touch Makefile.am
aclocal -I m4
autoheader
automake --add-missing --copy --foreign 2>/dev/null
libtoolize --automake --copy
automake --add-missing --copy --foreign
autoconf -f || exit 1
%configure \
%if %{without pcre}
	-with-libpcre=no \
%endif
%if %{without python}
	--disable-python \
%endif
	--disable-static \
	--with-gmetad \
	--enable-status
%__make


%install
mkdir -p %{buildroot}/var/lib/ganglia/rrds

%make_install

install -D -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/gmond.service
install -D -m 644 %{SOURCE8} %{buildroot}%{_unitdir}/gmetad.service

#Disabling setuid
echo "setuid off" >> %{_builddir}/%{name}-%{version}/gmetad/gmetad.conf

install -D -m 755 %{SOURCE4} %{buildroot}%{_bindir}

#script
mkdir -p %{buildroot}%{_datadir}/%{name}-script/script/
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-script-%{version}/
install %{_builddir}/%{name}-monitor-script-%{script_version}/* %{buildroot}%{_datadir}/%{name}-script/script/
install %{SOURCE5} %{buildroot}%{_defaultdocdir}/%{name}-script-%{version}/README

install -D -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/ganglia-monitor-core

%{_builddir}/%{name}-%{version}/gmond/gmond -t > %{buildroot}%{_sysconfdir}/gmond.conf
perl -pi -e 's|name = "unspecified".*|name = "Cluster"|' %{buildroot}%{_sysconfdir}/gmond.conf

%multiarch_binaries %{buildroot}%{_bindir}/ganglia-config

#we don't want these
find %{buildroot} -name "*.la" -delete

#core
%post core
%_post_service gmond

%preun core
%_preun_service gmond

#script
%post script
%_post_service ganglia-script

%preun script
%_preun_service ganglia-script

%post gmetad
%_post_service gmetad
if [ -d "var/lib/ganglia/rrds" ]; then
	echo "gmetad is launched as the nobody user now, changing /var/lib/ganglia/rrds permissions to nobody:nogroup"
	chown -R nobody:nogroup /var/lib/ganglia/rrds
fi

%preun gmetad
%_preun_service gmetad

%files gmetad
%attr(0777,nobody,nogroup) /var/lib/ganglia/rrds
%{_sbindir}/gmetad
%{_unitdir}/gmetad.service
%if %{with python}
%config(noreplace) %{_sysconfdir}/conf.d/modpython.conf
%endif
%config(noreplace) %{_sysconfdir}/gmetad.conf
%{_mandir}/man1/gmetad.1*
%{_mandir}/man1/gmetad.py.1*

%files core
%doc README AUTHORS COPYING gmond/gmond.conf.html
%{_bindir}/gmetric
%{_bindir}/gstat
%multiarch %{multiarch_bindir}/ganglia-config
%{_bindir}/ganglia-config
%{_sbindir}/gmond
%{_unitdir}/gmond.service
%config(noreplace) %{_sysconfdir}/gmond.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/ganglia-monitor-core
%{_mandir}/man1/gmetric.1*
%{_mandir}/man1/gmond.1*
%{_mandir}/man1/gstat.1*
%{_mandir}/man5/gmond.conf.5*

%files -n %{lib_name}
%doc README AUTHORS COPYING
%{_libdir}/libganglia.so.*
%{_libdir}/ganglia/*.so

%files -n %{dev_name}
%doc README AUTHORS COPYING
%{_includedir}/*
%{_libdir}/libganglia.so

%files script
%{_bindir}/ganglia-script
%{_datadir}/%{name}-script
%doc %{_defaultdocdir}/%{name}-script-%{version}/README
