# Check versions release: https://www.gcad3d.org/gCAD3D_log.txt
# grab commit source and archive it: https://github.com/gcad3d/gcad3d/
%define commit  3d80e9d677fe96530afb2ccd89ae8d968acfbd90
%define git_tag 20240628git%(cut -c1-7 <<< %{commit})

%define ARCH %(uname -s)_%(uname -m)

# version 2.48.00: primary GUI-Version set to Gtk2; Gtk3 does not
# support OpenGL-legacy-mode.
%define gtk_ver 2

Name:		gcad3d
Version:	2.60.06
Release:	%mkrel 1
Summary:	A 3D CAD CAM application
Group:		Graphics/3D
License:	GPLv3+
URL:		https://www.gcad3d.org/
Source0:	https://github.com/gcad3d/gcad3d/archive/%{commit}/%{name}-%{version}-%{git_tag}.tar.gz
ExclusiveArch:	%{ix86} x86_64
BuildRequires:	ctags
BuildRequires:	pkgconfig(gtk+-%{gtk_ver}.0)
BuildRequires:	pkgconfig(gtkgl-2.0)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	gcc-c++

Requires:	tar
Requires:	zenity

%description
gCAD3D is a 3D CAD CAM application that features an integrated 3D OpenGL
viewer, a program interpreter for geometry and NC-commands in 3D, an
integrated NC-processor, and a programming interface for user programs.

It can:
-Import and display data from Iges, Step, wire frame and solid objects
-Create and modify wire frame elements
-Create surfaces
-Create simple solid bodies
-Assemble user-created ancillary programs
-Export wire frame elements as DXF and Iges

%prep
%autosetup -p1 -n %{name}-%{commit}

# Set interface
echo gtk%{gtk_ver} > src/UIX/gcad_gui_version
echo gtk%{gtk_ver} > src/UIX/gcad_gui_version_UIX

# Set bin/build directory dirs
sed -e "s|gcad_dir_bin=\${HOME}.*|gcad_dir_bin=\"\${gcad_dir_bas}\${HTYP}/\"|" \
    -i src/UIX/devbase.sh

# Disable look up for unavailable/unneeded GLB.h
sed -e 's|\(^#include "../gui_gtk2/GLB.*$\)|// \1|' -i src/gui_gtk2/gtkgl_bnd.c

%build
pushd src/UIX
./do complete
popd

# Clean up
find %{ARCH} -type f -name "*.o" -delete
rm -f doc/msg/Readme

%install
install -d %{buildroot}%{_libdir}/%{name}/plugins{,/cut1}
install -d %{buildroot}%{_datadir}/%{name}/doc/{html,msg}
install -d %{buildroot}%{_datadir}/%{name}/icons

install -m 0755 %{ARCH}/gCAD3D %{buildroot}%{_libdir}/%{name}/
install -m 0755 %{ARCH}/GUI_* %{buildroot}%{_libdir}/%{name}/
install -m 0644 %{ARCH}/*.so %{buildroot}%{_libdir}/%{name}/
install -m 0644 %{ARCH}/plugins/*.so %{buildroot}%{_libdir}/%{name}/plugins/
install -m 0755 %{ARCH}/plugins/cut1/G-Code %{buildroot}%{_libdir}/%{name}/plugins/cut1/
install -m 0644 icons/{*.png,*.xpm,*.bmp} %{buildroot}%{_datadir}/%{name}/icons/
install -m 0644 doc/html/{*.htm,*.jpg,*.png,*.js} %{buildroot}%{_datadir}/%{name}/doc/html/
install -m 0644 doc/msg/*.txt %{buildroot}%{_datadir}/%{name}/doc/msg/
install -m 0644 packages/examples.gz %{buildroot}%{_datadir}/%{name}/

install -Dm 644 src/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 644 icons/gCAD3D.xpm %{buildroot}%{_datadir}/pixmaps/%{name}.xpm

# recreate startup script
echo "#! /bin/sh" > src/%{name}
echo "export LD_LIBRARY_PATH=%{_libdir}/%{name}" >> src/%{name}
echo "%{_libdir}/%{name}/gCAD3D \$*" >> src/%{name}
install -d %{buildroot}%{_bindir}
install -m 755 src/%{name} %{buildroot}%{_bindir}/%{name}

%files
%doc README.md doc/gCAD3D_log.txt
%license LICENSE LICENSE_GPLv3.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm
%{_libdir}/%{name}/
%{_datadir}/%{name}/
