%global __requires_exclude devel\\\(libogdi31.*\\\)|devel\\\(libcfitsio.*\\\)|libgrass

# We don't want to provide private Python extension libs
%global __provides_exclude_from ^%{python3_sitearch}/.*\.so$

%define major          36
%define libname        %mklibname %{name} %{major}
%define libnamedev     %mklibname %{name} -d

%define ogdidir %{_includedir}
%define ogdidir %{_includedir}/ogdi

Name:           gdal
Version:        3.10.2
Release:        %mkrel 4
Summary:        The Geospatial Data Abstraction Library (GDAL)
Group:          Sciences/Geosciences
License:        MIT
URL:            https://gdal.org/
Source0:        https://github.com/OSGeo/gdal/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  swig
BuildRequires:  gettext-devel
BuildRequires:  giflib-devel
BuildRequires:  hdf5-devel
BuildRequires:  mysql-devel
BuildRequires:  postgresql-devel
BuildRequires:  cmake(g2c)
BuildRequires:  pkgconfig(blosc)
BuildRequires:  pkgconfig(cryptopp)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libgeotiff)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(proj) >= 4.4.7
BuildRequires:  pkgconfig(jasper)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(geos)
BuildRequires:  pkgconfig(freexl)
BuildRequires:  pkgconfig(netcdf) >= 3.6.2
BuildRequires:  pkgconfig(ogdi)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(spatialite)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(Lerc)
BuildRequires:  pkgconfig(odbc)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libdeflate)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  pkgconfig(libpodofo)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(qhull)
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(gta)
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(charls)
BuildRequires:  pkgconfig(shapelib)

%description
The Geospatial Data Abstraction Library (GDAL) is a unifying
C/C++ API for accessing raster geospatial data, and currently
includes formats like GeoTIFF, Erdas Imagine, Arc/Info
Binary, CEOS, DTED, GXF, and SDTS. It is intended to provide
efficient access, suitable for use in viewer applications,
and also attempts to preserve coordinate systems and metadata.
Python, C, and C++ interfaces are available.

%package plugins
Summary:        Drivers information for GDAL library
Group:          Sciences/Geosciences

# ease upgrade mga9 -> mga10
# soversion 32/33 contained the drivers file and thus will cause a conflict
Conflicts:      %{_lib}gdal32 < 3.6.1-5
Conflicts:      %{_lib}gdal33 < 3.7.2-3

%description plugins
Drivers information for GDAL library.

%package -n     python3-gdal
Summary:        The Python 3 bindings for the GDAL library
Group:          Development/Python
Requires:       python3dist(numpy)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-numpy-devel
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(breathe)

%description -n python3-gdal
The Python 3 bindings for the GDAL library.

%package -n     %{libname}
Summary:        Libraries required for the GDAL library
Group:          System/Libraries
Provides:       lib%{name} = %{version}
Requires:       gdal-plugins >= %{version}-%{release}

%description -n %{libname}
Libraries required for the GDAL library.

%package -n     %{libnamedev}
Summary:        Development files for using the GDAL library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}
Provides:       %{name}-devel = %{version}

%description -n %{libnamedev}
Development files for using the GDAL library.

%prep
%autosetup -p1

sed -i 's|libdir=\${exec_prefix}/lib|libdir=\${exec_prefix}/%{_lib}|' cmake/template/gdal.pc.in

%build
%cmake -DCMAKE_CXX_STANDARD=20 \
       -DENABLE_GDAL_PLUGINS:BOOL=ON \
       -DGDAL_USE_OPENCL:BOOL=ON
%cmake_build

%install
%cmake_install

%files
%doc NEWS.md VERSION
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/%{name}/
%{_datadir}/bash-completion/completions/*
%exclude %{_bindir}/gdal-config
%exclude %{_mandir}/man1/gdal-config.1*

%files plugins
%{_libdir}/gdalplugins/

%files -n %{libnamedev}
%{_bindir}/%{name}-config
%{_mandir}/man1/%{name}-config.1*
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/gdal
%{_includedir}/*.h

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n python3-gdal
%doc swig/python/README.rst
%{python3_sitearch}/*
