Name:           gerbera
Version:        2.4.1
Release:        %mkrel 1
Summary:        UPnP Media Server
License:        GPLv2 and MIT and OFL
Group:          System/Servers
Url:            https://gerbera.io
Source0:        https://github.com/gerbera/gerbera/archive/v%{version}/%{name}-%{version}.tar.gz
Source2:        gerbera.sysconfig
Patch1:         gerbera-sysconfig.patch

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(duktape)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libebml)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libffmpegthumbnailer)
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(libmatroska)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(spdlog)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)

%{?systemd_requires}
Requires:       %{name}-data = %{version}-%{release}
Obsoletes:      mediatomb < 0.12.1-26

%description
Gerbera is a UPnP media server which allows you to stream your digital
media through your home network and consume it on a variety of UPnP
compatible devices.

%package data
Summary:        Data files for Gerbera
BuildArch:      noarch

%description data
Data files for the Gerbera media server.

%prep
%autosetup -n %{name}-%{version} -p1

# use Release as default serial number in device description
sed -i -e '/DESC_SERIAL_NUMBER/s/".*"/"%{release}"/' src/config/config_definition.cc

%build
%cmake \
    -DWITH_JS:BOOL=YES \
    -DWITH_MYSQL:BOOL=NO \
    -DWITH_CURL:BOOL=YES \
    -DWITH_TAGLIB:BOOL=YES \
    -DWITH_MAGIC:BOOL=YES \
    -DWITH_AVCODEC:BOOL=YES \
    -DWITH_EXIF:BOOL=YES \
    -DWITH_EXIV2:BOOL=YES \
    -DWITH_FFMPEGTHUMBNAILER:BOOL=YES \
    -DWITH_INOTIFY:BOOL=YES \
    -DWITH_SYSTEMD:BOOL=YES \
    -DUPNP_HAS_REUSEADDR:BOOL=YES
%cmake_build

%install
%cmake_install

# default config
mkdir -p %{buildroot}%{_sysconfdir}/gerbera/
%{_vpath_builddir}/gerbera --create-config > %{buildroot}%{_sysconfdir}/gerbera/config.xml
sed -i -e 's!\(<home>\).*\(</home>\)!\1%{_sysconfdir}/gerbera\2!' %{buildroot}%{_sysconfdir}/gerbera/config.xml

# sysconfig
install -p -D -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

# make all files under %%_sysconfdir/gerbera owned by
# this package
mkdir -p %{buildroot}%{_sysconfdir}/gerbera
touch %{buildroot}%{_sysconfdir}/gerbera/{gerbera.db,gerbera.html}

%pre
%_pre_useradd %{name} %{_sysconfdir}/gerbera %{_sbindir}/nologin

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%systemd_postun_with_restart gerbera.service

%files
%license LICENSE.md
%doc AUTHORS CONTRIBUTING.md ChangeLog.md
%attr(-,gerbera,gerbera) %dir %{_sysconfdir}/%{name}/
%attr(-,gerbera,gerbera) %config(noreplace) %{_sysconfdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/%{name}
%{_mandir}/man1/*
%{_unitdir}/gerbera.service

%files data
%dir %{_datadir}/gerbera/
%{_datadir}/gerbera/mysql.sql
%{_datadir}/gerbera/mysql-upgrade.xml
%{_datadir}/gerbera/sqlite3.sql
%{_datadir}/gerbera/sqlite3-upgrade.xml
%{_datadir}/gerbera/js/
%{_datadir}/gerbera/web/
