%define oname	getfem

%define major	3
%define libname	%mklibname %{oname} %{major}
%define devname %mklibname %{oname} -d

# No openmpi on 32bits with openmpi 5 in Mageia 10+
%ifarch %{ix86} %{arm32}
%bcond_with mpi
%else
%bcond_without mpi
%endif

%define gittag	4ed33482ba6f2a6e98083a8d0b0ad8860b587f4e
%define gitdate	20240910
%define rel	2

Name:		getfem++
Summary:	Generic and efficient C++ library for finite element methods
Version:	5.4.2
Release:	%mkrel %{rel}.git%{gitdate}
License:	LGPLv2+
Group:		System/Libraries
URL:		https://getfem.org/
# Source0:	https://download-mirror.savannah.gnu.org/releases/getfem/stable/%%{oname}-%%{version}.tar.gz
Source0:    	https://git.savannah.nongnu.org/cgit/getfem.git/snapshot/getfem-%{gittag}.tar.gz
BuildRequires:	blas-devel
BuildRequires:	lapack-devel
BuildRequires:	metis-devel
BuildRequires:	cmake(superlu)
BuildRequires:	pkgconfig(muparser)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(qhull)
BuildRequires:	python3dist(scipy)
%if %{with mpi}
BuildRequires:	python3dist(mpi4py)
%endif
BuildRequires:	python3-numpy-devel

%description
The Getfem++ project focuses on the development of a generic and efficient
C++ library for finite element methods. The goal is to provide a library
allowing the computation of any elementary matrix (even for mixed finite
element methods) on the largest class of methods and elements, and for
arbitrary dimension (i.e. not only 2D and 3D problems).

%package -n %{devname}
Summary:	Development files and headers for %{name}
Group:		Development/C++
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}
Provides:	gmm-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Recommends:	%{oname}-examples = %{version}-%{release}

%description -n %{devname}
This package contains the development files and headers for %{name}.

%files -n %{devname}
%{_bindir}/getfem-config
%{_includedir}/gmm/
%{_includedir}/getfem/
%{_libdir}/libgetfem.so

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries

%description -n %{libname}
The Getfem++ project focuses on the development of a generic and efficient
C++ library for finite element methods. The goal is to provide a library
allowing the computation of any elementary matrix (even for mixed finite
element methods) on the largest class of methods and elements, and for
arbitrary dimension (i.e. not only 2D and 3D problems).

%files -n %{libname}
%doc README
%{_libdir}/libgetfem.so.%{major}{,.*}

%package -n python3-getfem
Group:		Development/Python
Summary:	Python 3 binding for %{name}
%if %{with mpi}
Requires:	python3dist(mpi4py)
%endif
Requires:	python3dist(numpy)
Requires:	python3dist(scipy)

Provides:	python-getfem = %{version}-%{release}

%description -n python3-getfem
Python 3 binding for %{name}.

%files -n python3-getfem
%ifarch x86_64 aarch64
%dir %{python3_sitearch}/getfem
%endif
%dir %{python3_sitelib}/getfem
%{python3_sitearch}/getfem/_getfem*.so
%{python3_sitelib}/getfem/__init__.*
%{python3_sitelib}/getfem/getfem.py*
%{python3_sitelib}/getfem/__pycache__/

%package -n %{oname}-examples
Summary:	Examples for %{name}
Group:		Development/C++
BuildArch:	noarch

%description -n %{oname}-examples
This package contains some examples for %{name}.

%files -n %{oname}-examples
%{_datadir}/getfem_toolbox/

#--------------------------------------------------------------------

%prep
%if %{defined gittag}
%autosetup -p1 -n getfem-%{gittag}
%else
%autosetup -p1 -n getfem-%{version}
%endif

%build
autoreconf -vfi
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
	--enable-metis \
	--enable-python \
	--enable-shared \
	--disable-dependency-tracking \
	--disable-static \
	--disable-scilab \
 	--disable-mumps \
 	--enable-shared  \
	--with-matlab-toolbox-dir=%{_datadir}/getfem_toolbox
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

# Hack around
install -pm 0755 interface/src/python/_getfem*.so %{buildroot}%{python3_sitearch}/getfem/
