%define	major		3
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define lib_ver		%(echo %{version}|sed -e 's/\\.//g')
%define zart_version	d014169343f835381ad232ee11e077326561c9eb

%define gimpplugin	1
%define abi_version	3.0

%bcond_without krita_plugin

Name:		gmic
Version:	3.5.3
Release:	%mkrel 1
Summary:	A script language (G'MIC) dedicated to image processing
Group:		Graphics/Utilities
# CeCILL version 2.0
License:	CeCILL
Url:		https://gmic.eu/
Source0:	https://gmic.eu/files/source/%{name}_%{version}.tar.gz
Source1:	https://github.com/GreycLab/gmic-community/archive/gmic-3.4.3/%{name}-community-3.4.3.tar.gz
Source2:	zart.desktop
Source3: 	https://github.com/c-koi/zart/archive/%{zart_version}.tar.gz
Patch0:		gmic-3.5.0-mga-optflags.patch
Patch2:		gmic-3.5.3-qmake-flags.patch
Patch3:		gmic-3.3.3-ldflags.patch
Patch4:		gmic-dont-add-rpaths.patch
# patches (10,11) come from opensuse to enable krita plugin
Patch10:	0001-Find-the-local-gmic-library.patch
Patch11:	krita5.patch
BuildRequires:	dos2unix
BuildRequires:	cimg-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5Widgets)
BuildRequires:	cmake(Qt5Xml)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6LinguistTools)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	pkgconfig(GraphicsMagick)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(opencv)
%if %{gimpplugin}
BuildRequires:	pkgconfig(gimp-%{abi_version})
%else
Obsoletes:	gimp-plugin-gmic < %{version}-%{release}
%endif
%if %{with krita_plugin}
BuildRequires:	kf5-rpm-macros
BuildRequires:	krita-devel
BuildRequires:	cmake(Qt5LinguistTools)
%else
Obsoletes:	krita-plugin-gmic < %{version}-%{release}
%endif

Provides:	%{name}-qt = %{version}-%{release}

%description
G'MIC defines a complete image processing framework, and thus
can manage generic image data as other image-related tools.

Anyway, the specific features described below make it a bit particular :

* It internally works with lists of images.
  Image manipulations and interactions can be done
  either grouped or focused on specific items.
* It can process a wide variety of image types,
  including multi-spectral (arbitrary number of channels)
  and 3d volumetric images, as well as image sequences,
  or 3d vector objects.
  Images with different pixel types are supported,
  allowing to process flawlessly images with 8bits or
  16bits integers per channel, as well as float-valued datasets.
* It provides small but efficient visualization modules
  dedicated to the exploration/viewing of 2d/3d multi-spectral images,
  3d vector objects (elevation map, isocurves, isosurfaces,...),
  or 1d graph plots.
* It proposes commands to handle custom interactive windows
  where events can be managed easily by the user.
* It is highly extensible through the importation of custom command
  files which add new commands that become understood by the
  language interpreter.
%if %{gimpplugin}
* Most of the functionalities can be used inside GIMP
  via the provided plug-in, allowing end-users to integrate
  any G'MIC-based pipeline directly in a nice GUI,
  without coding efforts.
%endif
* It is based on the latest development versions of the CImg Library,
  a well established C++ template image processing toolkit,
  developed by the same team of developers.

%files -f %{name}.lang
%doc README
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}_qt
%{_datadir}/bash-completion/completions/%{name}
%{_mandir}/man1/%{name}.1.*
%{_datadir}/applications/gmic_qt.desktop
%{_iconsdir}/hicolor/*/*/gmic_qt.png
%{_iconsdir}/hicolor/*/*/gmic_qt.svg

#------------------------------------------------------

%package -n zart
Summary:        GUI for G'MIC real-time manipulations on the output of a webcam
Group:          Graphics/Utilities
Provides:	%{name}-zart = %{version}-%{release}

%description -n zart
ZArt is a computer program whose purpose is to demonstrate the possibilities of
the G'MIC image processing language by offering the choice of several
manipulations on a video stream acquired from a webcam.

%files -n zart
%license zart/LICENSE
%{_bindir}/zart
%{_datadir}/applications/zart.desktop
%{_iconsdir}/hicolor/*/*/zart.png
%{_iconsdir}/hicolor/*/*/zart.svg

#------------------------------------------------------

%if %{gimpplugin}
%package -n gimp-plugin-%{name}
Summary:	gmic plugin for gimp
Group:		Graphics/Utilities
Requires:	gimp >= 2.6.0
Provides:	%{name}-gimp = %{version}-%{release}

%description -n gimp-plugin-%{name}
G'MIC has been made available as an easy-to-use plug-in for GIMP.
It extends this retouching software capabilities by offering a large number of
pre-defined image filters and effects.
Of course, the plug-in is highly customizable and it is possible to add your
own custom G'MIC-written filters in it.

%files -n gimp-plugin-%{name}
%{_libdir}/gimp/%{abi_version}/plug-ins/%{name}_gimp_qt
%{_datadir}/gmic/
%endif

#------------------------------------------------------

%if %{with krita_plugin}
%package -n krita-plugin-%{name}
Summary:	gmic plugin for krita
Group:		Graphical desktop/KDE
Requires:	krita
Provides:	%{name}-krita = %{version}-%{release}

%description -n  krita-plugin-%{name}
This is a plugin for krita to provide G'MIC features.

%files -n krita-plugin-%{name}
%{_kf5_libdir}/kritaplugins/krita_gmic_qt.so
%endif

#------------------------------------------------------

%package -n %{libname}
Summary:	Library for gmic
Group:		System/Libraries

%description -n %{libname}
This package contains the library needed to run programs
dynamically linked with gmic.

%files -n %{libname}
%{_libdir}/lib*%{name}.so.%{major}{,.*}
%{_libdir}/lib*%{name}.so.%{lib_ver}

#------------------------------------------------------

%package -n %{develname}
Summary:	Header file for gmic
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the development file for gmic.

%files -n %{develname}
%{_includedir}/%{name}*.h
%{_libdir}/lib*%{name}.so

#------------------------------------------------------

%prep
%setup -q -a 1 -a 3
#dos2unix src/Makefile
%patch -P0 -p1
%patch -P2 -p1
%patch -P3 -p1
%patch -P4 -p1
%if %{with krita_plugin}
%patch -P10 -p1
%patch -P11 -p1
%endif

# fix file-not-utf8
iconv -f iso8859-1 -t utf-8 COPYING > COPYING.conv && mv -f COPYING.conv COPYING

# prepare libcgmic from community
mv %{name}-community-gmic-3.4.3/libcgmic/* ./src
mv zart-%{zart_version} zart

# We want to build against the system installed CImg package.
# G'MIC provides no way todo this, so we just copy the file over what's there already
pushd src
  mv CImg.h CImg.h.bak
  ln -s /usr/include/CImg.h CImg.h
popd

%build
%set_build_flags

pushd src
%if %{gimpplugin}
	%make_build -j1 all libc NOSTRIP=1 LIB=%{_lib} MAKE="%make_build -j1"
%else
	%make_build -j1 cli lib libc gmic_qt zart NOSTRIP=1 LIB=%{_lib} MAKE="%make_build -j1"
%endif
popd

pushd zart
	%qmake_qt5 zart.pro
	%make_build
popd

%if %{with krita_plugin}
pushd gmic-qt
%cmake_kf5 \
	-DENABLE_SYSTEM_GMIC=ON \
	-DENABLE_DYNAMIC_LINKING=ON \
	-DGMIC_QT_HOST=krita-plugin
%cmake_build
popd
%endif

%install
pushd src
	%make_install LIB=%{_lib}
%if ! %{gimpplugin}
	find %{buildroot} -name '*.gmz' -delete
%endif
popd

pushd zart
	install -m 0755 zart %{buildroot}%{_bindir}/zart
	install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/zart.desktop
	install -Dm 0644 images/gmic_hat.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/zart.png
popd

%if %{with krita_plugin}
pushd gmic-qt
%cmake_install
popd
%endif

%find_lang %{name} --with-man
