%define major	4.13
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

Name:		gmsh
Version:	4.13.2
Release:	%mkrel 5
Summary:	A three-dimensional finite element mesh generator
License:	GPLv2+
Group:		Sciences/Mathematics
Url:		https://gmsh.info
Source0:	https://gmsh.info/src/%{name}-%{version}-source.tgz
Patch0:		gmsh-4.11.1-fix_install_path.patch
Patch1:		gmsh-incompatible-pointer.patch
# Unbundle gl2ps
Patch5:		gmsh_unbundle_gl2ps.patch

BuildRequires:	cmake
BuildRequires:	cmake(alglib)
BuildRequires:	cmake(MEDFile)
BuildRequires:	cmake(opencascade)
BuildRequires:	imagemagick
BuildRequires:	gcc-gfortran
BuildRequires:	texinfo
BuildRequires:	cgns-devel
BuildRequires:	getfem-devel
BuildRequires:	gl2ps-devel
BuildRequires:	fltk-devel
BuildRequires:	hdf5-devel
BuildRequires:	libgomp-devel
BuildRequires:	metis-devel
BuildRequires:	pkgconfig(blas)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gmp)
BuildRequires:	pkgconfig(lapack)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)

%description
Gmsh is an automatic 3D finite element grid generator with a
built-in CAD engine and post-processor. Its design goal is to
provide a simple meshing tool for academic problems with
parametric input and advanced visualization capabilities.

Gmsh is built around four modules: geometry, mesh, solver and
post-processing. The specification of any input to these
modules is done either interactively using the graphical user
interface or in ASCII text files using Gmsh's own scripting
language.

%files
%doc README.txt CREDITS.txt CHANGELOG.txt doc/WELCOME.txt
%license LICENSE.txt
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*
%{python3_sitearch}/onelab.py
%{python3_sitearch}/__pycache__/onelab.*
%exclude %{_docdir}/%{name}/*txt
%exclude %{_docdir}/%{name}/examples
%exclude %{_docdir}/%{name}/images
%exclude %{_docdir}/%{name}/tutorials

#----------------------------------------------------------------------------

%package -n	%{libname}
Summary:	A three-dimensional finite element mesh generator
Group:		System/Libraries

%description -n	%{libname}
Gmsh is a 3D finite element grid generator with a build-in CAD engine
and post-processor.

This package contains the shared libraries.

%files -n %{libname}
%doc README.txt
%license LICENSE.txt
%{_libdir}/lib%{name}.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n	%{devname}
Summary:	Development files for Gmsh
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
This package contains development files for Gmsh.

%files -n %{devname}
%doc README.txt
%{_includedir}/gmsh.h
%{_includedir}/gmshc.h
%{_includedir}/gmsh.h_cwrap
%{_includedir}/gmsh.f90
%{_libdir}/libgmsh.so

#----------------------------------------------------------------------------

%package -n	python3-%{name}
Summary:	Python3 API for %{name}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n	python3-%{name}
Python3 API for %{name}.

%files -n python3-%{name}
%doc README.txt
%license LICENSE.txt
%{python3_sitearch}/%{name}.py
%{python3_sitearch}/%{name}*.*-info/
%{python3_sitearch}/__pycache__/%{name}.*

#----------------------------------------------------------------------------

%package	demos
Summary:	Tutorial and demo files for Gmsh
Group:		Sciences/Mathematics
BuildArch:	noarch

%description	demos
Gmsh is an automatic 3D finite element grid generator with a
built-in CAD engine and post-processor. Its design goal is to
provide a simple meshing tool for academic problems with
parametric input and advanced visualization capabilities.

Gmsh is built around four modules: geometry, mesh, solver and
post-processing. The specification of any input to these
modules is done either interactively using the graphical user
interface or in ASCII text files using Gmsh's own scripting
language.

This package contains tutorial and demo files for Gmsh.

%files demos
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/tutorials
%{_docdir}/%{name}/examples
%{_docdir}/%{name}/*.txt
%{_docdir}/%{name}/images/

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}-source

rm -fr contrib/blossom
rm -fr contrib/mpeg_encode

%build
# mpeg not in mageia due to patent issues
# blossom is nonfree, see contrib/blossom/README.txt

%cmake \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DENABLE_BUILD_LIB:BOOL=OFF \
	-DENABLE_BUILD_DYNAMIC:BOOL=ON \
	-DENABLE_BUILD_SHARED:BOOL=ON \
	-DENABLE_MPEG_ENCODE:BOOL=OFF \
	-DENABLE_BLOSSOM:BOOL=OFF \
	-DENABLE_CGNS:BOOL=ON \
	-DENABLE_ALGLIB:BOOL=ON \
	-DALGLIB_INC=%{_includedir}/alglib \
	-DENABLE_EIGEN:BOOL=ON \
	-DEIGEN_INC=%{_includedir}/eigen3 \
	-DENABLE_MED:BOOL=ON \
	-DENABLE_METIS:BOOL=ON \
	-DENABLE_OCC:BOOL=ON \
	-DENABLE_SYSTEM_CONTRIB:BOOL=ON \
	-DGMSH_HOST=%{_vendor} \
	-DGMSH_PACKAGER='daviddavid'
%cmake_build

%install
%cmake_install

# .deskop
install -dm 0755 %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Version=1.0
Name=Gmsh
GenericName=Mesh Generator
Comment=A 3D finite element mesh generator
Exec=gmsh
Icon=gmsh
Type=Application
Terminal=false
Categories=Science;Engineering;
EOF

# icon
for d in 16 32 48 64 72 128 256 512
do
	install -dm 0755 %{buildroot}%{_iconsdir}/hicolor/${d}x${d}/apps/
	convert -scale ${d}x${d} utils/icons/%{name}.png \
		%{buildroot}%{_iconsdir}/hicolor/${d}x${d}/apps/%{name}.png
done
