%define         srcname       gdl

#ImageMagick caused issues with plplot < 5.9.0
%define         with_magick   ON

#works now
%define         with_hdf4     ON

#not compulsory, but certainly faster
%define         with_fftw     ON

#compilation is buggy and PYTHON.txt claims that "Due to the
#neglectible feedback, the python module development is currently on
#hold"
%define         with_pymodule OFF

#but we still want to call python from GDL
#currently broken
%define         with_python   ON

#we would need to import eccodes, I've tried. This package is full of
#bugs, full of packaging shits, and upstream does not seem to care
%define         with_grib     OFF

%define         prodir        gnudatalanguage



%ifnarch %arm32 %ix86
%bcond_without  mpi
%else
%bcond_with     mpi
%endif 

#define         gitcommit

Name:           gnudl
Version:        1.1.1
#Release:        #mkrel -c #{gitcommit} #{rel}
Release:        %mkrel 2
Summary:        A free incremental compiler quite similar and compatible with IDL
License:        GPLv2+
Group:          Sciences/Physics

URL:            https://github.com/gnudatalanguage/gdl
Source0:        https://github.com/gnudatalanguage/gdl/releases/download/v%{version}/%{srcname}-v%{version}.tar.gz
Patch0:         gdl-mga-fix-building-with-libtiff-4.5.patch

BuildRequires:  sed
BuildRequires:  grep
BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  glpk
BuildRequires:  pkgconfig(pkg-config)
BuildRequires:  libstdc++-devel
BuildRequires:  libgomp-devel
BuildRequires:  pkgconfig(readline)
BuildRequires:  wxgtk-devel
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(plplot) >= 5.9.10-1
BuildRequires:  pkgconfig(shapelib)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  netcdf-cxx4-devel
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  hdf5-devel
BuildRequires:  hdf-devel
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libps)
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  udunits2-devel
BuildRequires:  qhull-devel
BuildRequires:  pkgconfig(libgeotiff)
BuildRequires:  glpk-devel
BuildRequires:  pkgconfig(libtirpc)
%if %{with mpi}
BuildRequires:  pkgconfig(ompi)
Requires:       openmpi
%endif

#contains required font files
Requires:       plplot



%description
A free compatible incremental compiler (i.e. runs Interactive Data
Language programs). IDL is a registered trademark of ITT Visual
Information Solutions. All IDL language elements up to IDL version 7.1
are supported and more than 380 library routines are implemented. For
a sorted list enter HELP,/LIB at the command prompt and look for
library routines written in GDL in the %prodir/lib directory.


%prep
%autosetup -p1 -n %{srcname}-v%{version}

# fix build with new proj
sed -i -e 's/proj_api.h/proj.h/g' src/projections.hpp

%build
#duplicate symbols on arm 32 bits only
#https://github.com/gnudatalanguage/gdl/issues/677
%ifarch %arm
%global build_ldflags %build_ldflags -z muldefs
export CXXFLAGS="%{optflags} -std=c++17"
export LDFLAGS="%{ldflags} -Wl,--allow-multiple-definition"
%endif
%cmake           -Wno-dev \
                 -DMAGICK:BOOL=%{with_magick} \
                 -DHDF:BOOL=%{with_hdf4} \
                 -DFFTW:BOOL=%{with_fftw} \
                 -DPYTHON:BOOL=%{with_python} \
                 -DPYTHONVERSION=3            \
                 -DPYTHON_EXECUTABLE=%{python3}      \
                 -DPYTHON_MODULE:BOOL=%{with_pymodule} \
                 -DWXWIDGETS:BOOL=ON \
                 -DUDUNITS:BOOL=ON \
                 -DUDUNITSDIR=%{_includedir}/udunits2 \
                 -DGRAPHICSMAGICK:BOOL=ON \
                 -DLIBPROJ4:BOOL=ON \
                 -DOPENMP:BOOL=ON \
		 %if %{with mpi}
		 -DMPI:BOOL=ON \
		 %else
		 -DMPI:BOOL=OFF \
		 %endif
		 -DGRIB:BOOL=%{with_grib}

%cmake_build


%install
%cmake_install


%files
%doc README README.md AUTHORS NEWS HACKING MAP_INSTALL
%license COPYING
%{_mandir}/man1/*
%{_bindir}/gdl
%{_datadir}/%prodir
