%define         pkgname    gnupg

Summary:	GNU privacy guard - a free PGP replacement
Name:		gnupg2
Version:	2.4.5
Release:	%mkrel 6
License:	GPLv3+
Group:		File tools
URL:		https://www.gnupg.org
Source0:	https://gnupg.org/ftp/gcrypt/gnupg/gnupg-%{version}.tar.bz2
Source1:	https://gnupg.org/ftp/gcrypt/gnupg/gnupg-%{version}.tar.bz2.sig
Patch0:		gnupg-1.9.3-use-ImageMagick-for-photo.patch
# Mostly reverts https://dev.gnupg.org/rGeae28f1bd4a5632e8f8e85b7248d1c4d4a10a5ed
Patch33:	gnupg-2.4.3-restore-systemd-sockets.patch
Patch34:	CVE-2025-30258-1.patch
Patch35:	CVE-2025-30258-2.patch
Patch36:	CVE-2025-30258-3.patch
Patch37:	CVE-2025-30258-4.patch
Patch38:	CVE-2025-30258-5.patch

BuildRequires:	docbook-utils
BuildRequires:	sendmail-command
BuildRequires:	npth-devel
BuildRequires:	pkgconfig(ldap)
BuildRequires:	pkgconfig(gpg-error) >= 1.11
BuildRequires:	pkgconfig(libgcrypt) >= 1.9.1
BuildRequires:	pkgconfig(libassuan) >= 2.0.0
BuildRequires:	pkgconfig(ksba) >= 1.0.7
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libusb)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(tss2-esys)

Recommends:	pinentry

# dirmngr is now part of gnupg2
Provides:	dirmngr = %{version}-%{release}
Obsoletes:	dirmngr < 1.2.0-1

Obsoletes:	gnupg2 < 2.2.11-3
Obsoletes:	gnupg < 1.4.23-3
Provides:	gnupg = %{version}-%{release}


%description
GnuPG is GNU's tool for secure communication and data storage.
It can be used to encrypt data and to create digital signatures.
It includes an advanced key management facility and is compliant
with the proposed OpenPGP Internet standard as described in RFC2440.

%prep
%autosetup -p1 -n %{pkgname}-%{version}

%build
%serverbuild

# Add libassuan headers to search path
CPATH=%{_includedir}:%{_includedir}/libassuan2
export CPATH

%configure \
	--libexecdir=%{_libexecdir}/gnupg2 \
	--enable-g13 \
	--disable-rpath \
	--with-tss=intel \
	--without-capabilities

%make_build

# all tests must pass on i586 and x86_64
%check
# need scratch gpg database for tests
mkdir -p $HOME/.gnupg
[[ -n "$GPG_AGENT_INFO" ]] || eval `./agent/gpg-agent --use-standard-socket --daemon --write-env-file gpg-agent-info`
make check
[[ -a gpg-agent-info ]] && kill -0 `cut -d: -f 2 gpg-agent-info`
rm -f gpg-agent-info

%install
%make_install \
  docdir=%{_pkgdocdir}

# gpgconf.conf
%__install -d %{buildroot}%{_sysconfdir}/gnupg
touch %{buildroot}%{_sysconfdir}/gnupg/gpgconf.conf

ln -s gpg %{buildroot}%{_bindir}/gpg2
ln -s gpgv %{buildroot}%{_bindir}/gpgv2
ln -s gpg.1 %{buildroot}%{_mandir}/man1/gpg2.1
ln -s gpgv.1 %{buildroot}%{_mandir}/man1/gpgv2.1
ln -s gnupg.7 %{buildroot}%{_mandir}/man7/gnupg2.7

# Move the systemd user units to appropriate directory
install -d -m755 %{buildroot}%{_userunitdir}
mv %{buildroot}%{_pkgdocdir}/examples/systemd-user/*.socket %{buildroot}%{_userunitdir}
mv %{buildroot}%{_pkgdocdir}/examples/systemd-user/*.service %{buildroot}%{_userunitdir}

%find_lang %{name}

%triggerpostun -- gnupg2 < 2.4.5-5
if [ -L %{_sysconfdir}/systemd/user/default.target.wants/gpg-agent.service ] && [ -x %{_bindir}/systemctl ]; then
 %{_bindir}/systemctl --no-reload preset --global gpg-agent.service
fi

%files -f %{name}.lang
%doc NEWS THANKS TODO ChangeLog
%doc %{_pkgdocdir}/*
%dir %{_sysconfdir}/gnupg
%ghost %config(noreplace) %{_sysconfdir}/gnupg/gpgconf.conf
%attr(4755,root,root) %{_bindir}/gpgsm
%{_bindir}/gpg-agent
%{_bindir}/gpg-card
%{_bindir}/gpg-wks-client
%{_bindir}/gpgconf
%{_bindir}/kbxutil
%{_bindir}/watchgnupg
%{_bindir}/gpg-connect-agent
%{_bindir}/gpgparsemail
%{_bindir}/gpg
%{_bindir}/gpg2
%{_bindir}/gpgv
%{_bindir}/gpgv2
%{_bindir}/dirmngr
%{_bindir}/dirmngr-client
%{_bindir}/g13
%{_bindir}/gpgscm
%{_bindir}/gpgsplit
%{_bindir}/gpgtar
%{_bindir}/gpg-wks-server
%{_sbindir}/addgnupghome
%{_sbindir}/applygnupgdefaults
%{_sbindir}/g13-syshelp
%{_datadir}/gnupg/
%dir %{_libexecdir}/gnupg2
%{_libexecdir}/gnupg2/gpg-auth
%{_libexecdir}/gnupg2/gpg-check-pattern
%{_libexecdir}/gnupg2/gpg-preset-passphrase
%{_libexecdir}/gnupg2/gpg-protect-tool
%{_libexecdir}/gnupg2/scdaemon
%{_libexecdir}/gnupg2/dirmngr_ldap
%{_libexecdir}/gnupg2/gpg-wks-client
%{_libexecdir}/gnupg2/gpg-pair-tool   
%{_libexecdir}/gnupg2/keyboxd
%{_libexecdir}/gnupg2/tpm2daemon
%{_infodir}/gnupg.info*
%{_mandir}/man?/*
%{_userunitdir}/*
