%bcond_with ssl

%define major     30
%define sslmajor  27
%define xxmajor   30
%define danemajor 0
%define libname   %mklibname %{name} %{major}
%define libssl    %mklibname %{name}-ssl %{sslmajor}
%define libxx     %mklibname %{name}xx %{xxmajor}
%define develname %mklibname %{name} -d
%define libdane   %mklibname %{name}-dane %{danemajor}

%define url_ver %(echo %{version}|cut -d. -f1,2)

Summary:        Library providing a secure layer (SSL)
Name:           gnutls
Version:        3.8.9
Release:        %mkrel 1
License:        LGPLv2+
Group:          Security
URL:            https://www.gnutls.org/
Source0:        https://www.gnupg.org/ftp/gcrypt/gnutls/v%{url_ver}/%{name}-%{version}.tar.xz
Source1:        https://www.gnupg.org/ftp/gcrypt/gnutls/v%{url_ver}/%{name}-%{version}.tar.xz.sig

BuildRequires:  liblzo-devel
BuildRequires:  pkgconfig(nettle) >= 3.4.1
BuildRequires:  pkgconfig(libtasn1) >= 4.3
BuildRequires:  pkgconfig(p11-kit-1) >= 0.23.1
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(readline)
%ifnarch %arm %mips aarch64
BuildRequires:  valgrind
%endif
BuildRequires:  pkgconfig(opencdk)
BuildRequires:  gettext-devel
BuildRequires:  autogen
BuildRequires:  pkgconfig(autoopts)
BuildRequires:  texinfo
BuildRequires:  pkgconfig(libunbound)
BuildRequires:  pkgconfig(tss2-esys)
Requires:       crypto-policies

%description
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%package -n %{libname}
Summary:        Library providing a secure layer (SSL)
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%if %{with ssl}
%package -n %{libssl}
Summary:        Library providing a secure layer (SSL)
Group:          System/Libraries

%description -n %{libssl}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.
%endif

%package -n %{libxx}
Summary:        Library providing a secure layer (SSL)
Group:          System/Libraries
# This conflict can be dropped when the xx lib also changes major
%define libname28 %mklibname %{name} 28
Conflicts:      %{libname28}

%description -n %{libxx}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%package -n %{libdane}
Summary:        Library supporting the dane certificate checker
Group:          System/Libraries
Provides:       lib%{name}-dane = %{version}-%{release}
Conflicts:      %{_lib}gnutls30 < 3.7.3-2

%description -n %{libdane}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
%if %{with ssl}
Requires:       %{libssl} = %{version}-%{release}
%endif
Requires:       %{libxx} = %{version}-%{release}
Requires:       %{libdane} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

This package contains all necessary files to compile or develop
programs/libraries that use %{name}.

%prep
%autosetup -p1

echo "SYSTEM=NORMAL" >> tests/system.prio

%build
%configure \
    --disable-static \
    --with-included-libtasn1=no \
    --enable-sha1-support \
%ifarch %{ix86}
    --disable-year2038 \
%endif
%if %{with ssl}
    --disable-openssl-compatibility \
%endif
    --with-system-priority-file=%{_sysconfdir}/crypto-policies/back-ends/gnutls.config \
    --disable-gtk-doc-html \
%ifnarch %arm %mips
    --enable-valgrind-tests \
%endif
    --with-tpm2 \
    --enable-ktls \
    --disable-rpath \
    --with-default-priority-string="@SYSTEM"

%make_build

%check
#__make check

%install
%make_install

%find_lang %{name}

find %{buildroot} -name '*.la' -delete

# (akien) We don't need to install those images if we don't ship the rest of the docs
rm -rf %{buildroot}%{_docdir}/%{name}

%files -f %{name}.lang
%doc NEWS README.md
%{_bindir}/[cgs]*
%{_bindir}/psktool
%{_bindir}/p11tool
%{_bindir}/ocsptool
%{_bindir}/danetool
%{_mandir}/man?/*
%{_infodir}/*

%files -n %{libname}
%{_libdir}/libgnutls.so.%{major}
%{_libdir}/libgnutls.so.%{major}.*

%files -n %{libdane}
%{_libdir}/libgnutls-dane.so.%{danemajor}
%{_libdir}/libgnutls-dane.so.%{danemajor}.*

%files -n %{libxx}
%{_libdir}/libgnutlsxx.so.%{xxmajor}
%{_libdir}/libgnutlsxx.so.%{xxmajor}.*

%if %{with ssl}
%files -n %{libssl}
%{_libdir}/libgnutls-openssl.so.%{sslmajor}
%{_libdir}/libgnutls-openssl.so.%{sslmajor}.*
%endif

%files -n %{develname}
%{_libdir}/libgnutls*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-dane.pc
%{_includedir}/gnutls/
