%define osmo		Osmo4

# disable format string check, can't fix it for WxWidgets part
%define Werror_cflags	%{nil}

# looks like no stable ABI => version is %%major
%define major		12
%define libname		%mklibname %{name} %{major}
%define modname		%mklibname %{name}-modules
%define devname		%mklibname %{name} -d

Name: 	 	gpac
Version: 	2.4.0
Release: 	%mkrel 2
Summary: 	MPEG-4 multimedia framework
License:	LGPLv2+
Group:		Video/Utilities
URL:		https://gpac.wp.imt.fr/
Source:		https://github.com/gpac/gpac/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		110_all_implicitdecls.patch
Patch2:		gpac-fix-library-detection.patch
# https://github.com/gpac/gpac/pull/2878
Patch3:		gpac-lto-type-mismatch.patch
Patch4:		gpac-ffmpeg6.patch
Patch5:		0001-private-fields-were-removed-in-libavformat-61.patch

BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(faad2)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(xmlrpc)
BuildRequires:	pkgconfig(xv)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	debhelper
BuildRequires:	imagemagick
BuildRequires:	a52dec-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	freeglut-devel
BuildRequires:	xvid-devel
BuildRequires:	subversion

%description
GPAC is a multimedia framework based on the MPEG-4 Systems standard developed
from scratch in ANSI C.  The original development goal is to provide a clean
(a.k.a. readable by as many people as possible), small and flexible
alternative to the MPEG-4 Systems reference software.

The natural evolution has been the integration of recent multimedia standards
(SVG/SMIL, VRML, X3D, SWF, 3GPP(2) tools, etc) into a single framework.
VRML97 and a good amount of the X3D standard have already been integrated
into GPAC, as well as some SVG support and experimental Macromedia Flash
support.

The current GPAC release (%{version}) already covers a very large part of the
MPEG-4 standard, and has some good support for 3GPP and VRML/X3D, and
features what can probably be seen as the most advanced and robust 2D MPEG-4
Player available worldwide, as well as a decent 3D player.

GPAC also features MPEG-4 Systems encoders/multiplexers, publishing tools for
content distribution for MP4 and 3GPP(2) files and many tools for scene
descriptions (MPEG4<->VRML<->X3D converters, SWF->MPEG-4, etc...).

This package is in tainted repository because it incorporates MPEG-4 technology,
covered by software patents.

%package -n	%{libname}
Summary:	GPAC shared library
Group:		System/Libraries

%description -n	%{libname}
GPAC is a multimedia framework based on the MPEG-4 Systems standard developed
from scratch in ANSI C.

This package provides the GPAC shared library.

This package is in tainted repository because it incorporates MPEG-4
technology which may be covered by software patents.

%package -n	%{devname}
Summary:	Development headers and library for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
Development headers and libraries for %{name}.

This package is in tainted repository because it incorporates MPEG-4
technology which may be covered by software patents.

%prep
%autosetup -p1

# SHH!
sed -i -e 's/Wall/w/g' `find -name Makefile`

%build
%configure \
		--libdir=%{_lib} \
		--use-zlib=system \
		--use-faad=system \
		--use-ffmpeg=system \
		--use-ogg=system \
		--use-vorbis=system \
		--use-theora=system \
		--use-openjpeg=system \
		--use-a52=system \
		--extra-cflags="%{optflags}" \
		--enable-pic

%make_build

%install
# Makefile needs the pkgconfig dir to install the gpac.pc file otherwise it can't
mkdir -p %{buildroot}%{_libdir}/pkgconfig

%make_install install-lib

# Windows includes
rm -rf %{buildroot}%{_includedir}/win32 %{buildroot}%{_includedir}/wince

%if 0
# menu
mkdir -p %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{osmo}.desktop
[Desktop Entry]
Name=%{osmo}
Comment=MPEG-4 Media Player
Exec=%{osmo}
Icon=%{osmo}
Terminal=false
Type=Application
Categories=AudioVideo;Video;
EOF

#icons
mkdir -p %{buildroot}%{_liconsdir}
convert -size 48x48 applications/osmo4_wx/osmo4.xpm %{buildroot}%{_liconsdir}/%{osmo}.png
mkdir -p %{buildroot}%{_iconsdir}
convert -size 32x32 applications/osmo4_wx/osmo4.xpm %{buildroot}%{_iconsdir}/%{osmo}.png
mkdir -p %{buildroot}%{_miconsdir}
convert -size 16x16 applications/osmo4_wx/osmo4.xpm %{buildroot}%{_miconsdir}/%{osmo}.png
%endif

%files
%doc Changelog README.md
%license COPYING
%{_bindir}/*
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/128x128/apps/gpac.png
%{_mandir}/man1/*.1.*

%files -n %{libname}
%{_libdir}/libgpac.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libgpac.so
%{_libdir}/libgpac_static.a
