# Please keep this package in sync with FC

%global major 4
%define libname %mklibname tcmalloc %major
%define devname %mklibname -d tcmalloc

# This package used to be called "google-perftools", but it was renamed on 2012-02-03.

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

Name:		gperftools
Version:	2.15
Release:	%mkrel 1
License:	BSD-3-Clause
Group:		Development/Tools
Summary:	Very fast malloc and performance analysis tools
URL:		https://github.com/gperftools/gperftools
Source0:	https://github.com/gperftools/gperftools/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
# Conditionalize generic dynamic tls model
Patch1:		gperftools-2.7.90-disable-generic-dynamic-tls.patch

ExcludeArch:	s390
BuildRequires:  gcc-c++
BuildRequires:	libunwind-devel
#BuildRequires:	perl-generators
BuildRequires:	autoconf, automake, libtool
BuildRequires:	make
Requires:	gperftools-devel = %{version}-%{release}
Requires:	pprof = %{version}-%{release}

%description
Perf Tools is a collection of performance analysis tools, including a
high-performance multi-threaded malloc() implementation that works
particularly well with threads and STL, a thread-friendly heap-checker,
a heap profiler, and a cpu-profiler.

This is a metapackage which pulls in all of the gperftools (and pprof)
binaries, libraries, and development headers, so that you can use them.

%package -n %devname
Summary:	Development libraries and headers for gperftools
Group:		Development/C
Requires:	%{name}-libs%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	google-perftools-devel = %{version}-%{release}
Obsoletes:	google-perftools-devel < 2.0
Obsoletes:	%{_lib}google-perftools-devel < 2.5-2

%description -n %devname
Libraries and headers for developing applications that use gperftools.

%package -n %libname
Summary:	Libraries provided by gperftools
Provides: %{name}-libs = %{version}-%{release}
Provides: %{name}-libs%{?_isa} = %{version}-%{release}
Obsoletes:	%{_lib}google-perftools0 < 2.5-2

%description -n %libname
Libraries provided by gperftools, including libtcmalloc and libprofiler.

%package -n pprof
Summary:	CPU and Heap Profiler tool
Requires:	gv, graphviz
BuildArch:	noarch
Provides:	google-perftools = %{version}-%{release}
Obsoletes:	google-perftools < 2.0

%description -n pprof
Pprof is a heap and CPU profiler tool, part of the gperftools suite.

%prep
%setup -q
%autopatch -p1

# Fix end-of-line encoding
sed -i 's/\r//' README_windows.txt

# No need to have exec permissions on source code
chmod -x src/*.h src/*.cc

autoreconf -ifv

%build
CFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
CXXFLAGS=`echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs -DTCMALLOC_LARGE_PAGES | sed -e 's|-fexceptions||g'`
%configure \
%ifarch s390x aarch64
	--disable-general-dynamic-tls \
%endif
	--disable-dynamic-sized-delete-support \
	--disable-static

# Bad rpath!
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
# Can't build with smp_mflags
make

%install
%make_install docdir=%{_pkgdocdir}/
find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

# Delete useless files
rm -rf %{buildroot}%{_pkgdocdir}/INSTALL

%check
# https://code.google.com/p/google-perftools/issues/detail?id=153
%ifnarch ppc
# Their test suite is almost always broken.
# LD_LIBRARY_PATH=./.libs make check
%endif


%files -n pprof
%{_bindir}/pprof
%{_bindir}/pprof-symbolize
%{_mandir}/man1/*

%files -n %devname
%{_pkgdocdir}/
%{_includedir}/google/
%{_includedir}/gperftools/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n %libname
%{_libdir}/libprofiler.so.*
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{major}.*

