%define major         11
%define gpgmepp_major 6
%define qgpgme_major  15

%define libname       %mklibname gpgme %{major}
%define libgpgmepp    %mklibname gpgmepp %{gpgmepp_major}
%define develname     %mklibname gpgme -d

### Qt5
%define libqgpgme     %mklibname qgpgme %{qgpgme_major}
%define qdevname      %mklibname qgpgme -d

### Qt6
%define libqgpgmeqt6  %mklibname qgpgmeqt6_ %{qgpgme_major}
%define qdevnameqt6   %mklibname qgpgme-qt6 -d

%bcond_without qt6

Summary:	GnuPG Made Easy (GPGME)
Name:		gpgme
Version:	1.24.2
Release:	%mkrel 3
License:	LGPLv2+
Group:		File tools
URL:		https://www.gnupg.org/gpgme.html
Source0:	https://gnupg.org/ftp/gcrypt/gpgme/%{name}-%{version}.tar.bz2
Source1:	https://gnupg.org/ftp/gcrypt/gpgme/%{name}-%{version}.tar.bz2.sig

## upstream patches

## downstream patches
# Don't add extra libs/cflags in gpgme-config/cmake equivalent
Patch1001:      0001-don-t-add-extra-libraries-for-linking.patch
# add -D_FILE_OFFSET_BITS... to gpgme-config, upstreamable
Patch1002:      gpgme-1.3.2-largefile.patch
# Avoid to generate python package containing -unknown in its version number, not conform
# Allow extra options to be passed to setup.py during installation
Patch1004:      0002-setup_py_extra_opts.patch

BuildRequires:	autoconf-archive
# support for Cryptographic Message Syntax protocol
BuildRequires:	gnupg2
BuildRequires:	pkgconfig(libassuan)
BuildRequires:	pkgconfig(gpg-error)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Test)
%if %{with qt6}
BuildRequires:	makeinfo
BuildRequires:	pkgconfig(Qt6Core)
BuildRequires:	pkgconfig(Qt6Test)
%endif
BuildRequires:	doxygen
BuildRequires:	graphviz
# Automatic provides generation for devel subpackage
BuildRequires:	cmake-rpm-macros
# Build dependencies for Python subpackages
BuildRequires:	swig
BuildRequires:	pkgconfig(python3)
# Needed since Python 3.12+ drops distutils
BuildRequires:	python3-setuptools

%description
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

%package -n %{libname}
Summary:	GnuPG Made Easy (GPGME)
Group:		System/Libraries
# support for Cryptographic Message Syntax protocol
Requires:	gnupg2
Provides:	%{name} = %{version}-%{release}

%description -n %{libname}
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

%package -n %{libgpgmepp}
Summary:	GpgME++ - C++ bindings/wrapper for gpgme
Group:		System/Libraries

%description -n %{libgpgmepp}
GpgME++ - C++ bindings/wrapper for gpgme.

### Qt5
%package -n %{libqgpgme}
Summary:	QGpgME - Qt5 bindings/wrapper for gpgme
Group:		System/Libraries
License:	GPLv2+

%description -n %{libqgpgme}
QGpgME - Qt5 bindings/wrapper for gpgme.

### Qt6
%package -n %{libqgpgmeqt6}
Summary:	QGpgME - Qt6 bindings/wrapper for gpgme
Group:		System/Libraries
License:	GPLv2+

%description -n %{libqgpgmeqt6}
QGpgME - Qt6 bindings/wrapper for gpgme.

%package -n %{develname}
Summary:	GnuPG Made Easy (GPGME) Header files and libraries for development
Group:		Development/C
License:	LGPLv2+
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libgpgmepp} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
gpgme library for crypto awareness.

### Qt5
%package -n %{qdevname}
Summary:        Qt5 GnuPG Made Easy (GPGME) Header files and libraries for development
Group:          Development/C
License:        GPLv2+
Requires:       %{libqgpgme} = %{version}-%{release}
Provides:       q%{name}-devel = %{version}-%{release}
Provides:       libq%{name}-devel = %{version}-%{release}
Conflicts:      %{_lib}%{name}-devel < 1.17.1-3

%description -n %{qdevname}
Qt5 GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
qgpgme library for crypto awareness.

### Qt6
%package -n %{qdevnameqt6}
Summary:        Qt6 GnuPG Made Easy (GPGME) Header files and libraries for development
Group:          Development/C
License:        GPLv2+
Requires:       %{libqgpgmeqt6} = %{version}-%{release}
Provides:       q%{name}-qt6-devel = %{version}-%{release}
Provides:       libq%{name}-qt6-devel = %{version}-%{release}

%description -n %{qdevnameqt6}
Qt6 GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
qgpgme library for crypto awareness.

%package -n python3-gpg
Summary:	GnuPG Made Easy (GPGME) bindings for Python 3
Group:		Development/Python
License:	GPLv2+
%{?python_provide:%python_provide python3-gpg}
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description -n python3-gpg
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

This package provides bindings to %{name} libraries for Python 3.

%prep
%autosetup -p1

# Force GPG2
find -type f -name Makefile\* -exec sed -i -e 's|GPG = gpg2\?|GPG = gpg2|' {} ';'

# Use ax_python_devel.m4 from autoconf-archive
rm -rf m4/ax_python_devel.m4

# use python.m4 from automake
rm -rf m4/python.m4

%if %{with qt6}
# Building qt5 and qt6 bindings in the same source tree is not supported
cp -r . %{_builddir}/%{name}-%{version}-qt6
%endif

%build
export PATH=%{_qt5_bindir}:$PATH
export SETUPTOOLS_USE_DISTUTILS=local

# Fix qgpgme build on 32bit arches
export CPPFLAGS='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'

%configure \
	--enable-languages=cpp,qt5,python,cl \
	--disable-static \
	--disable-gpgsm-test \
	--with-libassuan-prefix=%{_prefix}
%make_build

%if %{with qt6}
cd %{_builddir}/%{name}-%{version}-qt6
export PATH=%{_qt6_bindir}:$PATH

%configure \
	--enable-languages=cpp,qt6 \
	--disable-static \
	--disable-gpgsm-test \
	--with-libassuan-prefix=%{_prefix}
%make_build
%endif

%install
# When using distutils from setuptools 60+, ./setup.py install use
# the .egg format. This forces setuptools to use .egg-info format.
# SETUP_PY_EXTRA_OPTS is introduced by the Patch1004 above.
export SETUPTOOLS_USE_DISTUTILS=local
export SETUP_PY_EXTRA_OPTS="--single-version-externally-managed --root=/"
%make_install

%if %{with qt6}
cd %{_builddir}/%{name}-%{version}-qt6
%make_install
%endif

#we don't want these
find %{buildroot} -name "*.la" -delete

# autofoo installs useless stuff for uninstall
rm -vf %{buildroot}%{python3_sitelib}/gpg/install_files.txt

# all tests must pass
%check
# https://dev.gnupg.org/T3920
make check || :

%files -n %{libname}
%license COPYING*
%{_libdir}/libgpgme.so.%{major}{,.*}

%files -n %{libgpgmepp}
%doc lang/cpp/README
%{_libdir}/libgpgmepp.so.%{gpgmepp_major}{,.*}

### Qt5
%files -n %{libqgpgme}
%{_libdir}/libqgpgme.so.%{qgpgme_major}{,.*}

### Qt6
%files -n %{libqgpgmeqt6}
%{_libdir}/libqgpgmeqt6.so.%{qgpgme_major}{,.*}

%files -n %{develname}
%doc AUTHORS ChangeLog NEWS README THANKS TODO
%{_bindir}/gpgme-config
%{_bindir}/gpgme-json
%{_bindir}/gpgme-tool
%{_libdir}/libgpgme.so
%{_libdir}/libgpgmepp.so
%{_libdir}/pkgconfig/gpgme.pc
%{_libdir}/pkgconfig/gpgmepp.pc
%{_libdir}/pkgconfig/gpgme-glib.pc
%{_datadir}/aclocal/*.m4
%{_includedir}/gpgme++/
%{_includedir}/gpgme.h
%{_infodir}/gpgme.info*
%dir %{_datadir}/common-lisp/source/gpgme
%{_datadir}/common-lisp/source/gpgme/gpgme-package.lisp
%{_datadir}/common-lisp/source/gpgme/gpgme.asd
%{_datadir}/common-lisp/source/gpgme/gpgme.lisp
%{_datadir}/common-lisp/source/gpgme/gpgme-grovel.lisp
%{_libdir}/cmake/Gpgmepp/
%{_mandir}/man1/gpgme-json.1.*

### Qt5
%files -n %{qdevname}
%{_includedir}/qgpgme-qt5/
%{_libdir}/cmake/QGpgme/
%{_libdir}/libqgpgme.so

### Qt6
%files -n %{qdevnameqt6}
%{_includedir}/qgpgme-qt6/
%{_libdir}/cmake/QGpgmeQt6/
%{_libdir}/libqgpgmeqt6.so

%files -n python3-gpg
%doc lang/python/README
%{python3_sitearch}/gpg-*.egg-info
%{python3_sitearch}/gpg/
