# Allow first build without ncurses support
%define build_curses %{?_without_curses:0}%{!?_without_curses:1}

# this defines the library version that this package builds.
%define LIBMAJ 2
%define LIBVER %{LIBMAJ}.1.0
%define libname %mklibname %{name} %LIBMAJ
%define develname %mklibname %{name} -d
%global _legacy_common_support 1

Summary:	A mouse server for the Linux console
Name:		gpm
Version:	1.20.7
Release:	%mkrel 16
License:	GPLv2+
Group:		System/Servers
URL:		https://www.nico.schottelius.org/software/gpm/
Source0:	https://www.nico.schottelius.org/software/gpm/archives/%{name}-%{version}.tar.lzma
Source1:	gpm.service
Source2:	inputattach.c
Source3:	serio-ids.h
# fedora patches (gpm-1.20.5-1.fc10.src.rpm)
Patch1:		gpm-1.20.1-multilib.patch
Patch2:		gpm-1.20.1-lib-silent.patch
Patch4:		gpm-1.20.5-close-fds.patch
Patch5:		gpm-1.20.7-weak-wgetch.patch
# Include patch from upstream pull request: https://github.com/telmich/gpm/pull/12
Patch10:	gpm-1.20.7-sysmacros.patch
# Include patch from upstream pull request: https://github.com/telmich/gpm/pull/20
Patch11:	gpm-1.20.7-sigemptyset.patch

# mga patches
Patch50:	gpm-1.20.5-nodebug.patch
Patch51:	gpm-1.20.0-docfix.patch
Patch52:	gpm-1.20.7-do_not_build_it_twice.diff
Patch53:	gpm-1.20.5-format_not_a_string_literal_and_no_format_arguments.diff
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
BuildRequires:	byacc
%if %{build_curses}
BuildRequires:	pkgconfig(ncurses)
%endif
BuildRequires:	autoconf
BuildRequires:	texinfo

%description
Gpm provides mouse support to text-based Linux applications like the
emacs editor, the Midnight Commander file management system, and other
programs.  Gpm also provides console cut-and-paste operations using
the mouse and includes a program to allow pop-up menus to appear at
the click of a mouse button.

Gpm should be installed if you intend to use a mouse with your
system in virtual consoles.

%package -n	%{libname}
Summary:	Libraries and header files for developing mouse driven programs
Group:		System/Libraries

%description -n	%{libname}
Library used by the gpm program.

Install %{libname}dev if you need to develop text-mode programs which will use
the mouse.  You'll also need to install the gpm package.

%package -n	%{develname}
Summary:	Libraries and header files for developing mouse driven programs
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	gpm-devel = %{version}-%{release}
Provides:	libgpm-devel = %{version}-%{release}
Obsoletes:	gpm-devel < %{version}-%{release}
Obsoletes:	%{mklibname %{name} 1 -d} < %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains the libraries and header files needed
for development of mouse driven programs.  This package allows you to
develop text-mode programs which use the mouse.

Install %{develname} if you need to develop text-mode programs which will use
the mouse.  You'll also need to install the gpm package.

%prep
%setup -q

for i in `find . -type d -name CVS` `find . -type f -name .cvs\*` `find . -type f -name .#\*`; do
    if [ -e "$i" ]; then rm -rf $i; fi >&/dev/null
done

# fedora patches
%patch -P 1 -p1 -b .multilib
%patch -P 2 -p1 -b .lib-silent
%patch -P 4 -p1 -b .close-fds
%patch -P 5 -p1 -b .weak-wgetch
%patch -P 10 -p1
%patch -P 11 -p1

# mga patches
%patch -P 50 -p1 -b .nodebug
%patch -P 51 -p1 -b .docfix
%patch -P 52 -p1 -b .do_not_build_it_twice
%patch -P 53 -p0 -b .format_not_a_string_literal_and_no_format_arguments

cp %{SOURCE2} inputattach.c
cp %{SOURCE3} serio-ids.h

# fix runstatedir
sed -i -e 's,/var/run,%{_rundir},g' $(grep -rl /var/run)

%build
%serverbuild
./autogen.sh
CPPFLAGS="$CPPFLAGS -I$(pwd)/src/headers/" \
CFLAGS="$CFLAGS -D_GNU_SOURCE -DPIC -fPIC -fcommon" \
%configure %{?_without_curses}
CPPFLAGS="$CPPFLAGS" make

gcc $CPPFLAGS $CFLAGS -o inputattach inputattach.c serio-ids.h

%install
install -d %{buildroot}%{_sysconfdir}
install -d %{buildroot}/%{_lib}
install -d %{buildroot}%{_datadir}/emacs/site-lisp

PATH=/sbin:$PATH:%{_sbindir}:$PATH

%makeinstall

install -m0644 doc/gpm-root.1 %{buildroot}%{_mandir}/man1
install -m0644 conf/gpm-root.conf %{buildroot}%{_sysconfdir}
#install -m0755 src/hltest %{buildroot}%{_bindir}
install -m0755 inputattach %{buildroot}/%{_sbindir}

ln -sf /%{_lib}/libgpm.so.%{LIBVER} %{buildroot}%{_libdir}/libgpm.so
ln -sf libgpm.so.%{LIBVER} %{buildroot}/%{_lib}/libgpm.so.%{LIBMAJ}
mv %{buildroot}%{_libdir}/libgpm.so.* %{buildroot}/%{_lib}

mkdir -p %{buildroot}%_unitdir
install -m644 %{SOURCE1} %{buildroot}%_unitdir

# cleanup
rm -rf %{buildroot}%{_datadir}/emacs/site-lisp

%post
%_post_service gpm
%preun
%_preun_service gpm

%files
%config(noreplace) %{_sysconfdir}/gpm-root.conf
%{_unitdir}/gpm.service
%{_bindir}/display-buttons
%{_bindir}/display-coords
%{_bindir}/mev
%{_bindir}/gpm-root
%{_bindir}/hltest
%{_bindir}/mouse-test
%{_bindir}/disable-paste
%{_bindir}/get-versions
%{_sbindir}/gpm
%{_sbindir}/inputattach
%{_infodir}/gpm.info*
%{_mandir}/man1/mev.1*
%{_mandir}/man1/mouse-test.1*
%{_mandir}/man1/gpm-root.1*
%{_mandir}/man7/gpm-types.7*
%{_mandir}/man8/gpm.8*

%files -n %{libname}
%attr(0755,root,root) /%{_lib}/libgpm.so.%{LIBMAJ}*

%files -n %{develname}
%{_libdir}/libgpm.a
%{_includedir}/gpm.h
%{_libdir}/libgpm.so
