%define major     0
%define libname   %mklibname %{name} %{major}
%define devname   %mklibname %{name} -d

%global __provides_exclude_from %{python_sitearch}/osmosdr/.*\\.so$

Name:             gr-osmosdr
Summary:          Common software API for various radio hardware
Version:          0.2.6
Release:          %mkrel 5
License:          GPLv3+
Group:            Communications/Radio
URL:              https://github.com/osmocom/gr-osmosdr/releases

Source0:          https://github.com/osmocom/gr-osmosdr/archive/refs/tags/v%{version}/gr-osmosdr-%{version}.tar.gz
# https://osmocom.org/issues/5445
# https://osmocom.org/issues/5031
# Patch based on:
# https://github.com/dl1ksv/gr-osmosdr/commit/7d450ca7f20bcbf018a90662febcd9c5618372c2.patch
#Patch0:           gr-osmosdr-0.2.3-gr-funcube.patch
# https://osmocom.org/issues/5144
Patch1:           gr-osmosdr-0.2.3-airspy-multi-dev.patch

BuildRequires:    boost-devel
BuildRequires:    cmake
BuildRequires:    cmake(funcube)
BuildRequires:    doxygen
BuildRequires:    gcc-c++
BuildRequires:    gnuradio-utils
BuildRequires:    graphviz
BuildRequires:    mpir-devel
BuildRequires:    mpirxx-devel
BuildRequires:    pkgconfig(gmp)
BuildRequires:    pkgconfig(gmpxx)
BuildRequires:    pkgconfig(gnuradio-analog)
BuildRequires:    pkgconfig(gnuradio-digital)
BuildRequires:    pkgconfig(gnuradio-blocks)
BuildRequires:    pkgconfig(gnuradio-iqbalance)
BuildRequires:    pkgconfig(gnuradio-uhd)
BuildRequires:    pkgconfig(gnuradio-runtime)
BuildRequires:    pkgconfig(libairspy)
BuildRequires:    pkgconfig(libbladeRF)
BuildRequires:    pkgconfig(libhackrf)
BuildRequires:    pkgconfig(libmirisdr)
BuildRequires:    pkgconfig(python3)
BuildRequires:    pkgconfig(SoapySDR)
BuildRequires:    pkgconfig(uhd)
BuildRequires:    python-gnuradio-runtime
BuildRequires:    python3-numpy-devel
BuildRequires:    python3-mako
BuildRequires:    pybind11-devel
BuildRequires:    rtl-sdr-devel

%description
Primarily gr-osmosdr supports the OsmoSDR hardware, but it also
offers a wrapper functionality for FunCube Dongle,  Ettus UHD
and rtl-sdr devices. By using gr-osmosdr source you can take
advantage of a common software api in your application(s)
independent of the underlying radio hardware.

%package -n %{libname}
Summary:          Library files for gr-osmosdr
Group:            Communications/Radio
Requires:         %{name} = %{version}-%{release}

%description -n %{libname}
Library files for gr-osmosdr.

%package -n %{devname}
Summary:          Development files for gr-osmosdr
Group:            Communications/Radio
Requires:         %{libname} = %{version}-%{release}
Provides:         %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for gr-osmosdr.

%package doc
Summary:          Documentation files for gr-osmosdr
Group:            Communications/Radio
BuildArch:        noarch

%description doc
Documentation files for gr-osmosdr.

%prep
%autosetup -p1

%build
%cmake -DENABLE_DOXYGEN=on -DGR_PKG_DOC_DIR=%{_docdir}/%{name}
%cmake_build

%install
%cmake_install

cat > %{name}-doc.desktop << EOF
[Desktop Entry]
Version=1.0
Name=Gr-OsmoSDR Documentation
GenericName=Gr-OsmoSDR Documentation
Exec=xdg-open /usr/share/doc/%{name}/html/index.html
Icon=
Terminal=false
Type=Application
Categories=System;Documentation;X-Mageia-CrossDesktop;
EOF

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}-doc.desktop

# Create pkgconfig .pc file
mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat <<EOF > %{buildroot}%{_libdir}/pkgconfig/gnuradio-osmosdr.pc
prefix=%{_usr}
exec_prefix=\${prefix}
libdir=\${exec_prefix}/%{_lib}
includedir=\${prefix}/include

Name: gnuradio-osmosdr
Description: GNU Radio block for various radio hardware
URL: https://sdr.osmocom.org/trac/wiki/GrOsmoSDR
Version: %{version}
Requires: gnuradio-runtime gnuradio-blocks
Requires.private:
Conflicts:
Cflags: -I\${includedir} -I/usr/include
Libs: -L\${libdir} -lgnuradio-osmosdr
Libs.private: -L\${libdir}
EOF

%files
%exclude %{_docdir}/%{name}/html
%exclude %{_docdir}/%{name}/xml
%doc AUTHORS COPYING
%{_bindir}/*

%{python3_sitearch}/*
%{_datadir}/gnuradio/grc/blocks/*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/osmosdr/
%{_libdir}/*.so
%{_libdir}/cmake/osmosdr/
%{_libdir}/pkgconfig/*.pc

%files doc
%doc %{_docdir}/%{name}/html
%doc %{_docdir}/%{name}/xml
%{_datadir}/applications/%{name}-doc.desktop
