%define build_modules   1
%{?_with_modules: %global build_modules 1}

%define enable_jasper   1
%{?_with_jasper: %global enable_jasper 1}

%define enable_graphwiz 1
%{?_with_graphwiz: %global enable_graphwiz 1}

%define upstream_name   GraphicsMagick
%define major           3
%define libname         %mklibname %{name} %{major}
%define ppmajor         12
%define libppname       %mklibname %{name}++ %{ppmajor}
%define wandmajor       2
%define libwandname     %mklibname graphicsmagickwand %{wandmajor}
%define develname       %mklibname %{name} -d

%define qdepth          16
%define qlev            Q%{qdepth}

Summary:        An X application for displaying and manipulating images
Name:           graphicsmagick
Version:        1.3.45
Release:        %mkrel 3
License:        GPLv2+
Group:          Graphics/Editors and Converters
URL:            http://www.graphicsmagick.org/
Source0:        https://sourceforge.net/projects/graphicsmagick/files/graphicsmagick/%{version}/%{upstream_name}-%{version}.tar.xz
Patch0:         GraphicsMagick-1.3.15-use-so-for-modules.patch
Patch1:         GraphicsMagick-1.3.16-perl-link.patch
Patch2:         CVE-2025-27795.patch
Patch3:         CVE-2025-27796.patch

# Upstream patches
BuildRequires:  x11-proto-devel
BuildRequires:  perl-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(jasper)
BuildRequires:  pkgconfig(libwmf)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  libgs-devel
BuildRequires:  libtool-devel
BuildRequires:  jbigkit-devel
BuildRequires:  chrpath
BuildRequires:  pkgconfig(libheif) 
BuildRequires:  pkgconfig(libjxl)
%if "%distro_section" == "tainted"
BuildRequires:  pkgconfig(libde265)
Recommends:     libde265
Recommends:     libheif
%endif
Provides:       %{upstream_name} = %{version}-%{release}

%description
GraphicsMagick is the swiss army knife of image processing. It
provides a robust collection of tools and libraries which support
reading, writing, and manipulating an image in over 88 major formats
including important formats like DPX, GIF, JPEG, JPEG-2000, PNG, PDF,
SVG, and TIFF. GraphicsMagick supports huge images on systems that
support large files, and has been tested with gigapixel-size images.
GraphicsMagick can create new images on the fly, making it suitable
for building dynamic Web applications. GraphicsMagick may be used to
resize, rotate, sharpen, color reduce, or add special effects to an
image and save the result in the same or differing image format.
Image processing operations are available from the command line, as
well as through C, C++, Perl, or Windows COM programming interfaces.
Extensions are available from third-parties to support programming in
Python, Tcl, and Ruby. With some modification, language extensions for
ImageMagick may be used.

%files
%doc ChangeLog *.txt
%{_bindir}/gm
%dir %{_libdir}/GraphicsMagick-%{version}
%dir %{_libdir}/GraphicsMagick-%{version}/config
%{_libdir}/GraphicsMagick-%{version}/config/*.mgk
%dir %{_datadir}/GraphicsMagick-%{version}
%dir %{_datadir}/GraphicsMagick-%{version}/config
%{_datadir}/GraphicsMagick-%{version}/config/*.mgk
%if %build_modules
%dir %{_libdir}/%{upstream_name}-%{version}/modules-%{qlev}
%{_libdir}/%{upstream_name}-%{version}/modules-%{qlev}/filters
%dir %{_libdir}/%{upstream_name}-%{version}/modules-%{qlev}/coders
%{_libdir}/%{upstream_name}-%{version}/modules-%{qlev}/coders/*.so
%endif
%{_mandir}/man1/GraphicsMagick++-config.1.*
%{_mandir}/man1/GraphicsMagick-config.1.*
%{_mandir}/man1/GraphicsMagickWand-config.1.*
%{_mandir}/man1/gm.1.*
%{_mandir}/man4/miff.4.*
%{_mandir}/man5/quantize.5.*

#--------------------------------------------------------------

%package -n     %{libname}
Summary:        %upstream_name libraries
Group:          System/Libraries

%description -n %{libname}
This package contains the libraries needed to run programs dynamically
linked with GraphicsMagick libraries.

%files -n %{libname}
%{_libdir}/libGraphicsMagick.so.%{major}{,.*}

#--------------------------------------------------------------

%package -n     %{libppname}
Summary:        %upstream_name C++ libraries
Group:          System/Libraries

%description -n %{libppname}
This package contains the libraries needed to run C++ programs dynamically
linked with GraphicsMagick libraries.

%files -n %{libppname}
%{_libdir}/libGraphicsMagick++.so.%{ppmajor}{,.*}

#--------------------------------------------------------------

%package -n     %{libwandname}
Summary:        %upstream_name libraries
Group:          System/Libraries

%description -n %{libwandname}
This package contains the libraries needed to run programs dynamically
linked with GraphicsMagick libraries.

%files -n %{libwandname}
%{_libdir}/libGraphicsMagickWand.so.%{wandmajor}{,.*}

#--------------------------------------------------------------

%package -n     %{develname}
Summary:        Static libraries and header files for %{upstream_name} app development
Group:          Development/C
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{upstream_name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}
Requires:       %{libppname} = %{version}
Requires:       %{libwandname} = %{version}
Requires:       jbig-devel
%if %{enable_jasper}
Requires:       jasper-devel
%endif
%if %{enable_graphwiz}
Requires:       graphviz-devel
%global __requires_exclude devel\\(libcdt\\)|devel\\(libcircogen\\)|devel\\(libcommon\\)|devel\\(libdotgen\\)|devel\\(libdotneato\\)|devel\\(libfdpgen\\)|devel\\(libgraph\\)|devel\\(libgvrender\\)|devel\\(libneatogen\\)|devel\\(libpack\\)|devel\\(libpathplan\\)|devel\\(libtwopigen\\)|devel\\(libgvc\\)|devel\\(libgvgd\\)
%endif

%description -n %{develname}
If you want to create applications that will use GraphicsMagick code or
APIs, you'll need to install these packages as well as
GraphicsMagick. These additional packages aren't necessary if you simply
want to use GraphicsMagick, however.

graphicsmagick-devel is an addition to GraphicsMagick which includes static
libraries and header files necessary to develop applications.

%files -n %{develname}
%{_bindir}/GraphicsMagick++-config
%{_bindir}/GraphicsMagick-config
%{_bindir}/GraphicsMagickWand-config
%dir %{_includedir}/GraphicsMagick
%{_includedir}/GraphicsMagick/Magick++.h
%dir %{_includedir}/GraphicsMagick/magick
%{_includedir}/GraphicsMagick/magick/*.h
%dir %{_includedir}/GraphicsMagick/Magick++
%{_includedir}/GraphicsMagick/Magick++/*.h
%dir %{_includedir}/GraphicsMagick/wand
%{_includedir}/GraphicsMagick/wand/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

#--------------------------------------------------------------

%package -n     perl-Graphics-Magick
Summary:        Libraries and modules for access to %upstream_name from perl
Group:          Development/Perl
Requires:       %{name} = %{version}
%if %{enable_graphwiz}
Requires:       graphviz
%endif

%description -n perl-Graphics-Magick
This is the %upstream_name perl support package. It includes perl modules
and support files for access to GraphicsMagick library from perl.

%files -n perl-Graphics-Magick
%{_mandir}/man3*/*::*.3pm*
%{perl_vendorarch}/Graphics
%{perl_vendorarch}/auto/Graphics

#--------------------------------------------------------------

%package        doc
Summary:        %{name} Documentation
Group:          Documentation
BuildArch:      noarch

%description    doc
This package contains HTML/PDF documentation of %{name}.

%files doc
%{_datadir}/doc/GraphicsMagick

#--------------------------------------------------------------

%prep
%autosetup -p1 -n %{upstream_name}-%{version}

%build
%define Werror_cflags %nil
%configure \
    --enable-fast-install \
    --without-dps \
%if %{build_modules}
    --with-modules \
%else
    --without-modules \
%endif
    --enable-shared \
    --disable-static \
    --with-pic \
%if %{enable_jasper}
    --with-jp2 \
%else
    --without-jp2 \
%endif
    --with-perl-options="INSTALLDIRS=vendor"  \
    --with-perl \
    --with-quantum-depth=%{qdepth} \

%make_build
%make_build perl-build

%install
%make_install
%make_install -C PerlMagick

# fix rights and remove rpaths
chmod 755 %{buildroot}%{perl_vendorarch}/auto/Graphics/Magick/Magick.so
chrpath -d %{buildroot}%{perl_vendorarch}/auto/Graphics/Magick/Magick.so

# remove unwanted files
find %{buildroot} -name '*.la' -delete
rm -f %{buildroot}%{_datadir}/GraphicsMagick-%{version}/{ChangeLog,NEWS.txt}
