%define shortver 84
%define majorver 8

# %%{_bindir}/nviz is included in grass
%global __requires_exclude nviz

# filter out devel requires as we have also devel .so files pkg'ed in main pkg
%global __devel_exclude_path %{_libdir}/%{name}%{shortver}/lib/libgrass_[a-zA-Z0-9]\+\\.so

Name:		grass
Version:	8.4.1
Release:	%mkrel 1
Group:		Sciences/Geosciences
Summary:	Geographic Resources Analysis Support System
License:	GPLv2+
URL:		https://grass.osgeo.org/
# https://github.com/OSGeo/grass/releases/download/%%{version}/%%{name}-%%{version}.tar.xz
Source0:	https://github.com/OSGeo/grass/archive/%{version}/%{name}-%{version}.tar.gz

# fix pkgconfig file
Patch0:		grass-pkgconfig.patch
# fix broken runtime path
Patch2:		grass-8.2.0-mga-fixpath.patch
#
BuildRequires:	appstream-util
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(gdlib) >= 2.0
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	tk
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	gdbm-devel
BuildRequires:	pkgconfig(readline)
BuildRequires:	postgresql-devel
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(gdal)
BuildRequires:	flex
BuildRequires:	swig
BuildRequires:	bison
BuildRequires:	pkgconfig(proj)
BuildRequires:	proj >= 4.4.7
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:	lapack-devel
BuildRequires:	blas-devel
BuildRequires:	libgomp-devel
BuildRequires:	pkgconfig(cfitsio)
BuildRequires:	pkgconfig(odbc)
BuildRequires:	mysql-devel
BuildRequires:	termcap-devel
#BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(pdal)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(wxpython)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	python3dist(numpy)
BuildRequires:	python3dist(six)
BuildRequires:	python3dist(python-dateutil)
BuildRequires:	imagemagick
BuildRequires:	lzma
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(netcdf)
BuildRequires:	pkgconfig(OpenCL)

Requires:	xterm
Requires:	tk
Requires:	tcl
Requires:	python3-wxpython4


%description
GRASS (Geographic Resources Analysis Support System) is an
open source, Free Software Geographical Information System (GIS)
with raster, topological vector, image processing, and graphics
production functionality that operates on various platforms
through a graphical user interface and shell in X-Window.


%prep
%autosetup -p1


%build
%configure \
	--prefix=%{_libdir} \
	--with-libs=%{_libdir} \
	--with-includes=%{_includedir} \
	--with-postgres \
	--with-freetype \
	--with-freetype-includes=%{_includedir}/freetype2 \
	--with-cairo \
	--with-openmp \
	--with-lapack \
	--with-blas \
	--with-gdal \
	--with-geos \
	--with-mysql \
	--with-mysql-includes=%{_includedir}/mysql \
	--with-odbc \
	--with-sqlite \
	--with-cxx \
	--with-proj-share=%{_datadir}/proj \
	--with-nls \
	--with-readline \
	--with-bzlib \
	--with-zstd \
	--with-opencl \
	--with-netcdf
#   --with-ffmpeg --with-ffmpeg-includes="%%{_includedir}/libavcodec \
#   %%{_includedir}/libavdevice \
#   %%{_includedir}/libavformat %%{_includedir}/libavutil \
#   %%{_includedir}/libpostproc %%{_includedir}/libswscale"

%make_build


%install
mkdir -p %{buildroot}%{_bindir}
%make_install \
        prefix=%{_libdir} \
        UNIX_BIN=%{_bindir} \
        GISBASE_RUNTIME=%{_libdir}/%{name}%{shortver}

# fix paths:
# Change GISBASE in startup script
for I in %{buildroot}%{_bindir}/%{name} \
	%{buildroot}%{_libdir}/%{name}%{shortver}/include/Make/Platform.make \
	%{buildroot}%{_libdir}/%{name}%{shortver}/include/Make/Grass.make \
	%{buildroot}%{_libdir}/%{name}%{shortver}/demolocation/.grassrc%{shortver} \
	%{buildroot}%{_libdir}/%{name}%{shortver}/etc/fontcap; do
	sed -i \
		-e 's|%{buildroot}%{_libdir}/%{name}-%{version}|%{_libdir}/%{name}%{shortver}|g' \
		-e 's|%{buildroot}%{_libdir}/%{name}%{shortver}|%{_libdir}/%{name}%{shortver}|g' \
		-e 's|%{buildroot}%{_bindir}|%{_bindir}|g' \
		$I
done

# fix paths in grass.pc
sed -i -e 's|%{_prefix}/%{name}-%{version}|%{_libdir}/%{name}%{shortver}|g' \
	%{name}.pc

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig

# Make man pages available on the system, convert to utf8 and avoid name conflict
mkdir -p %{buildroot}%{_mandir}/man1
for man in $(ls %{buildroot}%{_libdir}/%{name}%{shortver}/docs/man/man1/*.1)
do
	iconv -f iso8859-1 -t utf8 $man > %{buildroot}%{_mandir}/man1/$(basename $man)"%{name}"
done

# Make desktop, appdata and icon files available on the system
cp -pr %{buildroot}%{_libdir}/%{name}%{shortver}/share/* %{buildroot}%{_datadir}/
desktop-file-validate %{buildroot}/%{_datadir}/applications/*.desktop
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/org.osgeo.%{name}.appdata.xml

%if 0
# fix runtime GISBASE path
sed -i -e 's|@MGAGISBASE@|%{_libdir}/%{name}%{shortver}|g' \
	bin.%{_target_platform}/grass
cp bin.%{_target_platform}/grass %{buildroot}%{_bindir}/grass
chmod a+x %{buildroot}/usr/bin/grass

for i in {16,22,24,32,36,48,64,72,96,128,192}
do
  install -p -D dist.%{_target_platform}/gui/icons/%{name}-${i}x${i}.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done
%endif

mkdir %{buildroot}%{_libdir}/%{name}%{shortver}/locks
chmod 1777 %{buildroot}%{_libdir}/%{name}%{shortver}/locks

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop << EOF
[Desktop Entry]
Name=GRASS GIS %{majorver}
GenericName=Geographic Information System
Comment=Geographic Resources Analysis Support System
Exec=%{_bindir}/grass
TryExec=%{_bindir}/grass
Icon=%{name}
Terminal=true
Type=Application
Categories=Science;Geology;
EOF

# avoid duplicate desktop entries in the menu
rm -f %{buildroot}%{_datadir}/applications/%{name}.desktop

# Add custom lib path to ld.conf.so.d
mkdir -p %{buildroot}%_sysconfdir/ld.so.conf.d
cat > %{buildroot}%_sysconfdir/ld.so.conf.d/%{name}.conf << EOF
%{_libdir}/%{name}%{shortver}/lib
EOF


%files
%doc AUTHORS README.md
%license COPYING
%attr(0755,root,root) %{_bindir}/*
%{_sysconfdir}/ld.so.conf.d/*
%{_libdir}/%{name}%{shortver}/
%{_libdir}/pkgconfig/*
%{_datadir}/applications/*
%{_metainfodir}/*
%{_mandir}/man1/*
%{_iconsdir}/*/*/*/*
