%define Werror_cflags %nil

# (tv) fix "build-grub-module-verifier: error: increment: unsupported relocation 0x1d":
%undefine _hardened_build

%ifarch x86_64
%global my_efi_arch x86_64-efi
%endif

%ifarch %arm
%global my_efi_arch arm-efi
%endif

%ifarch %ix86
%global my_efi_arch i386-efi
%endif

%ifarch aarch64
%global my_efi_arch arm64-efi
%endif

%global tarversion 2.12
%undefine _missing_build_ids_terminate_build
%global _configure_gnuconfig_hack 0

%global pc_arch i386-pc

%global theme_version 1.3
%global theme_source grub2-theme-%{theme_version}

%global theme_fonts MageiaLogoBold-16 MageiaLogoRegular-20 MageiaLogoBold-20 MageiaLogoBold-28

# Use 'commits since release tag' from git describe as the version minor
# so we can sanely implement snapshots without reconfiguring the spec.
# Using './make_snapshot_patch' creates a patch with the %%{git} (minor) 
# number in the name.
# Add the patch name as Patch0000: in SOURCES/grub.patches
%define git	0


# It's a commit from their gnulib's development tree.  They don't do releases,
# and it is *awful* to update this.
%global gnulibversion 9f48fb992a3d7e96610c4ce8be969cff2d61a01b

Name:		grub2
Version:	2.12
Release:	%mkrel 8
Summary:	Bootloader with support for Linux, Multiboot and more
Group:		System/Boot and Init
License:	GPLv3+
URL:		https://www.gnu.org/software/grub/
Source0:	https://ftp.gnu.org/gnu/grub/grub-%{tarversion}.tar.xz
Source1:	grub.macros
Source2:	gnulib-%{gnulibversion}.tar.gz
Source4:	https://unifoundry.com/pub/unifont/unifont-13.0.06/font-builds/unifont-13.0.06.pcf.gz
Source6:	gitignore
Source7:	bootstrap
Source8:	bootstrap.conf
Source9:	strtoull_test.c
Source11:	grub.patches
Source12:	sbat.csv.in
# 
# Mageia sources:
#
# Explain diff with FC:
Source100:	00_SUMMARY
Source101:	README.Mageia
Source102:	README.efi
Source110:	https://gitweb.mageia.org/software/design/grub2-theme/snapshot/%{theme_source}.tar.xz
Source111:	mageia.macros
# TODO/FIXME: Should be split as a standalone theme pkg:
Source114:	grub2-mageia-default.png
Source20:	theme.txt
Source21:	make_snapshot_patch
Source52:	grub.default

%include %{SOURCE1}
%include %{SOURCE111}

BuildRequires:	gcc efi-srpm-macros
BuildRequires:	autoconf
BuildRequires:	autogen
BuildRequires:	automake
BuildRequires:	binutils
BuildRequires:	bison
BuildRequires:	bzip2-devel
BuildRequires:	pkgconfig(devmapper)
BuildRequires:	flex
BuildRequires:	freetype2-devel
BuildRequires:	freetype-devel
BuildRequires:	freetype-devel
BuildRequires:	pkgconfig(fuse3)
BuildRequires:	gettext-devel
BuildRequires:	git
BuildRequires:	glibc-devel
BuildRequires:	liblzo-devel
BuildRequires:	libusb-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	python3
BuildRequires:	rpm-devel
BuildRequires:	ruby
BuildRequires:	squashfs-tools
BuildRequires:	texinfo
BuildRequires:	help2man
BuildRequires:	pesign >= 0.99-8

Provides:	bootloader
Provides:	grub2bootloader = %{version}-%{release}
Requires:	grub2-common = %{version}-%{release}
Recommends:	grub2-mkfont

%global desc \
This is the second version of GRUB. \
The GRand Unified Bootloader (GRUB) is a highly configurable and \
customizable bootloader with modular architecture.  It supports a rich \
variety of kernel formats, file systems, computer architectures and \
hardware devices.\
Refer to the README.Mageia file that is part of this package's documentation \
for more information. \
%{nil}

# generate with do-rebase
%include %{SOURCE11}

#
# Mga patches:
#
Patch20001:	grub2-2.12-mga-add_failsafe-10_linux.in.patch
Patch20003:	grub2-2.00-mga-dont_write_diskfilter_error_to_screen.patch
Patch20004:	grub2-2.00-mga-dont_check_uuid_in_installer.patch
Patch20006:	grub2-2.02-mga-translate-theme-label.patch
Patch20007:	grub2-2.12-disable_fdt_on_arm-uboot.patch
Patch20008:	grub2-2.02-mga-translate-theme-title.patch
# Fix https://savannah.gnu.org/bugs/?57889
# fix finding Mageia efi
Source20010:	grub-2.04-find-boot-EFI.patch
# Restore the upstream x86 'linux' command, which is removed by the FC
# patches. Rename it to 'linux32' to avoid clashing with the FC aliases.
# This is currently needed to run pcmemtest when booted by a UEFI BIOS.
Source20011:	grub2-2.12-mga-restore-linux-32bit-loader.patch
# Don't create boot menu entries for the vmlinuz/initrd soft links in /boot (mga#31621).
Patch20013:	grub2-2.06-mga-10_linux.in-skip-initrd-links.patch

#
# SuSE Patch:
#
# Fixes Mga#15846 - Grub2 doesn't install the bootloader on btrfs if we
# have a dualboot with windows starting at sector 63
Patch30001:	grub2-setup-try-fs-embed-if-mbr-gap-too-small.patch

#
# Unity Patches
#

#
# Upstream Patches
#

%description
%{desc}

%package efi
Summary:	Boot-loader with support for EFI
Group:		System/Boot and Init

Requires(post):	efibootmgr
Provides:	bootloader
Provides:	grub2bootloader = %{version}-%{release}
Requires:	grub2-common = %{version}-%{release}

%description efi
%{desc}
This subpackage supports EFI platforms.

%ifarch %arm
%package uboot
Summary:	Boot-loader with support for  UBOOT
Group:		System/Boot and Init

Provides:	bootloader
Provides:	grub2bootloader = %{version}-%{release}
Requires:	grub2-common = %{version}-%{release}

%description uboot
configurable and customizable boot-loader with modular architecture.
It supports a wide range of kernel formats, file systems, computer
architectures and hardware devices.
%endif
%if 0%{with_xen_arch}
%{expand:%define_xen_variant %%{xen_package_arch} -o}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%define_xen_pvh_variant %%{xen_pvh_package_arch} -o}
%endif

%package common
Summary:	Provides files common to both grub2 and grub2-efi
Group:		System/Boot and Init
Conflicts:	memtest86+ < 5.01-7
Conflicts:	grub2 < 2.02-0.git9752.19.mga5
Conflicts:	grub2-efi < 2.02-0.git9752.19.mga5
Recommends:	os-prober >= 1.53
Recommends:	xorriso
Requires:	grub2bootloader = %{version}-%{release}
Requires:	console-setup
Requires:	mtools

%description common
Common files used by both grub2 and grub2-efi.

%package mageia-theme
Summary:	Provides a graphical theme with a custom Mageia background for grub2
Group:		System/Boot and Init

Requires:	grub2bootloader = %{version}
Requires(post):	sed
Requires(post):	coreutils
Conflicts:	grub2-mageia-theme-dejavu

BuildArch:	noarch

%description mageia-theme
This package provides a custom Mageia graphical theme.
It is provided as a separate package so it may be easily excluded from
minimal installations where a graphical theme is not required.

%package mkfont
Summary:	Provides mkfont tool for grub2
Group:		System/Boot and Init
Requires:	grub2bootloader = %{version}
Conflicts:	grub2 < 2.12-3
Conflicts:	grub2-common < 2.12-4

%description mkfont
This package provides mkfont for grub2
It is provided as a separate package so it may be easily excluded from
minimal installations dependencies where libfreetype and its deps 
such as libx11 is not needed

%if 0%{with_emu_arch}
%package emu
Summary:	GRUB user-space emulation
Requires:	grub2-common = %{version}-%{release}

%description emu
%{desc}
This subpackage provides the GRUB user-space emulation support of all platforms.

%package emu-modules
Summary:	GRUB user-space emulation modules
Requires:	grub2-common = %{version}-%{release}

%description emu-modules
%{desc}
This subpackage provides the GRUB user-space emulation modules.
%endif

%prep
# Theme translations and fonts
tar xf %{SOURCE110}

%do_common_setup
%merge_theme_translations


%if 0%{with_efi_arch}
mkdir grub-%{grubefiarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubefiarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubefiarch}-%{tarversion}/unifont.pcf.gz
sed -e "s,@@VERSION@@,%{version},g" -e "s,@@VERSION_RELEASE@@,%{version}-%{release},g" \
    %{SOURCE12} > grub-%{grubefiarch}-%{tarversion}/sbat.csv
git add grub-%{grubefiarch}-%{tarversion}
%endif
%if 0%{with_alt_efi_arch}
mkdir grub-%{grubaltefiarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubaltefiarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubaltefiarch}-%{tarversion}/unifont.pcf.gz
git add grub-%{grubaltefiarch}-%{tarversion}
%endif
%if 0%{with_legacy_arch}
mkdir grub-%{grublegacyarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grublegacyarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grublegacyarch}-%{tarversion}/unifont.pcf.gz
git add grub-%{grublegacyarch}-%{tarversion}
%endif
%if 0%{with_emu_arch}
mkdir grub-emu-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-emu-%{tarversion}/.gitignore
cp %{SOURCE4} grub-emu-%{tarversion}/unifont.pcf.gz
git add grub-emu-%{tarversion}
%endif
%if 0%{with_xen_arch}
mkdir grub-%{grubxenarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubxenarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubxenarch}-%{tarversion}/unifont.pcf.gz
sed -e "s,@@VERSION@@,%{version},g" -e "s,@@VERSION_RELEASE@@,%{version}-%{release},g" \
    %{SOURCE12} > grub-%{grubxenarch}-%{tarversion}/sbat.csv
git add grub-%{grubxenarch}-%{tarversion}
%endif
%if 0%{with_xen_pvh_arch}
mkdir grub-%{grubxenpvharch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubxenpvharch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubxenpvharch}-%{tarversion}/unifont.pcf.gz
sed -e "s,@@VERSION@@,%{version},g" -e "s,@@VERSION_RELEASE@@,%{version}-%{release},g" \
    %{SOURCE12} > grub-%{grubxenpvharch}-%{tarversion}/sbat.csv
git add grub-%{grubxenpvharch}-%{tarversion}
%endif
git commit -m "After making subdirs"

# README.Mageia
cp %{SOURCE101} .
 
# README.efi
cp %{SOURCE102} .

%build
%if 0%{with_efi_arch}
%{expand:%do_primary_efi_build %%{grubefiarch} %%{grubefiname} %%{grubeficdname} %%{_target_platform} %%{efi_target_cflags} %%{efi_host_cflags}}
%endif
%if 0%{with_alt_efi_arch}
%{expand:%do_alt_efi_build %%{grubaltefiarch} %%{grubaltefiname} %%{grubalteficdname} %%{_alt_target_platform} %%{alt_efi_target_cflags} %%{alt_efi_host_cflags}}
%endif
%if 0%{with_legacy_arch}
%{expand:%do_legacy_build %%{grublegacyarch}}
%endif
%if 0%{with_emu_arch}
%{expand:%do_emu_build}
%endif
%if 0%{with_xen_arch}
%{expand:%do_xen_build %%{grubxenarch} %%{_target_platform} %%{xen_target_cflags} %%{xen_host_cflags}}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%do_xen_pvh_build %%{grubxenpvharch} %%{_target_platform} %%{xen_pvh_target_cflags} %%{xen_pvh_host_cflags}}
%endif
makeinfo --info --no-split -I docs -o docs/grub-dev.info \
docs/grub-dev.texi
makeinfo --info --no-split -I docs -o docs/grub.info \
docs/grub.texi
makeinfo --html --no-split -I docs -o docs/grub-dev.html \
docs/grub-dev.texi
makeinfo --html --no-split -I docs -o docs/grub.html \
docs/grub.texi

%install
set -e

%do_common_install
%if 0%{with_efi_arch}
%{expand:%do_efi_install %%{grubefiarch} %%{grubefiname} %%{grubeficdname}}
%endif
%if 0%{with_alt_efi_arch}
%{expand:%do_alt_efi_install %%{grubaltefiarch} %%{grubaltefiname} %%{grubalteficdname}}
%endif
%if 0%{with_legacy_arch}
%{expand:%do_legacy_install %%{grublegacyarch} %%{alt_grub_target_name} 0%%{with_efi_arch}}
%endif
%if 0%{with_emu_arch}
%{expand:%do_emu_install %%{package_arch}}
%endif
%if 0%{with_xen_arch}
%{expand:%do_xen_install %%{grubxenarch}}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%do_xen_pvh_install %%{grubxenpvharch}}
%endif

%find_lang grub

# Theme
install -d %{buildroot}/boot/grub2/themes/maggy
install -D -m 644 %{SOURCE20} %{buildroot}/boot/grub2/themes/maggy
for font in %{theme_fonts}; do
  %{buildroot}/usr/bin/grub2-mkfont -o %{buildroot}/boot/grub2/themes/maggy/$font.pf2 ../%{theme_source}/fonts/$font.bdf
done
# Install 4:3 default in case default.jpg is missing
install -D -m 644 %{SOURCE114} %{buildroot}/boot/grub2/themes
ln -sf ../grub2-mageia-default.png %{buildroot}/boot/grub2/themes/maggy/grub2-mageia-default.png

# Ghost config files
install -d %{buildroot}/boot/grub2
install -d %{buildroot}/boot/grub2/fonts

cat > %{buildroot}/boot/grub2/custom.cfg <<EOF
# Set non-graphical text/background colours
set menu_color_normal=cyan/blue
set menu_color_highlight=white/blue
# Add any extra custom menu entries in here:

EOF

# Provide 'update-grub' and update-grub2 symlink for *buntu exiles ;) 
cat > %{buildroot}%{_bindir}/update-grub <<EOF
#!/bin/sh
su --login root -c "/usr/sbin/grub2-mkconfig -o /boot/grub2/grub.cfg"

EOF
chmod +x %{buildroot}%{_bindir}/update-grub
ln -s %{_bindir}/update-grub %{buildroot}%{_bindir}/update-grub2

# Defaults
install -m 644 -D %{SOURCE52} %{buildroot}%{_sysconfdir}/default/grub

# Remove "GNU/Linux" in menu selections
sed -i 's/ GNU\/Linux//' %{buildroot}%{_sysconfdir}/grub.d/10_linux

install -d -m 0755 %{buildroot}%{_unitdir}/reboot.target.wants
ln -s ../grub2-systemd-integration.service \
	%{buildroot}%{_unitdir}/reboot.target.wants

# Don't run debuginfo on all the grub modules and whatnot; it just
# rejects them, complains, and slows down extraction.
%global finddebugroot "%{_builddir}/%{?buildsubdir}/debug"

%global dip RPM_BUILD_ROOT=%{finddebugroot} %{__debug_install_post}
%define __debug_install_post (						\
	mkdir -p %{finddebugroot}/usr					\
	mv ${RPM_BUILD_ROOT}/usr/bin %{finddebugroot}/usr/bin		\
	mv ${RPM_BUILD_ROOT}/usr/sbin %{finddebugroot}/usr/sbin		\
	%{dip}								\
	install -m 0755 -d %{buildroot}/usr/lib/ %{buildroot}/usr/src/	\
	cp -al %{finddebugroot}/usr/lib/debug/				\\\
		%{buildroot}/usr/lib/debug/				\
	cp -al %{finddebugroot}/usr/src/debug/				\\\
		%{buildroot}/usr/src/debug/ )				\
	mv %{finddebugroot}/usr/bin %{buildroot}/usr/bin		\
	mv %{finddebugroot}/usr/sbin %{buildroot}/usr/sbin		\
	%{nil}
 
%undefine buildsubdir

%post
if [ $1 -eq 2 ]; then
      touch /boot/grub2/updtrans
fi

%post efi
if [[ ! -e /boot/efi && -e /boot/EFI ]]; then
	ln -fs EFI /boot/efi
fi
if [ $1 -eq 2 ]; then
      touch /boot/grub2/updtrans
fi
# ensure we exit 0
:

%posttrans common
# On update re-install grub2 to where it was installed by drakboot if possible,
# otherwise next boot may fail due to mismatched boot code.
   if [ -f /boot/grub2/updtrans ] && [ -f /boot/grub2/install.sh -a -x /usr/sbin/detectloader ] && [ "$DURING_INSTALL" != "1" ] ; then
		LOADER=$(/usr/sbin/detectloader)
		[ "$LOADER" = "GRUB2" ] && /boot/grub2/install.sh ||:
		rm -f /boot/grub2/updtrans
   fi
   
# Don't let rpmdrake ask users to shoot themselves in feet! Mga#17263
		rm -f /etc/default/grub.rpm*

%post mageia-theme
# Don't install if updating
if [ $1 -eq 1 ] ; then
# Remove trailing blank lines from /etc/default/grub
sed -i -e :a -e '/^\n*$/{$d;N;};/\n$/ba' %{_sysconfdir}/default/grub
# Check that /etc/default/grub ends in a linefeed
[ "$(tail -n 1 %{_sysconfdir}/default/grub | wc --lines)" = "1" ] || echo >> %{_sysconfdir}/default/grub
# Add theme
echo "GRUB_THEME=/boot/grub2/themes/maggy/theme.txt" >> %{_sysconfdir}/default/grub

# If installing theme outside installer then update menu 
if [ "x${DURING_INSTALL}" != "x1" ]; then
grub2-mkconfig -o /boot/grub2/grub.cfg && rm -f /boot/grub2/grub.cfg.rpmsave
fi
fi

# Copy system default background at correct aspect ratio to grub2 default theme
if [ -h %{_datadir}/mga/backgrounds/default.png ] && [ "$DURING_INSTALL" != "1" ]; then
cp -f %{_datadir}/mga/backgrounds/default.png /boot/grub2/themes/grub2-mageia-default.png
fi

%triggerpostun mageia-theme -- grub2-mageia-theme <  2.02-0.git10463.5.mga6
# Run install.sh to replace /boot/grub2/fonts/unicode.pf2
   if [ -f /boot/grub2/install.sh -a -x /usr/sbin/detectloader ] && [ "$DURING_INSTALL" != "1" ]; then
		LOADER=$(/usr/sbin/detectloader)
		[ "$LOADER" = "GRUB2" ] && /boot/grub2/install.sh ||:
   fi

# If updating from below 2.02-0.git10101.4 then re-make grub.cfg once.
# grub2 dropped ownership of grub.cfg to avoid rpmnew being created.
# Remove rpmnew and after new grub.cfg is created remove rpmsave. Mga#17263
%triggerpostun common -- grub2 < 2.02-0.git10101.4, grub2-efi < 2.02-0.git10101.4
rm -f /boot/grub2/grub.cfg.rpmnew
grub2-mkconfig -o /boot/grub2/grub.cfg && rm -f /boot/grub2/grub.cfg.rpmsave
# Take this opportunity to remove some unwanted logs
rm -f /var/log/grub2_preun.log
rm -f /var/log/grub2_post.log
rm -f /var/log/grub2_theme_postun.log

%preun
# Only if uninstalling
if [ $1 -eq 0 ]; then
rm -rf /boot/grub2/%{pc_arch}
rm -rf /boot/grub2/locale
fi

%preun efi
# Only if uninstalling
if [ $1 -eq 0 ]; then
rm -rf /boot/grub2/%{my_efi_arch}
rm -rf /boot/grub2/locale
fi

%postun mageia-theme
# Only if uninstalling theme
if [ $1 -eq 0 ]; then
# Remove theme from config
sed -i '/GRUB_THEME=\/boot\/grub2\/themes\/maggy\/theme.txt/d' %{_sysconfdir}/default/grub
fi

%ifarch %ix86 x86_64
%files
%dir %{_libdir}/grub/i386-pc
%{_libdir}/grub/i386-pc/*
%attr(0644,root,root) %config(noreplace) /etc/dnf/protected.d/grub2-pc.conf
%endif

%files efi 
%doc README.efi
%dir %{_libdir}/grub/%{my_efi_arch}
%{_libdir}/grub/%{my_efi_arch}/*
%{_sysconfdir}/grub2-efi.cfg
%ifarch %{arm}
%attr(0700,root,root)%{efi_esp_boot}/BOOTARM.EFI
%endif
%attr(0644,root,root) %config(noreplace) /etc/dnf/protected.d/grub2-efi*.conf

%ifarch %arm
%files uboot
%dir %{_libdir}/grub/%{grublegacyarch}
%{_libdir}/grub/%{grublegacyarch}/*
%attr(0644,root,root) %config(noreplace) /etc/dnf/protected.d/grub2-arm.conf
%endif
%if 0%{with_xen_arch}
%{expand:%define_xen_variant_files %%{xen_package_arch} %%{xen_grub_target_name}}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%define_xen_pvh_variant_files %%{xen_pvh_package_arch} %%{xen_pvh_grub_target_name}}
%endif

%files common -f grub.lang
%license COPYING
%doc NEWS README THANKS TODO README.Mageia
%dir /boot/grub2
/boot/grub2/fonts
%dir /boot/grub2/themes
%dir %attr(0700,root,root) %{efi_esp_dir}
%exclude %{efi_esp_dir}/*
%{_unitdir}/grub2-systemd-integration.service
%{_unitdir}/reboot.target.wants
%{_unitdir}/systemd-logind.service.d
%{_infodir}/*
%{_bindir}/grub2-*
%exclude %{_bindir}/grub2-mkfont
%if 0%{with_emu_arch}
%exclude %{_bindir}/grub2-emu*
%endif
%{_bindir}/update-grub
%{_bindir}/update-grub2
%{_sbindir}/grub2-*
%{_libexecdir}/grub2
%dir %{_libdir}/grub
%{_datarootdir}/bash-completion/completions/grub
%{_sysconfdir}/grub.d/README
%config %{_sysconfdir}/grub.d/[^4]?_*
%config(noreplace) %{_sysconfdir}/grub.d/40_custom
%config(noreplace) %{_sysconfdir}/grub.d/41_custom
%config(noreplace) %{_sysconfdir}/default/grub
%{_datadir}/grub/*
%{_sysconfdir}/sysconfig/grub
%config(noreplace) /boot/grub2/custom.cfg
%ghost %config(noreplace) %verify(not size mode md5 mtime) /boot/grub2/grubenv
%exclude /boot/grub2/grub.cfg
%{_mandir}/man1/grub2-*.1*
%exclude %{_mandir}/man1/grub2-mkfont.1*
%if 0%{with_emu_arch}
%exclude %{_mandir}/man1/grub2-emu*
%endif
%{_mandir}/man3/grub2-*.3*
%{_mandir}/man8/grub2-*.8*
%{_sysconfdir}/grub2.cfg

%files mageia-theme
/boot/grub2/themes/*

%files mkfont
%{_bindir}/grub2-mkfont
%{_mandir}/man1/grub2-mkfont.1*

%if 0%{with_emu_arch}
%files emu
%{_bindir}/grub2-emu*
%{_datadir}/man/man1/grub2-emu*

%files emu-modules
%{_libdir}/grub/%{emuarch}-emu/*
%exclude %{_libdir}/grub/%{emuarch}-emu/*.module
%endif
