%define _disable_ld_no_undefined 1

%define major		%{ver}.%{subver}
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define ver	2.8
%define subver	104

Name:		gsoap
Version:	%{ver}.%{subver}
Release:	%mkrel 5
Summary:	Development toolkit for SOAP/XML Web services in C/C++
Group:		System/Libraries
License:	GPLv2
URL:		https://www.cs.fsu.edu/~engelen/soap.html
Source:		https://downloads.sourceforge.net/gsoap2/gsoap_%{version}.zip
Source1:	soapcpp2.1
Source2:	wsdl2h.1

Patch0:		%{name}-libtool.patch
# Backport from gsoap 2.8.105
# Included so that the following security fix applies cleanly
Patch2:		gsoap-wsse.patch
# Backport from gsoap 2.8.109
# Fixes CVE: CVE-2020-13574 CVE-2020-13575 CVE-2020-13577 CVE-2020-13578
Patch3:		gsoap-plugins-hardening.patch
# Backport from gsoap 2.8.111
# Fixes CVE: CVE-2020-13576
Patch4:		gsoap-url-parse-hardening.patch

BuildRequires:	automake
BuildRequires:	bison
BuildRequires:	libstdc++-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	flex

%description
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

%package -n	%{libname}
Summary:	Development toolkit for SOAP/XML Web services in C/C++
Group:		System/Libraries

Obsoletes:	%{_lib}gsoap2 < 2.8.93-5

%description -n	%{libname}
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

%package -n	%{develname}
Summary:	Devel libraries and headers for linking with gSOAP generated stubs
Group:		Development/C
Requires:	%{libname} = %version-%release
Provides:	%{name} = %version-%release
Provides:	%{name}-devel = %version-%release
Obsoletes:	%{name} < %version-%release

%description -n	%{develname}
gSOAP libraries, headers and generators for linking with and creating
gSOAP generated stubs.
 
%package	source
Summary:	Source files of %{name}
Group:		Development/C

%description	source
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

This package contains the source code.

%package	doc
Summary:	Documentation files of %{name}
Group:		Documentation

%description	doc
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

This package contains the documentation.

%prep
%setup -q -n %{name}-%{ver}
# keep a copy of source code (used by some TPM tools for Intel Classmate)
rm -rf %{name}-source
cp -a . ../%{name}-source
mv ../%{name}-source .

# remove pre-built binaries and libraries in source tree
rm -rf gsoap/bin
%patch -P 0 -p1 -b .soname
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1

# XML files non-executable
find gsoap/samples/autotest/databinding/examples -name '*.xml' \
    -exec chmod a-x {} ';'

# Documentation fonts non-executable
chmod a-x gsoap/doc/fonts/*

# make automake more happy
sed -i -e 's,\(^AM_INIT_AUTOMAKE(\[\),\1subdir-objects ,' configure.ac

# Remove stuff with gsoap license only - not GPL
rm -rf gsoap/extras gsoap/mod_gsoap gsoap/Symbian
sed 's!$(top_srcdir)/gsoap/extras/\*!!' -i gsoap/Makefile.am
rm -rf gsoap/doc/apache gsoap/doc/wininet gsoap/doc/isapi

# Remove pre-compiled binaries
rm -rf gsoap/bin
#rm gsoap/samples/calc_vs2005/calc_vs2005/soapcpp2.exe
rm gsoap/samples/rest/person
rm gsoap/samples/wcf/Basic/TransportSecurity/calculator
rm gsoap/VisualStudio2005/wsdl2h/wsdl2h/soapcpp2.exe

# Remove pre-generated files
rm gsoap/samples/webserver/opt{C.c,H.h,Stub.h}

# Remove .DS_Store files
find . -name .DS_Store -exec rm {} ';'

%build
export YACC='bison -y'
autoreconf -vfi
%configure --disable-static --prefix=/usr --enable-ipv6 --enable-samples

# Dependencies are not declared properly
%__make

%install
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -R %{name}/import %{buildroot}%{_datadir}/%{name}
cp -R %{name}/WS %{buildroot}%{_datadir}/%{name}
cp -R %{name}/uddi2 %{buildroot}%{_datadir}/%{name}
cp %{name}/stdsoap2.cpp %{buildroot}%{_datadir}/%{name}
cp %{name}/stdsoap2.c %{buildroot}%{_datadir}/%{name}

%make_install

install -d %{buildroot}%{_prefix}/src/
rm -f %{buildroot}%{_libdir}/*.la

cp -a %{name}-source %{buildroot}%{_prefix}/src/%{name}

mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 -p %{SOURCE1} %{SOURCE2} %{buildroot}%{_mandir}/man1

%check
make check

%files -n %{libname}
%license LICENSE.txt
%{_libdir}/libgsoap-*.so
%{_libdir}/libgsoap++-*.so
%{_libdir}/libgsoapck-*.so
%{_libdir}/libgsoapck++-*.so
%{_libdir}/libgsoapssl-*.so
%{_libdir}/libgsoapssl++-*.so

%files -n %{develname}
%{_bindir}/soapcpp2
%{_bindir}/wsdl2h
%{_includedir}/stdsoap2.h
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_mandir}/man1/soapcpp2.1*
%{_mandir}/man1/wsdl2h.1*
%{_libdir}/libgsoap.so
%{_libdir}/libgsoap++.so
%{_libdir}/libgsoapck.so
%{_libdir}/libgsoapck++.so
%{_libdir}/libgsoapssl.so
%{_libdir}/libgsoapssl++.so
%{_libdir}/pkgconfig/*.pc

%files source
%{_prefix}/src/%{name}

%files doc
%license LICENSE.txt
%doc NOTES.txt README.txt changelog.md factsheet.pdf license.pdf %name/doc
