%bcond_without qt5
%bcond_without qt6
%bcond_without check
%bcond_without amr

# disabled as we don't have hotdoc
%bcond_with docs

%define api	1.0
%define bname	gstreamer%{api}

Summary:	GStreamer Streaming-media framework plug-ins
Name:		%{bname}-plugins-good
Version:	1.26.0
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		https://gstreamer.freedesktop.org/
Source:		https://gstreamer.freedesktop.org/src/gst-plugins-good/gst-plugins-good-%{version}.tar.xz
BuildRequires:	pkgconfig(caca)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(cairo-gobject)
BuildRequires:	pkgconfig(flac)
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(gtk+-x11-3.0)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libavc1394)
BuildRequires:	pkgconfig(libdv)
BuildRequires:	pkgconfig(libiec61883)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libraw1394)
BuildRequires:	pkgconfig(libsoup-3.0)
BuildRequires:	pkgconfig(libv4l2)
%if %{with qt5}
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Qml)
BuildRequires:	pkgconfig(Qt5Quick)
BuildRequires:	pkgconfig(Qt5X11Extras)
BuildRequires:	pkgconfig(Qt5WaylandClient)
BuildRequires:	qt5platformsupport-devel
%endif
%if %{with qt6}
BuildRequires:	qttools6
BuildRequires:	qt6-qtshadertools
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Qml)
BuildRequires:	cmake(Qt6Quick)
BuildRequires:	cmake(Qt6WaylandClient)
%endif

BuildRequires:	pkgconfig(nettle)
BuildRequires:	pkgconfig(shout)
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(taglib)
BuildRequires:	pkgconfig(vpx)
BuildRequires:	pkgconfig(wavpack)
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xfixes)
BuildRequires:	pkgconfig(xv)
BuildRequires:	aalib-devel
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(check)
BuildRequires:	pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:	meson

%ifarch %ix86 x86_64
BuildRequires:	nasm >= 0.90
%endif

%ifarch %{valgrind_arches} %{arm32}
BuildRequires:	pkgconfig(valgrind)
%endif

%if %{with amr}
BuildRequires:	pkgconfig(opencore-amrnb)
%endif

Provides:	%{bname}-audiosrc
Provides:	%{bname}-audiosink

# gw this is the default http source:
Recommends:	%{bname}-soup

%description
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plug-ins.

This package contains a set of plug-ins that are considered to have
good quality code, correct functionality, the preferred license (LGPL
for the plug-in code, LGPL or LGPL-compatible for the supporting
library). People writing elements should base their code on these
elements.


%prep
%autosetup -p1 -n gst-plugins-good-%{version}

%build
%meson \
	-Ddoc=%{?with_docs:enabled}%{?!with_docs:disabled} \
	-Dqt5=%{?with_qt5:enabled}%{?!with_qt5:disabled} \
	-Dqt6=%{?with_qt6:enabled}%{?!with_qt6:disabled} \
	-Dexamples=disabled \
	-Dtests=disabled \
	-Drpicamsrc=disabled \
	-Damrnb=%{?with_amr:enabled}%{!?with_amr:disabled} \
	-Damrwbdec=%{?with_amr:enabled}%{!?with_amr:disabled} \
	-Dpackage-name='%{_vendor} %{name} package' \
	-Dpackage-origin='https://www.%{_real_vendor}.org/'

%meson_build

%if %{with check}
%check
%meson_test
%endif

%install
%meson_install

%find_lang gst-plugins-good-%{api}

#blino remove development doc since we don't ship devel files
rm -rf %{buildroot}%{_docdir}/docs/plugins/html %{buildroot}%{_datadir}/gtk-doc

%files -f gst-plugins-good-%{api}.lang
%license COPYING
%doc AUTHORS README.md NEWS
%{_libdir}/gstreamer-%{api}/libgstadaptivedemux2.so
%{_libdir}/gstreamer-%{api}/libgstalaw.so
%{_libdir}/gstreamer-%{api}/libgstalpha.so
%{_libdir}/gstreamer-%{api}/libgstalphacolor.so
%{_libdir}/gstreamer-%{api}/libgstapetag.so
%{_libdir}/gstreamer-%{api}/libgstaudiofx.so
%{_libdir}/gstreamer-%{api}/libgstaudioparsers.so
%{_libdir}/gstreamer-%{api}/libgstauparse.so
%{_libdir}/gstreamer-%{api}/libgstautodetect.so
%{_libdir}/gstreamer-%{api}/libgstavi.so
%{_libdir}/gstreamer-%{api}/libgstcairo.so
%{_libdir}/gstreamer-%{api}/libgstcutter.so
%{_libdir}/gstreamer-%{api}/libgstdebug.so
%{_libdir}/gstreamer-%{api}/libgstdeinterlace.so
%{_libdir}/gstreamer-%{api}/libgstdtmf.so
%{_libdir}/gstreamer-%{api}/libgsteffectv.so
%{_libdir}/gstreamer-%{api}/libgstflv.so
%{_libdir}/gstreamer-%{api}/libgstequalizer.so
%{_libdir}/gstreamer-%{api}/libgstflxdec.so
%{_libdir}/gstreamer-%{api}/libgstgdkpixbuf.so
%{_libdir}/gstreamer-%{api}/libgstgtk.so
%{_libdir}/gstreamer-%{api}/libgstgoom.so
%{_libdir}/gstreamer-%{api}/libgstgoom2k1.so
%{_libdir}/gstreamer-%{api}/libgsticydemux.so
%{_libdir}/gstreamer-%{api}/libgstid3demux.so
%{_libdir}/gstreamer-%{api}/libgstimagefreeze.so
%{_libdir}/gstreamer-%{api}/libgstinterleave.so
%{_libdir}/gstreamer-%{api}/libgstisomp4.so
%{_libdir}/gstreamer-%{api}/libgstjpeg.so
%{_libdir}/gstreamer-%{api}/libgstlevel.so
%{_libdir}/gstreamer-%{api}/libgstmatroska.so
%{_libdir}/gstreamer-%{api}/libgstmonoscope.so
%{_libdir}/gstreamer-%{api}/libgstmpg123.so
%{_libdir}/gstreamer-%{api}/libgstmulaw.so
%{_libdir}/gstreamer-%{api}/libgstmultifile.so
%{_libdir}/gstreamer-%{api}/libgstmultipart.so
%{_libdir}/gstreamer-%{api}/libgstnavigationtest.so
%{_libdir}/gstreamer-%{api}/libgstossaudio.so
%{_libdir}/gstreamer-%{api}/libgstoss4.so
%{_libdir}/gstreamer-%{api}/libgstpng.so
%if %{with qt5}
%{_libdir}/gstreamer-%{api}/libgstqmlgl.so
%endif
%if %{with qt6}
%{_libdir}/gstreamer-%{api}/libgstqml6.so
%endif
%{_libdir}/gstreamer-%{api}/libgstreplaygain.so
%{_libdir}/gstreamer-%{api}/libgstrtp.so
%{_libdir}/gstreamer-%{api}/libgstrtpmanager.so
%{_libdir}/gstreamer-%{api}/libgstrtsp.so
%{_libdir}/gstreamer-%{api}/libgstshapewipe.so
%{_libdir}/gstreamer-%{api}/libgstshout2.so
%{_libdir}/gstreamer-%{api}/libgstsmpte.so
%{_libdir}/gstreamer-%{api}/libgstspectrum.so
%{_libdir}/gstreamer-%{api}/libgsttaglib.so
%{_libdir}/gstreamer-%{api}/libgstudp.so
%{_libdir}/gstreamer-%{api}/libgstvideo4linux2.so
%{_libdir}/gstreamer-%{api}/libgstvideobox.so
%{_libdir}/gstreamer-%{api}/libgstvideocrop.so
%{_libdir}/gstreamer-%{api}/libgstvideofilter.so
%{_libdir}/gstreamer-%{api}/libgstvideomixer.so
%{_libdir}/gstreamer-%{api}/libgstwavenc.so
%{_libdir}/gstreamer-%{api}/libgstwavparse.so
%{_libdir}/gstreamer-%{api}/libgstxingmux.so
%{_libdir}/gstreamer-%{api}/libgstximagesrc.so
%{_libdir}/gstreamer-%{api}/libgsty4menc.so
%dir %{_datadir}/gstreamer-%{api}/
%dir %{_datadir}/gstreamer-%{api}/presets
%{_datadir}/gstreamer-%{api}/presets/*
%exclude %{_datadir}/gstreamer-%{api}/presets/GstAmrnbEnc.prs

%if %{with amr}
%package -n %{bname}-amrnb
Summary:	GStreamer plug-in for AMR-NB support
Group: 		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}

%description -n %{bname}-amrnb
Plug-in for decoding AMR-NB under GStreamer.

%files -n %{bname}-amrnb
%{_libdir}/gstreamer-%{api}/libgstamrnb.so
%{_datadir}/gstreamer-%{api}/presets/GstAmrnbEnc.prs

%package -n %{bname}-amrwbdec
Summary:	GStreamer plug-in for AMR-WB decoding support
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}

%description -n %{bname}-amrwbdec
Plug-in for decoding AMR-Wb under GStreamer.

%files -n %{bname}-amrwbdec
%{_libdir}/gstreamer-%{api}/libgstamrwbdec.so
%endif

%package -n %{bname}-jack
Summary:	GStreamer plug-in for the Jack Sound Server
Group:		Sound/Utilities
Provides:	%{bname}-audiosrc
Provides:	%{bname}-audiosink

%description -n %{bname}-jack
Plug-in for the JACK professional sound server.

%files -n %{bname}-jack
%{_libdir}/gstreamer-%{api}/libgstjack.so

%package -n %{bname}-soup
Summary:	GStreamer HTTP plugin based on libsoup
Group:		System/Libraries
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-soup
Plug-in for HTTP access based on libsoup.

%files -n %{bname}-soup
%{_libdir}/gstreamer-%{api}/libgstsoup.so

%package -n %{bname}-pulse
Summary:	Pulseaudio plugin for GStreamer
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-pulse
This is a GStreamer audio output plugin using the Pulseaudio sound server.

%files -n %{bname}-pulse
%{_libdir}/gstreamer-%{api}/libgstpulseaudio.so

### LIBDV ###
%package -n %{bname}-dv
Summary:	GStreamer DV plug-in
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-dv
Plug-in for digital video support using libdv.

%files -n %{bname}-dv
%{_libdir}/gstreamer-%{api}/libgstdv.so

%package -n %{bname}-speex
Summary:	Gstreamer plugin for encoding and decoding Ogg Speex audio files
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-speex
Plug-Ins for creating and playing Ogg Speex audio files.

%files -n %{bname}-speex
%{_libdir}/gstreamer-%{api}/libgstspeex.so

### RAW1394 ###
%package -n %{bname}-raw1394
Summary:	GStreamer raw1394 Firewire plug-in
Group:		System/Libraries
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-raw1394
Plug-in for digital video support using raw1394.

%files -n %{bname}-raw1394
%{_libdir}/gstreamer-%{api}/libgst1394.so

### FLAC ###
%package -n %{bname}-flac
Summary:	GStreamer plug-in for FLAC lossless audio
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-flac
Plug-in for the free FLAC lossless audio format.

%files -n %{bname}-flac
%{_libdir}/gstreamer-%{api}/libgstflac.so

### AALIB ###
%package -n %{bname}-aalib
Summary:	Gstreamer plugin for Ascii-art output
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-aalib
Plugin for viewing movies in Ascii-art using aalib library.

%files -n %{bname}-aalib
%{_libdir}/gstreamer-%{api}/libgstaasink.so

%package -n %{bname}-caca
Summary:	Gstreamer plugin for Ascii-art output
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-caca
Plugin for viewing movies in Ascii-art using caca library.

%files -n %{bname}-caca
%{_libdir}/gstreamer-%{api}/libgstcacasink.so

%package -n %{bname}-vp8
Summary:	GStreamer VP8 plug-in
Group:		Video/Utilities

%description -n %{bname}-vp8
VP8 encoding and decoding plug-in.

%files -n %{bname}-vp8
%{_libdir}/gstreamer-%{api}/libgstvpx.so

%package -n %{bname}-wavpack
Summary:	Gstreamer plugin for encoding and decoding WavPack audio files
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}

%description -n %{bname}-wavpack
Plug-Ins for creating and playing WavPack audio files.

%files -n %{bname}-wavpack
%{_libdir}/gstreamer-%{api}/libgstwavpack.so

### LAME ###
%package -n %{bname}-lame
Summary:        GStreamer plug-in for encoding mp3 songs using lame
Group:          Sound/Utilities
Requires:       %{bname}-plugins >= %{version}-%{release}
BuildRequires:  liblame-devel >= 3.89

%description -n %{bname}-lame
Plug-in for encoding mp3 with lame under GStreamer.

%files -n %{bname}-lame
%{_libdir}/gstreamer-%{api}/libgstlame.so

%package -n %{bname}-twolame
Summary: 	GStreamer plug-in for MP2 encoding support
Group:          Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:  pkgconfig(twolame)

%description -n %{bname}-twolame
Plug-in for encoding MP2 under GStreamer.

%files -n %{bname}-twolame
%{_libdir}/gstreamer-%{api}/libgsttwolame.so
