%define oname	gstreamer
%define api	1.0

%define major		0
%define libname		%mklibname %{oname} %{api} %{major}
%define gi_name		%mklibname gst-gir %{api}
%define libnamedev	%mklibname %{name} -d

# Disabled as we don't have hotdoc
%bcond_with docs

# Disabled tests
%bcond_with tests

Name:		%{oname}%{api}
Summary:	GStreamer Streaming-media framework runtime
Version:	1.26.0
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		https://gstreamer.freedesktop.org/
Source0: 	https://gstreamer.freedesktop.org/src/gstreamer/%{oname}-%{version}.tar.xz
## For GStreamer RPM provides
Source1:	gstreamer1.prov
Source2:	gstreamer1.attr
Patch0:		0001-gst-inspect-add-mode-to-output-RPM-requires-format.patch
# upstream patchset, from https://gitlab.freedesktop.org/gstreamer/gstreamer/
#
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gmodule-no-export-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(libunwind)
BuildRequires:	pkgconfig(libdw)
BuildRequires:	pkgconfig(gmp)
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(popt)
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(check)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	meson
BuildRequires:	rustc
# for setcap
BuildRequires:	pkgconfig(libcap)
BuildRequires:	libcap-utils
%ifarch %{valgrind_arches} %{arm32}
BuildRequires:	pkgconfig(valgrind)
%endif

%ifarch %ix86
BuildRequires:	nasm >= 0.90
%endif

%if %{with docs}
BuildRequires:	gtk-doc
BuildRequires:	transfig
BuildRequires:	docbook-dtd42-xml
BuildRequires:	docbook-dtd412-xml
BuildRequires:	ghostscript
%endif

%if %{with tests}
BuildRequires:	x11-server-xvfb
%endif

%description
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

%package tools
Summary:	GStreamer Streaming-media framework runtime
Group:		System/Libraries
Conflicts:	%{_lib}gstreamer1.0_0 < 1.16.2-3

%description tools
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

%package -n %{libname}
Summary:	Libraries for GStreamer streaming-media framework
Group:		System/Libraries
Requires:	%{name}-tools >= %{version}-%{release}
Provides:	libgstreamer%{api} = %{version}-%{release}

%description -n %{libname}
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

This package contains the libraries.

%package -n %{gi_name}
Summary:	GObject Introspection interface libraries for %{name}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n %{gi_name}
GObject Introspection interface libraries for %{name}.

%package -n %{libnamedev}
Summary:	Libraries and include files for GStreamer streaming-media framework
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{gi_name} = %{version}-%{release}
Requires:	%{name}-tools = %{version}-%{release}
Provides:	gstreamer%{api}-devel = %{version}-%{release}
Conflicts:	%{_lib}gstreamer-plugins-bad1.0-devel < 1.14.0

%description -n %{libnamedev}
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

This package contains the libraries and includes files necessary to develop
applications and plugins for GStreamer.

%prep
%autosetup -p3 -n %{oname}-%{version}

%build
%meson \
	-Dptp-helper-permissions=capabilities \
	-Dlibunwind=enabled \
	-Dlibdw=enabled \
	-Ddbghelp=disabled \
	-Dbash-completion=enabled \
	-Dexamples=disabled \
%if %{with tests}
	-Dtests=enabled \
%else
	-Dtests=disabled \
%endif
	-Dbenchmarks=enabled \
	-Dtools=enabled \
	-Ddoc=%{?_with_docs:enabled}%{?!_with_docs:disabled} \
	-Dintrospection=enabled \
	-Dgobject-cast-checks=disabled \
	-Dglib-asserts=disabled \
	-Dglib-checks=disabled \
	-Dpackage-name='%{_vendor} %{name} package' \
	-Dpackage-origin='https://www.%{_real_vendor}.org/'
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_var}/cache/%{oname}-%{api}

#clean the files we don't want to install
find %{buildroot} -name '*.la' -delete

%find_lang %{oname}-%{api}

# Add the provides script
install -m0755 -D %{SOURCE1} %{buildroot}%{_rpmconfigdir}/gstreamer1.prov

# Add the gstreamer plugin file attribute entry (rpm >= 4.9.0)
install -m0755 -D %{SOURCE2} %{buildroot}%{_rpmconfigdir}/fileattrs/gstreamer1.attr

%check
%if %{with tests}
export XDG_RUNTIME_DIR="$(pwd)/runtime-dir"
mkdir -p -m 700 "$XDG_RUNTIME_DIR"
xvfb-run -s '-nolisten local' \
        meson test -C %{_vpath_builddir} --print-errorlogs -t 3 
%endif

%files tools -f %{oname}-%{api}.lang
%license COPYING
%doc AUTHORS README.md NEWS
%dir %{_var}/cache/%{oname}-%{api}
%{_bindir}/gst-inspect-%{api}
%{_bindir}/gst-launch-%{api}
%{_bindir}/gst-typefind-%{api}
%{_bindir}/gst-stats-%{api}
%{_mandir}/man1/gst-inspect-%{api}.1*
%{_mandir}/man1/gst-launch-%{api}.1*
%{_mandir}/man1/gst-typefind-%{api}.1*
%{_mandir}/man1/gst-stats-%{api}.1*
%{_datadir}/bash-completion/completions/gst-inspect-1.0
%{_datadir}/bash-completion/completions/gst-launch-1.0
%{_datadir}/bash-completion/helpers/gst
%dir %{_libexecdir}/%{oname}-%{api}/
%caps(cap_sys_nice,cap_net_bind_service,cap_net_admin+ep) %{_libexecdir}/%{oname}-%{api}/gst-ptp-helper
%{_libexecdir}/%{oname}-%{api}/gst-completion-helper
%{_libexecdir}/%{oname}-%{api}/gst-plugin-scanner
%{_libexecdir}/%{oname}-%{api}/gst-hotdoc-plugins-scanner
%{_libexecdir}/%{oname}-%{api}/gst-plugins-doc-cache-generator

%files -n %{libname}
%dir %{_libdir}/%{oname}-%{api}
%{_libdir}/libgstbase-%{api}.so.%{major}{,.*}
%{_libdir}/libgstcheck-%{api}.so.%{major}{,.*}
%{_libdir}/libgstreamer-%{api}.so.%{major}{,.*}
%{_libdir}/libgstnet-%{api}.so.%{major}{,.*}
%{_libdir}/libgstcontroller-%{api}.so.%{major}{,.*}
%{_libdir}/%{oname}-%{api}/libgstcoreelements.so
%{_libdir}/%{oname}-%{api}/libgstcoretracers.so

%files -n %{gi_name}
%{_libdir}/girepository-1.0/Gst-%{api}.typelib
%{_libdir}/girepository-1.0/GstBase-%{api}.typelib
%{_libdir}/girepository-1.0/GstCheck-%{api}.typelib
%{_libdir}/girepository-1.0/GstController-%{api}.typelib
%{_libdir}/girepository-1.0/GstNet-%{api}.typelib

%files -n %{libnamedev}
%doc ChangeLog
%if %{with docs}
## gstreamer API
%doc %{_datadir}/gtk-doc/html/%{oname}/
## gstreamer-libs API
%doc %{_datadir}/gtk-doc/html/%{oname}-libs/
%endif

%{_rpmconfigdir}/gstreamer1.prov
%{_rpmconfigdir}/fileattrs/gstreamer1.attr
%dir %{_includedir}/%{oname}-%{api}
%dir %{_includedir}/%{oname}-%{api}/gst
%{_includedir}/%{oname}-%{api}/gst/*.h
%dir %{_includedir}/%{oname}-%{api}/gst/base/
%{_includedir}/%{oname}-%{api}/gst/base/*.h
%{_includedir}/%{oname}-%{api}/gst/check/
%dir %{_includedir}/%{oname}-%{api}/gst/controller/
%{_includedir}/%{oname}-%{api}/gst/controller/*.h
%{_includedir}/%{oname}-%{api}/gst/net/
%{_libdir}/libgstbase-%{api}.so
%{_libdir}/libgstcheck-%{api}.so
%{_libdir}/libgstreamer-%{api}.so
%{_libdir}/libgstnet-%{api}.so
%{_libdir}/libgstcontroller-%{api}.so
%{_datadir}/aclocal/gst-element-check-%{api}.m4
%{_datadir}/cmake/FindGStreamer.cmake
%{_libdir}/pkgconfig/gstreamer-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-base-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-check-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-net-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-controller-%{api}.pc
%{_datadir}/gir-1.0/Gst-%{api}.gir
%{_datadir}/gir-1.0/GstBase-%{api}.gir
%{_datadir}/gir-1.0/GstCheck-%{api}.gir
%{_datadir}/gir-1.0/GstController-%{api}.gir
%{_datadir}/gir-1.0/GstNet-%{api}.gir

# gdb extension
%{_datadir}/gdb/auto-load%{_libdir}/*.py
%dir %{_datadir}/gstreamer-1.0/
%{_datadir}/gstreamer-1.0/gdb/
