%bcond_without rdp

%define major          24
%define major_0        0
%define libguac        %mklibname guac %{major}
%define guac_cl_rdp    guacd-client-rdp
%define libguac_ter    %mklibname guac-terminal %{major_0}
%define libguac_cl_rdp %mklibname guac-client-rdp %{major_0}
%define libguac_cl_ssh %mklibname guac-client-ssh %{major_0}
%define libguac_cl_vnc %mklibname guac-client-vnc %{major_0}
%define libguac_cl_kubernetes %mklibname guac-client-kubernetes %{major_0}
%define develname      %mklibname guac -d

%global _hardened_build 1
%global username guacd
%global upname guacamole-server

Name:           guacd
Version:        1.5.5
Release:        %mkrel 2
Summary:        Server-side native components that form the Guacamole proxy
Group:          Networking/Other
License:        MPLv1.1 or GPLv2+
URL:            https://guacamole.apache.org/
Source0:        https://github.com/apache/guacamole-server/archive/%{version}/%{upname}-%{version}.tar.gz
Source1:        %{name}.sysconfig
Source2:        %{name}.service
# Add compatibility with FFMPEG 7.0
# https://github.com/apache/guacamole-server/pull/518
Patch1:         0001-Add-compatibility-with-FFMPEG-7.0.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  libtool
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(cairo)
%if %{with rdp}
BuildRequires:  pkgconfig(freerdp2)
BuildRequires:  pkgconfig(freerdp-client2)
%endif
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libssh2)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(ossp-uuid)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)

Recommends:     %{libguac_cl_vnc} = %{version}-%{release}
Provides:       %{upname} = %{version}-%{release}

%description
Guacamole is an HTML5 remote desktop gateway.

Guacamole provides access to desktop environments using remote desktop protocols
like VNC and RDP. A centralized server acts as a tunnel and proxy, allowing
access to multiple desktops through a web browser.

No browser plugins are needed, and no client software needs to be installed. The
client requires nothing more than a web browser supporting HTML5 and AJAX.

The main web application is provided by the "guacamole-client" package.

%package -n %{libguac}
Summary:        The common library used by all C components of Guacamole
Group:          System/Libraries

%description -n %{libguac}
libguac is the core library for guacd (the Guacamole proxy) and any protocol
support plugins for guacd. libguac provides efficient buffered I/O of text and
base64 data, as well as somewhat abstracted functions for sending Guacamole
instructions.

%if %{with rdp}
%package -n %{libguac_cl_rdp}
Summary:        RDP support for guacd
Group:          System/Libraries
Requires:       %{guac_cl_rdp} = %version-%release

%description -n %{libguac_cl_rdp}
libguac-client-rdp is a protocol support plugin for the Guacamole proxy (guacd)
which provides support for RDP, the proprietary remote desktop protocol used by
Windows Remote Deskop / Terminal Services, via the libfreerdp library.

%package -n %{guac_cl_rdp}
Summary:        RDP support for guacd
Group:          System/Libraries

%description -n %{guac_cl_rdp}
libguac-client-rdp is a protocol support plugin for the Guacamole proxy (guacd)
which provides support for RDP, the proprietary remote desktop protocol used by
Windows Remote Deskop / Terminal Services, via the libfreerdp library.

%endif

%package -n %{libguac_cl_ssh}
Summary:        SSH support for guacd
Group:          System/Libraries

%description -n %{libguac_cl_ssh}
libguac-client-ssh is a protocol support plugin for the Guacamole proxy (guacd)
which provides support for SSH, the secure shell.

%package -n %{libguac_cl_vnc}
Summary:        VNC support for guacd
Group:          System/Libraries

%description -n %{libguac_cl_vnc}
libguac-client-vnc is a protocol support plugin for the Guacamole proxy (guacd)
which provides support for VNC via the libvncclient library (part of
libvncserver).

%package -n %{libguac_ter}
Summary:        Terminal support for guacd
Group:          System/Libraries

Obsoletes:      %{_lib}guac-client-terminal0 < 1.5.1-2

%description -n %{libguac_ter}
libguac-terminal is a protocol support plugin for the Guacamole proxy
(guacd) which provides support for Terminal via the libterminal library.


%package -n %{libguac_cl_kubernetes}
Summary:        Kubernetes support for guacd
Group:          System/Libraries

%description -n %{libguac_cl_kubernetes}
libguac-client-kubernetes is a protocol support plugin for the Guacamole proxy
(guacd) which provides support for kubernetes.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libguac} = %{version}-%{release}
Requires:       %{libguac_ter} = %{version}-%{release}
%if %{with rdp}
Requires:       %{libguac_cl_rdp} = %{version}-%{release}
%endif
Requires:       %{libguac_cl_ssh} = %{version}-%{release}
Requires:       %{libguac_cl_vnc} = %{version}-%{release}
Requires:       %{libguac_cl_kubernetes} = %{version}-%{release}
Provides:       guac-devel = %{version}-%{release}
Provides:       libguac-devel = %{version}-%{release}

%description -n %{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.


%prep
%autosetup -n %{upname}-%{version} -p1

%build
autoreconf -vif
%configure \
  --disable-silent-rules \
  --disable-static \
  --without-telnet \
  --with-systemd-dir=%_unitdir

%make_build

cd doc/libguac
doxygen Doxyfile

%install
%make_install

cp -fr doc/libguac/doxygen-output/html .

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/guacd
mkdir -p %{buildroot}%{_sharedstatedir}/guacd

# Systemd unit files
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 -D %{SOURCE2} %{buildroot}%{_unitdir}/guacd.service

%pre
getent group %username >/dev/null || groupadd -r %username &>/dev/null || :
getent passwd %username >/dev/null || useradd -r -s /sbin/nologin \
    -d %{_sharedstatedir}/guacd -M -c 'Guacamole proxy daemon' -g %username %username &>/dev/null || :
exit 0

%post
%_post_service guacd

%preun
%_preun_service guacd

%files
%doc CONTRIBUTING README
%license LICENSE
%config(noreplace) %{_sysconfdir}/sysconfig/guacd
%{_bindir}/guaclog
%{_bindir}/guacenc
%{_mandir}/man1/guaclog.1.*
%{_mandir}/man5/guacd.conf.5.*
%{_mandir}/man8/guacd.8.*
%{_mandir}/man1/guacenc.1.*
%{_sbindir}/guacd
%{_unitdir}/guacd.service
%attr(750,%{username},%{username}) %{_sharedstatedir}/guacd

%files -n %{libguac}
%doc CONTRIBUTING README
%license LICENSE
%{_libdir}/libguac.so.%{major}{,.*}

%if %{with rdp}
%files -n %{libguac_cl_rdp}
%{_libdir}/libguac-client-rdp.so.%{major_0}{,.*}

%files -n %{guac_cl_rdp}
%dir %{_libdir}/freerdp2
%{_libdir}/freerdp2/libguac-common-svc-client.so
%{_libdir}/freerdp2/libguacai-client.so
%endif

%files -n %{libguac_cl_ssh}
%{_libdir}/libguac-client-ssh.so.%{major_0}{,.*}

%files -n %{libguac_cl_vnc}
%{_libdir}/libguac-client-vnc.so.%{major_0}{,.*}

%files -n %{libguac_ter}
%{_libdir}/libguac-terminal.so.%{major_0}{,.*}

%files -n %{libguac_cl_kubernetes}
%{_libdir}/libguac-client-kubernetes.so.%{major_0}{,.*}

%files -n %{develname}
%doc html
%{_includedir}/*
%{_libdir}/libguac.so
%{_libdir}/libguac-terminal.so
%if %{with rdp}
%{_libdir}/libguac-client-rdp.so
%endif
%{_libdir}/libguac-client-ssh.so
%{_libdir}/libguac-client-vnc.so
%{_libdir}/libguac-client-kubernetes.so
