%define major		1
%define	api		3.0
%define libname         %mklibname %{name} %{api} %{major}
%define develname	%mklibname %{name} %{api} -d

Name:		guile
Version:	3.0.9
Release:	%mkrel 3
Summary:	GNU implementation of Scheme for application extensibility
License:	LGPLv2+
Group:		Development/Other
URL:		https://www.gnu.org/software/guile/guile.html
Source0:	https://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.gz
Source1:	https://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.gz.sig
BuildRequires:	libgmp-devel
BuildRequires:	libltdl-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(readline)
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(bdw-gc)
BuildRequires:	pkgconfig(libffi)
# for srfi-19.test
BuildRequires:	timezone
BuildRequires:	chrpath
BuildRequires:	texinfo

%package -n %{name}%{api}
Summary:	GNU implementation of Scheme for application extensibility
Group:		Development/Other
Provides:	%{name} = %{version}-%{release}
Requires(post):		update-alternatives
Requires(postun):	update-alternatives
Conflicts:	guile1.8 < 1.8.8-30
Conflicts:	guile2.0 < 2.0.14-9
Conflicts:	guile < 2.0.14-8

%package -n %{libname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries
Requires:	%{name}%{api}-runtime = %{version}-%{release}

%package -n %{develname}
Summary:	Development headers and static library for libguile
Group:		Development/C
Requires:	%{name}%{api} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}%{api}-devel = %{version}-%{release}
Provides:	%{name}%{api}-devel = %{version}-%{release}
Provides:	%{name}%{api}-devel%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel%{?_isa} = %{version}-%{release}
Conflicts:	%{_lib}guile1.8-devel < 1.8.8-32
Conflicts:	%{_lib}guile2.0-devel < 2.0.14-9
Conflicts:	%{_lib}guile-devel < 2.0.14-8

%package -n %{name}%{api}-runtime
Summary:	Guile runtime library
Group:		System/Libraries

%description
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%description -n %{name}%{api}
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%description -n %{libname}
This package contains Guile shared object libraries.

%description -n %{develname}
This package contains the development headers and the static library
for libguile. C headers, aclocal macros, the `guile1.4-snarf' and
`guile-config' utilities, and static `libguile' library for Guile, the
GNU Ubiquitous Intelligent Language for Extension

%description -n %{name}%{api}-runtime
This package contains Scheme runtime for GUILE, including ice-9
Scheme module.

%prep
%autosetup -p1

#fix encodings
for i in libguile/ChangeLog*; do
	mv $i $i.old
	iconv -f ISO8859-1 -t UTF-8 $i.old -o $i
done

%build
autoreconf -vfi
%configure \
	--program-suffix="-%{api}" \
	--disable-error-on-warning \
	--disable-rpath \
	--disable-static \
	--with-threads \
	--with-pic

%make_build

%install
%make_install

#remove rpath
chrpath -d %{buildroot}%{_bindir}/%{name}-%{api}

#remove conflictin info pages
rm -rf %{buildroot}%{_infodir}

#rename conflicting m4 files
mv %{buildroot}%{_datadir}/aclocal/{guile.m4,guile-%{api}.m4}

#we don't want these
find %{buildroot} -name "*.la" -delete

#for ghost files
touch %{buildroot}%{_datadir}/%{name}/%{api}/slibcat
touch %{buildroot}%{_datadir}/%{name}/%{api}/slib

#slib needs this
mkdir -p %{buildroot}%{_datadir}/guile/site

# Taken from Opensuse to prevent this ugly error message
# ldconfig: /lib64/libguile-2.0.so.22.7.2-gdb.scm is not an ELF file - it has the wrong magic bytes at the start.
mkdir -p %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}
mv %{buildroot}%{_libdir}/libguile*-gdb.scm %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}/

%triggerin -n %{name}%{api} -- slib
ln -sfT ../../slib %{_datadir}/guile/%{api}/slib

rm -f %{_datadir}/guile/%{api}/slibcat
export SCHEME_LIBRARY_PATH=%{_datadir}/slib/

# Build SLIB catalog
for pre in \
    "(use-modules (ice-9 slib))" \
    "(load \"%{_datadir}/slib/guile.init\")"
do
    %{_bindir}/guile -c "$pre
        (set! implementation-vicinity (lambda () \"%{_datadir}/guile/%{api}/\"))
        (require 'new-catalog)" &> /dev/null && break
    rm -f %{_datadir}/guile/%{api}/slibcat
done
:

%triggerun -n %{name}%{api} -- slib
if [ "$1" = 0 -o "$2" = 0 ]; then
    rm -f %{_datadir}/guile/%{api}/slib{,cat}
fi

%posttrans -n %{name}%{api}
if [ "$1" -eq 1 ]; then
  update-alternatives \
    --install %{_bindir}/guile guile %{_bindir}/guile-%{api} 30 \
    --slave %{_bindir}/guile-tools guile-tools %{_bindir}/guile-tools-%{api} \
    --slave %{_bindir}/guild guild %{_bindir}/guild-%{api}
fi

%posttrans -n %{develname}
if [ "$1" -eq 1 ]; then
  update-alternatives \
    --install %{_bindir}/guile-config guile-config %{_bindir}/guile-config-%{api} 30 \
    --slave %{_bindir}/guile-snarf guile-snarf %{_bindir}/guile-snarf-%{api}
fi

%postun -n %{name}%{api}
if [ "$1" -eq 0 ]; then
  update-alternatives --remove guile %{_bindir}/guile-%{api}
fi

%postun -n %{develname}
if [ "$1" -eq 0 ]; then
  update-alternatives --remove guile-config %{_bindir}/guile-config-%{api}
fi

%files -n %{name}%{api}
%doc AUTHORS ChangeLog GUILE-VERSION LICENSE README THANKS
%ghost %{_bindir}/guile
%ghost %{_bindir}/guile-tools
%ghost %{_bindir}/guild
%{_bindir}/%{name}-%{api}
%{_bindir}/%{name}-tools-%{api}
%{_bindir}/guild-%{api}
%{_libdir}/%{name}/
%exclude %{_libdir}/%{name}/%{api}/
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/%{api}/
%{_mandir}/man1/guile-%{api}.1*

%files -n %{libname}
%{_libdir}/lib%{name}-%{api}.so.%{major}{,.*}

%files -n %{develname}
%doc HACKING NEWS libguile/ChangeLog*
%ghost %{_bindir}/guile-config
%ghost %{_bindir}/guile-snarf
%{_bindir}/guile-config-%{api}
%{_bindir}/guile-snarf-%{api}
%{_datadir}/aclocal/guile-%{api}.m4
%{_includedir}/%{name}/
%{_libdir}/lib%{name}-%{api}.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_datadir}/gdb/auto-load/%{_libdir}/libguile*-gdb.scm

%files -n %{name}%{api}-runtime
%{_libdir}/%{name}/%{api}/
%{_datadir}/%{name}/%{api}/
# ugly workaround to not list files twice
%exclude %{_datadir}/%{name}/%{api}/slibcat
%exclude %{_datadir}/%{name}/%{api}/slib
%ghost %{_datadir}/%{name}/%{api}/slibcat
%ghost %{_datadir}/%{name}/%{api}/slib
