%define oname		guile

%define major		17
%define libname		%mklibname %{oname} %{major}
%define develname	%mklibname %{oname}%{api} -d

%define api 1.8

%global __provides_exclude_from ^%{_libdir}/lib%{oname}-srfi-.*\\.so$
%global __requires_exclude_from ^%{_libdir}/lib%{oname}-srfi-.*\\.so$

Name:		guile%{api}
Version:	1.8.8
Release:	%mkrel 33
Summary:	GNU implementation of Scheme for application extensibility
License:	LGPLv2+
Group:		Development/Other
URL:		https://www.gnu.org/software/guile/guile.html
Source0:	https://ftp.gnu.org/gnu/guile/guile-%{version}.tar.gz
Source1:	https://ftp.gnu.org/gnu/guile/guile-%{version}.tar.gz.sig
Patch0:		guile-1.8.3-64bit-fixes.patch
Patch1:		guile-1.6.4-amd64.patch
Patch2:		guile-1.8.5-drop-ldflags-from-pkgconfig.patch
Patch3:		guile-1.8.7-testsuite.patch
Patch5:		guile-1.8.7-fix-doc.patch
Patch6:		guile-1.8.8-make-sockets.test-more-robust.patch
Patch7:		guile-1.8.8-automake-1.13.patch
Patch8:		guile-1.8.8-drop-broken-test-hack.patch
Patch9:		guile-1.8.8-mark-Unused-modules-are-removed-gc-test-as-unresolved.patch
# (martinw) fix CVE-2016-8605 (from FC)
Patch10:	guile-1.8.8-cve-2016-8605.patch
# (martinw) prevent find_stack_direction from being inlined and computing the wrong direction (from FC)
Patch11:	guile-1.8.8-configure.patch
Patch12:	guile-autoconf.patch
Requires(post):	%{libname} = %{version}-%{release}
Requires(post):	rpm-helper
Requires(post): update-alternatives
Requires(preun): rpm-helper
Requires(postun): update-alternatives
BuildRequires:	chrpath
BuildRequires:	libgmp-devel
BuildRequires:	libltdl-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	readline-devel
BuildRequires:	gettext-devel
# for srfi-19.test
BuildRequires:	timezone
Obsoletes:	%{oname} < 1.8.8-7

%package -n %{libname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries
Requires:	%{name}-runtime = %{version}-%{release}

%package -n %{develname}
Summary:	Development headers and static library for libguile
Group:	Development/C
Requires:	%{libname} = %{version}-%{release}
# AutoReq requires /usr/bin/guile which can be the 2.0 one
Requires:	%{name} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}%{oname}-devel < 1.8.8-7
Obsoletes:	%{_lib}%{oname}17-devel
Requires:	libgmp-devel
Requires:	libtool-devel

%package runtime
Summary:	Guile runtime library
Group:		System/Libraries

%description
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%description -n %{libname}
This package contains Guile shared object libraries. Guile is the GNU
Ubiquitous Intelligent Language for Extension.

%description -n %{develname}
This package contains the development headers and the static library
for libguile. C headers, aclocal macros, the `guile1.4-snarf' and
`guile-config' utilities, and static `libguile' library for Guile, the
GNU Ubiquitous Intelligent Language for Extension

%description runtime
This package contains Scheme runtime for GUILE, including ice-9
Scheme module.

%prep
%setup -q -n %{oname}-%{version}
%autopatch -p1

chmod +x scripts/snarf-check-and-output-texi

%build
autoreconf -vfi
%configure \
    --program-suffix="-%{api}" \
    --disable-error-on-warning \
    --disable-rpath \
    --enable-dynamic-linking \
    --with-threads \
    --disable-static

%make_build

%check
# There was a hack, now broken to make it generated before running the tests
# Patch8 drops the hack so we need to build the file
make -C libguile stack-limit-calibration.scm

%ifarch ia64 %ix86
# FAIL: r4rs.test: (6 9): (#<procedure leaf-eq? (x y)> (a (b (c))) ((a) b c))
%{__make} check -k || :
%else
# all tests must pass
%{__make} check -k || :
%endif

%install
%make_install

%{__mkdir_p} %{buildroot}%{_datadir}/%{oname}/site

%{_bindir}/chrpath -d %{buildroot}{%{_bindir}/%{oname}-%{api},%{_libdir}/*.so.*.*.*}

# create ghost file for packaging
touch %{buildroot}%{_datadir}/%{oname}/%{api}/slib %{buildroot}%{_datadir}/%{oname}/%{api}/slibcat

rm -f ${RPM_BUILD_ROOT}%{_libdir}/libguile*.la

# remove conflicting info pages
rm -rf %{buildroot}%{_infodir}/

# rename conflicting m4 files
mv %{buildroot}%{_datadir}/aclocal/{guile.m4,guile-%{api}.m4}

%triggerin -- slib
# Remove files created in guile < 1.8.7-4mdv
ln -sfT ../../slib %{_datadir}/guile/%{api}/slib

rm -f %{_datadir}/guile/%{api}/slibcat
export SCHEME_LIBRARY_PATH=%{_datadir}/slib/

# Build SLIB catalog
for pre in \
    "(use-modules (ice-9 slib))" \
    "(load \"%{_datadir}/slib/guile.init\")"
do
    %{_bindir}/guile -c "$pre
        (set! implementation-vicinity (lambda () \"%{_datadir}/guile/%{api}/\"))
        (require 'new-catalog)" &> /dev/null && break
    rm -f %{_datadir}/guile/%{api}/slibcat
done
:

%triggerun -- slib
if [ "$1" = 0 -o "$2" = 0 ]; then
    rm -f %{_datadir}/guile/%{api}/slib{,cat}
fi

%triggerpostun -- guile1.8 < 1.8.8-30
if [ -e %{_bindir}/guile -a ! -L %{_bindir}/guile ]; then
  rm -rf %{_bindir}/guile{,-tools}
fi

%triggerpostun -n %{develname} -- %{_lib}guile1.8-devel < 1.8.8-32
if [ -e %{_bindir}/guile-config -a ! -L %{_bindir}/guile-config ]; then
  rm -rf %{_bindir}/guile-{config,snarf}
fi

%posttrans
if [ "$1" -eq 1 ]; then
  update-alternatives \
    --install %{_bindir}/guile guile %{_bindir}/guile-%{api} 18 \
    --slave %{_bindir}/guile-tools guile-tools %{_bindir}/guile-tools-%{api}
fi

%posttrans -n %{develname}
if [ "$1" -eq 1 ]; then
  update-alternatives \
    --install %{_bindir}/guile-config guile-config %{_bindir}/guile-config-%{api} 18 \
    --slave %{_bindir}/guile-snarf guile-snarf %{_bindir}/guile-snarf-%{api}
fi

%postun
if [ "$1" -eq 0 ]; then
  update-alternatives --remove guile %{_bindir}/guile-%{api}
fi

%postun -n %{develname}
if [ "$1" -eq 0 ]; then
  update-alternatives --remove guile-config %{_bindir}/guile-config-%{api}
fi

%files
%doc AUTHORS ChangeLog GUILE-VERSION LICENSE README THANKS
%ghost %{_bindir}/%{oname}
%ghost %{_bindir}/%{oname}-tools
%{_bindir}/%{oname}-%{api}
%{_bindir}/%{oname}-tools-%{api}
%{_mandir}/man1/guile-%{api}.1.*

%files -n %{libname}
%{_libdir}/lib*.so.%{major}{,.*}
%{_libdir}/lib%{oname}-srfi-srfi-13-14-v-3.so.3*
%{_libdir}/lib%{oname}-srfi-srfi-4-v-3.so.3*
%{_libdir}/lib%{oname}-srfi-srfi-1-v-3.so.3*
%{_libdir}/lib%{oname}-srfi-srfi-60-v-2.so.2*

%files -n %{develname}
%doc ABOUT-NLS HACKING NEWS INSTALL libguile/ChangeLog*
%ghost %{_bindir}/%{oname}-config
%ghost %{_bindir}/%{oname}-snarf
%{_bindir}/%{oname}-config-%{api}
%{_bindir}/%{oname}-snarf-%{api}
%{_datadir}/aclocal/guile-%{api}.m4
%{_includedir}/lib%{oname}*
%{_includedir}/%{oname}*
%{_libdir}/lib%{oname}*.so
%exclude %{_libdir}/lib%{oname}-srfi*.so
%{_libdir}/pkgconfig/%{oname}*.pc

%files runtime
%{_datadir}/%{oname}/%{api}/*
# unversioned libraries needed in the runtime
%{_libdir}/lib%{oname}-srfi*.so
# ugly workaround to not list files twice
%exclude %{_datadir}/%{oname}/%{api}/slibcat
%exclude %{_datadir}/%{oname}/%{api}/slib
%ghost %{_datadir}/%{oname}/%{api}/slibcat
%ghost %{_datadir}/%{oname}/%{api}/slib
