%define major		22
%define	api		2.0
%define libname         %mklibname guile %{api} %{major}
%define develname	%mklibname guile %{api} -d

%define rlmajor		18
%define rlapi		18
%define rllibname	%mklibname guilereadline %{rlapi} %{rlmajor}

Name:		guile%{api}
Version:	2.0.14
Release:	%mkrel 13
Summary:	GNU implementation of Scheme for application extensibility
License:	LGPLv2+
Group:		Development/Other
URL:		https://www.gnu.org/software/guile/guile.html
Source0:	https://ftp.gnu.org/gnu/guile/guile-%{version}.tar.gz
Source1:	https://ftp.gnu.org/gnu/guile/guile-%{version}.tar.gz.sig
Patch1:		guile2.0.info.patch
Patch2:		guile-autoconf.patch
BuildRequires:	libgmp-devel
BuildRequires:	libltdl-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(readline)
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(bdw-gc)
BuildRequires:	pkgconfig(libffi)
# for srfi-19.test
BuildRequires:	timezone
BuildRequires:	chrpath
BuildRequires:	texinfo
Obsoletes:	guile < 3.0
Requires(post):		update-alternatives
Requires(postun):	update-alternatives

%package -n %{libname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries
Requires:	%{name}-runtime = %{version}-%{release}

%package -n %{rllibname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries

%package -n %{develname}
Summary:	Development headers and static library for libguile
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{rllibname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}guile-devel < 3.0

%package runtime
Summary:        Guile runtime library
Group:          System/Libraries
Requires:	%{rllibname} = %{version}-%{release}
Obsoletes:	guile-runtime < 3.0

%description
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%description -n %{libname}
This package contains Guile shared object libraries.

%description -n %{rllibname}
This package contains Guile shared object libraries.

%description -n %{develname}
This package contains the development headers and the static library
for libguile. C headers, aclocal macros, the `guile1.4-snarf' and
`guile-config' utilities, and static `libguile' library for Guile, the
GNU Ubiquitous Intelligent Language for Extension

%description runtime
This package contains Scheme runtime for GUILE, including ice-9
Scheme module.

%prep
%setup -qn guile-%{version}
%autopatch -p1

#fix encodings
for i in libguile/ChangeLog*; do
	mv $i $i.old
	iconv -f ISO8859-1 -t UTF-8 $i.old -o $i
done

#drop info pages
rm -rf doc/ref/guile.info*

%build
autoreconf -vfi
%configure \
	--program-suffix="-%{api}" \
	--disable-error-on-warning \
	--disable-rpath \
	--disable-static \
	--with-threads \
	--with-pic

%make_build

%install
%make_install

#remove rpath
chrpath -d %{buildroot}%{_bindir}/guile-%{api}

#rename conflicting m4 files
mv %{buildroot}%{_datadir}/aclocal/{guile.m4,guile-%{api}.m4}

#drop conflicting info pages
rm -rf %{buildroot}%{_infodir}

#we don't want these
find %{buildroot} -name "*.la" -delete

#remove ldflags from pkg-conf .pc file private.libs
sed -i -e 's/-Wl,.*\s\+//g' %{buildroot}%{_libdir}/pkgconfig/guile-%{api}.pc

#for ghost files
touch %{buildroot}%{_datadir}/guile/%{api}/slibcat
touch %{buildroot}%{_datadir}/guile/%{api}/slib

#slib needs this
mkdir -p %{buildroot}%{_datadir}/guile/site

# Taken from Opensuse to prevent this ugly error message
# ldconfig: /lib64/libguile-2.0.so.22.7.2-gdb.scm is not an ELF file - it has the wrong magic bytes at the start.
mkdir -p %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}
mv %{buildroot}%{_libdir}/libguile*-gdb.scm %{buildroot}%{_datadir}/gdb/auto-load%{_libdir}/

# Create .so symlink for guile dynload
mkdir -p %{buildroot}%{_libdir}/guile/%{api}/extensions
ln -s %{_libdir}/libguilereadline-v-%{rlapi}.so.%{rlmajor} %{buildroot}%{_libdir}/guile/%{api}/extensions/libguilereadline-v-%{rlapi}.so

%triggerin -- slib
ln -sfT ../../slib %{_datadir}/guile/%{api}/slib

rm -f %{_datadir}/guile/%{mver}/slibcat
export SCHEME_LIBRARY_PATH=%{_datadir}/slib/

# Build SLIB catalog
for pre in \
    "(use-modules (ice-9 slib))" \
    "(load \"%{_datadir}/slib/guile.init\")"
do
    %{_bindir}/guile%{api} -c "$pre
        (set! implementation-vicinity (lambda () \"%{_datadir}/guile/%{api}/\"))
        (require 'new-catalog)" &> /dev/null && break
    rm -f %{_datadir}/guile/%{api}/slibcat
done
:

%triggerun -- slib
if [ "$1" = 0 -o "$2" = 0 ]; then
    rm -f %{_datadir}/guile/%{api}/slib{,cat}
fi

%triggerpostun -- guile < 2.0.14-8
if [ -e %{_bindir}/guile -a ! -L %{_bindir}/guile ]; then
  rm -rf %{_bindir}/{guile,guile-tools,guild}
fi

%triggerpostun -n %{develname} -- %{_lib}guile-devel < 2.0.14-8, %{_lib}guile2.0-devel < 2.0.14-9
if [ -e %{_bindir}/guile-config -a ! -L %{_bindir}/guile-config ]; then
  rm -rf %{_bindir}/guile-{config,snarf}
fi

%posttrans
if [ "$1" -eq 1 ]; then
  update-alternatives \
    --install %{_bindir}/guile guile %{_bindir}/guile-%{api} 20 \
    --slave %{_bindir}/guile-tools guile-tools %{_bindir}/guile-tools-%{api} \
    --slave %{_bindir}/guild guild %{_bindir}/guild-%{api}
fi

%posttrans -n %{develname}
if [ "$1" -eq 1 ]; then
  update-alternatives \
    --install %{_bindir}/guile-config guile-config %{_bindir}/guile-config-%{api} 20 \
    --slave %{_bindir}/guile-snarf guile-snarf %{_bindir}/guile-snarf-%{api}
fi

%postun
if [ "$1" -eq 0 ]; then
  update-alternatives --remove guile %{_bindir}/guile-%{api}
fi

%postun -n %{develname}
if [ "$1" -eq 0 ]; then
  update-alternatives --remove guile-config %{_bindir}/guile-config-%{api}
fi

%files
%doc AUTHORS ChangeLog GUILE-VERSION LICENSE README THANKS
%ghost %{_bindir}/guile
%ghost %{_bindir}/guile-tools
%ghost %{_bindir}/guild
%{_bindir}/guile-%{api}
%{_bindir}/guile-tools-%{api}
%{_bindir}/guild-%{api}
%{_libdir}/guile/
%exclude %{_libdir}/guile/%{api}/
%{_datadir}/guile/
%exclude %{_datadir}/guile/%{api}/
%{_mandir}/man1/guile-%{api}.1*

%files -n %{libname}
%{_libdir}/libguile-%{api}.so.%{major}{,.*}

%files -n %{rllibname}
%{_libdir}/libguilereadline-v-%{rlapi}.so.%{rlmajor}{,.*}

%files -n %{develname}
%doc HACKING NEWS libguile/ChangeLog*
%ghost %{_bindir}/guile-config
%ghost %{_bindir}/guile-snarf
%{_bindir}/guile-config-%{api}
%{_bindir}/guile-snarf-%{api}
%{_datadir}/aclocal/guile-%{api}.m4
%{_includedir}/guile/
%{_libdir}/libguile-%{api}.so
%{_libdir}/libguilereadline-v-%{rlapi}.so
%{_libdir}/pkgconfig/guile-%{api}.pc
%{_datadir}/gdb/auto-load/%{_libdir}/libguile*-gdb.scm

%files runtime
%{_libdir}/guile/%{api}/
%{_datadir}/guile/%{api}/
# ugly workaround to not list files twice
%exclude %{_datadir}/guile/%{api}/slibcat
%exclude %{_datadir}/guile/%{api}/slib
%ghost %{_datadir}/guile/%{api}/slibcat
%ghost %{_datadir}/guile/%{api}/slib
