%define upstream_name   HandBrake
%define download        %{_builddir}/%{upstream_name}-%{version}/download

%define bluray_ver	1.3.4
%define dvdnav_ver	6.1.1
%define dvdread_ver	6.1.3

%define x265_ver	4.1
%define nv_ver		12.2.72.0
%define ffmpeg_ver	7.1
%define dav_ver		1.5.0

%define zimg_ver	3.0.5
%define svt_av1_ver	2.2.1
%define fdk_aac_ver	2.0.3
%define sse2neon_ver	1.7.0

%ifarch x86_64 aarch64
%bcond_without vpl
%else
%bcond_with vpl
%endif


Summary:        An open-source video transcoder
Name:           handbrake
Version:        1.9.0
Release:        %mkrel 7
License:        GPLv2
Group:          Video/Editors and Converters
URL:            https://handbrake.fr/
#these bundles are otherwise downloaded. They are heavily patched by
#the configure script and that prevents us to replace them by linking
#with our system libraries
Source0:        https://github.com/HandBrake/HandBrake/releases/download/%{version}/%{upstream_name}-%{version}-source.tar.bz2
Source1:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contribs/libbluray-%{bluray_ver}.tar.bz2
Source2:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contribs/libdvdnav-%{dvdnav_ver}.tar.bz2
Source3:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contribs/libdvdread-%{dvdread_ver}.tar.bz2

Source5:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contribs/x265_%{x265_ver}.tar.gz
Source6:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contrib2/nv-codec-headers-%{nv_ver}.tar.gz
Source7:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contrib2/ffmpeg-%{ffmpeg_ver}.tar.bz2
Source8:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contrib2/dav1d-%{dav_ver}.tar.bz2
Source9:        https://github.com/HandBrake/HandBrake-contribs/releases/download/contribs/zimg-%{zimg_ver}.tar.gz
Source10:       https://github.com/HandBrake/HandBrake-contribs/releases/download/contrib2/SVT-AV1-v%{svt_av1_ver}.tar.gz
Source11:       https://github.com/HandBrake/HandBrake-contribs/releases/download/contrib2/fdk-aac-%{fdk_aac_ver}.tar.gz
Source12:       https://github.com/HandBrake/HandBrake-contribs/releases/download/contrib2/sse2neon-%{sse2neon_ver}.tar.gz
#applied by the configure script
Source100:      linking-issue-on-non-x86-platform.patch
Source101:      x265-armv7hl.patch
Source102:	x265-armv7hl-PIC.patch

#required on ix86
Patch1:         handbrake-1.6.0-x265-max8bits.patch

#https://github.com/HandBrake/HandBrake/pull/6463
Patch2:         handbrake-1.9.0-comb_detect.patch

BuildRequires:  meson
BuildRequires:  appstream
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  yasm
BuildRequires:  nasm
BuildRequires:  python3
BuildRequires:  lame-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
#uildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libass)
%if %{with vpl}
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(vpl)
%endif
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(SvtAv1Enc)
%ifnarch %arm
BuildRequires:  pkgconfig(numa)
%endif
#(eatdirt) if missing, x265 gets silently build against system x265
#(if present): See mga#33148
BuildRequires:  git


#Heavily patched bundles
Provides: bundled(libbluray) = %{bluray_ver}
Provides: bundled(libdvdnav) = %{dvdnav_ver}
Provides: bundled(libdvdread) = %{dvdread_ver}

Provides: bundled(x265) = %{x265_ver}
Provides: bundled(nv-codec-headers) = %{nv_ver}
Provides: bundled(ffmpeg) = %{ffmpeg_ver}
Provides: bundled(libdav1d) = %{dav_ver}
Provides: bundled(libsvt-av1) = %{svt_av1_ver}
Provides: bundled(fdk-aac) = %{fdk_aac_ver}

%description
HandBrake takes videos you already have and makes new ones that work
on your mobile phone, tablet, TV media player, game console, computer,
or web browser, nearly anything that supports modern video formats.
HandBrake works with most common video files and formats, including
ones created by consumer and professional video cameras, mobile
devices such as phones and tablets, game and computer screen
recordings, and DVD and Blu-ray discs. HandBrake leverages tools such
as FFmpeg, x264, and x265 to create new MP4 or MKV video files from
these sources.

%prep
%setup -q -n %{upstream_name}-%{version}

%ifarch %ix86 %arm
%patch -P 1 -p1 -b .x265-no-10bit-12bit
%endif

%patch -P 2 -p1 -b .decombtype

mkdir -p %download
cp -t %download %{SOURCE1}
cp -t %download %{SOURCE2}
cp -t %download %{SOURCE3}

cp -t %download %{SOURCE5}
cp -t %download %{SOURCE6}
cp -t %download %{SOURCE7}
cp -t %download %{SOURCE8}
cp -t %download %{SOURCE9}
#cp -t %%download %%{SOURCE10} # 1.7.0 fails to build on 32bits
cp -t %download %{SOURCE11}
# needed only for aarch64
cp -t %download %{SOURCE12}

#patches
install -Dpm644 %{SOURCE101} ./contrib/x265/A98-armv7hl.patch
install -Dpm644 %{SOURCE102} ./contrib/x265/A99-armv7hl-PIC.patch

#(eatdirt) unneeded with stable x265 v3.6
%__rm -f contrib/x265/A00-crosscompile-fix.patch

# Use system libraries in place of bundled ones
for module in svt-av1 %{?with_vpl:libmfx libvpl}; do
    sed -i -e "/MODULES += contrib\/$module/d" make/include/main.defs
done


%build
#that is no a autoconf configure script (see ./configure --help)
%set_build_flags

echo "GCC.args.O.speed = %{optflags} %{?with_vpl:-I%{_includedir}/vpl -lvpl}" > custom.defs
echo "GCC.args.g.none = " >> custom.defs

./configure \
        --no-harden \
        --disable-df-fetch \
        --prefix=%{_prefix} \
%ifarch aarch64
        --disable-nvenc \
%endif
%ifarch %arm
        --disable-numa \
        --disable-nvenc \
%endif
        --launch \
        --launch-jobs=0 \
        --verbose \
        --debug=std \
        %{?with_vpl:--enable-qsv} \
        --enable-fdk-aac

%make_build -C build

%install
%make_install -C build

%find_lang ghb

desktop-file-install --vendor="" \
  --remove-category="Application" \
  --remove-key="Encoding" \
  --add-category="AudioVideo;Video;AudioVideoEditing;" \
  --add-category="X-Mageia-CrossDesktop" \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*

%files -f ghb.lang
%doc AUTHORS* NEWS* README* THANKS*
%license COPYING
%{_bindir}/ghb
%{_bindir}/HandBrakeCLI
%{_datadir}/applications/fr.handbrake.ghb.desktop
%{_iconsdir}/hicolor/scalable/apps/fr.handbrake.ghb.svg
%{_metainfodir}/fr.handbrake.ghb.metainfo.xml
