%{?!lua_version:%global lua_version 5.4}

%define url_ver %(echo %{version} | cut -d. -f1,2)

Summary:	Reliable High Performance TCP/HTTP Load Balancer
Name:		haproxy
Version:	3.1.6
Release:	%mkrel 1
License:	GPLv2 and LGPLv2
Group:		System/Servers
URL:		https://www.haproxy.org
Source0:	https://www.haproxy.org/download/%{url_ver}/src/%{name}-%{version}.tar.gz
Source1:	https://www.haproxy.org/download/%{url_ver}/src/%{name}-%{version}.tar.gz.sha256
Source2:	https://www.haproxy.org/download/%{url_ver}/src/%{name}-%{version}.tar.gz.md5
Source3:	%{name}.service
Source4:	%{name}.tmpfiles
Source5:	%{name}.logrotate
Source6:	%{name}.sysconfig
Source7:	%{name}.conf
Source8:	%{name}.check
Patch0:		haproxy-3.0.3-rapsys-key-private.patch
Patch1:		haproxy-3.1.0-quic.patch
Patch2:		haproxy-2.8.3-rapsys-fix-log-append.patch
Patch3:		haproxy-2.8.4-rapsys-buffered-stdout.patch
%ifarch armv7hl aarch64
BuildRequires:	libatomic-devel
%endif
Requires(pre):	shadow-utils
Requires(pre):	rpm-helper
Requires(post):	hostname openssl rpm-helper
Requires(postun):	rpm-helper
BuildRequires:	pcre2-devel
BuildRequires:	pkgconfig(libcrypt)
BuildRequires:	pkgconfig(lua) >= %{lua_version}
BuildRequires:	pkgconfig(openssl-quic)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libsystemd)
#BuildRequires:	pkgconfig(zlib)
BuildRequires:	slz-devel
BuildRequires:	perl
BuildRequires:	apg
Requires:	lua%{lua_version}
Requires:	haproxy-server = %{version}-%{release}
Requires(postun):	update-alternatives
Requires(posttrans):	update-alternatives

%description
HAProxy is free, open source software that provides a high availability load
balancer and proxy server for TCP and HTTP-based applications that spreads
requests across multiple servers. It is written in C and has a reputation for
being fast and efficient.

%package noquic
Summary:	Reliable High Performance TCP/HTTP Load Balancer
Group:		System/Servers
Provides:	haproxy-server = %{version}-%{release}
Requires:	haproxy = %{version}-%{release}
Requires:	libgcc1

%description noquic
HAProxy is free, open source software that provides a high availability load
balancer and proxy server for TCP and HTTP-based applications that spreads
requests across multiple servers. It is written in C and has a reputation for
being fast and efficient. Build without QUIC protocol support.

This HAProxy binary is linked to openssl without QUIC protocol support.

%package quic
Summary:	Reliable High Performance TCP/HTTP Load Balancer
Group:		System/Servers
Provides:	haproxy-server = %{version}-%{release}
Requires:	haproxy = %{version}-%{release}
Requires:	libgcc1

%description quic
HAProxy is free, open source software that provides a high availability load
balancer and proxy server for TCP and HTTP-based applications that spreads
requests across multiple servers. It is written in C and has a reputation for
being fast and efficient. Build with QUIC protocol support.

This HAProxy binary is linked to quictls with QUIC protocol support.

%package utils
Summary:	Utilities for working with HAProxy servers
Group:		Networking/Other

%description utils
HAProxy-utils contains a couple of command line utilities for working with
haproxy servers.

You should install haproxy-utils if you need to get information from HAProxy
servers.

%prep
%autosetup -p1

%build
# Build haproxy noquic and quic
for QUIC in "" "1"; do
%make_build \
	CFLAGS="%{build_cflags} -fwrapv" \
	LDFLAGS="%{build_ldflags}" \
	CPU="generic" \
	TARGET="linux-glibc" \
	USE_LUA="1" \
	LUA_LIB="%{lua_libdir}" \
	LUA_INC="%{_includedir}/lua" \
	USE_CRYPT_H="1" \
	USE_DL="1" \
	USE_EPOLL="1" \
	USE_GETADDRINFO="1" \
	USE_LIBCRYPT="1" \
	USE_LINUX_SPLICE="1" \
	USE_LINUX_TPROXY="1" \
	USE_NS="1" \
	USE_OPENSSL="1" \
	USE_PCRE2="1" \
	USE_PCRE2_JIT="1" \
	USE_PROMEX="1" \
	USE_QUIC="${QUIC}" \
	USE_RT="1" \
	USE_SYSTEMD="1" \
	USE_TFO="1" \
	USE_THREAD="1" \
	USE_THREAD_DUMP="1" \
	USE_TPROXY="1" \
	USE_SLZ="1" \
	PREFIX=%{_prefix} \
	MANDIR=%{_mandir} \
	DOCDIR=%{_pkgdocdir} \
	PCRE2_LIB=%{_libdir};
done

# Build utils
%make_build \
	CFLAGS="%{build_cflags} -fwrapv" \
	LDFLAGS="%{build_ldflags}" \
	admin/halog/halog \
	admin/iprange/iprange \
	dev/tcploop/tcploop \
	dev/poll/poll \
	dev/flags/flags \
	dev/hpack/{decode,gen-enc,gen-rht}

%install
for QUIC in "" "1"; do
%make_install \
	USE_QUIC="${QUIC}" \
	PREFIX=%{_prefix} \
	MANDIR=%{_mandir} \
	DOCDIR=%{_pkgdocdir};
done

# Install sysconfdirs
install -d 0755 %{buildroot}%{_sysconfdir}
install -d 0755 %{buildroot}%{_sysconfdir}/%{name}
install -d 0755 %{buildroot}%{_sysconfdir}/sysconfig

# Install shared state dir
install -d 0755 %{buildroot}%{_sharedstatedir}/%{name}

# Install service
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service

# Install tmpfiles
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# Install log rotation stuff
install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Install sysconfig
install -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

# Install configuration
#TODO: implement https://github.com/janeczku/haproxy-acme-validation-plugin/blob/master/acme-http01-webroot.lua ?
install -D -p -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# Install check
install -D -p -m 0755 %{SOURCE8} %{buildroot}%{_sbindir}/haproxy-check

# Replace admin password
perl -pne 's/ADMINPASSWORD/SECUREME!/' -i %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# Replace operator password
perl -pne 's/OPERATORPASSWORD/SECUREME!/' -i %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# Copy errors files
cp -r examples/errorfiles %{buildroot}%{_pkgdocdir}/error

# Install vim syntax
install -D -p -m 0644 admin/syntax-highlight/%{name}.vim %{buildroot}%{_datadir}/vim/syntax/%{name}.vim

# Install README.urpmi
cat << EOF | perl -pe 'chomp if eof' > README.urpmi
Haproxy is now installed.

Configuration file is %{_sysconfdir}/%{name}/%{name}.conf

The server listen on any:8000, 8080 and 8443 by default.

Add to %{_sysconfdir}/shorewall/rules.haproxy these shorewall rules for a transparent proxy:
# Redirect tcp traffic from net on port 80 to 8000
REDIRECT	net	8000	tcp	80
# Redirect tcp traffic from net on port 443 to 8000
REDIRECT	net	8000	tcp	443
# Redirect udp traffic from net on port 443 to 8443
#REDIRECT	net	8443	udp	443

Enable the service with:
# systemctl enable haproxy.service

Start the service with:
# systemctl start haproxy.service
EOF

# Install log dir
install -d -m 755 %{buildroot}%{_logdir}/%{name}

# Install bin dir
install -d 0755 %{buildroot}%{_bindir}

# Install haproxy utils
install -p -m 0755 admin/halog/halog %{buildroot}%{_bindir}/halog
install -p -m 0755 admin/iprange/iprange %{buildroot}%{_bindir}/iprange
install -p -m 0755 dev/flags/flags %{buildroot}%{_bindir}/flags
install -p -m 0755 dev/poll/poll %{buildroot}%{_bindir}/poll
install -p -m 0755 dev/tcploop/tcploop %{buildroot}%{_bindir}/tcploop
install -p -m 0755 dev/hpack/gen-rht %{buildroot}%{_bindir}/gen-rht
install -p -m 0755 dev/hpack/gen-enc %{buildroot}%{_bindir}/gen-enc
install -p -m 0755 dev/hpack/decode %{buildroot}%{_bindir}/hadecode

%pre
%_pre_useradd %{name} %{_sharedstatedir}/%{name} /bin/false
%_pre_groupadd %{name} %{name}

%preun
%_preun_service %{name}

%post
%_tmpfilescreate %{name}
%_post_service %{name}
%_create_ssl_certificate %{name} -g %{name}

%postun
%_postun_userdel %{name}
%_postun_groupdel %{name}

%posttrans noquic
%{_sbindir}/update-alternatives --install %{_sbindir}/haproxy haproxy %{_sbindir}/haproxy-noquic 10

%postun noquic
if [ "$1" -eq "0" ]; then
	%{_sbindir}/update-alternatives --remove haproxy %{_sbindir}/haproxy-noquic
fi

%posttrans quic
%{_sbindir}/update-alternatives --install %{_sbindir}/haproxy haproxy %{_sbindir}/haproxy-quic 20

%postun quic
if [ "$1" -eq "0" ]; then
	%{_sbindir}/update-alternatives --remove haproxy %{_sbindir}/haproxy-quic
fi

%files
%doc README.urpmi
%dir %{_logdir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_sbindir}/haproxy-check
%{_pkgdocdir}/*.txt
%{_pkgdocdir}/error/*
%{_mandir}/man1/*
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_datadir}/vim/syntax/%{name}.vim
%attr(0750, %{name}, %{name}) %{_sharedstatedir}/%{name}

%files noquic
%{_sbindir}/%{name}-noquic

%files quic
%{_sbindir}/%{name}-quic

%files utils
%{_bindir}/flags
%{_bindir}/gen-enc
%{_bindir}/gen-rht
%{_bindir}/hadecode
%{_bindir}/halog
%{_bindir}/iprange
%{_bindir}/poll
%{_bindir}/tcploop
