%define Werror_cflags %nil
%define _disable_ld_no_undefined 1

%define major    0
%define libdf    %mklibname df %{major}
%define libmfhdf %mklibname mfhdf %{major}

%bcond_without java

Name:           hdf
Version:        4.3.0
Release:        %mkrel 1
Summary:        A general purpose library and file format for storing scientific data
License:        BSD
Group:          System/Libraries
URL:            https://portal.hdfgroup.org/
Source0:        https://github.com/HDFGroup/hdf4/archive/hdf%{version}.tar.gz
Source1:        h4comp
# Fix java build
Patch1:         hdf-build.patch
BuildRequires:  flex
BuildRequires:  byacc
BuildRequires:  chrpath
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  libaec-devel
BuildRequires:  gcc-gfortran
%if %{with java}
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  hamcrest
BuildRequires:  junit
BuildRequires:  slf4j
%else
Obsoletes:      java-hdf < %{version}-%{release}
%endif
Obsoletes:      HDF-util < %{version}-%{release}


%description
HDF is a general purpose library and file format for storing scientific data.
HDF can store two primary objects: datasets and groups. A dataset is
essentially a multidimensional array of data elements, and a group is a
structure for organizing objects in an HDF file. Using these two basic
objects, one can create and store almost any kind of scientific data
structure, such as images, arrays of vectors, and structured and unstructured
grids. You can also mix and match them in HDF files according to your needs.


%package devel
Summary:        HDF development files
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libdf} = %{version}-%{release}
Requires:       %{libmfhdf} = %{version}-%{release}
Requires:       pkgconfig(libjpeg)
Requires:       pkgconfig(libtirpc)
Requires:       pkgconfig(zlib)
Obsoletes:      HDF < %{version}-%{release}

%description devel
HDF development headers and libraries.


%package -n %{libdf}
Summary:        HDF4 shared libraries
Group:          System/Libraries

%description -n %{libdf}
HDF4 shared libraries.


%package -n %{libmfhdf}
Summary:        HDF4 shared libraries
Group:          System/Libraries

%description -n %{libmfhdf}
HDF4 shared libraries.


%package static
Summary:        HDF4 static libraries
Group:          Development/C
Requires:       %{name}-devel = %{version}-%{release}

%description static
HDF4 static libraries.


%if %{with java}
%package -n java-hdf
Summary:        HDF4 java library
Group:          Development/Java
Requires:       slf4j

%description -n java-hdf
HDF4 java library.
%endif


%prep
%setup -q -n hdf4-hdf%{version}
%patch -P 1 -p1 -b .build

%if %{with java}
# Replace jars with system versions
# hamcrest-core is obsoleted in hamcrest-2.2
# Junit tests are failing with junit-4.13.1
find . ! -name junit.jar -name "*.jar" -delete
ln -s $(build-classpath hamcrest) java/lib/hamcrest-core.jar

ln -s $(build-classpath slf4j/api) java/lib/slf4j-api-1.7.33.jar
ln -s $(build-classpath slf4j/nop) java/lib/ext/slf4j-nop-1.7.33.jar
ln -s $(build-classpath slf4j/simple) java/lib/ext/slf4j-simple-1.7.33.jar
%endif

find . -type f -name "*.h" -exec chmod 0644 '{}' \;
find . -type f -name "*.c" -exec chmod 0644 '{}' \;

# restore include file timestamps modified by patching
#touch -c -r ./hdf/src/hdfi.h.ppc ./hdf/src/hdfi.h

%build

# For destdir/examplesdir patches
autoreconf -vfi

# avoid upstream compiler flags settings
rm config/*linux-gnu

# TODO: upstream fix
# libmfhdf.so is link to libdf.so
export CFLAGS="%{optflags} -std=gnu17 -I%{_usr}/include/tirpc"
export LIBS="-ltirpc"
%global _configure ../configure
# Java test needs this but doesn't create it
mkdir -p build-shared/java/lib
cd build-shared
# Java requires shared libraries, fortran requires static
%configure --disable-production %{?with_java:--enable-java} --disable-netcdf \
 --enable-shared=yes --enable-static=no --disable-fortran --with-szlib \
 --includedir=%{_includedir}/%{name}
%make_build
cd -
mkdir build-static
cd build-static
# Java requires shared libraries, fortran requires static

# Temporary workaround for compiling on GCC-10
export FCFLAGS="%{build_fflags} -fallow-argument-mismatch"
export FFLAGS="%{build_fflags} -fallow-argument-mismatch"

%configure --disable-production --disable-java --disable-netcdf \
 --enable-shared=no --enable-static=yes --enable-fortran --with-szlib \
 --includedir=%{_includedir}/%{name}
%make_build
cd -

# correct the timestamps based on files used to generate the header files
touch -c -r hdf/src/hdf.inc hdf/src/hdf.f90
touch -c -r hdf/src/dffunc.inc hdf/src/dffunc.f90
touch -c -r mfhdf/fortran/mffunc.inc mfhdf/fortran/mffunc.f90
# netcdf fortran include need same treatement, but they are not shipped


%install
%make_install -C build-static
%make_install -C build-shared
chrpath --delete --keepgoing %{buildroot}%{_bindir}/* %{buildroot}%{_libdir}/%{name}/*.so.* \
	%{buildroot}%{_libdir}/*.so.* || :

#Don't conflict with netcdf
for file in ncdump ncgen; do
  mv %{buildroot}%{_bindir}/$file %{buildroot}%{_bindir}/h$file
  # man pages are the same than netcdf ones
  rm %{buildroot}%{_mandir}/man1/${file}.1
done

#Fixup headers and scripts for multiarch
%if "%{_lib}" == "lib64"
for x in h4cc h4fc
do
  mv %{buildroot}%{_bindir}/${x} \
     %{buildroot}%{_bindir}/${x}-64
  install -m 0755 %SOURCE1 %{buildroot}%{_bindir}/${x}
done
%else
for x in h4cc h4fc
do
  mv %{buildroot}%{_bindir}/${x} \
     %{buildroot}%{_bindir}/${x}-32
  install -m 0755 %SOURCE1 %{buildroot}%{_bindir}/${x}
done
%endif


%check
make -j1 -C build-shared check
make -j1 -C build-static check


%files
%license COPYING
%doc README.md release_notes/*.txt
%{_bindir}/*

%files devel
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/*.settings

%files -n %{libdf}
%{_libdir}/libdf.so.%{major}{,.*}

%files -n %{libmfhdf}
%{_libdir}/libmfhdf.so.%{major}{,.*}

%files static
%{_libdir}/*.a

%if %{with java}
%files -n java-hdf
%{_jnidir}/hdf.jar
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libhdf_java.so
%endif
