%define         hpsrcname       Healpix
%define         hpsrctime       2024Nov13
%define         srcname         %{hpsrcname}_%{version}_%{hpsrctime}

%define         majornum        0
%define         smajornum       2
%define         cmajornum       0
%define         cxxmajornum     4
%define         hpmajornum      0

%define         sharpname       sharp%{name}
%define         cname           c%{name}
%define         cxxname         %{name}_cxx
%define         hpname          healpy

%define         libname         %mklibname %{name} %{majornum}
%define         develname       %mklibname %{name} -d
%define         libsharpname    %mklibname %{sharpname} %{smajornum}
%define         develsharpname  %mklibname %{sharpname} -d
%define         libcname        %mklibname %{cname} %{cmajornum}
%define         develcname      %mklibname %{cname} -d
%define         libcxxname      %mklibname %{cxxname} %{cxxmajornum}
%define         develcxxname    %mklibname %{cxxname} -d
%define         libhpname        %mklibname %{hpname} %{hpmajornum}
%define         develhpname      %mklibname %{hpname} -d
%define         gnudlname       gnudl-%{name}

%define         gccinstalldir   %(LC_ALL=C %__cc --print-search-dirs | grep install | %__awk '{print $2}')
%define         fincludedir     %{gccinstalldir}/finclude
%define         gnudldir        %{_datadir}/gnudatalanguage
%define         gnudllibdir     %{gnudldir}/lib

Name:           healpix
Version:        3.83
Release:        %mkrel 1
Summary:        Hierarchical Equal Area isoLatitude Pixelation of a sphere
License:        GPLv2+
Group:          Sciences/Astronomy

URL:            https://healpix.sourceforge.net/
Source0:        https://downloads.sourceforge.net/project/healpix/Healpix_%{version}/%{srcname}.tar.gz
Source1:        Makefile_f
Source2:        HEALPIX_startup.gdl
Source3:        idl_default_previewer.pro
Source4:        README_healpix.gdl

#remove test of libsharp (generated by this package) to avoid
#bootstrapping and tweak autotools to use the one in the package
Patch0:         healpix_3.60-configure-cxx.patch

#broken with new cfitsio numbering
#Patch1:         healpix_3.80-fitschecker.patch


BuildRequires:  pkgconfig(pkg-config)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
%ifarch %ix86 x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel


%description
HEALPix is a set of scientific tools implementing the Hierarchical Equal
Area isoLatitude Pixelation of a sphere. As suggested in the name,
this pixelation produces a subdivision of a spherical surface in which
each pixel covers the same surface area as every other pixel. HEALPix
provides various programs and libraries in C, C++, Fortran and
GDL/IDL which facilitate discretization of functions on a sphere at
sufficiently high resolution. It is the state-of-the-art program used
in Astronomy and Cosmology to deal with massive full-sky data sets.



%package -n %{libsharpname}
License:        GPLv2+
Summary:        The HEALPix Sharp libraries
Group:          System/Libraries

%description -n %{libsharpname}
%{summary}.

%package -n %{develsharpname}
License:        GPLv2+
Summary:        Headers and modules for the Sharp HEALPix libraries
Group:          Development/Other
Provides:       %{sharpname}-devel = %{version}-%{release}
Provides:       lib%{sharpname}-devel = %{version}-%{release}
Requires:       %{libsharpname} = %{version}-%{release}

%description -n %{develsharpname}
%{summary}.


%package -n %{libname}
License:        GPLv2+
Summary:        The HEALPix Fortran libraries
Group:          System/Libraries

%description -n %{libname}
%{summary}.


%package -n %{develname}
License:        GPLv2+
Summary:        Headers and modules for the Fortran HEALPix libraries
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{develname}
%{summary}.


%package -n %{libcname}
License:        GPLv2+
Summary:        The HEALPix C libraries
Group:          System/Libraries

%description -n %{libcname}
%{summary}.


%package -n %{develcname}
License:        GPLv2+
Summary:        Headers and development files for the C HEALPix libraries
Group:          Development/C
Provides:       healpix-C-devel = %{version}-%{release}
Provides:       %{cname}-devel = %{version}-%{release}
Provides:       lib%{cname}-devel = %{version}-%{release}
Requires:       %{libcname} = %{version}-%{release}

%description -n %{develcname}
%{summary}.



%package -n %{libcxxname}
License:        GPLv2+
Summary:        The HEALPix C++ libraries
Group:          System/Libraries
Obsoletes:       %{libhpname} <= 3.40

%description -n %{libcxxname}
%{summary}.


%package -n %{develcxxname}
License:        GPLv2+
Summary:        Headers and development files for the C++ HEALPix libraries
Group:          Development/C++
Provides:       healpix-c++-devel = %{version}-%{release}
Provides:       %{cxxname}-devel = %{version}-%{release}
Provides:       lib%{cxxname}-devel = %{version}-%{release}
Requires:       %{libcxxname} = %{version}-%{release}
Obsoletes:       %{develhpname} <= 3.40

%description -n %{develcxxname}
%{summary}.



%package -n %{gnudlname}
License:        BSD
Summary:        HEALPix GDL/IDL routines for the GNU data language
Group:          Sciences/Astronomy
Provides:       gdl-healpix = %{version}-%{release}
Provides:       gdl-healpix-astron = %{version}-%{release}
Requires:       gnudl
Requires:       imagemagick
Requires:       gv
Requires:       ghostscript

%description -n %{gnudlname}
HEALPix support for the GNU data language. This package provides
IDL/GDL routines to project any data in HEALPIX tessellation, create
maps, make nice plots, and perform various input/output operations
using the FITS format. For an automatic loading of the HEALPix
routines, check the README file located in the %{_docdir}/%{gnudlname}
directory.



%prep

%setup -q -n %{hpsrcname}_%{version}
%autopatch -p1

cp %{SOURCE1} Makefile
mkdir binf libf includef
pushd libf
ln -s libhealpix.so.%{majornum} libhealpix.so
ln -s libhpxgif.so.%{majornum} libhpxgif.so
popd
cp %{SOURCE4} README_healpix.gdl



%build

#common libs
pushd src/common_libraries/libsharp
autoreconf -fi
%configure --enable-static=no
%make_build
popd

#C libraries and binaries
pushd src/C/autotools
autoreconf -fi
%configure --enable-static=no
%make_build
popd

#C++ libs
pushd src/cxx
autoreconf -fi
%configure --enable-static=no
ln -s ../common_libraries/libsharp/libsharp libsharp
export SHARP_PATH="%{_builddir}/%{hpsrcname}_%{version}/src/common_libraries/libsharp/.libs"
%make_build
popd

#fortran libraries + binaries + modules

%__make  F90_FFLAGS="%{optflags} -DGFORTRAN -fopenmp -fPIC " \
         SHLIB_SUFFIX=".so.%{majornum}" \
         F90_CFLAGS="%{optflags} -std=c99 -DgFortran -fopenmp -fPIC \
         -I %{_builddir}/%{hpsrcname}_%{version}/src/common_libraries/libsharp"


%install

#libs
pushd src/common_libraries/libsharp
%make_install
popd

#C
pushd src/C/autotools
%make_install
popd

#C++
pushd src/cxx
%make_install
popd

#Fortran
pushd binf
%__install -d %{buildroot}%{_bindir}
%__install -D -m 755 alteralm %{buildroot}%{_bindir}
%__install -D -m 755 anafast %{buildroot}%{_bindir}
%__install -D -m 755 hotspot %{buildroot}%{_bindir}
%__install -D -m 755 map2gif %{buildroot}%{_bindir}
%__install -D -m 755 median_filter %{buildroot}%{_bindir}
%__install -D -m 755 plmgen %{buildroot}%{_bindir}
%__install -D -m 755 process_mask %{buildroot}%{_bindir}
%__install -D -m 755 sky_ng_sim* %{buildroot}%{_bindir}
%__install -D -m 755 smoothing %{buildroot}%{_bindir}
%__install -D -m 755 synfast %{buildroot}%{_bindir}
%__install -D -m 755 ud_grade %{buildroot}%{_bindir}
popd

pushd libf
%__install -d %{buildroot}%{_libdir}
%__install -D -m 755 libhealpix.so.%{majornum} %{buildroot}%{_libdir}
%__install -D -m 755 libhpxgif.so.%{majornum} %{buildroot}%{_libdir}
popd
pushd %{buildroot}%{_libdir}
ln -s libhealpix.so.%{majornum} libhealpix.so
ln -s libhpxgif.so.%{majornum} libhpxgif.so
popd

pushd includef
%__install -d %{buildroot}/%{fincludedir}/healpix
%__install -D -m 644 *.mod %{buildroot}/%{fincludedir}/healpix
popd


#GDL
%__install -D -m 644 %{SOURCE2} %{buildroot}%gnudldir/HEALPIX_startup.gdl

pushd src/idl

%__install -d %{buildroot}/%gnudllibdir/healpix
%__install -D -m 644 %{SOURCE3} %{buildroot}%gnudllibdir/healpix

%__install -d %{buildroot}/%gnudllibdir/healpix/examples
pushd examples
%__install -D -m 644 coadd_raw_obs.pro %{buildroot}%gnudllibdir/healpix/examples
%__install -D -m 644 raw_obs.txt %{buildroot}%gnudllibdir/healpix/examples
popd

pushd fits
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd interfaces
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd misc
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd toolkit
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd visu
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix
popd

pushd zzz_external
%__install -D -m 644 README %{buildroot}%gnudllibdir/healpix/README.external
popd

%__install -d %{buildroot}%gnudllibdir/healpix/astron
pushd zzz_external/astron
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix/astron
popd

%__install -d %{buildroot}%gnudllibdir/healpix/cgis
pushd zzz_external/cgis
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix/cgis
popd

%__install -d %{buildroot}%gnudllibdir/healpix/obsolete_astron
pushd zzz_external/obsolete_astron
%__install -D -m 644 *.pro %{buildroot}%gnudllibdir/healpix/obsolete_astron
popd

popd

#nuke la files from libtools
find %{buildroot}%{_libdir} -name *.la -delete



%files
%doc COPYING READ_Copyrights_Licenses.txt test
%{_bindir}/alice3
%{_bindir}/alteralm
%{_bindir}/anafast
%{_bindir}/hotspot
%{_bindir}/map2gif
%{_bindir}/median_filter
%{_bindir}/plmgen
%{_bindir}/process_mask
%{_bindir}/sky_ng_sim
%{_bindir}/sky_ng_sim_bin
%{_bindir}/smoothing
%{_bindir}/synfast
%{_bindir}/ud_grade
%{_bindir}/anafast_cxx
%{_bindir}/alm2map_cxx
%{_bindir}/calc_powspec
%{_bindir}/hotspots_cxx
%{_bindir}/map2tga
%{_bindir}/median_filter_cxx
%{_bindir}/mult_alm
%{_bindir}/rotalm_cxx
%{_bindir}/udgrade_harmonic_cxx
%{_bindir}/udgrade_cxx
%{_bindir}/smoothing_cxx
%{_bindir}/syn_alm_cxx
%{_bindir}/compute_weights
%{_bindir}/needlet_tool




%files -n %{libsharpname}
%{_libdir}/libsharp.so.%{smajornum}{,.*}


%files -n %{develsharpname}
%{_includedir}/libsharp/*.h
%{_libdir}/libsharp.so
%{_libdir}/pkgconfig/libsharp.pc


%files -n %{libname}
%{_libdir}/libhealpix.so.%{majornum}{,.*}
%{_libdir}/libhpxgif.so.%{majornum}{,.*}


%files -n %{develname}
%{_libdir}/libhealpix.so
%{_libdir}/libhpxgif.so
%dir %{fincludedir}/healpix
%{fincludedir}/healpix/*.mod


%files -n %{libcname}
%{_libdir}/libchealpix.so.%{cmajornum}{,.*}


%files -n %{develcname}
%doc src/C/CHANGES
%{_includedir}/chealpix.h
%{_libdir}/libchealpix.so
%{_libdir}/pkgconfig/chealpix.pc



%files -n %{libcxxname}
%{_libdir}/libhealpix_cxx.so.%{cxxmajornum}{,.*}



%files -n %{develcxxname}
%doc src/cxx/NEWS
%dir %{_includedir}/%{cxxname}
%{_includedir}/%{cxxname}/*.h
%{_libdir}/libhealpix_cxx.so
%{_libdir}/pkgconfig/healpix_cxx.pc



%files -n %{gnudlname}
%doc README_healpix.gdl src/idl/README.txt
%{gnudldir}/HEALPIX_startup.gdl
%dir %{gnudllibdir}/healpix
%dir %{gnudllibdir}/healpix/examples
%dir %{gnudllibdir}/healpix/astron
%dir %{gnudllibdir}/healpix/cgis
%dir %{gnudllibdir}/healpix/obsolete_astron
%{gnudllibdir}/healpix/README.external
%{gnudllibdir}/healpix/*.pro
%{gnudllibdir}/healpix/examples/*.pro
%{gnudllibdir}/healpix/examples/*.txt
%{gnudllibdir}/healpix/astron/*.pro
%{gnudllibdir}/healpix/cgis/*.pro
%{gnudllibdir}/healpix/obsolete_astron/*.pro


