# Workaround for quilt to work
%if "x%{?rust_arches}" == "x"
%global rust_arches x86_64
%endif

%global _helix_runtimedir %{_libdir}/%{name}/runtime

Name:           helix
Version:        24.03
Release:        %mkrel 1
Summary:        A post-modern modal text editor written in Rust
Group:          Editors
License:        (ASL 2.0 OR MIT) AND BSD AND (ASL 2.0 OR MIT) AND (ASL 2.0 OR MIT) AND (MIT OR ASL 2.0 OR zlib) AND (zlib OR ASL 2.0 OR MIT) AND ASL 2.0 AND MIT AND ISC AND MIT AND MPLv2.0 AND zlib
URL:            https://github.com/helix-editor/helix
Source0:        https://github.com/helix-editor/helix/releases/download/%{version}/%{name}-%{version}-source.tar.xz
# Include directories vendor and .cargo from source directory
Source1:        %{name}-%{version}-vendor.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  cargo
BuildRequires:  cargo-rpm-macros
BuildRequires:  hicolor-icon-theme
BuildRequires:  desktop-file-utils
BuildRequires:  xz
BuildRequires:  git-core
Recommends:     %{name}-runtime
ExclusiveArch:  %{rust_arches}

%description
A kakoune/neovim inspired modal text editor with built-in LSP and
has treesitter support for syntax highlighting and improved navigation

The binary is named "hx" with a symlink to "helix" for simplicity.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          Editors
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description    bash-completion
Bash command-line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          Editors
Supplements:    (%{name} and fish)
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Editors
Supplements:    (%{name} and zsh)
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description    zsh-completion
Zsh command-line completion support for %{name}.

%package        runtime
Summary:        Runtime files for %{name}
Requires:       %{name} = %{version}-%{release}

%description runtime
Helix runtime files. Separated due to how huge the runtime files are.
The runtime contains tree-sitter and grammars that makes run helix normally
if there is no runtime present in the users config directory specifically
`XDG_CONFIG_HOME/helix`.

%prep
%autosetup -p1 -c
tar xvf %{S:1}

# Replace RUNTIME dir
sed -e 's|@HELIX_RUNTIME_DIR@|%{_libdir}/%{name}|' -i helix-loader/src/lib.rs

# Remove shell definitions
sed -e '/^\#\!\/usr\/bin\/env .*/d' -i contrib/completion/hx.*

%build
export HELIX_RUNTIME="%{_helix_runtimedir}"
export HELIX_DISABLE_AUTO_GRAMMAR_BUILD=true
export RUSTFLAGS="$RUSTFLAGS -g"
export TARGET="%_arch"
%cargo_build
cargo run --release -- --grammar build

%install
install -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 target/release/hx %{buildroot}%{_bindir}/

install -d -m 0755 %{buildroot}%{_helix_runtimedir}
cp -av "runtime/queries" %{buildroot}%{_helix_runtimedir}
cp -av "runtime/themes" %{buildroot}%{_helix_runtimedir}
find "%{_builddir}/%{name}-%{version}/runtime/grammars" -type f -name '*.so' -exec \
    install --verbose -Dm 755 {} -t "%{buildroot}%{_helix_runtimedir}/grammars" \;
install -Dm644 runtime/tutor -t %{buildroot}%{_helix_runtimedir}

# Desktop application file
install -Dm644 -T %{_builddir}/%{name}-%{version}/contrib/Helix.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

# Icon
install -Dm644 -T %{_builddir}/%{name}-%{version}/logo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

# Shell completions
install -Dm644 -T %{_builddir}/%{name}-%{version}/contrib/completion/hx.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm644 -T %{_builddir}/%{name}-%{version}/contrib/completion/hx.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm644 -T %{_builddir}/%{name}-%{version}/contrib/completion/hx.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

# Let's add a symlink for helix for simplicity
cd %{buildroot}%{_bindir}
ln -s hx helix

# Not needed during runtime
rm -rfv %{buildroot}%{_libdir}/%{name}/grammars/sources

%pre
if [ -l "%{_helix_runtimedir}" ] ; then
    rm -f "%{_helix_runtimedir}"
fi

%files
%license LICENSE
%doc README.md CHANGELOG.md languages.toml docs/CONTRIBUTING.md docs/architecture.md docs/vision.md
%{_bindir}/hx
%{_bindir}/%{name}

# Desktop application file
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/*

%dir %{_libdir}/helix

# Tutor
%dir %{_helix_runtimedir}
%{_helix_runtimedir}/tutor

%files runtime
# Runtimes and runtime files
# Grammars
%dir %{_helix_runtimedir}/grammars
%{_helix_runtimedir}/grammars/*
# Queries
%dir %{_helix_runtimedir}/queries
%{_helix_runtimedir}/queries/*
# Themes
%dir %{_helix_runtimedir}/themes
%{_helix_runtimedir}/themes/*

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*
