Name: hiawatha
Version: 10.9
Summary: Hiawatha, an advanced and secure webserver for Unix
Release: %mkrel 8
License: GPLv2
Group: System/Servers
Url: https://www.hiawatha-webserver.org/
Source0: https://www.hiawatha-webserver.org/files/%{name}-%{version}.tar.gz
Source1: %{name}.service
Source2: %{name}.tmpfiles
Patch0: hiawatha-10.7-mbedtls-fix.patch
Patch1: hiawatha-10.9-mbedtls-fix.patch

BuildRequires:  mbedtls-devel
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  cmake
Requires: webserver-base
Requires(post):  rpm-helper >= %{rpmhelper_required_version}
Requires(preun): rpm-helper >= %{rpmhelper_required_version}

%description
Hiawatha is an advanced and secure webserver for Unix. It has been written
with 'being secure' as its main goal. This resulted in a webserver which
has for example DoS protection, connection control and traffic throttling.
It has of course also thoroughly been checked and tested for buffer overflows


%prep
%autosetup -p1

# build against system libmbedtls
rm -rf mbedtls

%build
%cmake -DENABLE_MONITOR:BOOL=ON \
 -DCMAKE_SKIP_RPATH:BOOL=OFF \
 -DCMAKE_INSTALL_LOCALSTATEDIR:PATH=var \
 -DCMAKE_INSTALL_BINDIR:PATH=%{_bindir} \
 -DCMAKE_INSTALL_SBINDIR:PATH=%{_sbindir} \
 -DCMAKE_INSTALL_MANDIR:PATH=%{_mandir} \
 -DLOG_DIR="%{_localstatedir}/log/hiawatha" \
 -DPID_DIR="%{_rundir}" \
 -DWORK_DIR="%{_localstatedir}/lib/hiawatha" \
 -DENABLE_CACHE=On \
 -DENABLE_IPV6=On \
 -DENABLE_RPROXY=On \
 -DENABLE_SSL=On \
 -DENABLE_TOMAHAWK=On \
 -DENABLE_TOOLKIT=On \
 -DENABLE_XSLT=On \
 -DENABLE_ZLIB_SUPPORT=On \
 -DUSE_SYSTEM_MBEDTLS=On

%cmake_build

%install
%cmake_install

install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -d -m 755 %{buildroot}%{_var}/log/%name
install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d


#logrotate

cat > %{buildroot}%{_sysconfdir}/logrotate.d/%{name} <<EOF
%{_logdir}/%{name}/*.log {
    size=10M
    rotate 5
    weekly
    missingok
    notifempty
    postrotate
    service %{name} reload
    endscript
}
EOF


#run as apache  user
sed "s/#ServerId = www-data/ServerId = apache/" -i %{buildroot}%{_sysconfdir}/hiawatha/hiawatha.conf


%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}


%files
%attr(4755,root,root) %{_sbindir}/cgi-wrapper
%attr(0755,root,root) %{_bindir}/ssi-cgi
%attr(0755,root,root) %{_sbindir}/wigwam
%attr(0755,root,root) %{_sbindir}/%{name}
%attr(0755,root,root) %{_sbindir}/lefh

%dir %{_sysconfdir}/%{name}
%dir %{_libdir}/hiawatha/
%dir %{_libdir}/hiawatha/letsencrypt
%{_libdir}/hiawatha/letsencrypt/*
%config(noreplace) %{_sysconfdir}/%{name}/*
%{_mandir}/*/*.*
%{_sysconfdir}/logrotate.d/%{name}
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%{_localstatedir}/www/%name/index.html
%dir %attr(-,apache,apache) %{_localstatedir}/log/%{name}/
