%define major   0
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

# TODO Fix underlinking issue
%define _disable_ld_no_undefined 1

Name:           hivex
Version:        1.3.24
Release:        %mkrel 6
Summary:        Read and write Windows Registry binary hive files

Group:          File tools
License:        LGPLv2
URL:            https://libguestfs.org/
Source0:        https://libguestfs.org/download/%{name}/%{name}-%{version}.tar.gz

BuildRequires:  gettext-devel
BuildRequires:  perl-devel
BuildRequires:  perl(Test::Simple)
BuildRequires:  perl(Test::Pod)
BuildRequires:  perl(Test::Pod::Coverage)
BuildRequires:  perl-IO-stringy
BuildRequires:  perl-libintl-perl
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib
BuildRequires:  pkgconfig(ruby)
BuildRequires:  ruby-rake
BuildRequires:  ruby-minitest
BuildRequires:  ruby-test-unit
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(python3)

%description
Hive files are the undocumented binary files that Windows uses to
store the Windows Registry on disk.  Hivex is a library that can read
and write to these files.

'hivexsh' is a shell you can use to interactively navigate a hive
binary file.

'hivexregedit' (in perl-hivex) lets you export and merge to the
textual regedit format.

'hivexml' can be used to convert a hive file to a more useful XML
format.

In order to get access to the hive files themselves, you can copy them
from a Windows machine.  They are usually found in
%%systemroot%%\system32\config.  For virtual machines we recommend
using libguestfs or guestfish to copy out these files.  libguestfs
also provides a useful high-level tool called 'virt-win-reg' (based on
hivex technology) which can be used to query specific registry keys in
an existing Windows VM.

For OCaml bindings, see 'ocaml-hivex-devel'.

For Perl bindings, see 'perl-hivex'.

For Python 3 bindings, see 'python3-hivex'.

For Ruby bindings, see 'ruby-hivex'.


%package -n %{devname}
Summary:        Development tools and libraries for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains development tools and libraries
for %{name}.


%package -n %{libname}
Summary:        Shared libraries for %{name}
Group:          System/Libraries

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n ocaml-%{name}
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml


%description -n ocaml-%{name}
ocaml-%{name} contains OCaml bindings for %{name}.

This is for toplevel and scripting access only.  To compile OCaml
programs which use %{name} you will also need ocaml-%{name}-devel.


%package -n ocaml-%{name}-devel
Summary:       OCaml bindings for %{name}
Group:         Development/OCaml
Requires:      ocaml-%{name} = %{version}-%{release}
Requires:      %{devname} = %{version}-%{release}


%description -n ocaml-%{name}-devel
ocaml-%{name}-devel contains development libraries
required to use the OCaml bindings for %{name}.


%package -n perl-%{name}
Summary:       Perl bindings for %{name}
Group:         Development/Perl
Requires:      %{name} = %{version}-%{release}


%description -n perl-%{name}
perl-%{name} contains Perl bindings for %{name}.


%package -n python3-%{name}
Summary:       Python 3 bindings for %{name}
Group:         Development/Python

%description -n python3-%{name}
python3-%{name} contains Python 3 bindings for %{name}.


%package -n ruby-%{name}
Summary:       Ruby bindings for %{name}
Group:         Development/Ruby
Requires:      %{name} = %{version}-%{release}
Requires:      ruby(release)
Requires:      ruby
Provides:      ruby(hivex) = %{version}

%description -n ruby-%{name}
ruby-%{name} contains Ruby bindings for %{name}.


%prep
%autosetup -p1


%build
%configure \
    PYTHON=%{__python3} \
    --disable-static \
    %{nil}
%make_build


%install
%make_install INSTALLSITEMAN3DIR=%{_mandir}/man3 INSTALLDIRS=vendor

# fix rights
chmod +w %{buildroot}%{perl_vendorarch}/auto/Win/Hivex/Hivex.so

# Remove unwanted Perl files:
find %{buildroot} -name perllocal.pod -delete
find %{buildroot} -name .packlist -delete
find %{buildroot} -name '*.bs' -delete


# we don't want these
find %{buildroot} -name "*.la" -delete

%find_lang %{name}


%check
if ! make check -k; then
    for f in $( find -name test-suite.log | xargs grep -l ^FAIL: ); do
        echo
        echo "***" $f "***"
        cat $f
        echo
    done
    exit 1
fi

%files -f %{name}.lang
%doc README.md
%license LICENSE
%{_bindir}/hivexget
%{_bindir}/hivexml
%{_bindir}/hivexsh
%{_mandir}/man1/hivexget.1*
%{_mandir}/man1/hivexml.1*
%{_mandir}/man1/hivexsh.1*


%files -n %{devname}
%license LICENSE
%{_libdir}/libhivex.so
%{_mandir}/man3/hivex.3*
%{_includedir}/hivex.h
%{_libdir}/pkgconfig/hivex.pc


%files -n %{libname}
%doc README.md
%license LICENSE
%{_libdir}/libhivex.so.%{major}{,.*}


%files -n ocaml-%{name}
%doc README.md
%{_libdir}/ocaml/hivex
%exclude %{_libdir}/ocaml/hivex/*.a
%exclude %{_libdir}/ocaml/hivex/*.cmxa
%exclude %{_libdir}/ocaml/hivex/*.cmx
%exclude %{_libdir}/ocaml/hivex/*.mli
%{_libdir}/ocaml/stublibs/*.so
%{_libdir}/ocaml/stublibs/*.so.owner


%files -n ocaml-%{name}-devel
%{_libdir}/ocaml/hivex/*.a
%{_libdir}/ocaml/hivex/*.cmxa
%{_libdir}/ocaml/hivex/*.cmx
%{_libdir}/ocaml/hivex/*.mli


%files -n perl-%{name}
%{perl_vendorarch}/*
%{_mandir}/man3/Win::Hivex.3pm*
%{_mandir}/man3/Win::Hivex::Regedit.3pm*
%{_bindir}/hivexregedit
%{_mandir}/man1/hivexregedit.1*


%files -n python3-%{name}
%{python3_sitearch}/hivex/
%{python3_sitearch}/*.so


%files -n ruby-%{name}
%doc ruby/doc/site/*
%{ruby_vendorlibdir}/hivex.rb
%{ruby_vendorarchdir}/_hivex.so
