# Define if you want to build the sane backend (default)
%define sane_backend		1
%{?_with_sane:			%global sane_backend 1}
%{?_without_sane:		%global sane_backend 0}

%define hpip_major		0
%define hpip_libname		%mklibname hpip %{hpip_major}

%define sane_hpaio_major	1
%define sane_hpaio_libname	%mklibname sane-hpaio %{sane_hpaio_major}

# Suppress automatically generated Requires for devel packages
%global __requires_exclude	devel\\\(.*\\\)

# we don't want to provide private python extension libs
%global __provides_exclude	%{python3_sitearch}/.*\\.so$

#define extraversion -RC1
%define extraversion		%nil

Summary:	HP printer/all-in-one driver infrastructure
Name:		hplip
Version:	3.25.2
Release:	%mkrel 1
License:	GPLv2+ and MIT
Group:		System/Printing
Url:		https://developers.hp.com/hp-linux-imaging-and-printing
Source:		https://downloads.sourceforge.net/sourceforge/hplip/%{name}-%{version}%{extraversion}.tar.gz
Source1:	hpcups-update-ppds.sh
Source2:	%{name}-tmpfiles.conf

# (doktor5000) newer automake [>1.13.1] need option subdir-objects if one
# source file is in a subdirectory, build does not complete otherwise
Patch1:		hplip-3.15.11-mga-automake-fix-subdir-objects.patch

# (Anssi) Apply udev rules even on ACTION=="change", otherwise the permissions
# do not get applied in %%post on a new installation:
Patch2:		hplip-apply-udev-rules-on-action-change.patch

# Link patch
Patch4:		hplip-3.25.2-hp_ipp.patch

# (akien) Start after panel in Plasma5 (mga#16946)
Patch5:		hplip-3.15.11-mga-plasma-delay-startup.patch

### Fedora patches
Patch101:	hplip-pstotiff-is-rubbish.patch
Patch102:	hplip-strstr-const.patch
Patch104:	hplip-no-asm.patch
Patch107:	hplip-udev-rules.patch
Patch108:	hplip-retry-open.patch
Patch109:	hplip-snmp-quirks.patch

Patch111:	hplip-hpijs-marker-supply.patch
Patch112:	hplip-clear-old-state-reasons.patch
Patch113:	hplip-colorlaserjet-mfp-m278-m281.patch
Patch114:	hplip-hpcups-sigpipe.patch
Patch115:	hplip-logdir.patch
Patch116:	hplip-bad-low-ink-warning.patch
Patch117:	hplip-ui-optional.patch
Patch121:	hplip-ppd-ImageableArea.patch
# error with new gcc, already reported in upstream as
# https://bugs.launchpad.net/hplip/+bug/1836735
Patch122:	hplip-fix-Wreturn-type-warning.patch
# upstream check for python clears OS build system CFLAGS
# https://bugs.launchpad.net/hplip/+bug/1879445
Patch123:	hplip-configure-python.patch
# if an user tries to install scanner via hp-setup (printer/fax utility)
# it fails further down - break out earlier with a message
# reported upstream as https://bugs.launchpad.net/hplip/+bug/1916114
Patch126:	hplip-hpsetup-noscanjets.patch
# Upstream https://bugs.launchpad.net/hplip/+bug/2028001
Patch127:	hplip-no-readfp.patch
# fix SyntaxWarning from python3.12
# https://bugs.launchpad.net/hplip/+bug/2029480
Patch128:	hplip-use-raw-strings.patch
# C99 compatibility fixes by fweimer - use explicit int
# Submitted upstream: <https://bugs.launchpad.net/hplip/+bug/1997875>
Patch129:	hplip-pserror-c99.patch
# C99 compatibility patch by fweimer - several undefined functions in hpaio
# backend are declared in orblite.h
# Submitted upstream: <https://bugs.launchpad.net/hplip/+bug/1997875>
Patch130:	hplip-scan-hpaio-include.patch
# C99 compatibility patch by fweimer - undefined _DBG() and dynamic linking funcs in orblite.c
# - _DBG() looks like typo and new header is added for funcs
# Submitted upstream: <https://bugs.launchpad.net/hplip/+bug/1997875>
Patch131:	hplip-scan-orblite-c99.patch
# FTBFS GCC 14
# https://bugs.launchpad.net/hplip/+bug/2048780
Patch132:	hplip-hpaio-gcc14.patch

### Debian/Ubuntu patches
# taken from latest version at http://patch-tracker.debian.org/package/hplip
Patch201:	01_rss.dpatch
Patch203:	14_charsign_fixes.dpatch
# (doktor5000) rediff original debian patch for hplip 3.13.2 (due to Patch1)
Patch204:	hplip-3.15.11-mga-85_rebuild_python_ui.dpatch
# HP upstream introduced new binary blob, which is not open-source, so it violates
# FPG by two ways - shipping binary blob and non open source code - so it needs to be removed.
Patch205:	0025-Remove-all-ImageProcessor-functionality-which-is-clo.patch
# QMessagebox call was copy-pasted from Qt4 version, but Qt5 has different arguments,
# This patch solves most of them
Patch206:	0026-Call-QMessageBox-constructors-of-PyQT5-with-the-corr.patch

Patch207:	hplip-pjl-duplex-binding.patch
# user should be member of group "lp" to scan/print/fax and lpadmin to manage?
# check comment above patch application, currently not applied
#Patch215:	simple-scan-as-default.dpatch
Patch219:	try_libhpmud.so.0.dpatch
Patch220:	add-lidil-two-cartridge-modes.dpatch
Patch222:	hp-plugin-download-fix.dpatch
Patch223:	install-check-plugin.diff
Patch224:	pcardext-python3-workaround-upstream.dpatch
Patch225:	hpfax-bug-function-used-before-importing-log.dpatch
Patch226:	hp-systray-make-menu-title-visible-in-sni-qt-indicator.dpatch
Patch227:	hp-systray-make-menu-appear-in-sni-qt-indicator-with-kde.dpatch
Patch228:	hpaio-option-duplex.diff
Patch229:	ui-patch-upstream-like.dpatch

### Mageia patches
Patch300:	add-mga-support.patch
Patch301:	hplip-mga21945-disable-hp-upgrade-log-msg.patch
# (daviddavid) set Qt5 in Help About Dialog
Patch302:	hplip-3.17.10-mga-set-qt5-in-HelpAboutDialog.patch
# (daviddavid) fix HP systray destkop file
Patch303:	hplip-3.18.7-mga-fix-hp-systray-desktop-file.patch
# (daviddavid) fix HP uiscan destkop file
Patch304:	hplip-3.18.12-mga-fix-hp-uiscan-desktop-file.patch
# (ns80) fix ppd for HP Envy Photo 7800 series to allow US Letter size duplex printing
Patch305:	hplip-3.21.12-mga-allow-US-Letter-size-duplex-printing.patch
# don't install files in root filesystem out of buildroot
Patch306:	hplip-dont-install-out-of-buildroot.patch
#
Patch307:	hplip-gcc14.patch
### Opensuse patches
#

%if %{sane_backend}
BuildRequires:	pkgconfig(sane-backends)
BuildRequires:	xsane
%endif
BuildRequires:	openssl-devel
BuildRequires:	python3
BuildRequires:	python3-qt5-devel
BuildRequires:	pkgconfig(avahi-client)
BuildRequires:	pkgconfig(avahi-core)
BuildRequires:	pkgconfig(python3)
BuildRequires:	net-snmp-devel
# implements support for USB devices
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	imagemagick
BuildRequires:	autoconf
BuildRequires:	pkgconfig(cups)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	desktop-file-utils
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(udev)
BuildRequires:	polkit
BuildRequires:	pkgconfig(libgphoto2)
BuildRequires:	libv4l-devel
# Make sure we get postscriptdriver tags:
BuildRequires:	cups
BuildRequires:	python3-cups
Requires(post):	systemd >= %{systemd_required_version}
Requires:	cups
# For dynamic ppd generation.
Requires:	cups-filters
Requires:	hplip-model-data
Requires:	hplip-hpijs
Requires:	hplip-hpijs-ppds
# Needed for communicating with ethernet-connected printers
Requires:	net-snmp-mibs
# Needed to generate fax cover pages
Requires:	python3-reportlab
# Needed since 2.8.4 for IPC
Requires:	python3-dbus
Requires:	polkit-agent
Requires:	python3-gobject3
# Required by hp-scan for command line scanning
Requires:	python3-pillow
Requires:	sane-backends-hpaio
# Needed to avoid misleading errors about network connectivity (RH bug #705843)
Requires:	wget
# (cg) needed by at least hp-check
Requires:	acl
# (doktor5000) lsusb is required for hp-check
Requires:	usbutils

%description
This is the HP driver package to supply Linux support for most
Hewlett-Packard DeskJet, LaserJet, PSC, OfficeJet, and PhotoSmart
printers and all-in-one peripherals (also known as Multi-Function
Peripherals or MFPs), which can print, scan, copy, fax, and/or access
flash memory cards.

It is work in progress, but printing, scanning, memory card access,
ink/toner/battery/consumable level checking, and inkjet printer
maintenance are supported on most models, when either connected to the
USB or LAN (built-in interfaces or selected HP JetDirect models) on a
Linux workstation with CUPS printing system.

For status and consumable checking and also for inkjet maintenance
there is the graphical tool "hp-toolbox" available (Menu:
"System"/"Monitoring"/"HP Printer Toolbox").

#----------------------------------------------------

%package -n	%{hpip_libname}
Summary:	Dynamic library for the "hplip" HP printer/all-in-one drivers
Group:		System/Printing

%description -n	%{hpip_libname}
Library needed for the "hplip" HP printer/all-in-one drivers.

#----------------------------------------------------

%package -n	%{hpip_libname}-devel
Summary:	Headers and links to compile against the "%{hpip_libname}" ("hplip") library
Group:		Development/C
Requires:	%{hpip_libname} >= %{version}-%{release}
Provides:	libhpip-devel = %{version}-%{release}

%description -n	%{hpip_libname}-devel
This package contains all files which one needs to compile programs using
the "%{hpip_libname}" library.

#----------------------------------------------------

%if %{sane_backend}
%package -n	%{sane_hpaio_libname}
Summary:	SANE driver for scanners in HP's multi-function devices (from HPLIP)
Group:		System/Printing
Requires:	sane-backends
Provides:	sane-backends-hpaio = %{version}-%{release}
# (cjw) for system-config-printer
Provides:	libsane-hpaio
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libcrypto\\)|devel\\(libdl\\)|devel\\(libhpip\\)|devel\\(libm\\)|devel\\(libsnmp\\)
%endif

%if %{sane_backend}
%description -n	%{sane_hpaio_libname}
SANE driver for scanners in HP's multi-function devices (from HPLIP).
%endif

#----------------------------------------------------

%if 0
%if %{sane_backend}
%package -n	%{sane_hpaio_libname}-devel
Summary:	Headers and links to compile against the "%{sane_hpaio_libname}" ("sane-hpaio") library
Group:		Development/C
Requires:	%{sane_hpaio_libname} >= %{version}-%{release}
Provides:	libsane-hpaio-devel = %{version}-%{release}
%endif

%if %{sane_backend}
%description -n	%{sane_hpaio_libname}-devel
This package contains all files which one needs to compile programs using
the "%{sane_hpaio_libname}" library.
%endif
%endif
#----------------------------------------------------

%package	model-data
Summary:	Data file listing the HP printer models supported by HPLIP
Group:		System/Printing

%description	model-data
HPLIP supports most current HP printers and multifunction devices, but
there are some older models not supported. This package contains the
list of supported models. Printerdrake installs it automatically to
determine whether HPLIP has to be installed or not.

#----------------------------------------------------

%package	gui
Summary:	HPLIP graphical tools
Group:		System/Printing
Requires:	python3-qt5-core
Requires:	python3-qt5-dbus
Requires:	python3-qt5-gui
Requires:	python3-qt5-widgets
Requires:	%{name} = %{version}-%{release}
Requires:	polkit-agent

%description	gui
HPLIP graphical tools.

#----------------------------------------------------

%package	hpijs
Summary:	HPs printer driver IJS plug-in for GhostScript
Group:		System/Printing
Requires:	ghostscript
Provides:	hpijs

%description	hpijs
HPs printer driver IJS plug-in for GhostScript. This driver gives full
printing support for nearly all non-PostScript inkjet and laser
printers made by HP.

#----------------------------------------------------

%package	hpijs-ppds
Summary:	PPD files for the HPIJS printer driver
Group:		System/Printing
Requires:	cups-filters
Requires:	hplip-hpijs

%description	hpijs-ppds
PPD files to use the HPIJS printer driver with foomatic-rip and a
printer spooler like CUPS, LPRng, PDQ, ...

#----------------------------------------------------

%package	doc
Summary:	Documentation for HPLIP
Group:		System/Printing

%description	doc
This package contains documentation for the HPLIP driver.

This is the HP driver package to supply Linux support for most
Hewlett-Packard DeskJet, LaserJet, PSC, OfficeJet, and PhotoSmart
printers and all-in-one peripherals (also known as Multi-Function
Peripherals or MFPs), which can print, scan, copy, fax, and/or access
flash memory cards.

#----------------------------------------------------

%prep
rm -rf $RPM_BUILD_DIR/%{name}-%{version}%{extraversion}
%setup -q -n %{name}-%{version}%{extraversion}

%patch -P1 -p1 -b .automake-subdir-objects

%patch -P2 -p1 -b .udev-rules-on-action-change

%patch -P4 -p1 -b .hp_ipp

### Fedora patches

# The pstotiff filter is rubbish so replace it (launchpad #528394).
%patch -P101 -p1 -b .pstotiff-is-rubbish

# Fix compilation.
%patch -P102 -p1 -b .strstr-const

# Make sure to avoid handwritten asm.
%patch -P104 -p1 -b .no-asm

# Removed SYSFS use in udev rules and actually made them work (bug #560754).
# Move udev rules to /lib/udev/rules.d (bug #748208).
%patch -P107 -p1 -b .udev-rules

# Retry when connecting to device fails (RH bug #532112).
%patch -P108 -p1 -b .retry-open

# Mark SNMP quirks in PPD for HP OfficeJet Pro 8500 (RH bug #581825).
%patch -P109 -p1 -b .snmp-quirks

# Fixed bogus low ink warnings from hpijs driver (RH bug #643643).
%patch -P111 -p1 -b .hpijs-marker-supply

# Clear old printer-state-reasons we used to manage (RH bug #510926).
%patch -P112 -p1 -b .clear-old-state-reasons

# Add support for HP ColorLaserjet MFP M278-M281 (bug #1509394)
#patch -P113 -p1 -b .colorlaserjet-mfp-m278-m281

# Avoid busy loop in hpcups when backend has exited (RH bug #525944).
%patch -P114 -p1 -b .hpcups-sigpipe

# CUPS filters should use TMPDIR when available (bug #865603).
%patch -P115 -p1 -b .logdir

# Fixed Device ID parsing code in hpijs's dj9xxvip.c (RH bug #510926).
%patch -P116 -p1 -b .bad-low-ink-warning

# Make utils.checkPyQtImport() look for the gui sub-package (bug #243273).
%patch -P117 -p1 -b .ui-optional

# Fix ImageableArea for Laserjet 8150/9000 (RH bug #596298).
for ppd_file in $(grep '^diff' %{PATCH121} | cut -d " " -f 4);
do
  gunzip ${ppd_file#*/}.gz
done
%patch -P121 -p1 -b .ImageableArea
for ppd_file in $(grep '^diff' %{PATCH121} | cut -d " " -f 4);
do
  gzip -n ${ppd_file#*/}
done

# Don't run 'chgrp lp /var/log/hp' in makefile (removes all lines with "chgrp")
sed -i '/chgrp/d' Makefile.am

sed -i.duplex-constraints \
    -e 's,\(UIConstraints.* \*Duplex\),//\1,' \
    prnt/drv/hpcups.drv.in

%patch -P122 -p1 -b .Wreturn-fix
%patch -P123 -p1 -b .configure-python
# if an user tries to install scanner via hp-setup (printer/fax utility)
# it fails further down - break out earlier with a message
%patch -P126 -p1 -b .hpsetup-noscanjets

#patch -P127 -p1
%patch -P128 -p1
%patch -P129 -p1 -b .pserror-int
%patch -P130 -p1 -b .hpaio-orblite-defs
%patch -P131 -p1 -b .orblite-undefs
%patch -P132 -p1 -b .hpaio-gcc14

### Debian/Ubuntu patches

# This patch tries to make sure that black is printed with just
# the black pen, if the printer supports it
%patch -P201 -p1 -b .01_rss

# code cleanup related to char signedness
%patch -P203 -p1 -b .14_charsign

# compiling ui files to py
%patch -P204 -p1 -b .85_rebuild_python_ui

# Remove all ImageProcessor functionality, which is closed-source
%patch -P205 -p1 -b .0025_ImageProcessor

# TypeError: argument 5 has unexpected type 'StandardButtons' (bug #1594602)
# upstream bug: https://bugs.launchpad.net/ubuntu/+source/hplip/+bug/1745383
# bug caused by typo in QMessageBox constructor call
# this patch fixes more of those typos - some fixed by tkorbar, some taken from ubuntu fix
%patch -P206 -p1 -b .qmsgbox-typos-fix

# Fixes Short-edge duplex printing if duplex is PJL-controlled
# https://bugs.launchpad.net/hplip/+bug/244295
%patch -P207 -p1 -b .hplip-pjl-duplex-binding

# disable for now, as this changes default hplip behavior
# and change in default scanning application should be decided by a poll first
#%%patch -P215 -p1 -b .simple-scan-as-default

# dlopen libhpmud.so.0 instad of libhpmud.so, in order not to depend on
# devel package (http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=548379)
# obsoletes hplip-3.9.8-dlopen-libhpmud.patch, newer & extended version
%patch -P219 -p1 -b .try_libhpmud.so.0

%patch -P220 -p1 -b .add-lidil-two-cartridge-modes

%patch -P222 -p1 -b .plugin-download

%patch -P223 -p1 -b .install-check-plugin

%patch -P224 -p1 -b .pcardext-python3-workaround

%patch -P225 -p1 -b .hpfax-bug-function-used-before-importing-log

%patch -P226 -p1 -b .hp-systray-make-menu-title-visible-in-sni-qt-indicator

%patch -P227 -p1 -b .hp-systray-make-menu-appear-in-sni-qt-indicator-with-kde

%patch -P228 -p1 -b .hpaio-option-duplex

%patch -P229 -p1 -b .ui-patch-upstream-like


### Mageia patches
%patch -P300 -p1 -b .add-mga-support
%patch -P301 -p1 -b .remove-hp-upgrade-calls
%patch -P302 -p1 -b .set_qt5
%patch -P303 -p1 -b .systray
%patch -P304 -p1 -b .uiscan
%patch -P306 -p1 -b .buildroot
%patch -P307 -p1 -b .gcc14

### Opensuse patches

%if 0
# Use filter foomatic-rip instead of foomatic-rip-hplip (fix from Mandriva)
for PPDGZ in ppd/hpijs/*.ppd.gz
do
mv -T "$PPDGZ" "$PPDGZ.old"
zcat "$PPDGZ.old" | sed -e 's/foomatic-rip-hplip/foomatic-rip/' | gzip -c > "$PPDGZ"
rm -f "$PPDGZ.old"
done
%endif

# Make all files in the source user-writable
chmod -R u+w .

# Change shebang /usr/bin/env python -> /usr/bin/python3
find -name '*.py' -print0 | xargs -0 sed -i \
    -e 's,^#!/usr/bin/env python[2-3]\?,#!%{__python3},' \
    -e 's,^#!/usr/bin/python[2-3]\?,#!%{__python3},'
sed -i -e 's,^#!/usr/bin/env python[2-3]\?,#!%{__python3},' \
    prnt/filters/hpps \
    fax/filters/pstotiff

%build
%serverbuild
export CFLAGS="${CFLAGS:-%{build_cflags}} -Wno-deprecated-declarations"

# create required files as placeholder, otherwise autoreconf fails
touch NEWS README AUTHORS ChangeLog

# needed by patches 204 and 205
autoreconf -ifv

%if !%{sane_backend}
WITHOUT_SANE="--without-sane"
%endif

%configure $WITHOUT_SANE \
	--disable-foomatic-rip-hplip-install \
	--disable-imageProcessor-build \
	--enable-scan-build \
	--enable-gui-build \
	--enable-fax-build \
	--enable-pp-build \
	--enable-qt5 --disable-qt4 \
	--enable-hpcups-install \
	--enable-cups-ppd-install \
	--enable-hpijs-install \
	--enable-policykit \
	--with-mimedir=%{_datadir}/cups/mime \
	PYTHON=%{__python3}

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_initrddir}
mkdir -p %{buildroot}%{_sysconfdir}/hp

%make_install

# Install files which the "make install" missed to install
install -m 644 ip/hpip.h %{buildroot}%{_includedir}
install -m 644 ip/xform.h %{buildroot}%{_includedir}

# Move doc in sub-package
mv %{buildroot}%{_docdir}/%{name}-%{version}%{extraversion} %{buildroot}%{_docdir}/%{name}-doc-%{version}%{extraversion}

# Remove static libraries of SANE driver
rm -f %{buildroot}%{_libdir}/sane/libsane-hpaio*.so
rm -f %{buildroot}%{_libdir}/sane/libsane-hpaio*.la
rm -f %{buildroot}%{_sysconfdir}/sane.d/dll.conf

# Remove other unneeded/unwanted files
rm -f %{buildroot}%{_datadir}/hplip/uninstall.*
rm -f %{buildroot}%{_bindir}/hp-uninstall
# remove all upgrade-dialog files, also related to CVE-2013-6427
# previously we only removed the upgrade binary, but missed some upgrade dialog files
rm -f %{buildroot}%{_datadir}/hplip/upgrade*
rm -f %{buildroot}%{_bindir}/hp-upgrade
rm -f %{buildroot}%{_bindir}/hp-config_usb_printer
rm -f %{buildroot}%{_unitdir}/hplip-printer@.service
rm -f %{buildroot}%{_datadir}/hplip/config_usb_printer.*
rm -f %{buildroot}%{_datadir}/ipp-usb/quirks/HPLIP.conf

mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install --vendor='' \
	--dir=%{buildroot}%{_datadir}/applications \
	--remove-category='Application' \
	--remove-category='Utility' \
	--add-category='System' \
	--add-category='Settings' \
	--add-category='Printing' \
	--add-category='Qt' \
	--add-category='HardwareSettings' \
	--remove-key='Encoding' \
	%{buildroot}%{_datadir}/applications/hplip.desktop

cat > %{buildroot}%{_datadir}/applications/hp-sendfax.desktop << EOF
[Desktop Entry]
Name=HP Sendfax
Name[br]=Kas ur faks (HP)
Name[ru]=Отправка факсов (HP)
Name[zh_CN]=惠普发送传真
GenericName=Sending faxes (HP)
GenericName[bg]=Изпращане на факсове (HP)
GenericName[ca]=Enviant faxos (HP)
GenericName[el]=Αποστολή φαξ (HP)
GenericName[es]=Enviando faxes (HP)
GenericName[hu]=Faxok küldése (HP)
GenericName[it]=Inviare i fax (HP)
GenericName[pl]=Wysyłanie faksu (HP)
GenericName[ru]=Отправка факсов (МФУ HP)
GenericName[sq]=Dërgim faksesh (HP)
GenericName[sv]=Sändning av fax (HP)
Comment=Utility for sending faxes with HP's multi-function devices
Comment[bs]=Alat za slanje faksova putem HPovih višefunkcijskih uređaja
Comment[cs]=Pomocný program pro posílání faxů pomocí multifunkčních zařízení HP
Comment[cy]=Gwasanaeth anfon ffacs drwy ddyfeisiau amlbwrpas HP
Comment[de]=Werkzeug um Faxe mit HP-Multifunktionsgeräten zu versenden
Comment[et]=Tööriist fakside saatmiseks HP multifunktsionaalsetest seadmetest
Comment[gl]=Utilidade para enviar faxes cos dispositivos multifunción de HP
Comment[he]=יישום למשלוח פקסים עם מכשירים משולבים של HP
Comment[hu]=Faxküldés a HP-féle többfunkciós eszközökkel
Comment[id]=Utilitas untuk mengirimkan fax dengan divais multi fungsi HP
Comment[is]=Forrit til að senda fax með fjölnotatækjum HP
Comment[it]=Strumento per inviare fax con i dispositivi HP multi-funzione
Comment[ja]=HP の多機能デバイスで FAX を送信するためのユーティリティ
Comment[mk]=Алатка за праќање факсови со повеќе-функциски „HP“ уреди
Comment[nb]=Verktøy for å sende fakser med HPs multifunksjonsenheter
Comment[nl]=Hulpprogramma voor het sturen van faxen met HP multifunctionele apparaten
Comment[nn]=Verktøy for sending av faksar med HPs multifunksjonseiningar
Comment[pl]=Program do wysyłania faksów przez wielofunkcyjne urządzenia HP
Comment[pt]=Utilitário para enviar faxes com dispositivos multi-funções HP
Comment[pt_BR]=Utilitário para enviar faxes com multifuncionais HP
Comment[ru]=Утилита для отправки факсов с помощью МФУ HP
Comment[sl]=Program za pošiljanje faksov z večnamensko napravo HP
Comment[sv]=Verktyg för att skicka fax med HPs multi-funktions-enheter
Comment[tr]=HP'nin çok fonksiyonlu aygıtlarıyla faks göndermek için yardımcı program
Comment[zh_CN]=使用惠普多功能一体机发送传真的工具
Comment[zh_TW]=使用 HP 多功能設備發送傳真的工具程式
Exec=%{_bindir}/hp-sendfax
Icon=%{_datadir}/%{name}/data/images/32x32/fax_machine.png
Terminal=false
Type=Application
Categories=TelephonyTools;Qt;Printing;Utility;X-Mageia-CrossDesktop;
EOF

# tmpfiles.d for folders on transient media
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# switched to udev, no need for hal information
rm -rf  %{buildroot}%{_datadir}/hal/fdi

rm -f   %{buildroot}%{_libdir}/*.la \
        %{buildroot}%{python3_sitearch}/*.la \
        %{buildroot}%{_libdir}/sane/*.la

# Regenerate hpcups PPDs on upgrade if necessary (bug #579355).
install -p -m755 %{SOURCE1} %{buildroot}%{_bindir}/hpcups-update-ppds

# Fedora pstotiff
rm -f %{buildroot}%{_sysconfdir}/cups/pstotiff.types
rm -f %{buildroot}%{_datadir}/cups/mime/pstotiff.types
rm -f %{buildroot}%{_datadir}/hplip/fax/pstotiff*
rm -f %{buildroot}%{_prefix}/lib/cups/filter/hpcac

# bork?
install -d %{buildroot}%{_sysconfdir}/cups
cp -p %{buildroot}%{_datadir}/cups/mime/pstotiff.convs %{buildroot}%{_sysconfdir}/cups/pstotiff.convs

# (cg) Create post consolehelper compatibility links
mkdir -p %{buildroot}%{_sbindir}
ln -sf %{_bindir}/hp-setup %{buildroot}%{_sbindir}

# Make sure pyc files are generated, otherwise we can get
# difficult to debug problems
pushd %{buildroot}%{_datadir}/%{name}
python -m compileall .
popd

# create empty /var/lip/hp/hplip.state to fix hp-plugin installation (mga#5395)
mkdir -p %{buildroot}%{_localstatedir}/lib/hp/
touch %{buildroot}%{_localstatedir}/lib/hp/hplip.state

# create empty log directory so that it can be owned
mkdir -p %{buildroot}%{_localstatedir}/log/hp/tmp


# Restart CUPS to make the Fax PPD known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

pushd %{buildroot}%{_datadir}/ppd/HP
gunzip hp-envy_photo_7800_series.ppd.gz
/usr/bin/patch --no-backup-if-mismatch -f -p0 --fuzz=0 < %{PATCH305}
gzip hp-envy_photo_7800_series.ppd
popd

# hp-setup needs to have cups service enabled and running for setups of queues
%pre
%{_bindir}/systemctl start cups &>/dev/null ||:
%{_bindir}/systemctl enable cups &>/dev/null ||:

%post
%_tmpfilescreate %{name}

%post -n hplip-hpijs-ppds
# Restart CUPS to make the printing PPDs known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

%post -n hplip-hpijs
%{_bindir}/hpcups-update-ppds &>/dev/null ||:

%post -n hplip-model-data
/sbin/udevadm trigger --subsystem-match=usb --attr-match=idVendor=03f0
# ensure permissions are ready when installation completes
/sbin/udevadm settle --timeout=15
:

%if %{sane_backend}
%post -n %{sane_hpaio_libname}

# Add HPLIP driver to /etc/sane.d/dll.conf
if ! grep ^hpaio /etc/sane.d/dll.conf >/dev/null 2>/dev/null ; then \
	echo hpaio >> /etc/sane.d/dll.conf; \
fi
%endif

%if %{sane_backend}
%preun -n %{sane_hpaio_libname}
# Remove HPLIP driver from /etc/sane.d/dll.conf
if [ "$1" = 0 ]; then \
	if grep ^hpaio /etc/sane.d/dll.conf >/dev/null 2>/dev/null ; then \
		sed '/hpaio/d' /etc/sane.d/dll.conf > /tmp/$$; \
		cp -f /tmp/$$ /etc/sane.d/dll.conf; \
		rm -f /tmp/$$; \
	fi; \
fi
%endif

# Restart CUPS to make the removal of the Fax PPD known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

%postun -n hplip-hpijs-ppds
# Restart CUPS to make the removal of the printing PPDs known to it
if [ -f /etc/init.d/cups ]; then
	/sbin/service cups condrestart || :
fi

%files
#doc COPYING doc/*
%config(noreplace) %{_sysconfdir}/hp
%dir %{_localstatedir}/lib/hp/
%{_bindir}/hp-align
%{_bindir}/hp-clean
%{_bindir}/hp-colorcal
%{_bindir}/hp-devicesettings
%{_bindir}/hp-diagnose_plugin
%{_bindir}/hp-diagnose_queues
%{_bindir}/hp-doctor
%{_bindir}/hp-fab
%{_bindir}/hp-faxsetup
%{_bindir}/hp-firmware
%{_bindir}/hp-info
%{_bindir}/hp-levels
%{_bindir}/hp-logcapture
%{_bindir}/hp-linefeedcal
%{_bindir}/hp-makecopies
%{_bindir}/hp-makeuri
%{_bindir}/hp-pkservice
%{_bindir}/hp-plugin
%{_bindir}/hp-pqdiag
%{_bindir}/hp-printsettings
%{_bindir}/hp-probe
%{_bindir}/hp-query
%{_bindir}/hp-scan
%{_bindir}/hp-sendfax
%{_bindir}/hp-setup
%{_sbindir}/hp-setup
%{_bindir}/hp-testpage
%{_bindir}/hp-timedate
%{_bindir}/hp-unload
%{_bindir}/hp-wificonfig

%exclude %{_datadir}/hplip/data/models
%exclude %{_datadir}/hplip/__pycache__
# C libraries for Python
%{python3_sitearch}/*.so*
# CUPS backends (0755 permissions, so that CUPS 1.2 runs these backends
# as lp user)
# Note: this must be /usr/lib not %%{_libdir}, since that's the
# CUPS serverbin directory.
%attr(0755,root,root) %{_prefix}/lib/cups/backend/hp*
%{_prefix}/lib/cups/filter/hpcdmfax
%{_prefix}/lib/cups/filter/hpcups
%{_prefix}/lib/cups/filter/hpcupsfax
%{_prefix}/lib/cups/filter/hpps
%{_prefix}/lib/cups/filter/pstotiff
%{_datadir}/cups/mime/pstotiff.convs
%config(noreplace) %{_sysconfdir}/cups/pstotiff.convs
%{_datadir}/ppd/HP/HP-Fax*.ppd*
%{_datadir}/cups/drv/hp/hpcups.drv
# Files
%dir %{_datadir}/hplip
%{_datadir}/hplip/align.py*
%{_datadir}/hplip/check-plugin.py*
%{_datadir}/hplip/clean.py*
%{_datadir}/hplip/colorcal.py*
%{_datadir}/hplip/dat2drv
%{_datadir}/hplip/devicesettings.py*
%{_datadir}/hplip/diagnose_plugin.py*
%{_datadir}/hplip/diagnose_queues.py*
%{_datadir}/hplip/doctor.py*
%{_datadir}/hplip/fab.py*
%{_datadir}/hplip/fax
%{_datadir}/hplip/faxsetup.py*
%{_datadir}/hplip/firmware.py*
%{_datadir}/hplip/hpdio.py*
%{_datadir}/hplip/hplip_clean.sh
%{_datadir}/hplip/hpssd*
%{_datadir}/hplip/info.py*
%{_datadir}/hplip/__init__.py*
%{_datadir}/hplip/levels.py*
%{_datadir}/hplip/locatedriver
%{_datadir}/hplip/logcapture.py*
%{_datadir}/hplip/linefeedcal.py*
%{_datadir}/hplip/makecopies.py*
%{_datadir}/hplip/makeuri.py*
%{_datadir}/hplip/pkservice.py*
%{_datadir}/hplip/plugin.py*
%{_datadir}/hplip/pqdiag.py*
%{_datadir}/hplip/printsettings.py*
%{_datadir}/hplip/probe.py*
%{_datadir}/hplip/query.py*
%{_datadir}/hplip/scan.py*
%{_datadir}/hplip/sendfax.py*
%{_datadir}/hplip/setup.py*
%{_datadir}/hplip/testpage.py*
%{_datadir}/hplip/timedate.py*
%{_datadir}/hplip/unload.py*
%{_datadir}/hplip/wificonfig.py*
# Directories
%{_datadir}/hplip/base
%{_datadir}/hplip/copier
%dir %{_datadir}/hplip/data
%{_datadir}/hplip/data/ldl
%{_datadir}/hplip/data/localization
%{_datadir}/hplip/data/models
%{_datadir}/hplip/data/pcl
%{_datadir}/hplip/data/ps
%{_datadir}/hplip/installer
%{_datadir}/hplip/pcard
%{_datadir}/hplip/prnt
%{_datadir}/hplip/scan
%{_datadir}/polkit-1/actions/com.hp.hplip.policy
%{_datadir}/dbus-1/system-services/com.hp.hplip.service
%{_tmpfilesdir}/%{name}.conf
%{_localstatedir}/lib/hp/hplip.state
%dir %attr(0774,root,lp) %{_logdir}/hp
%dir %attr(1774,root,lp) %{_logdir}/hp/tmp
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/com.hp.hplip.conf

%files doc
%doc %{_docdir}/%{name}-doc-%{version}%{extraversion}

%files -n %{hpip_libname}
%{_libdir}/libhpip*.so.*
%{_libdir}/libhpmud.so.*
%{_libdir}/libhpdiscovery.so.*

%files -n %{hpip_libname}-devel
%{_includedir}/hpip.h
%{_includedir}/xform.h
%{_libdir}/libhpip*.so
%{_libdir}/libhpmud.so
%{_libdir}/libhpdiscovery.so

%if %{sane_backend}

%files -n %{sane_hpaio_libname}
%{_libdir}/sane/libsane-hpaio*.so.*

%endif

%files model-data
%{_udevrulesdir}/*.rules
%{_datadir}/hplip/data/models

%files gui
%{_bindir}/hp-check
%{_bindir}/hp-check-plugin
%{_bindir}/hp-print
%{_bindir}/hp-systray
%{_bindir}/hp-toolbox
%{_bindir}/hp-uiscan
%{_datadir}/applications/*.desktop
%{_sysconfdir}/xdg/autostart/hplip-systray.desktop
%{_datadir}/hplip/check.py*
%{_datadir}/hplip/print.py*
%{_datadir}/hplip/systray.py*
%{_datadir}/hplip/toolbox.py*
%{_datadir}/hplip/data/images
%{_datadir}/hplip/ui5
%{_datadir}/hplip/uiscan.py*

%files hpijs
%{_bindir}/hpijs
# Needed for both printing and fax PPDs. They all need HPIJS, therefore
# the link is here
%dir %{_datadir}/ppd
%dir %{_datadir}/ppd/HP
%{_bindir}/hpcups-update-ppds

%files hpijs-ppds
%{_datadir}/ppd/HP/apollo*.ppd*
%{_datadir}/ppd/HP/hp-*.ppd*

