Summary:        Panorama Tools GUI
Name:           hugin
Version:        2024.0.1
Release:        %mkrel 3
License:        GPLv2+
Group:          Graphics/Utilities
URL:            https://hugin.sourceforge.net/
Source0:        https://downloads.sourceforge.net/hugin/%{name}-%{version}.tar.bz2
Patch0:         hugin-2012.0.0-invalid-utf8.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(tclap)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(libpano13) >= 2.9.19
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(freeglut)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  boost-devel
BuildRequires:  wxgtk-devel
BuildRequires:  libgomp-devel
BuildRequires:  vigra-devel
BuildRequires:  lapack-devel
BuildRequires:  desktop-file-utils
BuildRequires:  imagemagick
BuildRequires:  perl(Image::ExifTool)
BuildRequires:  swig
# contains deprecated distutils
BuildRequires:  python3-setuptools

Requires:       libpano13-tools >= 2.9.19
Requires:       enblend
Requires:       perl-Image-ExifTool
Requires:       make

%description
Hugin can be used to stitch multiple images together. The resulting image can
span 360 degrees. Another common use is the creation of very high resolution
pictures by combining multiple images.


%files -f %{name}.lang
%doc AUTHORS Changes.txt README TODO
%license COPYING*
%{_bindir}/*
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man?/*
%{_datadir}/applications/*.desktop
%{_iconsdir}/*.png
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/*/mimetypes/application-x-ptoptimizer-script.png
%{_datadir}/mime/packages/%{name}.xml
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/scalable/apps/ptbatcher.svg
%{_iconsdir}/hicolor/*/apps/ptbatcher.png
%{_metainfodir}/*.xml
%{python3_sitearch}/*

%prep
%autosetup -p1

%py3_shebang_fix \
src/hugin_script_interface/plugins-dev/*.py \
src/hugin_script_interface/*.py \
src/hugin_script_interface/plugins/*.py

# use system module
rm -rf CMakeModules/FindZLIB.cmake

%build
%cmake -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DENABLE_LAPACK=ON \
       -DBUILD_HSI=ON \
       -DUSE_GDKBACKEND_X11=ON
%cmake_build

%install
%cmake_install

%find_lang %{name}

# Menu icons
for i in {16,22,32,48}; do
	mkdir -p %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
	convert -resize $ix$i src/hugin1/hugin/xrc/data/hugin.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done
convert -resize 32x32 src/hugin1/hugin/xrc/data/hugin.png %{buildroot}%{_iconsdir}/%{name}.png

# menu entry
desktop-file-install --vendor="" \
  --remove-category="Application" \
  --add-category="Photography" \
  --add-category="Graphics" \
  --dir %{buildroot}%{_datadir}/applications \
  %{buildroot}%{_datadir}/applications/*
