%bcond_without  rogueviz
# Broken fontconfig as of version 13.0s
%bcond_with  fontconfig

Name:           hyperrogue
Version:        13.0v
Release:        %mkrel 1
Summary:        Roguelike game in a strange, non-Euclidean world
Group:          Games/Adventure
License:        GPLv2+
URL:            https://www.roguetemple.com/z/hyper
Source0:        https://github.com/zenorogue/hyperrogue/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         hyperrogue-13.0v-makefile_SDL2.patch
Patch1:         hyperrogue-13.0v-mga-FHS-and-userdir.patch

# Split build for low resources systems: arm, ix86
# https://salsa.debian.org/games-team/hyperrogue/-/raw/master/debian/patches/split-build.patch
Patch101:       hyperrogue-13.0v-split-build.patch

BuildRequires:  imagemagick
%if %{with fontconfig}
BuildRequires:  pkgconfig(fontconfig)
%endif
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_gfx)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
Requires:       %{name}-data >= %{version}
Requires:       fonts-ttf-dejavu

%description
You are a lone outsider in a strange, non-Euclidean world.
As a rogue, your goal is to collect as many treasures as possible.
However, collecting treasures attracts dangerous monsters (on the other hand,
killing the monsters allows more treasures to be generated).
Collecting enough treasure also allows you to find rare magical orbs,
which grant you one-time or time-limited special abilities.

%package data
Summary:        Arch-independent data files for HyperRogue
License:        CC-BY-SA 3.0
BuildArch:      noarch

%description data
This package contains arch-independent data files (CC-BY-SA 3.0 music)
for the HyperRogue game. The binary is provided by %{name}.

%prep
%autosetup -p1

# Fix background music load
sed -e "s/find_file(musicfile)/musicfile/" -i sound.cpp

%build
export CXXFLAGS="%{optflags}"
export EXTRA_CXXFLAGS='-DFHS -DHYPERPATH=\"%{_gamesdatadir}/%{name}/\"'
export HYPERROGUE_USE_GLEW=1
export HYPERROGUE_USE_PNG=1
%{?with_fontconfig:
export FONTCONFIG=1 }
%{?with_rogueviz:
export HYPERROGUE_USE_ROGUEVIZ=1 }

%make_build

%install
# No install target, use own.
mkdir -p %{buildroot}%{_gamesbindir}
install -pDm755 -p %{name} %{buildroot}%{_gamesbindir}/%{name}

# Install music/sounds/rogueviz files
mkdir -p %{buildroot}%{_gamesdatadir}/%{name}/{music,sounds}
install -pDm644 music/*    %{buildroot}%{_gamesdatadir}/%{name}/music/
install -pDm644 sounds/*   %{buildroot}%{_gamesdatadir}/%{name}/sounds/
install -pDm644 *.dat *.txt *.ttf %{buildroot}%{_gamesdatadir}/%{name}/

# Icon
for d in 16 24 32 48 64 96 128; do
  magick hyperroid/app/src/main/res/drawable-xxhdpi/icon.png -resize ${d} ${d}.png
  install -pDm644 ${d}.png %{buildroot}%{_iconsdir}/hicolor/${d}x${d}/apps/%{name}.png
done

# Desktop entry
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=HyperRogue
GenericName=Roguelike
Comment=Roguelike game in a strange, non-Euclidean world
Comment[de]=Ein nicht-euklidisches grafisches Spiel im Stil von Rogue
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Game;AdventureGame;
EOF

%files
%license COPYING sounds/credits.txt licenses/*.txt
%doc changelog.txt README.md source-doc.md
%{_gamesbindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png

%files data
%{_gamesdatadir}/%{name}/
