%define major		0
%define libname		%mklibname i2c %{major}
%define develname	%mklibname i2c -d

Name:		i2c-tools
Version:	4.4
Release:	%mkrel 2
Summary:	Heterogeneous set of I2C tools for Linux
Group:		System/Kernel and hardware
License:	GPLv2+
URL:		https://i2c.wiki.kernel.org/index.php/I2C_Tools
Source0:	https://git.kernel.org/pub/scm/utils/i2c-tools/i2c-tools.git/snapshot/%{name}-%{version}.tar.gz
Requires:	udev

Provides:	%{name}-eepromer = %{version}-%{release}
Obsoletes:	i2c-tools-eepromer < 4.3.2

%description
This package contains a heterogeneous set of I2C tools for Linux: a bus
probing tool, a chip dumper, register-level access helpers, EEPROM
decoding scripts, and more.

#------------------------------------------------

%package -n python3-smbus
Summary:	Python 3 module for SMBus access via I2C
Group:		System/Kernel and hardware
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
%{?python_provide:%python_provide python3-smbus}
Requires:	python3

%description -n python3-smbus
This Python 3 module allows SMBus access through the I2C /dev interface
on Linux hosts. The host kernel must have I2C support, I2C device
interface support, and a bus adapter driver.

#------------------------------------------------

%package -n	%{libname}
Summary:	I2C/SMBus bus access library
Group:		System/Libraries
License:	LGPLv2+

%description -n	%{libname}
libi2c offers a way for applications to interact with the devices
connected to the I2C or SMBus buses of the system.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for the I2C library
Group:		Development/C++
License:	LGPLv2+
Requires:	%{libname} = %{version}-%{release}
Provides:	i2c-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development for the I2C library.

#------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%make_build CFLAGS="%{optflags}" LDFLAGS="%{ldflags}"

pushd py-smbus
%py3_build
popd

%install
%make_install PREFIX=%{_prefix} libdir=%{_libdir} BUILD_STATIC_LIB=0 EXTRA=eeprog

pushd py-smbus
%py3_install
popd

# for i2c-dev ondemand loading through kmod
mkdir -p %{buildroot}%{_modprobedir}
echo "alias char-major-89-* i2c-dev" > \
  %{buildroot}%{_modprobedir}/i2c-dev.conf
# for /dev/i2c-# creation (which are needed for kmod i2c-dev autoloading)
mkdir -p %{buildroot}%{_sysconfdir}/udev/makedev.d
for (( i = 0 ; i < 8 ; i++ )) do
  echo "i2c-$i" >> %{buildroot}%{_sysconfdir}/udev/makedev.d/99-i2c-dev.nodes
done

# auto-load i2c-dev after reboot
mkdir -p %{buildroot}%{_modulesloaddir}
echo 'i2c-dev' > %{buildroot}%{_modulesloaddir}/%{name}.conf

%post
# load i2c-dev after the first install
if [ "$1" = 1 ] ; then
    %{_sbindir}/modprobe i2c-dev
fi
exit 0

%files
%doc CHANGES COPYING README
%doc eeprog/README.eeprog
%config(noreplace) %{_modprobedir}/i2c-dev.conf
%config(noreplace) %{_sysconfdir}/udev/makedev.d/99-i2c-dev.nodes
%{_modulesloaddir}/%{name}.conf
%{_bindir}/ddcmon
%{_bindir}/decode-dimms
%{_bindir}/decode-edid
%{_bindir}/decode-vaio
%{_sbindir}/eeprog
%{_sbindir}/i2cdetect
%{_sbindir}/i2cdump
%{_sbindir}/i2cget
%{_sbindir}/i2cset
%{_sbindir}/i2ctransfer
%{_sbindir}/i2c-stub-from-dump
%{_mandir}/man1/decode-dimms.1*
%{_mandir}/man1/decode-vaio.1*
%{_mandir}/man8/eepro*.8*
%{_mandir}/man8/i2cdetect.8*
%{_mandir}/man8/i2cdump.8*
%{_mandir}/man8/i2cget.8*
%{_mandir}/man8/i2cset.8*
%{_mandir}/man8/i2ctransfer.8*
%{_mandir}/man8/i2c-stub-from-dump.8*

%files -n python3-smbus
%doc py-smbus/README
%{python3_sitearch}/smbus*

%files -n %{libname}
%license COPYING.LGPL
%{_libdir}/libi2c.so.%{major}{,.*}

%files -n %{develname}
%dir %{_includedir}/i2c
%{_includedir}/i2c/smbus.h
%{_libdir}/libi2c.so
%{_mandir}/man3/libi2c.3*
