%define icecreamdir %{_libdir}/icecc

Name:		icecream
Epoch:		3
Version:	1.4
Release:	%mkrel 2
Group:		Development/C
Summary:	Distributed p2p based compile system
License:	GPLv2+ and LGPLv2+
URL:		https://github.com/icecc/icecream
Source0:	https://github.com/icecc/icecream/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	iceccd.service
Source2:	icecc-scheduler.service
Source3:	sysconfig.icecream
Source4:	icecream.sh
Source5:	icecream.csh
Source7:	logrotate.icecream
Source8:	logrotate.icecream-scheduler
Source9:	iceccd-wrapper
Source10:	icecc-scheduler-wrapper
Source11:	icecream-tmpfiles.conf

BuildRequires:	docbook2x
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(libcap-ng)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(lzo2)

Requires(pre):    shadow-utils
Requires(post):   systemd
Requires(preun):  systemd

%description
Icecream is a distributed p2p based compile system.

%post
%_tmpfilescreate icecc
%_post_service iceccd

%preun
%_preun_service iceccd

%files
%doc NEWS README.md
%license COPYING
%dir %{_libexecdir}/icecc
%{_libexecdir}/icecc/icecc-create-env
%{_libexecdir}/icecc/compilerwrapper
%{_libexecdir}/icecc/iceccd-wrapper
%{_bindir}/create-env
%{_sbindir}/iceccd
%{_bindir}/icecc
%{_bindir}/icerun
%{_bindir}/icecc-create-env
%{_bindir}/icecc-test-env
%dir %{_libexecdir}/icecc/bin
%{_libexecdir}/icecc/bin/*cc
%{_libexecdir}/icecc/bin/*g++
%{_libexecdir}/icecc/bin/*c++
%{_unitdir}/iceccd.service
%{_tmpfilesdir}/icecream.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_sysconfdir}/profile.d/*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%defattr(0644,root,root,1777)
%dir %{_var}/cache/%{name}
%{_mandir}/man?/ice*.*
%{_libdir}/libicecc.so.*
%dir %ghost %attr(0775, root, icecc) %{_rundir}/icecc
%ghost %attr(0660, -, -) %{_rundir}/icecc/icecc.pid

#-------------------------------------------------------------------------------

%package scheduler
Summary:	Icecream scheduler
Group:		Development/C
Requires:	%{name} = %epoch:%version
Requires(post):   systemd
Requires(preun):  systemd

%description scheduler
%{name} scheduler.

%post scheduler
%_post_service icecc-scheduler

%preun scheduler
%_preun_service icecc-scheduler

%files scheduler
%doc NEWS README.md
%license COPYING
%{_sbindir}/icecc-scheduler
%{_libexecdir}/icecc/icecc-scheduler-wrapper
%{_unitdir}/icecc-scheduler.service
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-scheduler
%{_mandir}/man?/icecc-scheduler.*

#-------------------------------------------------------------------------------

%package devel
Summary: 	Icecream devel
Group: 		Development/C
Requires:	icecream = %{epoch}:%{version}

%description devel
%{name} devel.

%files devel
%doc NEWS README.md
%license COPYING
%{_libdir}/icecc*
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_libdir}/libicecc.so

#---------------------------------------------------------------------------------

%prep
%autosetup -p1

%build
./autogen.sh
%configure --disable-static --enable-shared
%make_build

%install
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -d %{buildroot}%{_sysconfdir}/profile.d
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}%{icecreamdir}/bin
install -d %{buildroot}%{_prefix}
install -d %{buildroot}%{_datadir}
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_var}/cache/%{name}
install -d %{buildroot}%{_tmpfilesdir}
mkdir -p %{buildroot}%{_rundir}/icecc

%make_install

install -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/iceccd.service
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/icecc-scheduler.service
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
# nb: prefixing icecream.sh by "80" so that it is sourced after 20colorgcc.sh
install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/profile.d/80%{name}.sh
install -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/profile.d/80%{name}.csh
install -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -m 644 %{SOURCE8} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-scheduler
install -m 755 %{SOURCE9} %{buildroot}%{_libexecdir}/icecc/iceccd-wrapper
install -m 755 %{SOURCE10} %{buildroot}%{_libexecdir}/icecc/icecc-scheduler-wrapper
install -m 644 %{SOURCE11} %{buildroot}%{_tmpfilesdir}/icecream.conf

# symlinks for libtool
cd %{buildroot}%{icecreamdir}/bin/
pref=`gcc -dumpmachine`
for a in cc gcc g++ c++; do
	ln -s %{_bindir}/icecc $pref-$a
   ln -s %{_bindir}/icecc $a
   rm -f %{buildroot}%{_bindir}/$a
done

# Fix profile locations
sed -i "s,@DEFINEDBYRPMSPEC@,%{icecreamdir},g" %{buildroot}%{_sysconfdir}/profile.d/*

cat << EOF > %{buildroot}%{_bindir}/create-env
#!/bin/bash
GCC="%{_bindir}/gcc"
GCPP="%{_bindir}/g++"

if [ ! -z $1 ]; then
   GCC=\$1
fi

if [ ! -z \$2 ]; then
   GCPP=\$2
fi

%{icecreamdir}/icecc-create-env \$GCC \$GCPP
EOF

find %{buildroot} -name *.a -o -name *.la -delete
