%define major 3
%define libname %mklibname icu %{major}
%define develname %mklibname icu -d
%define realversion 3.4
%define tarballver %(echo %realversion|sed -e 's|\\.|_|g')

%define _with_doc 0

Name:          icu3
Version:       3.4
Release:       %mkrel 1
Epoch:         0
Summary:       International Components for Unicode
Group:         Development/Java
License:       MIT, GPL
Url:           https://www.icu-project.org/index.html
Source0:       https://download.icu-project.org/files/ftp.software.ibm.com/icu/%{version}/icu-%{version}.tgz
# svn export http://source.icu-project.org/repos/icu/icu4jni/tags/release-3-4/ icu4jni
# tar czf icu4jni-3.4-src-svn.tar.gz icu4jni
Source1:       icu4jni-3.4-src-svn.tar.gz
Source2:       icu4jni-3.4-osgi-MANIFEST.MF
# gcc 4.x patch
Patch0:        icu-3.4-ParagraphLayout.patch
BuildRequires: doxygen

%description
The International Components for Unicode (ICU) libraries provide robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and they provide support
for supplementary Unicode characters (needed for GB 18030 repertoire support).

As computing environments become more heterogeneous, software portability
becomes more important. ICU lets you produce the same results across all the
various platforms you support, without sacrificing performance. It offers
great flexibility to extend and customize the supplied services, which 
include:

  * Text: Unicode text handling, full character properties and character set
    conversions (500+ codepages)
  * Analysis: Unicode regular expressions; full Unicode sets; character, word
    and line boundaries
  * Comparison: Language sensitive collation and searching
  * Transformations: normalization, upper/lowercase, script transliterations 
    (50+ pairs)
  * Locales: Comprehensive locale data (230+) and resource bundle architecture
  * Complex Text Layout: Arabic, Hebrew, Indic and Thai
  * Time: Multi-calendar and time zone
  * Formatting and Parsing: dates, times, numbers, currencies, messages and   
    rule based

%files
%{_bindir}/derb
%{_bindir}/genbrk
%{_bindir}/gencnval
%{_bindir}/genrb
%{_bindir}/makeconv
%{_bindir}/pkgdata
%{_bindir}/uconv
%{_sbindir}/decmn
%{_sbindir}/genccode
%{_sbindir}/gencmn
%{_sbindir}/gensprep
%{_sbindir}/genuca
%{_sbindir}/icuswap

#--------------------------------------------------------------------

%package doc
Group:         Development/Java
Summary:       Documentation for the International Components for Unicode
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description doc
Documentation for the International Components for Unicode.

%files doc
%doc license.html readme.html
%{_mandir}/man1/*
%{_mandir}/man8/*

#--------------------------------------------------------------------

%package -n %{libname}
Group:         System/Libraries
Summary:       Libraries for the International Components for Unicode

%description -n %{libname}
Libraries for the International Components for Unicode.

%files -n %{libname}
%{_libdir}/*.so.%{major}*

#--------------------------------------------------------------------

%package -n %{develname}
Group:         Development/Other
Summary:       Development files for the International Components for Unicode
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      %{name}%{major}-devel = %{?epoch:%epoch:}%{version}-%{release}
Requires:      %{name}-devel = %{?epoch:%epoch:}%{version}-%{release}
Requires:      lib%{name}-devel = %{?epoch:%epoch:}%{version}-%{release}

%description -n	%{develname}
Development files and headers for the International Components for Unicode.

%files -n %{develname}
%{_bindir}/icu-config
%{_libdir}/*.so
%dir %{_includedir}/layout
%dir %{_includedir}/unicode
%{_includedir}/layout/*
%{_includedir}/unicode/*
%dir %{_libdir}/icu
%{_libdir}/icu/*
%dir %{_datadir}/icu
%{_datadir}/icu/*

#--------------------------------------------------------------------

%package -n %{libname}jni
Group:         System/Libraries
Summary:       International Components for Unicode for Java Native Interface
BuildRequires: java-devel
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      jpackage-utils

%description -n %{libname}jni
ICU4JNI contains Java Native Interface wrappers for ICU4C's character set conversion and collation libraries.
These wrappers provide increased performace of conversion and collation, and complete compatibility with ICU4C.

%files -n %{libname}jni
%{_javadir}/icu4jni.jar
%{_jnidir}/libICUInterface34*.so

#--------------------------------------------------------------------

%package -n %{libname}jni-devel
Group:         Development/Other
Summary:       Development files for the International Components for Unicode JNI
Requires:      %{libname}jni = %{?epoch:%epoch:}%{version}-%{release}

%description -n %{libname}jni-devel
Development files for the International Components for Unicode JNI.

%files -n %{libname}jni-devel
%{_includedir}/native

#--------------------------------------------------------------------

%prep
%setup -q -n icu
%patch -P 0 -p0

tar xf %{SOURCE1}
cd icu4jni
chmod -R go=u-w *
perl -pi -e 's/\r$//g' config.sub configure Makefile.in aclocal.m4 config.guess config.sub configure configure.in install-sh license.html readme.html unicode-license.txt

%build

pushd source
export CFLAGS='%optflags -fno-strict-aliasing'
export CXXFLAGS='%optflags -fno-strict-aliasing'
%configure \
  --with-library-bits=64else32 \
  --with-data-packaging=library \
  --disable-samples
%make

%if %_with_doc
%make doc
%endif

popd
export tmp_icu=$PWD/source
pushd icu4jni
export CFLAGS='%optflags -fno-strict-aliasing'
export CXXFLAGS='%optflags -fno-strict-aliasing'
export JAVA_HOME=%{_jvmdir}/java
sed -i 's,default_prefix="/usr",default_prefix="$tmp_icu",' $tmp_icu/config/icu-config
sed -i 's,exec_prefix="/usr",exec_prefix="$tmp_icu",' $tmp_icu/config/icu-config
sed -i 's,libexecdir="/usr/lib",libexecdir="$tmp_icu/lib",' $tmp_icu/config/icu-config
sed -i 's,bindir="/usr/bin",bindir="$tmp_icu/bin",' $tmp_icu/config/icu-config
sed -i 's,datadir="/usr/share",datadir="$tmp_icu",' $tmp_icu/config/icu-config
sed -i 's,sbindir="/usr/sbin",bindir="$tmp_icu/bin",' $tmp_icu/config/icu-config

sed -i 's,INSTALL = @INSTALL@,INSTALL = install -pm 755,' Makefile.in 
sed -i 's,INSTALL_PROGRAM = @INSTALL_PROGRAM@,INSTALL_PROGRAM = install -pm 755,' Makefile.in
sed -i 's,INSTALL_DATA = @INSTALL_DATA@,INSTALL_DATA = install -pm 644,' Makefile.in
sed -i 's,INSTALL_SCRIPT = @INSTALL_SCRIPT@,INSTALL_SCRIPT = install -pm 755,' Makefile.in


export ICU_CONFIG=$tmp_icu/config/icu-config
sh ./configure \
  --prefix=%{_prefix} \
  --enable-jdk14
%make debug
%make release

popd

sed -i 's,default_prefix="$tmp_icu",default_prefix="/usr",' $tmp_icu/config/icu-config
sed -i 's,exec_prefix="$tmp_icu",exec_prefix="/usr",' $tmp_icu/config/icu-config
sed -i 's,libexecdir="$tmp_icu/lib",libexecdir="/usr/lib",' $tmp_icu/config/icu-config
sed -i 's,bindir="$tmp_icu/bin",bindir="/usr/bin",' $tmp_icu/config/icu-config
sed -i 's,datadir="$tmp_icu",datadir="/usr/share",' $tmp_icu/config/icu-config
sed -i 's,bindir="$tmp_icu/bin",sbindir="/usr/sbin",' $tmp_icu/config/icu-config

%check
pushd source
make check
popd

%install
pushd source
%make_install
popd


pushd icu4jni
mkdir -p %{buildroot}%{_includedir}/native/{common,collation,converter,normalizer} %{buildroot}%{_jnidir}
install -pm 644 src/native/common/ErrorCode.h %{buildroot}%{_includedir}/native/common/ErrorCode.h
install -pm 644 src/native/collation/CollationInterface.h %{buildroot}%{_includedir}/native/collation/CollationInterface.h
install -pm 644 src/native/converter/ConverterInterface.h %{buildroot}%{_includedir}/native/converter/ConverterInterface.h
install -pm 644 src/native/normalizer/NormalizationInterface.h %{buildroot}%{_includedir}/native/normalizer/NormalizationInterface.h
install -pm 755 build/lib/libICUInterface34.so %{buildroot}%{_jnidir}/
install -pm 755 build/lib/libICUInterface34d.so %{buildroot}%{_jnidir}/
mkdir -p %{buildroot}%{_javadir}
cd build/classes
mkdir -p META-INF
cp -pr ../../META-INF/services/* META-INF/
cp -pr %{SOURCE2} META-INF/MANIFEST.MF
jar cMf ../icu4jni.jar *
install -pm 644 ../icu4jni.jar %{buildroot}%{_javadir}/
popd

chmod +x %{buildroot}%{_libdir}/*.so.*

mkdir -p icu-%{version}
cp -p %{buildroot}%{_jnidir}/libICUInterface34.so icu-%{version}/libICUInterface34.so
cp -p %{buildroot}%{_libdir}/libicudata.so.34.0  icu-%{version}/libicudata.so.34
cp -p %{buildroot}%{_libdir}/libicui18n.so.34.0  icu-%{version}/libicui18n.so.34
cp -p %{buildroot}%{_libdir}/libicuuc.so.34.0  icu-%{version}/libicuuc.so.34

(
  cd icu-%{version}
  zip ../icu-%{version}-mga.zip *34*
  rm -rf *34*
  cp -pr %{buildroot}%{_includedir}/unicode .
  (
    cd unicode
    zip ../../icu-includes-%{version}-mga.zip *.h
  )
)
rm -rf icu-%{version}
mv icu-%{version}-mga.zip %{_sourcedir}/
mv icu-includes-%{version}-mga.zip %{_sourcedir}/

