%define build_test 0
%{?_with_test: %{expand: %%global build_test 1}}
%{?_without_test: %{expand: %%global build_test 0}}

%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

# hardcode build_arch for imagemagick, otherwise it will run in to SIGFAULT
%define build_arch %(echo %{_target_cpu} | sed -e 's/_/-/')

# V E R S I O N   P A R T S

# their "official" version
%define rversion 7.1.1

# their "minor" version
%define minor_rev 41

# some other funny version
# (aw) from the docs: Versions with Q8 in the name are 8 bits-per-pixel
# component (e.g. 8-bit red, 8-bit green, etc.), whereas, Q16 in the
# filename are 16 bits-per-pixel component. A Q16 version permits you
# to read or write 16-bit images without losing precision but requires
# twice as much resources as the Q8 version.
%define qlev Q16HDRI

# the full file version
%define dversion %{rversion}-%{minor_rev}

%define major 10
%define cppmajor 5

%define libname   %mklibname magick-7 %{qlev} %{major}
%define libcpp    %mklibname magick++-7 %{qlev} %{cppmajor}
%define develname %mklibname magick -d

Summary:        An X application for displaying and manipulating images
Name:           imagemagick
Version:        %{rversion}.%{minor_rev}
Release:        %mkrel 3
License:        ASL 2.0
Group:          Graphics/Editors and Converters
URL:            https://www.imagemagick.org/
Source0:        https://imagemagick.org/archive/ImageMagick-%{dversion}.tar.xz
Source1:        https://imagemagick.org/archive/ImageMagick-%{dversion}.tar.xz.asc
Source2:        ImageMagick.pdf.bz2
# re-scaled from ftp://ftp.imagemagick.org/pub/ImageMagick/images/magick-icon.png
Source10:       magick-icon_16x16.png
Source11:       magick-icon_32x32.png
Source12:       magick-icon_48x48.png
Source13:       magick-icon_64x64.png
Patch0:         ImageMagick-7.0.7-docdir.patch
Patch2:         ImageMagick-7.1.0-force-so.patch
Patch7:         ImageMagick-7.0.7-urw.patch
Patch17:        ImageMagick-7.0.10-fpx.patch
Patch19:        ImageMagick-7.0.7-libpath.patch
Patch20:        ImageMagick-7.0.7-fix-montageimages-test.patch
Patch21:        ImageMagick-LPRDelegate.patch

Provides:       ImageMagick = %{version}-%{release}

BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  bzip2-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2) >= 2.1.7
BuildRequires:  chrpath
BuildRequires:  graphviz-devel >= 2.9.0
BuildRequires:  libjbig-devel
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(lqr-1)
BuildRequires:  libltdl-devel
BuildRequires:  perl-devel
BuildRequires:  pkgconfig(libraw_r)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwmf)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(OpenEXR) >= 1.0.6
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(raqm)
%if !%bootstrap
BuildRequires:  pkgconfig(ddjvuapi)
%endif
BuildRequires:  ghostscript
BuildRequires:  ghostscript-devel
BuildRequires:  subversion
%if "%distro_section" == "tainted"
BuildRequires:  pkgconfig(libde265)
BuildRequires:  pkgconfig(libheif)
Recommends:     libde265
Recommends:     libheif
%endif
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  %{_lib}qoi-devel

Requires:       potrace

%description
ImageMagick is a powerful image display, conversion and manipulation tool. It
runs in an X session. With this tool, you can view, edit and display a variety
of image formats.

ImageMagick can make use of the following delegate programs, available as
packages in %{_vendor}: curl enscript ffmpeg ghostscript ghostscript-X gimp
gnuplot graphviz html2ps mplayer ncompress netpbm sane-backends texlive-texmf
transfig ufraw xdg-utils zip autotrace povray

The tainted package supports converting heif/heic image formats.

%package        desktop
Summary:        ImageMagick menus
Group:          Graphics/Editors and Converters
Requires:       xterm

%description    desktop
This package contains the menu and .desktop entries to run the "display"
command from the menu.

%package -n     %{libname}
Summary:        ImageMagick libraries
Group:          System/Libraries
Provides:       %{_lib}magick = %{version}

%description -n %{libname}
This package contains the libraries needed to run programs dynamically linked
with ImageMagick libraries.

%package -n     %{libcpp}
Summary:        ImageMagick libraries
Group:          System/Libraries

%description -n %{libcpp}
This package contains the libraries needed to run programs dynamically linked
with ImageMagick libraries.

%package -n     %{develname}
Summary:        Static libraries and header files for ImageMagick app development
Group:          Development/C
Requires:       %{libname} = %{version}
Requires:       %{libcpp} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       ImageMagick-devel = %{version}-%{release}
Provides:       libmagick-devel = %{version}-%{release}
Provides:       libMagick-devel = %{version}-%{release}

%description -n %{develname}
If you want to create applications that will use ImageMagick code or APIs,
you'll need to install these packages as well as ImageMagick. These additional
packages aren't necessary if you simply want to use ImageMagick, however.

ImageMagick-devel is an addition to ImageMagick which includes static libraries
and header files necessary to develop applications.

%package -n     perl-Image-Magick
Summary:        Libraries and modules for access to ImageMagick from perl
Group:          Development/Perl
Requires:       %{name} = %{version}
Provides:       perl-Magick = %{version}-%{release}

%description -n perl-Image-Magick
This is the ImageMagick perl support package. It includes perl modules and
support files for access to ImageMagick library from perl.

%package        doc
Summary:        %{name} Documentation
Group:          Documentation
BuildArch:      noarch

%description    doc
This package contains HTML/PDF documentation of %{name}.

%prep

%setup -q -n ImageMagick-%{rversion}-%{minor_rev}
%autopatch -p1

bzcat %{SOURCE2} > ImageMagick.pdf
install -m 644 %{SOURCE10} %{SOURCE11} %{SOURCE12} %{SOURCE13} .

%build
#autoreconf -fi

#gw the format-string patch is incomplete:
%define Werror_cflags %nil
%define _disable_ld_no_undefined 1
export CFLAGS="%{optflags} -fno-strict-aliasing -fPIC -DIMPNG_SETJMP_IS_THREAD_SAFE"
export CXXFLAGS="%{optflags} -fno-strict-aliasing -fPIC"

# don't use icecream
export PATH=/bin:/usr/bin

%configure \
    --docdir=%{_defaultdocdir}/imagemagick \
    --with-gcc-arch=generic \
    --with-pic \
    --enable-shared --disable-static \
    --enable-fast-install \
    --with-threads \
    --with-magick_plus_plus \
    --with-gslib \
    --with-wmf \
    --with-lcms \
    --with-rsvg \
    --with-xml \
    --without-dps \
    --without-windows-font-dir \
    --with-modules \
    --with-perl \
    --with-perl-options="INSTALLDIRS=vendor CC='%{__cc} -L$PWD/magick/.libs' LDDLFLAGS='-shared -L$PWD/magick/.libs' INSTALLVENDORMAN3DIR=%{_mandir}/man3 INSTALLVENDORARCH=%{perl_vendorarch}" \
    --with-openjp2 \
    --with-gvc \
    --with-lqr \
    --with-raw \
    --with-gvc \
    --with-jxl \
    --with-raqm \
    --with-jbig \
    --with-fftw

# Disable rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%if %{build_test}
%check
# these tests require X
if [ -f PerlMagick/t/x11/read.t ]; then
        mv PerlMagick/t/x11/read.t PerlMagick/t/x11/read.t.disabled
fi
if [ -f PerlMagick/t/x11/write.t ]; then
        mv PerlMagick/t/x11/write.t PerlMagick/t/x11/write.t.disabled
fi
#dlname=`grep "^dlname" Magick++/lib/.libs/libMagick++.la | cut -d\' -f2`
#LD_PRELOAD="$PWD/Magick++/lib/.libs/$dlname" VERBOSE="1" make check
make check
%endif

%install
# TODO: temporarily disable "empty" RPATHs checking, until finding a better solution
export QA_RPATHS=$((0x0010))

# (Abel) set LD_RUN_PATH to null, to avoid adding rpath to perlmagick module
%make_install LD_RUN_PATH="" pkgdocdir=/installed_docs

# fix docs inclusion (fix an unknown new rpm bug)
rm -rf installed_docs; mv %{buildroot}/installed_docs .

# Remove unpackaged files
find %{buildroot} -name '*.la' -delete

# create compatible symlinks
ln -s libMagick++-7.%{qlev}.so %{buildroot}%{_libdir}/libMagick++.so
ln -s libMagickCore-7.%{qlev}.so %{buildroot}%{_libdir}/libMagickCore.so
ln -s libMagickWand-7.%{qlev}.so %{buildroot}%{_libdir}/libMagickWand.so

%multiarch_binaries %{buildroot}%{_bindir}/Magick++-config
%multiarch_binaries %{buildroot}%{_bindir}/MagickCore-config
%multiarch_binaries %{buildroot}%{_bindir}/MagickWand-config
%multiarch_includes %{buildroot}%{_includedir}/ImageMagick-7/MagickCore/magick-baseconfig.h

# fix invalid rights
chmod 755 \
        %{buildroot}%{perl_vendorarch}/auto/Image/Magick/%{qlev}/%{qlev}.so

find %{buildroot} -name "perllocal.pod" -delete

# icons
install -m 755 -d %{buildroot}%{_liconsdir} \
           %{buildroot}%{_iconsdir} \
           %{buildroot}%{_iconsdir}/hicolor/64x64/apps \
           %{buildroot}%{_miconsdir}
install -m 644 magick-icon_16x16.png %{buildroot}%{_miconsdir}/%{name}.png
install -m 644 magick-icon_32x32.png %{buildroot}%{_iconsdir}/%{name}.png
install -m 644 magick-icon_48x48.png %{buildroot}%{_liconsdir}/%{name}.png
install -m 644 magick-icon_64x64.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/%{name}.png


install -m 755 -d %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=ImageMagick
Comment=Views Graphics files
Exec=%{_bindir}/xterm -geometry 40x15 -title ImageMagick +sb -iconic -e %{_bindir}/display
Icon=%{name}
Terminal=false
Type=Application
Categories=Graphics;Viewer;
EOF

%files
%doc README.md
%{_sysconfdir}/ImageMagick-7
%{_bindir}/animate
%{_bindir}/compare
%{_bindir}/composite
%{_bindir}/convert
%{_bindir}/conjure
%{_bindir}/display
%{_bindir}/identify
%{_bindir}/import
%{_bindir}/magick
%{_bindir}/magick-script
%{_bindir}/mogrify
%{_bindir}/montage
%{_bindir}/stream
%{_libdir}/ImageMagick-%{rversion}
%{_datadir}/ImageMagick-7
%{_mandir}/man1/*
%exclude %{_mandir}/man1/*-config.*

%files desktop
%{_datadir}/applications/*.desktop
%{_iconsdir}/%{name}.png
%{_liconsdir}/%{name}.png
%{_miconsdir}/%{name}.png
%{_iconsdir}/hicolor/64x64/apps/%{name}.png

%files -n %{libname}
%{_libdir}/libMagickCore-7.%{qlev}.so.%{major}{,.*}
%{_libdir}/libMagickWand-7.%{qlev}.so.%{major}{,.*}

%files -n %{libcpp}
%{_libdir}/libMagick++-7.%{qlev}.so.%{cppmajor}{,.*}

%files -n %{develname}
%{_includedir}/ImageMagick-7
%multiarch %{multiarch_bindir}/Magick++-config
%multiarch %{multiarch_bindir}/MagickCore-config
%multiarch %{multiarch_bindir}/MagickWand-config
%multiarch %dir %{multiarch_includedir}/ImageMagick-7
%multiarch %dir %{multiarch_includedir}/ImageMagick-7/MagickCore
%multiarch %{multiarch_includedir}/ImageMagick-7/MagickCore/magick-baseconfig.h
%{_bindir}/Magick++-config
%{_bindir}/MagickCore-config
%{_bindir}/MagickWand-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man1/*-config.*

%files -n perl-Image-Magick
%{perl_vendorarch}/Image
%{perl_vendorarch}/auto/Image
#{perl_vendorarch}/perllocal.pod
%{_mandir}/man3*/*::*.3pm*

%files doc
%doc ImageMagick.pdf LICENSE NOTICE
%doc installed_docs/*
%{_docdir}/ImageMagick-7/
