%define _disable_ld_no_undefined 1

%define shortname indi


Summary:        Library to control astronomical devices
Name:           indilib
Version:        2.1.3
Release:        %mkrel 1
License:        LGPLv2
Group:          System/Libraries
Url:            https://www.indilib.org/
Source0:        https://github.com/indilib/indi/archive/v%{version}/%{shortname}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  fli-devel
BuildRequires:  nova-devel
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(cfitsio) >= 3.090
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libxisf)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libev)

Provides:       %{shortname} = %{version}-%{release}

%description
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

%files
%doc AUTHORS ChangeLog README* NEWS
%{_bindir}/*
%{_datadir}/%{shortname}/
%{_libdir}/%{shortname}/
%{_udevrulesdir}/80-*.rules
%{_udevrulesdir}/99-*.rules

#--------------------------------------------------------------------

%define major   2
%define libname %mklibname indiclient %{major}

%package -n     %{libname}
Summary:        Indi Client library files for INDI
Group:          System/Libraries

Obsoletes:      %{_lib}indi2 < 2.0.8-2

%description -n %{libname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indiclient library files of indilib.

%files -n %{libname}
%{_libdir}/libindiclient.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_alignment %mklibname indialignmentdriver %{major}

%package -n     %{libname_alignment}
Summary:        Indi Alignment Driver library files for INDI
Group:          System/Libraries

%description -n %{libname_alignment}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indiAlignmentDriver library files of indilib.

%files -n %{libname_alignment}
%{_libdir}/libindiAlignmentDriver.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_qt %mklibname indiclientqt %{major}

%package -n     %{libname_qt}
Summary:        Indi Client Qt library files for INDI
Group:          System/Libraries

%description -n %{libname_qt}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indiclientqt library files of indilib.

%files -n %{libname_qt}
%{_libdir}/libindiclientqt.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_driver %mklibname indidriver %{major}

%package -n     %{libname_driver}
Summary:        Indi Driver library files for INDI
Group:          System/Libraries

%description -n %{libname_driver}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indidriver library files of indilib.

%files -n %{libname_driver}
%{_libdir}/libindidriver.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_lx200 %mklibname indilx200_ %{major}

%package -n     %{libname_lx200}
Summary:        Indi lx200 library files for INDI
Group:          System/Libraries

%description -n %{libname_lx200}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indilx200 library files of indilib.

%files -n %{libname_lx200}
%{_libdir}/libindilx200.so.%{major}{,.*}

#--------------------------------------------------------------------

%define develname %mklibname %{shortname} -d

%package -n     %{develname}
Summary:        INDI development files
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname_alignment} = %{version}-%{release}
Requires:       %{libname_qt} = %{version}-%{release}
Requires:       %{libname_driver} = %{version}-%{release}
Requires:       %{libname_lx200} = %{version}-%{release}
Provides:       indi-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains files needed to build applications using indilib.

%files -n %{develname}
%doc AUTHORS ChangeLog README* NEWS
%{_libdir}/*.so
%{_libdir}/pkgconfig/libindi.pc
%{_includedir}/libindi/

#--------------------------------------------------------------------
# (lm) libindiclient is built as static only
# libindiclient BR by kstars

%define staticname %mklibname indiclient -s -d

%package -n     %{staticname}
Summary:        INDI indiclient static development file
Group:          Development/C
Requires:       %{develname} = %{version}-%{release}
Provides:       indiclient-static-devel = %{version}-%{release}

%description -n %{staticname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains libindiclient static file needed to build applications
using indiclient.

%files -n %{staticname}
%{_libdir}/libindiclient.a

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n %{shortname}-%{version}

%build
# This package tries to mix and match PIE and PIC which is wrong and will
# trigger link errors when LTO is enabled.
# Disable LTO
%define _lto_cflags %{nil}

%cmake  \
	-DUDEVRULES_INSTALL_DIR=%{_udevrulesdir} \
	-DINDI_BUILD_QT5_CLIENT=ON \
	-DLIBEV_INCLUDE_DIR=%{_includedir}/libev
%cmake_build

%install
%cmake_install

find %{buildroot} \( -name "*.a" ! -name "libindiclient.a" \) -delete
