# === GLOBAL MACROS ===========================================================

%global _hardened_build 1

# Mageia specific scriplet:
%define _mypost_service() /sbin/chkconfig --add %{1};

%global shared_requirements \
Requires:         bash                       \
Requires:         filesystem          >= 2   \
Requires:         coreutils                  \
Requires:         gawk                       \

# =============================================================================

Name:             initscripts
Summary:          Basic support for legacy System V init scripts
Version:          10.04
Release:          %mkrel 8

License:          GPLv2
Group:            System/Base

URL:              https://github.com/fedora-sysv/initscripts
Source:           https://github.com/fedora-sysv/initscripts/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:          %name-%version-mageia.tar.xz

# === PATCHES =================================================================

# To modify/see the source, mgaconf super patch and other patches
# please read:
# https://gitweb.mageia.org/software/forks/initscripts/tree/README.md?h=distro/mga

Patch1:           %name-%version-mageia.patch

%shared_requirements

Requires:         findutils
Requires:         grep
Requires:         procps-ng
Requires:         setup
Requires:         systemd
Requires:         util-linux

# (ovitters)  Due to urpmi not liking multiple packages obsoleting one package,
#             I'm requiring all the various other packages here. As a result
#             the various other packages are NOT optional. But this has the benefit
#             of making it easier to see the differences of this spec file vs
#             the Fedora one
Requires:         network-scripts
Requires:         netconsole-service
Requires:         readonly-root
Requires:         partmon

Requires(pre):    shadow-utils
Requires(posttrans):   coreutils

BuildRequires:    filesystem          >= 2
BuildRequires:    gcc
BuildRequires:    git
BuildRequires:    gettext
BuildRequires:    glib2-devel
BuildRequires:    pkgconfig
BuildRequires:    popt-devel
BuildRequires:    setup

%{?systemd_requires}
BuildRequires:    systemd

Provides:         /sbin/service

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description
This package provides basic support for legacy System V init scripts, and some
other legacy tools & utilities.

# === SUBPACKAGES =============================================================

%package -n network-scripts
Summary:          Legacy scripts for manipulating of network devices
Requires:         %{name}%{?_isa} = %{version}-%{release}

%shared_requirements

Requires:         bc
Requires:         dbus
Requires:         gawk
Requires:         grep
Requires:         hostname
Requires:         iproute2
Requires:         ipcalc
Requires:         kmod
Requires:         procps-ng
Requires:         sed
Requires:         systemd

# Mageia change because scripts still seem to require this:
Requires:         ethtool
Requires:         ifplugd

Requires(post):   chkconfig
Requires(preun):  chkconfig

Requires(posttrans): chkconfig
Requires(postun): chkconfig

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

# Mageia specific:
Recommends:       dhcp-client

%description -n network-scripts
This package contains the legacy scripts for activating & deactivating of most
network interfaces. It also provides a legacy version of 'network' service.

The 'network' service is enabled by default after installation of this package,
and if the network-scripts are installed alongside NetworkManager, then the
ifup/ifdown commands from network-scripts take precedence over the ones provided
by NetworkManager.

If user has both network-scripts & NetworkManager installed, and wishes to
use ifup/ifdown from NetworkManager primarily, then they has to run command:
 $ update-alternatives --config ifup

Please note that running the command above will also disable the 'network'
service.

# ---------------

%package -n netconsole-service
Summary:          Service for initializing of network console logging
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

# Mageia customization: glibc instead of glibc-common
Requires:         glibc
Requires:         iproute2
Requires:         iputils
Requires:         kmod
Requires:         sed
Requires:         util-linux

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description -n netconsole-service
This packages provides a 'netconsole' service for loading of netconsole kernel
module with the configured parameters. The netconsole kernel module itself then
allows logging of kernel messages over the network.

# ---------------

%package -n readonly-root
Summary:          Service for configuring read-only root support
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

Requires:         cpio
Requires:         findutils
Requires:         hostname
Requires:         iproute2
Requires:         ipcalc
Requires:         util-linux

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description -n readonly-root
This package provides script & configuration file for setting up read-only root
support. Additional configuration is required after installation.

Please note that readonly-root package is considered deprecated with limited support.
Please use systemd-volatile-root functionality instead, if possible.

# ---------------

%package -n partmon
Summary:          Service for monitoring partition free space
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

Requires:         perl-MDK-Common >= 1.0.1

# (ovitters) urpmi does not like this, so instead the main package just requires all subpackages
#Obsoletes:        %%{name}            < 9.82-2

%description -n partmon
This package provides script & configuration file for monitoring the free space
of partitions at boot.

# === BUILD INSTRUCTIONS ======================================================

%prep
%autosetup -S git -a 1

# ---------------

%build
%make_build PYTHON=%{__python3}

# ---------------

%install
%make_install

# Mageia specific: use forked gprintify to change initscripts (the spec-helper
# one does not work)
%{__python3} po-mageia/gprintify.py \
	$(find %{buildroot}/etc/rc.d -type f) \
	$(find %{buildroot}/sysconfig/network-scripts -type f) \
	$(find %{buildroot}%{_prefix}/libexec -type f)
export DONT_GPRINTIFY=1

# This installs the NLS language files:
%find_lang %{name}

%ifnarch s390 s390x
  rm -f %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup-ctc
%endif

# Additional ways to access documentation:
install -m 0755 -d %{buildroot}%{_docdir}/network-scripts

ln -s  %{_docdir}/%{name}/sysconfig.txt   %{buildroot}%{_docdir}/network-scripts/
ln -sr %{buildroot}%{_mandir}/man8/ifup.8 %{buildroot}%{_mandir}/man8/ifdown.8

# We are now using alternatives approach to better co-exist with NetworkManager:
touch %{buildroot}%{_sbindir}/ifup
touch %{buildroot}%{_sbindir}/ifdown

# =============================================================================

# Mageia specific
# fix %%{_sysconfdir}/sysconfig/network-scripts/if{down,up}-* permissions
chmod 755 %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/if{down,up}-*

# create missing dir (mga#29671)
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/wireless.d/
chmod 755 %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/wireless.d/

# (cg) Clean up danging symlinks after initscript removal
%transfiletriggerpostun -- %{_initrddir}/
find -L /etc/rc.d/rc{0,1,2,3,4,5,6,7}.d -type l -delete

# ---------------

# Mageia specific:
# (ovitters) avoid enabling services after split of services
%triggerin -- %{name} < 9.82-2
mkdir -p "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/partmon.notinstall" 2> /dev/null || :
mkdir -p "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" 2> /dev/null || :

# ---------------

%post
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" 2> /dev/null || :
fi

%posttrans
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" ]; then
  %systemd_post import-state.service loadmodules.service
  # Mageia specific services:
  %systemd_post mandriva-save-dmesg.service mandriva-everytime.service
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/%{name}.notinstall" 2> /dev/null || :
fi


%preun
%systemd_preun import-state.service loadmodules.service
%systemd_preun mandriva-save-dmesg.service mandriva-everytime.service

%postun
%systemd_postun import-state.service loadmodules.service
%systemd_postun mandriva-save-dmesg.service mandriva-everytime.service

# ---------------

%post -n network-scripts
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" 2> /dev/null || :
fi

%posttrans -n network-scripts
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" ]; then
  chkconfig --add network > /dev/null 2>&1 || :
  # Mageia specific (network-up)
  chkconfig --add network-up > /dev/null 2>&1 || :
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/network-scripts.notinstall" 2> /dev/null || :
fi

[ -L %{_sbindir}/ifup ]   || rm -f %{_sbindir}/ifup
[ -L %{_sbindir}/ifdown ] || rm -f %{_sbindir}/ifdown

%{_sbindir}/update-alternatives --install %{_sbindir}/ifup   ifup   %{_sysconfdir}/sysconfig/network-scripts/ifup 90 \
                                --slave   %{_sbindir}/ifdown ifdown %{_sysconfdir}/sysconfig/network-scripts/ifdown \
                                --initscript network

%preun -n network-scripts
if [ $1 -eq 0 ]; then
  chkconfig --del network > /dev/null 2>&1 || :
  # Mageia specific (network-up):
  chkconfig --del network-up > /dev/null 2>&1 || :
  %{_sbindir}/update-alternatives --remove ifup %{_sysconfdir}/sysconfig/network-scripts/ifup
fi

# ---------------

%post -n netconsole-service
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" 2> /dev/null || :
fi

%posttrans -n netconsole-service
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" ]; then
  %systemd_post netconsole.service
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/netconsole-service.notinstall" 2> /dev/null || :
fi

%preun -n netconsole-service
%systemd_preun netconsole.service

%postun -n netconsole-service
%systemd_postun netconsole.service

# ---------------

%post -n readonly-root
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" 2> /dev/null || :
fi

%posttrans -n readonly-root
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" ]; then
  %systemd_post readonly-root.service
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/readonly-root.notinstall" 2> /dev/null || :
fi

%preun -n readonly-root
%systemd_preun readonly-root.service

%postun -n readonly-root
%systemd_postun readonly-root.service

# ---------------

%post -n partmon
# (ovitters) remember $1 for usage in posttrans scriptlet as posttrans always
# sets $1 to 1. See see https://bugs.mageia.org/show_bug.cgi?id=19882 and the
# comment in posttrans scriplet
#
# Note: Logic is a bit weird to avoid a dependency on mkdir. The 'mkdir'
# command might not exist in the install case. On upgrade the system will have·
# 'mkdir'. So basically this post scriptlet tells posttrans not to run the
# 'install' logic.
#
# WARNING: Do NOT add a Requires(post) on coreutils! Might cause dependency
# loops (see above bug for detailed discussion
if [ "$1" -ne 1 ]; then
# ignore "mkdir" not found errors
  mkdir -p "%{_localstatedir}/lib/rpm-state/partmon.notinstall" 2> /dev/null || :
fi

%posttrans -n partmon
# (ovitters) The posttrans scriptlet always has $1 to 1. This confuses:
# 1. The systemd_post scriplet (makes use of $1).
# 2. Any usage of $1 in posttrans (was used to not call chkconfig)
#
# systemd_post scriptlet only does something when the rpm is installed.·
# Make use of that knowledge to only call these scriptlets when this package is
# first installed. See https://bugs.mageia.org/show_bug.cgi?id=19882
if [ ! -d "%{_localstatedir}/lib/rpm-state/partmon.notinstall" ]; then
  %_mypost_service partmon
  # reset the state
  rmdir "%{_localstatedir}/lib/rpm-state/partmon.notinstall" 2> /dev/null || :
fi

%preun -n partmon
%_preun_service partmon

# === PACKAGING INSTRUCTIONS ==================================================

%files -f %{name}.lang
%license COPYING
%doc doc/sysconfig.txt

# NOTE: /etc/profile.d/ is owned by setup package.
#       /etc/sysconfig/ is owned by filesystem package.
%dir %{_sysconfdir}/rc.d
%dir %{_sysconfdir}/rc.d/init.d
%dir %{_sysconfdir}/rc.d/rc[0-6].d
%dir %{_sysconfdir}/sysconfig/console
%dir %{_sysconfdir}/sysconfig/modules
%dir %{_libexecdir}/%{name}
%dir %{_libexecdir}/%{name}/legacy-actions

# ---------------

%{_sysconfdir}/rc.d/init.d/functions

# RC symlinks:
%{_sysconfdir}/rc[0-6].d

%{_sysconfdir}/init.d

# ---------------

%attr(0755,root,root) %{_bindir}/listhome
%{_bindir}/usleep

%{_sbindir}/consoletype
%{_sbindir}/genhostid
%{_sbindir}/service

%{_libexecdir}/import-state
%{_libexecdir}/loadmodules

%{_prefix}/lib/systemd/system/import-state.service
%{_prefix}/lib/systemd/system/loadmodules.service
%{_prefix}/lib/udev/rename_device

%{_udevrulesdir}/*

%{_mandir}/man1/*
%{_mandir}/man8/service.*

# Mageia-specific:
%config(noreplace) /etc/modules
   /etc/sysconfig/autofsck

/etc/rc.modules
# hibernate-cleanup.sh: obsolete/unneeded?
%{_sbindir}/hibernate-cleanup.sh
%{_prefix}/lib/lsb/lsb-init-functions
%{_prefix}/lib/systemd/system/mandriva-everytime.service
%{_prefix}/lib/systemd/system/mandriva-save-dmesg.service
%{_libexecdir}/mageia-save-dmesg
%{_libexecdir}/mageia_everytime
%{_tmpfilesdir}/mageia.conf
%{_sysconfdir}/profile.d/*inputrc.*sh
%{_sysconfdir}/profile.d/*tmpdir.*sh
%{_sysconfdir}/profile.d/lang.*sh
%lang(cs)     %{_mandir}/cs/man*/*
%lang(et)     %{_mandir}/et/man*/*
%lang(fr)     %{_mandir}/fr/man*/*
%lang(it)     %{_mandir}/it/man*/*
%lang(pt_BR)  %{_mandir}/pt_BR/man*/*
%lang(ru)     %{_mandir}/ru/man*/*
%lang(uk)     %{_mandir}/uk/man*/*


# =============================================================================

%files -n network-scripts
%doc doc/examples/
%dir %{_sysconfdir}/sysconfig/network-scripts

%{_sysconfdir}/rc.d/init.d/network
%{_sysconfdir}/sysconfig/network-scripts/cellular.d
%{_sysconfdir}/sysconfig/network-scripts/hostname.d
%{_sysconfdir}/sysconfig/network-scripts/ifdown*
%{_sysconfdir}/sysconfig/network-scripts/ifup*
%{_sysconfdir}/sysconfig/network-scripts/init*
%{_sysconfdir}/sysconfig/network-scripts/network-functions*
%{_sysconfdir}/sysconfig/network-scripts/vpn.d
%{_sysconfdir}/sysconfig/network-scripts/wireless.d

%config(noreplace)    %{_sysconfdir}/sysconfig/network-scripts/ifcfg-lo

%ghost                %{_sbindir}/ifup
%ghost                %{_sbindir}/ifdown
%attr(4755,root,root) %{_sbindir}/usernetctl

%{_mandir}/man8/ifup.*
%{_mandir}/man8/ifdown.*
%{_mandir}/man8/usernetctl.*
%{_docdir}/network-scripts/*

# Mageia-specific:
%{_sbindir}/mdv-network-event
%{_sbindir}/vpn-{start,stop}
%{_sysconfdir}/rc.d/init.d/network-auth
%{_sysconfdir}/rc.d/init.d/network-up


# ---------------

%files -n netconsole-service
%config(noreplace) %{_sysconfdir}/sysconfig/netconsole

%{_libexecdir}/netconsole
%{_prefix}/lib/systemd/system/netconsole.service

# ---------------

%files -n readonly-root
%dir %{_sharedstatedir}/stateless
%dir %{_sharedstatedir}/stateless/state
%dir %{_sharedstatedir}/stateless/writable

%config(noreplace) %{_sysconfdir}/rwtab
%config(noreplace) %{_sysconfdir}/statetab
%config(noreplace) %{_sysconfdir}/sysconfig/readonly-root

%{_libexecdir}/readonly-root
%{_prefix}/lib/systemd/system/readonly-root.service

# ---------------

%files -n partmon
%config(noreplace) /etc/sysconfig/partmon
%{_sysconfdir}/rc.d/init.d/partmon
%attr(0755,root,root) %{_bindir}/partmon
