%define major		13
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Tools for managing sets of IP or ports with iptables
Name:		ipset
Version:	7.22
Release:	%mkrel 1
License:	GPLv2+
Group:		System/Kernel and hardware
Url:		https://ipset.netfilter.org/
Source0:	https://ipset.netfilter.org/%{name}-%{version}.tar.bz2
Source10:	ipset.service
Source11:	ipset.init
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(libmnl)

%description
IP sets are a framework inside the Linux kernel since 2.4.x, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

ipset may be the proper tool for you, if you want to

 o store multiple IP addresses or port numbers and match against the collection
   by iptables at one swoop;

 o dynamically update iptables rules against IP addresses or ports without
   performance penalty;

 o express complex IP address and ports based rulesets with one single iptables
   rule and benefit from the speed of IP sets

%package -n	%{libname}
Summary:	Shared %{name} library
Group:          System/Libraries

%description -n	%{libname}
IP sets are a framework inside the Linux kernel since 2.4.x, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

This package contains the shared %{name} library.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Provides:	%{name}-devel = %{version}
Requires:	%{libname} >= %{version}

%description -n	%{develname}
IP sets are a framework inside the Linux kernel since 2.4.x, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

This package contains the development files for %{name}.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -vfi
%configure \
    --enable-bashcompl \
    --enable-shared \
    --disable-static \
    --enable-settype-modules \
    --with-settype-modules-list="all" \
    --with-kmod=no
%make_build

%install
%make_install

# install systemd unit file
install -Dpm644 %{_sourcedir}/ipset.service %{buildroot}%{_unitdir}/ipset.service

# install supporting script
install -Dpm755 %{_sourcedir}/ipset.init %{buildroot}%{_libexecdir}/ipset.init

# we don't want these
find %{buildroot} -name "*.la" -delete

%post
%systemd_post %{name}.service

%preun
if [[ $1 -eq 0 && -n $(lsmod | grep "^xt_set ") ]]; then
    rmmod xt_set 2>/dev/null
    [[ $? -ne 0 ]] && echo Current iptables configuration requires ipsets && exit 1
fi
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%files
%doc ChangeLog ChangeLog.ippool
%{_sbindir}/*
%{_mandir}/man8/*.8*
%{_unitdir}/ipset.service
%{_libexecdir}/ipset.init
%{_datadir}/bash-completion/completions/ipset

%dir %{_libdir}/%{name}
%{_libdir}/%{name}/%{name}_bitmap_ip.so
%{_libdir}/%{name}/%{name}_bitmap_ipmac.so
%{_libdir}/%{name}/%{name}_bitmap_port.so
%{_libdir}/%{name}/%{name}_hash_ip.so
%{_libdir}/%{name}/%{name}_hash_ipmac.so
%{_libdir}/%{name}/%{name}_hash_ipmark.so
%{_libdir}/%{name}/%{name}_hash_ipport.so
%{_libdir}/%{name}/%{name}_hash_ipportip.so
%{_libdir}/%{name}/%{name}_hash_ipportnet.so
%{_libdir}/%{name}/%{name}_hash_mac.so
%{_libdir}/%{name}/%{name}_hash_net.so
%{_libdir}/%{name}/%{name}_hash_netiface.so
%{_libdir}/%{name}/%{name}_hash_netnet.so
%{_libdir}/%{name}/%{name}_hash_netport.so
%{_libdir}/%{name}/%{name}_hash_netportnet.so
%{_libdir}/%{name}/%{name}_list_set.so

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%dir %{_includedir}/libipset/
%{_includedir}/libipset/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libipset.pc
%{_mandir}/man3/libipset.3*
