Summary:	Network monitoring tools including ping
Name:		iputils
Version:	20240905
Release:	%mkrel 1
License:	BSD
Group:		System/Base
URL:		https://github.com/iputils/iputils
Source0:	https://github.com/iputils/iputils/archive/%{version}/%{name}-%{version}.tar.gz
# ifenslave.c seems to come from linux-2.6.25/Documentation/networking/ifenslave.c
Source1:	ifenslave.c
# bonding.txt seems to come from linux-2.6.25/Documentation/networking/bonding.txt
Source2:	bonding.txt
Source3:	ifenslave.8
Source4:	ninfod.service

Patch100:	iputils-ifenslave.patch
Requires(pre):	filesystem >= 2.1.9-18
BuildRequires:	docbook-dtd31-sgml
BuildRequires:	docbook5-style-xsl
BuildRequires:	gettext
BuildRequires:	pkgconfig(libidn2)
BuildRequires:	iproute2
BuildRequires:	libsysfs-devel
BuildRequires:	meson
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(libxslt)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	libgcrypt-devel
BuildRequires:	xsltproc

Requires:	traceroute

%description
The iputils package contains ping, a basic networking tool. The ping command
sends a series of ICMP protocol ECHO_REQUEST packets to a specified network
host and can tell you if that machine is alive and receiving network traffic.

%package	ninfod
Summary:	Node Information Query Daemon
Requires:	%{name} = %{version}-%{release}
Group:		System/Base
Requires(post):	rpm-helper >= %{rpmhelper_required_version}
Requires(preun): rpm-helper >= %{rpmhelper_required_version}

%description	ninfod
Node Information Query (RFC4620) daemon. Responds to IPv6 Node Information
Queries.

%prep
%setup -q -n %{name}-%{version}

cp %{SOURCE1} .
cp %{SOURCE2} .
cp %{SOURCE3} .
cp %{SOURCE4} .

%autopatch -p1

%build
%serverbuild
%meson
%meson_build
gcc -Wall %{optflags} $CFLAGS $LDFLAGS ifenslave.c -o ifenslave

%install
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_mandir}/man8

%meson_install
%find_lang %{name}

ln -s ping %{buildroot}%{_bindir}/ping6
ln -s ../bin/tracepath %{buildroot}%{_sbindir}/tracepath
ln -s ../bin/tracepath %{buildroot}%{_sbindir}/tracepath6
ln -s ../bin/arping %{buildroot}%{_sbindir}/arping
ln -s traceroute %{buildroot}%{_sbindir}/traceroute6
install -cp ifenslave %{buildroot}%{_sbindir}/
install -cp ifenslave.8 %{buildroot}%{_mandir}/man8/
install -cp ninfod.service %{buildroot}%{_unitdir}
rm -rf %{buildroot}%{_sysconfdir}/init.d

%pretrans -p <lua>
st = posix.stat(rpm.expand("{_bindir}/ping6"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_bindir}/ping6"))
end
st = posix.stat(rpm.expand("{_sbindir}/tracepath6"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_sbindir}/tracepath6"))
end
st = posix.stat(rpm.expand("{_sbindir}/tracepath"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_sbindir}/tracepath"))
end
st = posix.stat(rpm.expand("{_sbindir}/arping"))
if st and st.type ~= "link" then
   os.remove(rpm.expand("{_sbindir}/arping"))
end

%post ninfod
%_post_service ninfod

%preun ninfod
%_preun_service ninfod

%files -f %{name}.lang
%doc bonding.txt
%{_bindir}/clockdiff
%attr(4755,root,root)	%{_bindir}/ping
%{_bindir}/arping
%{_sbindir}/arping
%{_sbindir}/ifenslave
%{_bindir}/ping6
%{_sbindir}/tracepath6
%{_bindir}/tracepath
%{_sbindir}/tracepath
%{_sbindir}/traceroute6
%{_mandir}/man8/*

%files ninfod
%{_unitdir}/ninfod.service
