%define pypi_name ipyparallel

%bcond_with docs

Name:           ipyparallel
Version:        9.0.1
Release:        %mkrel 2
Group:          Development/Python
Summary:        Interactive Parallel Computing with IPython (tools)

License:        BSD
URL:            https://ipython.org/
Source0:        https://pypi.io/packages/source/i/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(pyzmq)
BuildRequires:  python3dist(traitlets)
BuildRequires:  python3dist(ipython-genutils)
BuildRequires:  python3dist(decorator)
BuildRequires:  python3dist(jupyter-client)
BuildRequires:  python3dist(ipykernel)
BuildRequires:  python3dist(tornado)
BuildRequires:  python3dist(pexpect)
BuildRequires:  python3dist(pickleshare)
BuildRequires:  python3dist(prompt-toolkit)
BuildRequires:  python3dist(simplegeneric)
BuildRequires:  python3dist(backcall)
# for docs
%if %{with docs}
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(intersphinx-registry)
BuildRequires:  python3dist(sphinxext-rediraffe)
BuildRequires:  python3dist(myst-nb)
# Not yet packaged
#BuildRequires:  python3-autodoc-traits
%endif

Requires:       python3-%{name} = %{version}-%{release}
Recommends:     %{name}-doc

%description
Use multiple instances of IPython in parallel, interactively.

This package installs the ipyparallel tools.

%package -n     python3-%{name}
Group:          Development/Python
Summary:        Interactive Parallel Computing with IPython (Python 3)
Recommends:     python3dist(mpi4py)
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Use multiple instances of IPython in parallel, interactively.

This package installs the library for Python 3.

%package doc
Summary:       Interactive Parallel Computing with IPython documentation
Group:         Development/Python

%description doc
Use multiple instances of IPython in parallel, interactively.

This package contains examples of usage.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if %{with docs}
pushd docs
PYTHONPATH=.. make html man SPHINXBUILD=sphinx-build-3
rm -f build/html/.buildinfo
popd
%endif

%install
%pyproject_install

# Install man page
%if %{with docs}
install -Dpm644 ./docs/build/man/ipythonparallel.1 %{buildroot}%{_mandir}/man1/ipythonparallel.1
%endif

# Fix wrong install directory for configuraton files
mv %{buildroot}%{_prefix}%{_sysconfdir} %{buildroot}%{_sysconfdir}

# python shebang
%py3_shebang_fix %{buildroot}%{python3_sitelib}/ipyparallel/*

%files
%{_bindir}/ipcluster
%{_bindir}/ipcontroller
%{_bindir}/ipengine

%files doc
%doc docs/source/examples
%if %{with docs}
%doc docs/build/html
%endif

%files -n python3-%{name}
%license COPYING.md
%if %{with docs}
%{_mandir}/man1/*
%endif
%{python3_sitelib}/ipyparallel/
%{python3_sitelib}/ipyparallel-%{version}.dist-info/
%{_datadir}/jupyter/labextensions/ipyparallel-labextension/
%{_datadir}/jupyter/nbextensions/ipyparallel/
%config(noreplace) %{_sysconfdir}/jupyter/jupyter_notebook_config.d/ipyparallel.json
%config(noreplace) %{_sysconfdir}/jupyter/jupyter_server_config.d/ipyparallel.json
%config(noreplace) %{_sysconfdir}/jupyter/nbconfig/tree.d/ipyparallel.json
