%bcond_with doc
%bcond_with check

Summary:       An interactive computing environment for Python
Name:          ipython
Version:       8.32.0
Release:       %mkrel 1
License:       BSD
Group:         Development/Python
Url:           https://ipython.org/
Source0:       %{pypi_source}
BuildArch:     noarch
BuildRequires: pyproject-rpm-macros
BuildRequires: python3-devel
Provides:      python3-ipython = %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description
IPython provides a rich toolkit to help you make the most out of using
Python interactively. Its main components are:

* A powerful interactive Python shell
* A Jupyter kernel to work with Python code in Jupyter notebooks and
  other interactive frontends.

The enhanced interactive Python shell has the following main features:

* Comprehensive object introspection.
* Input history, persistent across sessions.
* Caching of output results during a session with automatically generated references.
* Extensible tab completion, with support by default for completion of python variables
  and keywords, filenames and function keywords.
* Extensible system of ‘magic’ commands for controlling the environment and performing
  many tasks related either to IPython or the operating system.
* A rich configuration system with easy switching between different setups
  (simpler than changing $PYTHONSTARTUP environment variables every time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs and GUIs.
* Integrated access to the pdb debugger and the Python profiler.

%pyproject_extras_subpkg -n python3-%{name} notebook

%prep
%autosetup -p1 -n %{name}-%{version}

%generate_buildrequires
%pyproject_buildrequires %{?with_doc:-x doc} %{?with_check:-x test}

%build
%pyproject_wheel

%if %{with doc}
pushd docs
PYTHONPATH=.. make html SPHINXBUILD='sphinx-build-3 -D intersphinx_timeout=1'
mkdir -p build/html/
rm -rf build/html/.buildinfo
popd
%endif

%install
%pyproject_install
%pyproject_save_files IPython

# move the manpage to ipython3
mv %{buildroot}%{_mandir}/man1/ipython{,3}.1

%if %{with check}
%check
# Ensure that the user's .pythonrc.py is not invoked during any tests.
export PYTHONSTARTUP=""
# Fedora's Koji builders can be slow, especially on arms, we scale timeouts 4 times
export IPYTHON_TESTING_TIMEOUT_SCALE=4
# To prevent _pytest.pathlib.ImportPathMismatchError, we are
# testing directly in buildroot
pushd %{buildroot}%{python3_sitelib}/IPython
%pytest -k "not test_latex_to_png_color"
rm -rf .pytest_cache
popd
%else
rm -r %{buildroot}%{python3_sitelib}/IPython/*/tests
sed -i -e '/\/tests\//d' -e '/\/tests$/d' %{pyproject_files}
%endif

%files -f %{pyproject_files}
%doc README.rst
%if %{with doc}
%doc docs/build/html
%endif
%{_bindir}/ip*
%{_mandir}/man1/*
