%global        _legacy_common_support 1

%define        hbin	    bin

Summary:       Image Reduction and Analysis Facility
Name:          iraf
Version:       2.18
Release:       %mkrel 1
License:       MIT-like
Group:         Sciences/Astronomy
Url:           https://iraf-community.github.io/
Source0:       https://github.com/iraf-community/iraf/archive/v%{version}/%{name}-%{version}.tar.gz
# From Debian
Source11:      iraf.desktop
Source12:      iraf.svg
Source13:      precompile.cl

#adusted to mga
Patch0:      iraf-2.18-vnum-motd.patch
Patch1:      iraf-2.18-skip-source-dependent-tests.patch
Patch2:      iraf-2.18-ensure-reproducible-build.patch

#arch dep lib dir name
Patch10:      iraf-2.18-libfix.patch

BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(expat)
BuildRequires: readline-devel
BuildRequires: pkgconfig(cfitsio)
BuildRequires: xmlrpc-c-devel
BuildRequires: f2c
BuildRequires: tcsh
BuildRequires: flex

BuildRequires: bison
BuildRequires: pkgconfig(ncurses)
Requires:      f2c
Requires:      bison

%description
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

%package noao
Summary:       IRAF NOAO data reduction package
Group:         Sciences/Astronomy
Requires:      iraf = %{version}-%{release}

%description noao
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

This file contains the NOAO packages for the reduction and analysis
of Optical Astronomy data.

%package devel
Summary:       Image Reduction and Analysis Facility (development files)
Group:         Sciences/Astronomy
Requires:      iraf = %{version}-%{release}

%description devel
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

This package contains the IMFORT Fortran/C programming interface, and
the full SPP/VOS programming environment in which the portable IRAF
system and all applications are written.

%package noao-devel
Summary:       IRAF NOAO data reduction package (development files)
Group:         Sciences/Astronomy
Requires:      iraf-devel = %{version}-%{release}
Requires:      iraf-noao = %{version}-%{release}

%description noao-devel
IRAF stands for the Image Reduction and Analysis Facility. It
is the de facto standard for the general processing of astronomical images
and spectroscopy from the ultraviolet to the far infrared. IRAF is a
product of the National Optical Astronomy Observatories (www.noao.edu).

This package contains additional libraries and headers used for
compiling packages that extend the functionality of the iraf-noao
package.

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1

%build

export CC='gcc'
export CFLAGS="%{build_cflags} -Wno-incompatible-pointer-types"
export LDFLAGS="%{build_ldflags}"
export IRAFARCH=''
export iraf=$(pwd)/
bin=${iraf}bin/ noaobin=${iraf}/noao/bin/ %make_build
./bin/cl.e -f %{SOURCE13}

%install


prefix=%{_prefix} libfix=%{_lib} %make_install IRAFARCH=''

mkdir -p %{buildroot}%{_datadir}/applications
install -Dpm644 %{_sourcedir}/iraf.desktop %{buildroot}%{_datadir}/applications/iraf.desktop

mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -Dpm644 %{_sourcedir}/iraf.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/iraf.svg

%__mkdir_p %{buildroot}%{_includedir}
%__ln_s %{_libdir}/iraf/unix/hlib/libc/iraf.h %{buildroot}%{_includedir}/iraf.h


%files
%doc doc/*
%dir %{_libdir}/iraf/
%dir %{_libdir}/iraf/lib/
%dir %{_libdir}/iraf/lib/scr/
%{_libdir}/iraf/lib/scr/*
%{_libdir}/iraf/lib/helpdb.mip
%{_libdir}/iraf/lib/syserrmsg
%{_libdir}/iraf/lib/syshelpdir
%{_libdir}/iraf/lib/clpackage.hd
%{_libdir}/iraf/lib/root.hd
%dir %{_libdir}/iraf/dev/
%{_libdir}/iraf/dev/*
%dir %{_libdir}/iraf/pkg/
%dir %{_libdir}/iraf/pkg/bench/
%{_libdir}/iraf/pkg/bench/*
%dir %{_libdir}/iraf/pkg/lists/
%{_libdir}/iraf/pkg/lists/*
%dir %{_libdir}/iraf/pkg/cl/
%{_libdir}/iraf/pkg/cl/*
%dir %{_libdir}/iraf/pkg/language/
%{_libdir}/iraf/pkg/language/*
%dir %{_libdir}/iraf/pkg/system/
%{_libdir}/iraf/pkg/system/*
%dir %{_libdir}/iraf/pkg/obsolete/
%{_libdir}/iraf/pkg/obsolete/*
%dir %{_libdir}/iraf/pkg/plot/
%{_libdir}/iraf/pkg/plot/*
%dir %{_libdir}/iraf/pkg/xtools/
%{_libdir}/iraf/pkg/xtools/*
%dir %{_libdir}/iraf/pkg/proto/
%{_libdir}/iraf/pkg/proto/*
%dir %{_libdir}/iraf/pkg/ecl/
%{_libdir}/iraf/pkg/ecl/*
%dir %{_libdir}/iraf/pkg/utilities/
%{_libdir}/iraf/pkg/utilities/*
%dir %{_libdir}/iraf/pkg/dataio/
%{_libdir}/iraf/pkg/dataio/*
%dir %{_libdir}/iraf/pkg/images/
%{_libdir}/iraf/pkg/images/*
%dir %{_libdir}/iraf/pkg/softools/
%{_libdir}/iraf/pkg/softools/*
%dir %{_libdir}/iraf/sys/
%{_libdir}/iraf/sys/*
%dir %{_libdir}/iraf/math/
%{_libdir}/iraf/math/*
%dir %{_libdir}/iraf/bin
%{_libdir}/iraf/%{hbin}/cl.e
%{_libdir}/iraf/%{hbin}/ecl.e
%{_libdir}/iraf/%{hbin}/irafks.e
%{_libdir}/iraf/%{hbin}/x_*.e
%dir %{_libdir}/iraf/unix/%{hbin}
%{_libdir}/iraf/unix/%{hbin}/*.e
%dir %{_libdir}/iraf/unix/boot/
%{_libdir}/iraf/unix/boot/*
%dir %{_libdir}/iraf/unix/os/
%{_libdir}/iraf/unix/os/*
%dir %{_libdir}/iraf/local/
%{_libdir}/iraf/local/*
%{_libdir}/iraf/extern/*
%dir %{_libdir}/iraf/unix/hlib/
%{_libdir}/iraf/unix/hlib/motd
%{_libdir}/iraf/unix/hlib/*.cl
%{_libdir}/iraf/unix/hlib/*.sh
%exclude %{_libdir}/iraf/unix/hlib/f77.sh
%{_libdir}/iraf/unix/hlib/clpackage.hd
%{_libdir}/iraf/unix/hlib/clpackage.men
%{_libdir}/iraf/unix/hlib/extern.pkg
%{_libdir}/iraf/unix/hlib/mkfloat
%{_libdir}/iraf/unix/hlib/motd.etc
%dir %{_libdir}/iraf/test
%{_libdir}/iraf/test/*.md
%{_libdir}/iraf/test/run_tests
%{_libdir}/iraf/unix/hlib/zzsetenv.def
%{_bindir}/irafcl
%{_bindir}/sgidispatch
%{_bindir}/cl
%{_bindir}/ecl
%{_bindir}/mkiraf
%{_bindir}/rmbin
%{_bindir}/rmfiles
%{_bindir}/rtar
%{_bindir}/wtar
%dir %{_sysconfdir}/iraf/
%{_sysconfdir}/iraf/irafroot
%{_mandir}/man1/*.1.*
%{_datadir}/applications/iraf.desktop
%{_iconsdir}/hicolor/scalable/apps/iraf.svg

%files noao
%dir %{_libdir}/iraf/noao/
%dir %{_libdir}/iraf/noao/artdata/
%{_libdir}/iraf/noao/artdata/*
%dir %{_libdir}/iraf/noao/astcat/
%{_libdir}/iraf/noao/astcat/*
%dir %{_libdir}/iraf/noao/astrometry/
%{_libdir}/iraf/noao/astrometry/*
%dir %{_libdir}/iraf/noao/astutil/
%{_libdir}/iraf/noao/astutil/*
#{_libdir}/iraf/noao/bin/
%dir %{_libdir}/iraf/noao/%{hbin}
%{_libdir}/iraf/noao/%{hbin}/x_*.e
%dir %{_libdir}/iraf/noao/digiphot
%{_libdir}/iraf/noao/digiphot/*
%dir %{_libdir}/iraf/noao/filterphot/
%{_libdir}/iraf/noao/filterphot/*
%dir %{_libdir}/iraf/noao/focas/
%{_libdir}/iraf/noao/focas/*
%dir %{_libdir}/iraf/noao/imred/
%{_libdir}/iraf/noao/imred/*
%dir %{_libdir}/iraf/noao/lib/
%{_libdir}/iraf/noao/lib/*
%exclude %{_libdir}/iraf/noao/lib/*.h
%exclude %{_libdir}/iraf/noao/lib/*.inc
%dir %{_libdir}/iraf/noao/mtlocal/
%{_libdir}/iraf/noao/mtlocal/*
%{_libdir}/iraf/noao/noao.cl
%{_libdir}/iraf/noao/noao.hd
%{_libdir}/iraf/noao/noao.men
%{_libdir}/iraf/noao/noao.par
%dir %{_libdir}/iraf/noao/nobsolete/
%{_libdir}/iraf/noao/nobsolete/*
%dir %{_libdir}/iraf/noao/nproto/
%{_libdir}/iraf/noao/nproto/*
%dir %{_libdir}/iraf/noao/obsutil/
%{_libdir}/iraf/noao/obsutil/*
%dir %{_libdir}/iraf/noao/onedspec/
%{_libdir}/iraf/noao/onedspec/*
%dir %{_libdir}/iraf/noao/rv/
%{_libdir}/iraf/noao/rv/*
%dir %{_libdir}/iraf/noao/surfphot/
%{_libdir}/iraf/noao/surfphot/*
%dir %{_libdir}/iraf/noao/twodspec/
%{_libdir}/iraf/noao/twodspec/*
%exclude %{_libdir}/iraf/noao/*/*.a

# dev files
%files devel
%{_includedir}/iraf.h
%{_bindir}/mkpkg
%{_bindir}/xc
%{_bindir}/xyacc
%{_libdir}/iraf/%{hbin}/lib*.a
%{_libdir}/iraf/%{hbin}/libmain.o
%dir %{_libdir}/iraf/include/
%{_libdir}/iraf/include/*.h
%dir %{_libdir}/iraf/lib
%{_libdir}/iraf/lib/*.h
%{_libdir}/iraf/lib/*.inc
%{_libdir}/iraf/lib/*.a
%{_libdir}/iraf/lib/*.com
%{_libdir}/iraf/lib/names
%{_libdir}/iraf/lib/*.x
%{_libdir}/iraf/lib/math/*.h
%{_libdir}/iraf/lib/pkg/*.h
%{_libdir}/iraf/unix/%{hbin}/f2c.e
%{_libdir}/iraf/unix/%{hbin}/generic.e
%{_libdir}/iraf/unix/%{hbin}/libboot.a
%{_libdir}/iraf/unix/%{hbin}/libf2c.a
%{_libdir}/iraf/unix/%{hbin}/libos.a
%{_libdir}/iraf/unix/%{hbin}/mkpkg.e
%{_libdir}/iraf/unix/%{hbin}/rm%{hbin}.e
%{_libdir}/iraf/unix/%{hbin}/rmfiles.e
%{_libdir}/iraf/unix/%{hbin}/rpp.e
%{_libdir}/iraf/unix/%{hbin}/rtar.e
%{_libdir}/iraf/unix/%{hbin}/wtar.e
%{_libdir}/iraf/unix/%{hbin}/xc.e
%{_libdir}/iraf/unix/%{hbin}/xpp.e
%{_libdir}/iraf/unix/%{hbin}/xyacc.e
%{_libdir}/iraf/unix/hlib/strip.iraf
%{_libdir}/iraf/unix/hlib/*.a
%{_libdir}/iraf/unix/hlib/*.man
%{_libdir}/iraf/unix/hlib/*.csh
%{_libdir}/iraf/unix/hlib/*.f
%{_libdir}/iraf/unix/hlib/*.h
%{_libdir}/iraf/unix/hlib/*.inc
%{_libdir}/iraf/unix/hlib/*.sf
%{_libdir}/iraf/unix/hlib/f77.sh
%dir %{_libdir}/iraf/unix/hlib/libc
%{_libdir}/iraf/unix/hlib/libc/*

# noao dev files
%files noao-devel
%{_libdir}/iraf/noao/%{hbin}/lib*.a
%{_libdir}/iraf/noao/lib/*.h
%{_libdir}/iraf/noao/lib/*.inc
