%global major       1
%define libname     %mklibname ispcrt %major
%define libname_cpu %mklibname ispcrt-device-cpu %major
%define devname     %mklibname ispcrt -d

%global with_snapshot	0
%global date		20190309
%global commit		34da2d23bbf32abf44da11d2cdca595dc7318cec
%global shortcommit	%(c=%{commit}; echo ${c:0:7})

%bcond_with examples

%global toolchain clang

%define rel	3

Name:		ispc
Version:	1.25.3
%if %{with_snapshot}
Release:	%mkrel -c git%{date} %{rel}
%else
Release:	%mkrel %{rel}
%endif
Summary:	C-based SPMD programming language compiler
Group:		Development/C
License:	BSD
URL:		https://ispc.github.io/
%if %{with_snapshot}
Source0:	https://github.com/%{name}/%{name}/archive/%{commit}/%{name}-%{shortcommit}.tar.gz
%else
Source0:	https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
%endif
BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	clang-devel
BuildRequires:	doxygen
BuildRequires:	flex
BuildRequires:	git
BuildRequires:	gcc-c++
BuildRequires:	llvm-devel >= 16.0.0
BuildRequires:	rst2html
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(zlib)

# Upstream only supports these architectures
ExclusiveArch:	x86_64 %{arm64}

# patches from upstream (starting from 100)

%if ! %{with examples}
Obsoletes:	%{name}-examples < %{version}-%{release}
%endif

%description
A compiler for a variant of the C programming language, with extensions for
"single program, multiple data" (SPMD) programming.

%package examples
Summary:	Examples binaries for ispc
Group:		Development/C

%description examples
This package contains the examples binaries for the ispc SPMD compiler.

%package -n %libname
Summary:	Library for ispc
Group:		System/Libraries

%description -n %libname
Library for ispc.

%package -n %libname_cpu
Summary:	Library for ispc
Group:		System/Libraries

%description -n %libname_cpu
Library for ispc.

%package -n %devname
Group:		Development/C
Summary:	Development files for %{name}
Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	%{libname_cpu}%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
applications that use %{name}.

%prep
%if %{with_snapshot}
%autosetup -n %{name}-%{commit} -p1
%else
%autosetup -n %{name}-%{version} -p1
%endif

# Suppress warning message as error
sed -i 's| -Werror ||g' CMakeLists.txt

# Fix BUILD_VERSION
sed -i -e '/BUILD_VERSION/s/${GIT_COMMIT_HASH}/%{version}/' CMakeLists.txt

# Fix all Python shebangs recursively in .
%py3_shebang_fix .

%build
%cmake	\
	-DISPC_INCLUDE_EXAMPLES=%{?with_examples:ON}%{!?with_examples:OFF} \
	-DISPC_INCLUDE_TESTS=OFF
%cmake_build

(
 cd ./docs/
 ./build.sh
)

%install
%cmake_install

#Remove static file
rm %{buildroot}%{_libdir}/lib%{name}rt_static.a

%files
%license LICENSE.txt
%doc docs/*.html docs/ReleaseNotes.txt
%{_bindir}/%{name}
%{_bindir}/check_isa

%if %{with examples}
%files examples
%{_prefix}/lib/ispc/examples
%endif

%files -n %libname
%{_libdir}/lib%{name}rt.so.%{major}{,.*}

%files -n %libname_cpu
%{_libdir}/libispcrt_device_cpu.so.%{major}{,.*}

%files -n %devname
%{_includedir}/%{name}rt/
%{_libdir}/cmake/%{name}rt-%{version}/
%{_libdir}/lib%{name}rt.so
%{_libdir}/lib%{name}rt_device_cpu.so
