# Bootstrap without libffado
%bcond_without firewire

# D-Bus support enabled by default, set "--with nodbus" to disable
%define enable_dbus 1
%{?_with_nodbus: %{expand: %%define enable_dbus 0}}

# Build classic jackd executable as well
%define enable_classic 1
%{?_with_noclassic: %{expand: %%define enable_noclassic 0}}

# clients crash if built with lto
# https://github.com/jackaudio/jack2/issues/485
%define _lto_cflags %{nil}

%define     lib_name_orig  libjack
%define     lib_major      0
%define     lib_name       %mklibname jack %{lib_major}
%define     lib_name_devel %mklibname jack -d

Summary:        The Jack Audio Connection Kit 2
Name:           jackit
Version:        1.9.22
Release:        %mkrel 1
# Lib is LGPL, apps are GPL
License:        LGPLv2+ and GPLv2+
Group:          System/Servers
URL:            https://jackaudio.org/
Source0:        https://github.com/jackaudio/jack2/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        jackit-limits.conf
# Fix compilation on aarch64
Source5:        %{name}-aarch64.patch
BuildRequires:  doxygen
BuildRequires:  waf
BuildRequires:  fltk-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(celt)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(libraw1394) >= 1.2.1
BuildRequires:  pkgconfig(libavc1394)
BuildRequires:  pkgconfig(libiec61883) >= 1.1.0
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(readline)
%if %{with firewire}
BuildRequires:  pkgconfig(libffado) >= 1.999.17
%endif
BuildRequires:  python3
%if %{enable_dbus}
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(expat)
%endif

%description
This package provides the C++ multiprocessor implementation of the Jack
Audio Connection Kit (JACK), also known as JACK2. This package comes with
enabled D-Bus support for JACK2, which is required by the LADI
session handler.
JACK is a low-latency audio server, written primarily for the Linux
operating system. It can connect a number of different applications to
an audio device, as well as allowing them to share audio between
themselves. Its clients can run in their own processes (ie. as a
normal application), or can they can run within a JACK server (ie. a
"plugin").

JACK is different from other audio server efforts in that it has been
designed from the ground up to be suitable for professional audio
work. This means that it focuses on two key areas: synchronous
execution of all clients, and low latency operation.

%package -n     %{lib_name}
Summary:        Library associated with jack kit, needed for jackd/jackdbus
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{lib_name}
This library is mandatory for the Jack Audio Connection Kit.

%package -n     %{lib_name_devel}
Summary:        Header files for Jack
Group:          Development/C
Requires:       %{lib_name} = %{version}
Provides:       %{lib_name_orig}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       jack-audio-connection-kit-devel = %{version}-%{release}

Requires:       pkgconfig(samplerate)

%description -n %{lib_name_devel}
Header files for the Jack Audio Connection Kit.

%prep
%autosetup -p1 -n jack2-%{version}

# force system waf
mkdir -pv tools
touch __init__.py
cp -rv autooptions tools
cp -v waflib/extras/xcode*.py tools
rm -rv waflib waf
sed -e "s/load('xcode6'/load('xcode6', tooldir='tools'/g" \
    -e "s/load('autooptions'/load('autooptions', tooldir='tools'/g" \
    -i wscript

%build
export CPPFLAGS="%{optflags} -O0"
%waf \
%if %{with firewire}
    --firewire \
%endif
%if %{enable_dbus}
    --dbus \
%if %{enable_classic}
    --classic \
%endif
%endif
    --alsa \
    --doxygen \
    --systemd-unit

%waf_build -v

%install
%waf_install

mkdir -p %{buildroot}%{_sysconfdir}/security/limits.d
cp %{SOURCE1} %{buildroot}%{_sysconfdir}/security/limits.d/95-jack.conf

# move doxygen documentation to the right place
mv %{buildroot}%{_datadir}/jack-audio-connection-kit/reference .
rm -rf %{buildroot}%{_datadir}/jack-audio-connection-kit

%pre
%_pre_groupadd realtime

%postun
%_postun_groupdel realtime

%files
%doc README.rst README_NETJACK2
%license COPYING
%dir %{_sysconfdir}/jack
%config(noreplace) %{_sysconfdir}/jack/example.conf
%config(noreplace) %{_sysconfdir}/security/limits.d/95-jack.conf
%{_userunitdir}/jack@.service

%if %{enable_dbus}
%{_bindir}/jackdbus
%{_datadir}/dbus-1/services/org.jackaudio.service
%{_bindir}/jack_control
%if %{enable_classic}
%{_bindir}/jackd
%endif
%else
%{_bindir}/jackd
%endif

%dir %{_libdir}/jack
%{_libdir}/jack/*.so

%{_mandir}/man1/*

%files -n %{lib_name}
%{_libdir}/libjack.so.%{lib_major}{,.*}
%{_libdir}/libjacknet.so.%{lib_major}{,.*}
%{_libdir}/libjackserver.so.%{lib_major}{,.*}

%files -n %{lib_name_devel}
%doc reference/html/
%{_includedir}/jack/
%{_libdir}/lib*.so
%dir %{_libdir}/jack
%{_libdir}/pkgconfig/jack.pc
