#
# git clone https://git.jami.net/savoirfairelinux/jami-daemon.git
# cd jami-daemon
# DATE=$(git log -1 --pretty=format:'%cd' --date=format:'%Y%m%d')
# HASH=$(git log -1 --pretty=format:'%h')
# git config tar.tar.xz.command 'xz -c'
# git archive --format=tar.xz -o ../jami-daemon-${DATE}-${HASH}.tar.xz --prefix=jami-daemon-${DATE}/ master
#

%global gdate	20241001
%global ghash	bb752b886
%define rel	2

%define major	15
%define libname	%mklibname jami %{major}
%define devname	%mklibname jami -d

%bcond_with	system_pj
%bcond_with	system_ffmpeg
%bcond_with	system_dhtnet

%define pjver     8fc165b833eea6e3c88d67a541385424b129fd3f
%define ffmpegver 6.0.1
%define dhtnetver 872e82fb62ab3119f3b6f715e21c0edbeb427891

%bcond_with portaudio
%bcond_with dbus

Name:		jami-daemon
Version:	15.3.0
Release:	%mkrel %{?gdate:0.git%gdate.%ghash.}%{rel}
Summary:	Jami is a software for secure communications with distributed architecture
Group:		System/Libraries
License:	GPLv3+
Url:		https://jami.net/
%if 0%{?gdate:1}
Source0:	jami-daemon-%{gdate}-%{ghash}.tar.xz
%else
Source0:	https://git.jami.net/savoirfairelinux/jami-daemon/archive/%{version}/jami-daemon-%{version}.tar.gz
%endif
Source1:	https://github.com/savoirfairelinux/pjproject/archive/%{pjver}/pjproject-%{pjver}.tar.gz
Source2:	https://ffmpeg.org/releases/ffmpeg-%{ffmpegver}.tar.xz
Source3:	https://review.jami.net/plugins/gitiles/dhtnet/+archive/%{dhtnetver}.tar.gz
# ffmpeg patches
Source100:	0001-avcodec-nvenc-stop-using-long-deprecated-format-spec.patch
Source101:	0001-avcodec-nvenc-support-SDK-12.2-bit-depth-API.patch
Source102:	0001-get_cabac_inline_x86_Do-not-inline-the-assembly-function-on-32-bit.patch

Patch2:		jami-daemon-do-not-force-O3.patch
Patch3:		jami-daemon-ffmpeg.patch
Patch4:		0001-fix-build-for-libgit2-1.8-1.9.patch

BuildRequires:	cmake
BuildRequires:	meson
BuildRequires:	asio-devel
%if %{with system_ffmpeg}
BuildRequires:	ffmpeg-devel
%else
BuildRequires:	yasm
BuildRequires:	pkgconfig(x264)
BuildRequires:	pkgconfig(ffnvcodec)
BuildRequires:	pkgconfig(vdpau)
%endif
BuildRequires:	gsm-devel
BuildRequires:	libnatpmp-devel
#BuildRequires:	restbed-devel
#BuildRequires:	swig
#BuildRequires:	gyp
BuildRequires:	pipewire-devel
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(cppunit)
%if %{with dbus}
BuildRequires:	pkgconfig(dbus-c++-1)
%endif
BuildRequires:	pkgconfig(expat)
BuildRequires:	fmt9-devel
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(libargon2)
BuildRequires:	pkgconfig(libgit2)
BuildRequires:	pkgconfig(libilbc)
%if %{with system_pj}
BuildRequires:	pkgconfig(libpjproject)
%endif
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libsecp256k1)
BuildRequires:	pkgconfig(libudev)
BuildRequires:	pkgconfig(libupnp)
BuildRequires:	pkgconfig(libva)
BuildRequires:	pkgconfig(msgpack-c)
BuildRequires:	msgpack-cxx-devel
BuildRequires:	pkgconfig(nettle)
BuildRequires:	pkgconfig(opendht) >= 2.3.0
BuildRequires:	pkgconfig(opus)
%if %{with portaudio}
BuildRequires:	pkgconfig(portaudio-2.0)
%endif
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(speexdsp)
BuildRequires:	pkgconfig(yaml-cpp)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(webrtc-audio-processing)
Obsoletes:	ring-daemon < 9.6.0
Provides:	ring-daemon = %{version}-%{release}
%if ! %{with system_pj}
Provides:	bundled(pjproject) = 2.12.1
%endif
%if ! %{with system_ffmpeg}
Provides:	bundled(ffmpeg) = %{ffmpegver}
%endif
%if ! %{with system_dhtnet}
Provides:	bundled(dhtnet)
%endif

%description
Jami is a free and open source software, which allows to make encrypted audio
or video calls and to send files and messages around the world. Jami is an
official GNU package, that uses fully distributed architecture and independent
from any centralized service. Additional support for SIP communications is
provided.

#------------------------------------------------

%package -n	%{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n	%{libname}
Shared libraries for %{name}.

#------------------------------------------------

%package -n	%{devname}
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	ring-daemon-devel = %{version}-%{release}
Obsoletes:	%{_lib}ring-devel < 9.6.0

%description -n	%{devname}
The development libraries and header files for %{name}.

#------------------------------------------------

%prep
%autosetup -p1 -n jami-daemon-%{?gdate}%{?!gdate:%version}

%if ! %{with system_pj}
mkdir -p contrib/tarballs/
# for bundled pjproject
cp -a %{SOURCE1} contrib/tarballs/
mkdir -p contrib/native
%endif

%if ! %{with system_ffmpeg}
mkdir -p contrib/tarballs/
# for bundled ffmpeg
cp -a %{SOURCE2} contrib/tarballs/
cp -a %{SOURCE100} %{SOURCE101} %{SOURCE102} contrib/src/ffmpeg/
mkdir -p contrib/native
%endif

%if ! %{with system_dhtnet}
mkdir -p contrib/tarballs/
# for bundled dhtnet
cp -a %{SOURCE3} contrib/tarballs/dhtnet-%{dhtnetver}.tar.gz
mkdir -p contrib/native
%endif

%build
export CXXFLAGS="%{optflags} -std=gnu++17 -fdiagnostics-all-candidates"
%if ! %{with system_pj} || ! %{with system_ffmpeg}
# bundled pjproject and/or ffmpeg
pushd contrib/native
  %set_build_flags
  ../bootstrap \
    --disable-downloads \
    --disable-all \
    %{!?with_system_pj:--enable-pjproject} \
    %{!?with_system_ffmpeg:--enable-ffmpeg} \
    %{!?with_system_dhtnet:--enable-dhtnet} \
    %nil

  %make_build \
    DISABLE_CONTRIB_CHECKSUMS=TRUE \
    %if ! %{with system_pj}
    PJPROJECT_VERSION=%{pjver} \
    DEPS_pjproject= \
    %endif
    %if ! %{with system_ffmpeg}
    FFMPEG_VERSION=%{ffmpegver} \
    DEPS_ffmpeg= \
    %endif
    %if ! %{with system_dhtnet}
    DHTNET_VERSION=%{dhtnetver} \
    DEPS_dhtnet=pjproject \
    %endif
    %nil

%ifnarch %{arm}
  export PKG_CONFIG_PATH=./contrib/%{_host_cpu}-%{_real_vendor}-%{_host_os}/lib/pkgconfig:$PKG_CONFIG_PATH
%else
  export PKG_CONFIG_PATH=./contrib/%{_host_cpu}-%{_real_vendor}-%{_host_os}%{?_gnu}/lib/pkgconfig:$PKG_CONFIG_PATH
%endif
popd
%endif

%meson \
	-Dportaudio=%{?with_portaudio:auto}%{!?with_portaudio:disabled} \
	-Dopensl=disabled \
	-Dinterfaces=library%{?with_dbus:,dbus}

%meson_build

%install
%meson_install

%if ! %{with system_pj}
# drop pjproject from devel reqs
perl -pi -e 's/\s+libpj[^,]*[0-9]*,//g' %{buildroot}%{_libdir}/pkgconfig/jami.pc
%endif

%if ! %{with system_ffmpeg}
# drop ffmpeg from devel reqs
perl -pi -e 's/\s+lib(av|sw)[^,]*[0-9]*,//g' %{buildroot}%{_libdir}/pkgconfig/jami.pc
%endif

%if ! %{with system_dhtnet}
# drop dhtnet from devel reqs
perl -pi -e 's/\s+dhtnet[^,]*[0-9]*,//g' %{buildroot}%{_libdir}/pkgconfig/jami.pc
%endif

%files
%if %{with dbus}
%{_libexecdir}/jamid
%{_mandir}/man?/jamid.?*
%{_datadir}/dbus-1/interfaces/cx.ring.Ring.*.xml
%{_datadir}/dbus-1/services/cx.ring.Ring.service
%endif
%{_datadir}/jami/
%{_metainfodir}/net.jami.daemon.metainfo.xml

%files -n %{libname}
%{_libdir}/libjami.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/jami/
%{_libdir}/libjami.so
%{_libdir}/pkgconfig/jami.pc
