%define _disable_ld_no_undefined 1

Summary:	Java GNOME bindings
Name:		java-gnome
Version:	4.1.3
Release:	%mkrel 13
# This is the "Classpath" exception.
License:	GPLv2 with exceptions
Group:		Development/Java
URL:		https://java-gnome.sourceforge.net/
Source0:	https://download.gnome.org/sources/java-gnome/4.1/java-gnome-%{version}.tar.xz
# Workaround for brp-java-repack-jars skipping top-level dot-files
Patch0:		java-gnome-4.1.3-libdir.patch
# Disable strict java 8 doclint
Patch1:		java-gnome-doclint.patch
# Argument -client not supported everywhere.
Patch2:		java-gnome-4.1.3-javaargs.patch
# Use "javac -h" instead of "javah" for JDK 11 compatibility
Patch3:		java-gnome-4.1.3-javah.patch
# Fix build script for Python 3
Patch4:		java-gnome-4.1.3-py3.patch

# Fix enchant detection on Mageia 
Patch10:	java-gnome-4.1.2-unique3-enchant2.patch
# Fix build with JDK 17
Patch11:	java-gnome-4.1.3-17.patch

BuildRequires:	pkgconfig(atk)
BuildRequires:	pkgconfig(cairo-svg)
BuildRequires:	pkgconfig(enchant-2)
BuildRequires:	pkgconfig(gdk-3.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(gtk+-unix-print-3.0)
BuildRequires:	pkgconfig(gtksourceview-3.0)
BuildRequires:	pkgconfig(gtkspell3-3.0)
BuildRequires:	pkgconfig(libnotify)
BuildRequires:	pkgconfig(pango)
BuildRequires:	pkgconfig(unique-3.0)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	gettext
BuildRequires:	junit
BuildRequires:	python3
BuildRequires:	java-devel >= 0:1.6.0
BuildRequires:	jpackage-utils
Requires:	java >= 0:1.6.0
Requires:	jpackage-utils

%description
These are the Java bindings for GTK and GNOME! Featuring a robust 
engineering design, completely generated internals, a lovingly 
crafted layer presenting the public API, and steadily increasing 
coverage of the underlying libraries.

You can use java-gnome to develop sophisticated user interfaces 
for Linux applications so that they richly integrate with the 
GNOME Desktop while leveraging the power of the Java language 
and your expertise with it.

%package	javadoc
Summary:	Javadoc for %{name}
Group:		Development/Java
Requires:	%{name} >= %{version}-%{release}
Requires:	jpackage-utils
BuildArch:	noarch

%description	javadoc
This package contains the API documentation for %{name}, along with
design documentation and sample code.

%prep
%autosetup -p1

# Remove all binaries
find . -name "*.jar" -exec rm -f {} \;
find . -name "*.class" -exec rm -f {} \;

# JDK 11 does not generate pointless empty headers for classes with no native methods
# so we have to fool the java-gnome build
mkdir -p tmp/include
for c in atk_AtkRegistry atk_AtkUtil glib_GBoxed gdk_GdkWindowAttr gdk_GdkPixbufSimpleAnimIter gtk_GtkPlug gtk_GtkFilePath sourceview_GtkSourceViewSearchFlags \
pango_PangoAnalysis pango_PangoEngine pango_PangoEngineShape pango_PangoEngineLang pango_PangoGlyphGeometry pango_PangoGlyphInfo pango_PangoCairoFcFont pango_PangoFcFont ; do
	touch tmp/include/org_gnome_${c}.h
done

%build
# It'll get two conflicting --libdir parameters, but the last one
# happens to win which is what we want.
%configure --jardir=%{_libdir}/%{name} --libdir=%{_libdir}/%{name}

# The build system does not support parallell builds, so no
# _smp_mflags.
make V=1 build-java doc

%install
mkdir -p %{buildroot}%{_javadir}
make install DESTDIR=%{buildroot}

# Install javadoc
mkdir -p %{buildroot}%{_javadocdir}
cp -rp doc/api %{buildroot}%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%files
%doc
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.jar
%{_libdir}/%{name}/*.so

%files javadoc
# Note that not all here is javadoc. Two subpackages for documentation
# seems silly.
%doc doc/design doc/examples
%{_javadocdir}/%{name}
%{_javadocdir}/%{name}-%{version}

