Name:           jbuilder
Version:        1.0.1
Release:        %mkrel 4
Summary:        A composable build system for OCaml
Group:          Development/OCaml

%global libname %(echo %{name} | sed -e 's/^ocaml-//')

License:        ASL 2.0
URL:            https://github.com/janestreet/jbuilder/
Source0:        https://github.com/janestreet/%{libname}/archive/%{version}/%{libname}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.02.3
BuildRequires:  ocaml-findlib-devel

# Depend on /usr/bin/sphinx-build for python version invariance.
BuildRequires:  python3-sphinx

# Required by tests.
# The migrate-parsetree dependency could... be a problem since that requires
# jbuilder to build.
BuildRequires:  git-core
BuildRequires:  ocaml-menhir
BuildRequires:  ocaml-ocaml-migrate-parsetree-devel
BuildRequires:  ocaml-result-devel

# Jbuilder has vendored deps (ugh):
# I'm not clear on how to unbundle them.
# It seems to be unsupported upstream; the bootstrap process for jbuilder
# doesn't seem to be able to detect libraries installed systemwide.
# https://github.com/janestreet/jbuilder/issues/220
Provides:      bundled(ocaml-opam-file-format)
Provides:      bundled(ocaml-cmdliner) = 1.0.0
Provides:      bundled(ocaml-re)

%description
Jbuilder is a build system designed for OCaml/Reason projects only. It focuses
on providing the user with a consistent experience and takes care of most of
the low-level details of OCaml compilation. All you have to do is provide a
description of your project and Jbuilder will do the rest.

The scheme it implements is inspired from the one used inside Jane Street and
adapted to the open source world. It has matured over a long time and is used
daily by hundred of developers, which means that it is highly tested and
productive.

%package        doc
Summary:        HTML documentation for %{name}
Requires:       %{name} >= %{version}-%{release}

BuildArch:      noarch

%description    doc
HTML documentation for jbuilder, a composable build system for OCaml.

%prep
# Eep. Upstream is (slowly) renaming jbuilder -> dune. This has already
# affected the tarball here.
%autosetup -n dune-%{version} -p1

# Remove blackbox tests. This is necessary pending a fix to:
# https://github.com/ocaml/dune/issues/593
#rm -rf test/blackbox-tests
#rm -f example/jbuild

%build
# The jbuilder build script figures out if the native code compiler is available
# and uses it if it is, otherwise it uses the bytecode compiler. Thus I think
# we just need to "make" here.
%make_build release
%make_build doc

%install
# jbuilder's makefile has a "make install" target. Tragically, it uses opam-install(er)
# to install itself. Even more tragically, opam now requires jbuilder to build.
# Therefore as a workaround we can just manually install things ourselves--
# jbuilder is *mostly* just a binary, making this easy.
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_libdir}/ocaml/jbuilder/
mkdir -p %{buildroot}%{_mandir}/man1

# The files to install are stored in _build as symlinks; dereference them.
cp -aL _build/install/default/bin/jbuilder %{buildroot}%{_bindir}/
cp -aL _build/install/default/bin/dune %{buildroot}%{_bindir}/
cp -aL _build/install/default/lib/dune/* %{buildroot}%{_libdir}/ocaml/jbuilder/
cp -aL _build/install/default/man/man1/* %{buildroot}%{_mandir}/man1

# Install documentation by way of pkgdocdir.
mkdir -p %{buildroot}%{_pkgdocdir}/
cp -ar README.md CHANGES.md doc/_build/* %{buildroot}%{_pkgdocdir}/

# Run the unit tests. runtest-no-deps.
%check
# Ugh. Why is this necessary?
# Because the tests do things with git and complain if these things aren't set...
git config --global user.name "Your Name"
git config --global user.email you@example.com

# Also, need to fix something in one of the results files...?
# This is incredibly fragile, but I really don't want to write a patch.
# Okay, so this fix only works on 64-bit arches. I... am not sure why.
%ifnarch %{ix86} armv7hl
sed "s,\$LIB_PREFIX/lib,%{_libdir}/ocaml,g" -i test/blackbox-tests/test-cases/merlin-tests/run.t
sed "s,%{_libdir}/ocaml/bytes,%{_libdir}/ocaml,g" -i test/blackbox-tests/test-cases/merlin-tests/run.t
sed "s,%{_libdir}/ocaml/findlib,%{_libdir}/ocaml/bytes,g" -i test/blackbox-tests/test-cases/merlin-tests/run.t
sed "s,%{_libdir}/ocaml/ocaml,%{_libdir}/ocaml/findlib,g" -i test/blackbox-tests/test-cases/merlin-tests/run.t
%else
sed "s,\$LIB_PREFIX/lib/ocaml,\$LIB_PREFIX/lib/ocaml/findlib,g" -i test/blackbox-tests/test-cases/merlin-tests/run.t
sed "s,\$LIB_PREFIX/lib/findlib,\$LIB_PREFIX/lib/ocaml/bytes,g" -i test/blackbox-tests/test-cases/merlin-tests/run.t
sed "s,\$LIB_PREFIX/lib/bytes,\$LIB_PREFIX/lib/ocaml,g" -i test/blackbox-tests/test-cases/merlin-tests/run.t
%endif

./_build/default/bin/main_dune.exe build @runtest-no-deps

%files
%license LICENSE.md
%doc %{_pkgdocdir}/README.md
%doc %{_pkgdocdir}/CHANGES.md
%{_libdir}/ocaml/%{libname}
%{_bindir}/jbuilder
%{_bindir}/dune
%{_mandir}/man1/dune.1*
%{_mandir}/man1/dune-build.1*
%{_mandir}/man1/dune-clean.1*
%{_mandir}/man1/dune-exec.1*
%{_mandir}/man1/dune-external-lib-deps.1*
%{_mandir}/man1/dune-help.1*
%{_mandir}/man1/dune-install.1*
%{_mandir}/man1/dune-installed-libraries.1*
%{_mandir}/man1/dune-printenv.1*
%{_mandir}/man1/dune-promote.1*
%{_mandir}/man1/dune-rules.1*
%{_mandir}/man1/dune-runtest.1*
%{_mandir}/man1/dune-subst.1*
%{_mandir}/man1/dune-uninstall.1*
%{_mandir}/man1/dune-utop.1*

%files doc
%exclude %{_pkgdocdir}/README.md
%exclude %{_pkgdocdir}/CHANGES.md
%doc %{_pkgdocdir}/*
