Name:           jinput
Version:        2.0.9
Release:        %mkrel 2
Summary:        Java Game Controller API

Group:          Development/Java
License:        BSD
URL:            https://github.com/jinput/jinput
Source0:        https://github.com/jinput/jinput/archive/%{version}/%{name}-%{version}.tar.gz
# Fedora-specific patch: will not be sent upstream.  Remove dependencies on
# Windows and OSX code, and fix build issues with the AWT plugin.
Patch0:         001_jinput_build.patch
# Fedora-specific patch: will not be sent upstream.  Do not strip the native
# library.
Patch1:         002_jinput_dontstripso.patch
# Fedora-specific patch: will not be sent upstream.  Load the shared library
# from the Fedora-mandated location.
Patch2:         003_jinput_usesystemload.patch
# Patch from https://java.net/jira/browse/JINPUT-51 to fix a resource leak
Patch4:         005_jinput_leak.patch

BuildRequires:  gcc
BuildRequires:  java-javadoc >= 1:1.6.0
BuildRequires:  jutils-javadoc
BuildRequires:  maven-local
BuildRequires:  mvn(net.java.jutils:jutils)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)

%description
jinput is an implementation of an API for game controller discovery and
polled input.  It is part of a suite of open-source technologies
initiated by the Game Technology Group at Sun Microsystems with the
intention of making the development of high performance games in Java a
reality.  The API itself is pure Java and presents a platform-neutral,
completely portable model of controller discovery and polling.  It can
handle arbitrary controllers and returns both human and machine
understandable descriptions of the inputs available.

%package javadoc
Summary:        Javadocs for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       jutils-javadoc
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%autosetup -p0

# Use Fedora's CFLAGS and LDFLAGS
sed -i "s|-O2 -Wall|$RPM_OPT_FLAGS|;s|-shared|& $RPM_LD_FLAGS|" \
    plugins/linux/build.xml

# Remove unnecessary maven plugins
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_remove_plugin -r :maven-nativedependencies-plugin

# The examples have a jar (rather than pom) dependency on the main project
%pom_xpath_remove pom:project/pom:dependencies/pom:dependency/pom:type \
  examples/pom.xml

# The native plugin is included
%mvn_package net.java.jinput:linux-plugin::natives-linux:%{version}-SNAPSHOT

%build
# Get the latest definitions from <linux/input-event-codes.h>
gawk -f plugins/linux/src/main/native/getDefinitions \
  %{_includedir}/linux/input.h \
  %{_includedir}/linux/input-event-codes.h \
  > plugins/linux/src/main/java/net/java/games/input/NativeDefinitions.java

# Build
%mvn_build

%install
%mvn_install

# jni
install -Dp -m 755 plugins/linux/target/natives/libjinput*.so \
    %{buildroot}%{_libdir}/%{name}/libjinput.so
ln -s ../../..%{_jnidir}/%{name}/%{name}.jar %{buildroot}%{_libdir}/%{name}/

%files -f .mfiles
%doc README.md
%{_libdir}/%{name}/

%files javadoc -f .mfiles-javadoc

