%global __provides_exclude_from	^(%{_libdir}/%{name}/native/.*\\.so|%{_javadir}/%{name}/.*)$

%define buildversion	5550

Name:		jitsi
Version:	2.10.%{buildversion}
Release:	%mkrel 11
Summary:	Open Source Video Calls And Chat
Group:		Networking/Instant messaging
License:	LGPLv2+
URL:		https://jitsi.org/
Source0:	https://download.jitsi.org/jitsi/src/%{name}-src-%{version}.zip
#Source0:	https://download.jitsi.org/jitsi/nightly/src/%%{name}-src-%%{version}.zip
Patch0:		jitsi-2.9-mga-fix_bin_file_path.patch
Patch1:		jitsi-2.9-mga-fix_man_file_package-name.patch
Patch2:		jitsi-2.9-mga-fix_desktop_file_package-name.patch
Patch3:		jitsi-2.10-harfbuzz-header-path.patch
Patch4:		jitsi-2.9-mga-fix_javabin_path.patch

# Upstream
Patch50:	0001-Fix-build-for-as-needed.patch
Patch51:	0001-Silence-warning-about-unused-parameters.patch

# Apply after upstream patches
Patch100:	jitsi-2.9-build-native-modules.patch


BuildRequires:	ant
BuildRequires:	desktop-file-utils
BuildRequires:	git-core
BuildRequires:	gzip
BuildRequires:	java-1.8.0-devel >= 1.8.0

BuildRequires:	x11-proto-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xtst)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(xscrnsaver)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(alsa)

Requires:	java-1.8.0-openjdk


%description
Jitsi is an audio/video Internet phone and instant messenger that
supports some of the most popular instant messaging and telephony protocols
such as SIP, Jabber/XMPP (and hence Facebook and Google Talk), AIM/ICQ,
Yahoo! Messenger, RSS and counting.
Jitsi is completely Open Source / Free Software, and is freely available
under the terms of the GNU Lesser General Public License.


%prep
%setup -q -n %{name}
%autopatch -p1

# precompiled code
find . -name "*.so" -delete

%build
export JAVA_HOME=%{_jvmdir}/java-1.8.0-openjdk
%ant -Dlabel=%{buildversion} rebuild

pushd src/native
for i in clean-native init-native galagonotification globalshortcut-linux hid hwaddressretriever sysactivity; do
  %ant -Dsystem.JAVA_HOME=%{_jvmdir}/java-1.8.0-openjdk $i
done

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/pixmaps
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
mkdir -p %{buildroot}%{_javadir}/%{name}/lib/bundle
mkdir -p %{buildroot}%{_javadir}/%{name}/sc-bundles
mkdir -p %{buildroot}%{_libdir}/%{name}/native

# copy the documentation
cp -pr resources/install/debian/jitsi.1.tmpl %{buildroot}%{_mandir}/man1/%{name}.1
gzip %{buildroot}%{_mandir}/man1/%{name}.1

# copy the launcher script
install -m 755 resources/install/debian/jitsi.sh.tmpl %{buildroot}%{_bindir}/%{name}

# copy the menu icons
cp -pr resources/install/debian/jitsi-32.xpm %{buildroot}%{_datadir}/pixmaps/%{name}-32.xpm
cp -pr resources/install/debian/jitsi-16.xpm %{buildroot}%{_datadir}/pixmaps/%{name}-16.xpm
cp -pr resources/install/debian/jitsi.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

# copy the menu entry
cp -pr resources/install/debian/jitsi.desktop.tmpl %{buildroot}%{_datadir}/applications/%{name}.desktop

desktop-file-install \
	--dir %{buildroot}%{_datadir}/applications \
	--set-icon=%{name} \
	%{buildroot}%{_datadir}/applications/%{name}.desktop

# copy the sc-bundles
cp -pr sc-bundles/*.jar %{buildroot}%{_javadir}/%{name}/sc-bundles/
# remove all slicks
rm -rf %{buildroot}%{_javadir}/%{name}/sc-bundles/*-slick.jar
rm -rf %{buildroot}%{_javadir}/%{name}/sc-bundles/slick*.jar

# copy the os-specific sc-bundles
cp -pr sc-bundles/os-specific/linux/*.jar %{buildroot}%{_javadir}/%{name}/sc-bundles/

# copy the lib jars
cp -pr lib/*.jar %{buildroot}%{_javadir}/%{name}/lib/
cp -pr lib/bundle/* %{buildroot}%{_javadir}/%{name}/lib/bundle/
rm -rf %{buildroot}%{_javadir}/%{name}/lib/bundle/junit.jar

# copy the native libs
%ifarch i386 i586 i686 armv5tl armv7hl
cp -pr lib/native/linux/* %{buildroot}%{_libdir}/%{name}/native/
%else
cp -pr lib/native/linux-64/* %{buildroot}%{_libdir}/%{name}/native/
%endif

# copy the resources
cp -pr resources/install/logging.properties %{buildroot}%{_libdir}/%{name}/
cp -pr lib/felix.client.run.properties %{buildroot}%{_libdir}/%{name}/
cp -pr lib/jitsi-defaults.properties %{buildroot}%{_libdir}/%{name}/
cp -pr resources/install/resources/splash.gif %{buildroot}%{_javadir}/%{name}/

if [ -f lib/jitsi-default-overrides.properties ]
	then
	cp -pr lib/jitsi-default-overrides.properties %{buildroot}%{_libdir}/%{name}/
fi

%files
%doc LICENSE README.md
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_javadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}*
%{_iconsdir}/hicolor/*/*/%{name}.svg
%{_mandir}/man1/%{name}.1*
