# Native CPU names
%ifarch %{ix86}
%global nativearch x86
%else
%ifarch %{arm64}
%global nativearch arm64
%else
%global nativearch %{_arch}
%endif
%endif

# The only ELF object is hidden inside the native JAR, so turn off debuginfo
%global debug_package %{nil}

# There is a circular dependency with picocli, but this package needs
# picocli-codegen only to run tests.  Disable the tests in a bootstrap scenario.
%bcond_with bootstrap

Name:           jline
Version:        3.23.0
Release:        %mkrel 3
Group:          Development/Java
Summary:        Java library for handling console input
License:        BSD-3-Clause
URL:            https://github.com/jline/jline3
#ExclusiveArch:  %%{java_arches}

Source0:        %{url}/archive/jline-parent-%{version}.tar.gz

# Add support for ppc64le and s390x
Patch0:         %{name}-native-arches.patch
# Removed -Werror tag
Patch1:         %{name}-ignore-warnings.patch

BuildRequires:  gcc
BuildRequires:  maven-local
BuildRequires:  mvn(com.googlecode.juniversalchardet:juniversalchardet)
BuildRequires:  mvn(net.java.dev.jna:jna)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-enforcer-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.apache.sshd:sshd-core) >= 2.6.0
BuildRequires:  mvn(org.apache.sshd:sshd-scp) >= 2.6.0
BuildRequires:  mvn(org.apache.sshd:sshd-sftp) >= 2.6.0
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.easymock:easymock)
BuildRequires:  mvn(org.fusesource.jansi:jansi)

%if %{without bootstrap}
# Test dependencies
BuildRequires:  mvn(info.picocli:picocli-codegen)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apiguardian:apiguardian-api)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-params)
%endif

%global _desc %{expand:
JLine is a Java library for handling console input.  It is similar in
functionality to BSD editline and GNU readline but with additional
features that bring it in par with the ZSH line editor.  Those familiar
with the readline/editline capabilities for modern shells (such as bash
and tcsh) will find most of the command editing features of JLine to be
familiar.}

%description %_desc

%javadoc_package

%package        parent
Summary:        Parent POM for Java library for handling console input
BuildArch:      noarch

# This can be removed when F42 reaches EOL
Obsoletes:      jline < 3.23.0-1
Provides:       jline = %{version}-%{release}

%description    parent %_desc

This package contains the parent POM for the jline project

%package        native
Summary:        JLine native library

%description    native %_desc

This package contains a native library for JLine.

%package        terminal
Summary:        JLine terminal
BuildArch:      noarch
Requires:       %{name}-native = %{version}-%{release}

%description    terminal %_desc

This package contains the basic terminal support for JLine.

%package        terminal-jansi
Summary:        JLine terminal with JANSI
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    terminal-jansi %_desc

This package contains a functioning terminal based on JANSI.

%package        terminal-jna
Summary:        JLine terminal with JNA
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    terminal-jna %_desc

This package contains a functioning terminal based on JNA.

%package        reader
Summary:        JLine reader
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    reader %_desc

This package supports reading lines from a console with customizable key
bindings and input editing.

%package        style
Summary:        JLine style processor
BuildArch:      noarch
Requires:       %{name}-terminal = %{version}-%{release}

%description    style %_desc

This package contains a style processor for JLine, which can apply
colors to strings, for example.

%package        builtins
Summary:        JLine builtins
BuildArch:      noarch
Requires:       %{name}-reader = %{version}-%{release}
Requires:       %{name}-style = %{version}-%{release}
Recommends:     mvn(com.googlecode.juniversalchardet:juniversalchardet)

%description    builtins %_desc

This package contains keybindings to emulate popular tools such as nano
and less.

%package        console
Summary:        JLine console
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Requires:       %{name}-style = %{version}-%{release}

%description    console %_desc

This package contains a console with command and script execution
support, and tab completion.

%package        remote-ssh
Summary:        JLine remote SSH
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Recommends:     mvn(org.apache.sshd:sshd-core) >= 2.6.0
Recommends:     mvn(org.apache.sshd:sshd-scp) >= 2.6.0
Recommends:     mvn(org.apache.sshd:sshd-sftp) >= 2.6.0

%description    remote-ssh %_desc

This package contains an ssh client.

%package        remote-telnet
Summary:        JLine remote telnet
BuildArch:      noarch
Requires:       %{name}-builtins = %{version}-%{release}
Recommends:     mvn(org.apache.sshd:sshd-core) >= 2.6.0

%description    remote-telnet %_desc

This package contains a telnet client.

%prep
%autosetup -n jline3-jline-parent-%{version} -p1

# remove unnecessary dependency on parent POM
%pom_remove_parent

# We don't need the bundle
%pom_disable_module jline

# Missing dependencies in Fedora
%pom_disable_module demo
%pom_disable_module groovy
%pom_disable_module graal
%pom_remove_plugin :gmavenplus-plugin
%pom_remove_dep :graal-sdk

# Unnecessary plugins for an rpm build
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-release-plugin
%pom_remove_plugin :native-image-maven-plugin
%pom_remove_plugin :spotless-maven-plugin

%if %{with bootstrap}
# In a bootstrap situation, do not try to run picocli-codegen
%pom_remove_plugin :exec-maven-plugin native
%endif

# junit-jupiter needs apiguardian-api but doesn't depend on it
%pom_add_dep org.apiguardian:apiguardian-api:1.1.2:test native

# Bump the JNI version up to the minimum supported by Fedora
sed -i 's/\(JNI_VERSION_1_\)2/\18/' native/src/main/native/jlinenative.c

# Remove prebuilt native objects
rm -fr native/src/main/resources/org/jline/nativ/{FreeBSD,Mac,Windows}
rm -fr native/src/main/resources/org/jline/nativ/Linux/*

%build
# Build a native object
mkdir native/src/main/resources/org/jline/nativ/Linux/%{nativearch}
cd native/src/main/native
gcc %{build_cflags} -fPIC -fvisibility=hidden -shared -I. \
  -I %{_jvmdir}/java/include -I %{_jvmdir}/java/include/linux %{build_ldflags} \
  -o ../resources/org/jline/nativ/Linux/%{nativearch}/libjlinenative.so \
  jlinenative.c
cd -

# Build the Java artifacts
%if %{with bootstrap}
%mvn_build -f -s
%else
%mvn_build -s
%endif

%install
%mvn_install

%files parent -f .mfiles-jline-parent
%doc changelog.md README.md
%license LICENSE.txt

%files native -f .mfiles-jline-native
%doc changelog.md README.md
%license LICENSE.txt

%files terminal -f .mfiles-jline-terminal

%files terminal-jansi -f .mfiles-jline-terminal-jansi

%files terminal-jna -f .mfiles-jline-terminal-jna

%files reader -f .mfiles-jline-reader

%files style -f .mfiles-jline-style

%files builtins -f .mfiles-jline-builtins

%files console -f .mfiles-jline-console

%files remote-ssh -f .mfiles-jline-remote-ssh

%files remote-telnet -f .mfiles-jline-remote-telnet


