%define major 2.57

Name:           keepass
Version:        2.57
Release:        %mkrel 1
License:        GPLv2+
Summary:        Password Manager
Group:          File tools
Url:            https://keepass.info/
Source:         https://downloads.sourceforge.net/keepass/KeePass-%{version}-Source.zip
Source1:        https://downloads.sourceforge.net/keepass/KeePass-%{major}-French.zip
Source2:        https://downloads.sourceforge.net/keepass/KeePass-%{major}-German.zip
Source3:        https://downloads.sourceforge.net/keepass/KeePass-%{major}-Russian.zip
# Upstream does not include a .desktop file, etc..
Patch0:         keepass-desktop-integration.patch
Patch3:         keepass-appdata.patch
# Move XSL files to /usr/share/keepass:
Patch1:         keepass-fix-XSL-search-path.patch
# Locate locally-installed help files:
Patch2:         keepass-enable-local-help.patch
Requires:       mono-winforms
Requires:       xdotool
Requires:       xsel
BuildRequires:  pkgconfig(libgdiplus)
BuildRequires:  imagemagick
BuildRequires:  x11-server-xvfb
BuildRequires:  mono-web
BuildRequires:  mono-devel
BuildRequires:  mono-winforms
ExclusiveArch:  %{mono_arches}
BuildArch:      noarch

%description
KeePass is a free open source password manager, which helps you to manage your
passwords in a secure way. You can put all your passwords in one database,
which is locked with one master key or a key file. So you only have to remember
one single master password or select the key file to unlock the whole database.
The databases are encrypted using the best and most secure encryption
algorithms currently known (AES and Twofish).

%prep
%autosetup -p1 -c

unzip %{SOURCE1}
unzip %{SOURCE2}
unzip %{SOURCE3}

# Work around libpng bug (https://bugzilla.redhat.com/show_bug.cgi?id=1276843):
find -name \*.png -print0 | xargs -0 mogrify -define png:format=png32


%build
( cd Build && sh PrepMonoDev.sh )
find . -name "*.sln" -print -exec sed -i 's/Format Version 10.00/Format Version 11.00/g' {} \;
xbuild /target:KeePass /property:TargetFrameworkVersion=v$(ls -d /usr/lib/mono/*-api | cut -d/ -f5 | cut -d- -f1 | sort -Vr | head -1) /property:Configuration=Release
for subdir in Images_App_HighRes Images_Client_16 Images_Client_HighRes; do
    xvfb-run -a mono Build/KeePass/Release/KeePass.exe -d:`pwd`/Ext/$subdir --makexspfile `pwd`/KeePass/Resources/Data/$subdir.bin
done
xbuild /target:KeePass /property:TargetFrameworkVersion=v$(ls -d /usr/lib/mono/*-api | cut -d/ -f5 | cut -d- -f1 | sort -Vr | head -1) /property:Configuration=Release

%install
install -d \
    %{buildroot}%{_prefix}/lib/%{name} \
    %{buildroot}%{_datadir}/%{name} \
    %{buildroot}%{_datadir}/%{name}/XSL \
    %{buildroot}%{_datadir}/applications \
    %{buildroot}%{_bindir} \
    %{buildroot}%{_datadir}/mime/packages \
    %{buildroot}%{_datadir}/icons/hicolor/512x512/apps \
    %{buildroot}%{_datadir}/icons/hicolor/256x256/apps \
    %{buildroot}%{_datadir}/icons/hicolor/128x128/apps \
    %{buildroot}%{_datadir}/icons/hicolor/64x64/apps \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps \
    %{buildroot}%{_datadir}/icons/hicolor/32x32/apps \
    %{buildroot}%{_datadir}/icons/hicolor/16x16/apps \
    %{buildroot}%{_mandir}/man1 \
    %{buildroot}%{_docdir}/%{name} \
    %{buildroot}%{_datadir}/appdata
install -p -m 0644 \
    Build/KeePass/Release/KeePass.exe \
    Ext/KeePass.config.xml \
    Ext/KeePass.exe.config \
    %{buildroot}%{_prefix}/lib/%{name}
install -p -m 0644 \
    Ext/XSL/KDBX_Common.xsl Ext/XSL/KDBX_DetailsFull_HTML.xsl \
    Ext/XSL/KDBX_DetailsLight_HTML.xsl Ext/XSL/KDBX_PasswordsOnly_TXT.xsl \
    Ext/XSL/KDBX_Tabular_HTML.xsl \
    %{buildroot}%{_datadir}/%{name}/XSL
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_512.png \
    %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_256.png \
    %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_128.png \
    %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_64.png \
    %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_48.png \
    %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_32.png \
    %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_16.png \
    %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
desktop-file-install --dir=%{buildroot}%{_datadir}/applications dist/%{name}.desktop
install -p -m 0644 dist/%{name}.xml %{buildroot}%{_datadir}/mime/packages
install -p -m 0644 dist/%{name}.1 %{buildroot}%{_mandir}/man1
install -p -m 0644 dist/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata
install -p dist/%{name} %{buildroot}%{_bindir}

sed 's/\r$//' Docs/History.txt > %{buildroot}%{_docdir}/%{name}/History.txt
sed 's/\r$//' Docs/License.txt > %{buildroot}%{_docdir}/%{name}/License.txt

# translations
install -d -m 755 %{buildroot}%{_prefix}/lib/keepass/plugins
install -d -m 755 %{buildroot}%{_prefix}/lib/keepass/Languages
install -m 644 French.lngx  %{buildroot}%{_prefix}/lib/keepass/Languages
install -m 644 German.lngx  %{buildroot}%{_prefix}/lib/keepass/Languages
install -m 644 Russian.lngx  %{buildroot}%{_prefix}/lib/keepass/Languages

%files
%{_docdir}/%{name}
%{_bindir}/%{name}
%{_prefix}/lib/%{name}
%{_datadir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*
