#
# This rpm is based on the git tree from:
# git://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git
# version is date of the youngest commit
#
# (tmb) rpm build mis-detects firmwares as arch specific
%define _binaries_in_noarch_packages_terminate_build	0
# (tmb) dont try to strip firmware files
%define __strip /bin/true

Summary:	Non-free firmware files for the Linux kernel
Name:   	kernel-firmware-nonfree
Version:	20250109
Release:	%mkrel 1
License:	Freeware
Group:  	System/Kernel and hardware
URL:    	https://www.kernel.org/
# kernel-firmware tarball is generated from the git tree mentioned
# above, by simply cloning it and doing:
#
#   git archive --prefix=linux-firmware-20231111/ origin/main | xz -T0 -9e -v > linux-firmware-2023031111.tar.xz
#
# Then use gen-free-firmware-tarball.sh script in kernel-firmware to split firmware tarball
# into free and nonfree.
#
Source0:	linux-firmware-nonfree-%{version}.tar.xz
Source1:	https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/snapshot/linux-firmware-%{version}.tar.gz
Conflicts:	kernel-firmware < 20130624-1
Conflicts:	iwlwifi-agn-ucode < 20180211-1
Conflicts:	iwlwifi-firmware < 20201118-1
%rename		kernel-firmware-extra
Recommends:	iwlwifi-firmware
Recommends:	radeon-firmware
Recommends:	ralink-firmware
Recommends:	rtlwifi-firmware
Obsoletes:	korg1212-firmware
Obsoletes:	maestro3-firmware
Obsoletes:	sb16-firmware
Obsoletes:	yamaha-firmware
BuildRequires:	python-pre-commit
BuildRequires:	rdfind
BuildArch:	noarch

%description
This package contains all the firmware files without an open source
license but used by the in-kernel drivers.

The files are shared by all kernels.

Other non-free firmware files are contained in the radeon-firmware,
iwlwifi-firmware, ralink-firmware and rtlwifi-firmware packages.

Open source firmware files are contained in the kernel-firmware
package in the core section.

%package -n iwlwifi-firmware
Summary:	Nonfree iwlwifi firmware files for the Linux kernel
%rename		iwlwifi-agn-ucode
Obsoletes:	iwlwifi-100-ucode
Obsoletes:	iwlwifi-105-ucode
Obsoletes:	iwlwifi-135-ucode
Obsoletes:	iwlwifi-1000-ucode
Obsoletes:	iwlwifi-2000-ucode
Obsoletes:	iwlwifi-2030-ucode
Obsoletes:	iwlwifi-5000-ucode
Obsoletes:	iwlwifi-5150-ucode
Obsoletes:	iwlwifi-6000-ucode
Obsoletes:	iwlwifi-6005-ucode
Obsoletes:	iwlwifi-6030-ucode
Obsoletes:	iwlwifi-6050-ucode
Conflicts:      kernel-firmware-extra < 20130624-1
Conflicts:      kernel-firmware-nonfree < 20201118-1

%description -n iwlwifi-firmware
This package contains all the iwlwifi wireless firmware files
including the matching bluethooth firmwares.

%package -n ralink-firmware
Summary:	Nonfree Ralink firmware files for the Linux kernel
Obsoletes:      rt61-firmware
Obsoletes:      rt2860-firmware
Obsoletes:      rt2870-firmware
Obsoletes:      rt3090-firmware
Obsoletes:      rt73-firmware
Conflicts:      kernel-firmware-extra < 20130624-1
Conflicts:      kernel-firmware-nonfree < 20130624-1

%description -n ralink-firmware
This package contains all the Ralink wireless firmware files.

%package -n rtlwifi-firmware
Summary:	Nonfree rtlwifi firmware files for the Linux kernel
Obsoletes:	rtl8192se-firmware
Conflicts:      kernel-firmware-extra < 20130624-1
Conflicts:      kernel-firmware-nonfree < 20191220-1

%description -n rtlwifi-firmware
This package contains all the rtlwifi wireless firmware files.

%prep
%setup -q -n linux-firmware-nonfree-%{version}

# drop obsolete bnx2 firmwares
rm -f bnx2/bnx2-mips-06-{4,5}.*.fw
rm -f bnx2/bnx2-mips-06-6.0.15.fw
rm -f bnx2/bnx2-mips-06-6.2.1.fw
rm -f bnx2/bnx2-mips-09-{4,5}.*.fw
rm -f bnx2/bnx2-mips-09-6.0.17.fw
rm -f bnx2/bnx2-mips-09-6.2.1.fw
rm -f bnx2/bnx2-mips-09-6.2.1a.fw
rm -f bnx2/bnx2-rv2p-06-{4,5}.*.fw
rm -f bnx2/bnx2-rv2p-06-5.0.0.j3.fw
rm -f bnx2/bnx2-rv2p-09-{4,5}.*.fw
rm -f bnx2/bnx2-rv2p-09ax-5.*.fw

# drop obsolete bnx2x firmwares
rm -f bnx2x-e1-{4,5}.*
rm -f bnx2x-e1h-{4,5}.*
rm -f bnx2x/bnx2x-e1-6*
rm -f bnx2x/bnx2x-e1-7.{0,2,8}.*
rm -f bnx2x/bnx2x-e1h-6*
rm -f bnx2x/bnx2x-e1h-7.{0,2,8}.*
rm -f bnx2x/bnx2x-e2-6*
rm -f bnx2x/bnx2x-e2-7.{0,2,8}.*

# remove files provided in legacy iwlwifi-3945/4965-ucode packages
rm -f iwlwifi-{3945,4965}-2.ucode
# obsolete iwl ucode
rm -f iwlwifi-1000-3.ucode
rm -f iwlwifi-3160-{7,8,9}.ucode
rm -f iwlwifi-5000-{1,2}.ucode
rm -f iwlwifi-6000g2b-5.ucode
rm -f iwlwifi-6050-4.ucode
rm -f iwlwifi-7260-{7,8,9}.ucode
rm -f iwlwifi-7265-{8,9}.ucode

# remove all radeon and amdgpu files as they are provided by radeon-firmware or kernel-firmware
rm -f LICENSE.radeon LICENSE.amdgpu 
rm -rf radeon
rm -rf r128
rm -rf amdgpu

# remove obsolete ti-connectivity firmwares
rm -f ti-connectivity/wl127x-fw-{3,4}*.bin
rm -f ti-connectivity/wl128x-fw-{3,4}*.bin

# remove unwanted source files for firmware in kernel-firmware or microcode
rm -rf atusb usbdux dsp56k keyspan_pda cis isci amd amd-ucode LICENSE.amd-ucode LICENSE.amd-sev configure check_whence.py*
#
rm -rf av7110
rm -f carl9170-1.fw usbduxfast_firmware.bin usbdux_firmware.bin usbduxsigma_firmware.bin

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

# remove empty files and directories to fix conflicts with kernel-firmware
find %{buildroot}/lib/firmware/ -type f -empty -print -delete
find %{buildroot}/lib/firmware/ -type d -empty -print -delete

# pre* scripts
%pretrans -p <lua>
-- moved data and changed from dir to symlink in 20220913 snapshot
-- work around missing recursive removal support by removing the
-- files before the dir
path = "/lib/firmware/qcom/LENOVO/21BX"
st = posix.stat(path)
if st and st.type == "directory" then
  os.remove("/lib/firmware/qcom/LENOVO/21BX/adspr.jsn")
  os.remove("/lib/firmware/qcom/LENOVO/21BX/adspua.jsn")
  os.remove("/lib/firmware/qcom/LENOVO/21BX/battmgr.jsn")
  os.remove("/lib/firmware/qcom/LENOVO/21BX/cdspr.jsn")
  os.remove("/lib/firmware/qcom/LENOVO/21BX/qcadsp8280.mbn")
  os.remove("/lib/firmware/qcom/LENOVO/21BX/qccdsp8280.mbn")
  os.remove("/lib/firmware/qcom/LENOVO/21BX/qcdxkmsuc8280.mbn")
  os.remove("/lib/firmware/qcom/LENOVO/21BX/qcslpi8280.mbn")
  os.remove(path)
end

%files
%defattr(0644,root,root,0755)
%license LICENCE.* LICENSE.*
%doc README.md WHENCE
%exclude /lib/firmware/iwlwifi-*
%exclude /lib/firmware/intel/ibt-*
%exclude /lib/firmware/mt7650.bin
%exclude /lib/firmware/rt2561.bin
%exclude /lib/firmware/rt2561s.bin
%exclude /lib/firmware/rt2661.bin
%exclude /lib/firmware/rt2860.bin
%exclude /lib/firmware/rt2870.bin
%exclude /lib/firmware/rt3070.bin
%exclude /lib/firmware/rt3071.bin
%exclude /lib/firmware/rt3090.bin
%exclude /lib/firmware/rt3290.bin
%exclude /lib/firmware/rt73.bin
%exclude /lib/firmware/rtl_bt
%exclude /lib/firmware/rtlwifi
%exclude /lib/firmware/rtw88
%exclude /lib/firmware/rtw89
/lib/firmware/*

%files -n iwlwifi-firmware
%defattr(0644,root,root,0755)
%doc LICENCE.iwlwifi_firmware LICENCE.ibt_firmware
/lib/firmware/iwlwifi-*
# ship bluetooth firmware here as its a hw combo
/lib/firmware/intel/ibt-*

%files -n ralink-firmware
%defattr(0644,root,root,0755)
%doc LICENCE.ralink-firmware.txt LICENCE.ralink_a_mediatek_company_firmware
/lib/firmware/mt7650.bin
/lib/firmware/rt2561.bin
/lib/firmware/rt2561s.bin
/lib/firmware/rt2661.bin
/lib/firmware/rt2860.bin
/lib/firmware/rt2870.bin
/lib/firmware/rt3070.bin
/lib/firmware/rt3071.bin
/lib/firmware/rt3090.bin
/lib/firmware/rt3290.bin
/lib/firmware/rt73.bin

%files -n rtlwifi-firmware
%defattr(0644,root,root,0755)
%doc LICENCE.rtlwifi_firmware.txt
/lib/firmware/rtl_bt/*
/lib/firmware/rtlwifi/*
/lib/firmware/rtw88/*
/lib/firmware/rtw89/*
