#
# This rpm is based on the git tree from:
# git://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git
# version is date of the youngest commit
#
# it's advisable to get a full tagged release rather than a versioned of a singled commit.
#
# e.g.
# tagged_firmware=20240909
# wget https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/snapshot/linux-firmware-${tagged_firmware}.tar.gz

Summary:	Open source Linux kernel firmware files
Name:   	kernel-firmware
Version:	20250109
Release:	%mkrel 1
License:	GPLv2 and GPLv2+ and GPLv3
Group:  	System/Kernel and hardware
URL:    	https://www.kernel.org/
#
# The linux-firmware tarball is generated from the git tree mentioned
# above, by simply cloning it, and  doing:
#
#   git archive --prefix=linux-firmware/ origin/main | xz > linux-firmware-20240909.tar.xz
#
# or by using wget with the tagged version as adviced above.
#
# Then use gen-free-firmware-tarball.sh to generate a free-only and a nonfree tarball
# to be used in kernel-firmware-nonfree from the full firmware tarball. E.g.:
#
#    ./gen-free-firmware-tarball.sh linux-firmware-20240909.tar.gz 20240909
#
# which will produce:
#
# linux-firmware-free-20240909.tar.xz and linux-firmware-nonfree-20240909.tar.xz
#
Source0: 	linux-firmware-free-%{version}.tar.xz
Source1:	gen-free-firmware-tarball.sh
%rename		carl9170-firmware
Conflicts:	kernel-firmware-extra < %{version}-1
Conflicts:	kernel-firmware-nonfree < %{version}-1
Conflicts:	radeon-firmware < 20130624-1
Recommends:	kernel-firmware-nonfree
BuildArch:	noarch

%description
This package contains all the open source firmware for in-kernel drivers.

This package includes the firmware for keyspan_pda, dsp56k, pcnet_cs,
3c589_cs, 3c574_cs, serial_cs, dvb-ttpci (base), isci, usbdux.

Other firmware is contained in the radeon-firmware, iwlwifi-*-ucode,
rtlwifi-firmware, and kernel-firmware-nonfree packages in the nonfree section.

%prep
%setup -q -n linux-firmware-free-%{version}

# .bin files are only Redistributable, GPLv2 files are just .txt files
rm -rf brcm cypress

%install
mkdir -p %{buildroot}/lib/firmware
cp -avf * %{buildroot}/lib/firmware
rm -f %{buildroot}/lib/firmware/{WHENCE,GPL*}

%files
%defattr(0644,root,root,0755)
%doc WHENCE
# Check license before adding/removing files here,
# the tarball script is not fault-proof.
%dir /lib/firmware/atusb
/lib/firmware/atusb/atusb-0.2.dfu
/lib/firmware/atusb/atusb-0.3.dfu
/lib/firmware/atusb/rzusb-0.3.bin
%dir /lib/firmware/av7110
/lib/firmware/av7110/bootcode.bin
%dir /lib/firmware/cis
/lib/firmware/cis/*.cis
%dir /lib/firmware/dsp56k
/lib/firmware/dsp56k/bootstrap.bin
%dir /lib/firmware/isci
/lib/firmware/isci/isci_firmware.bin
%dir /lib/firmware/keyspan_pda
/lib/firmware/keyspan_pda/*.fw
/lib/firmware/usbdux*_firmware.bin
%dir /lib/firmware/r128
/lib/firmware/r128/r128_cce.bin
%dir /lib/firmware/radeon
/lib/firmware/radeon/R100_cp.bin
/lib/firmware/radeon/R200_cp.bin
/lib/firmware/radeon/R300_cp.bin
/lib/firmware/radeon/R420_cp.bin
/lib/firmware/radeon/R520_cp.bin
/lib/firmware/radeon/R600_me.bin
/lib/firmware/radeon/R600_pfp.bin
/lib/firmware/radeon/RS600_cp.bin
/lib/firmware/radeon/RS690_cp.bin
/lib/firmware/radeon/RS780_me.bin
/lib/firmware/radeon/RS780_pfp.bin
/lib/firmware/radeon/RV610_me.bin
/lib/firmware/radeon/RV610_pfp.bin
/lib/firmware/radeon/RV620_me.bin
/lib/firmware/radeon/RV620_pfp.bin
/lib/firmware/radeon/RV630_me.bin
/lib/firmware/radeon/RV630_pfp.bin
/lib/firmware/radeon/RV635_me.bin
/lib/firmware/radeon/RV635_pfp.bin
/lib/firmware/radeon/RV670_me.bin
/lib/firmware/radeon/RV670_pfp.bin
/lib/firmware/radeon/RV710_me.bin
/lib/firmware/radeon/RV710_pfp.bin
/lib/firmware/radeon/RV730_me.bin
/lib/firmware/radeon/RV730_pfp.bin
/lib/firmware/radeon/RV770_me.bin
/lib/firmware/radeon/RV770_pfp.bin
/lib/firmware/carl9170-1.fw
