# limit parallel builds on aarch64
%ifarch aarch64
  %global _smp_ncpus_max 8
%endif

# Wayland EGL support
%bcond_with wayland_egl

%define	Werror_cflags	%nil

%ifarch x86_64
%define buildarch	-DKICAD_BUILD_ARCH_X64:BOOL=ON
%endif

%ifarch %ix86
%define buildarch	-DKICAD_BUILD_ARCH_X86:BOOL=ON
%endif

%ifarch %arm
%define buildarch	-DKICAD_BUILD_ARCH_ARM:BOOL=ON
%endif

%ifarch %arm64
%define buildarch	-DKICAD_BUILD_ARCH_ARM64:BOOL=ON
%endif

Name:		kicad
Summary:	An open source program for the creation of electronic schematic diagrams
Epoch:		1
Version:	9.0.0
Release:	%mkrel 3
License:	GPLv3+
Group:		Sciences/Computer science
Url:		https://www.kicad.org/
Source0:	https://gitlab.com/kicad/code/kicad/-/archive/%{version}/%{name}-%{version}.tar.bz2
# upstream disable the "find_package(wxPython)" on ARM64, why???
Patch0:		kicad-find-wxPython-also-on-aarch64.patch
Patch1:		kicad-9.0-fix-compilation-with-protobuf-30.0.patch
BuildRequires:	cmake
BuildRequires:	chrpath
BuildRequires:	doxygen
BuildRequires:	ninja
BuildRequires:	protobuf-compiler
BuildRequires:	wxgtk-devel
BuildRequires:	mesa-common-devel
BuildRequires:	imagemagick
BuildRequires:	boost-devel
BuildRequires:	glm-devel
BuildRequires:	opencascade-devel
BuildRequires:	EGL-devel
BuildRequires:	libgomp-devel
BuildRequires:	cmake(nng)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(odbc)
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libgit2)
BuildRequires:	pkgconfig(libsecret-1)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(ngspice)
BuildRequires:	pkgconfig(protobuf)
# python scripting
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-wxpython4
BuildRequires:	swig

BuildRequires:	desktop-file-utils

Requires:	%{name}-doc >= 1:%{version}
Requires:	%{name}-symbols >= 1:%{version}
Recommends:	%{name}-packages3d >= 1:%{version}
Requires:	%{name}-templates >= 1:%{version}
Requires:	%{name}-footprints >= 1:%{version}
Requires:	python3-wxpython4

%description
Kicad is an open source (GPL) program for the creation of electronic
schematic diagrams and printed circuit board artwork.

Kicad is a set of four programs and a project manager:

* Eeschema:     Schematic entry.
* Pcbnew:       Board editor.
* Gerbview:     GERBER viewer (photoplotter documents).
* Cvpcb:        footprint selector for components used in the circuit design.
* Kicad:        project manager.

%prep
%autosetup -p1

%build
export LC_ALL=C.UTF-8

# Building kicad
%cmake -GNinja \
	-DKICAD_IPC_API=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DCMAKE_BUILD_TYPE=Release \
	-DKICAD_BUILD_QA_TESTS=OFF \
	%{?buildarch} \
	-DKICAD_BUILD_I18N=ON \
	-DKICAD_I18N_UNIX_STRICT_PATH:BOOL=ON \
%if %{with wayland_egl}
	-DKICAD_USE_EGL=ON \
	-DKICAD_USE_BUNDLED_GLEW=OFF \
%endif
	-DKICAD_USE_CMAKE_FINDPROTOBUF=OFF \
	-DKICAD_SCRIPTING_WXPYTHON=ON \
	-DPYTHON_SITE_PACKAGE_PATH=%{python3_sitearch} \
	-DKICAD_VERSION_EXTRA=%{release}
%cmake_build

%install
%cmake_install

%find_lang %{name}

# drop RPATH
chrpath -d %{buildroot}%{python3_sitearch}/_pcbnew.so

# create desktop file
for i in %{buildroot}%{_datadir}/applications/*.desktop; do
desktop-file-edit \
	--remove-category='Scientific' \
	--add-category='Science;Electronics;Education' \
	$i
done

# remove unwanted devel files
rm -r %{buildroot}%{_libdir}/{libkicommon.so,libkigal.so,libkicad_3dsg.so,libkiapi.so}

%files -f %{name}.lang
%license LICENSE*
%doc AUTHORS.txt
%{_bindir}/*
%{_libdir}/libkicad_3dsg.so.*
%{_libdir}/libkicommon.so.*
%{_libdir}/libkigal.so.*
%{_libdir}/libkiapi.so.*
%{_iconsdir}/hicolor/*/{apps,mimetypes}/*.{png,svg}
%{_datadir}/applications/org.kicad.*.desktop
%{_datadir}/mime/packages/kicad-*.xml
%{_metainfodir}/org.kicad.kicad.metainfo.xml
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/demos/
%{_datadir}/%{name}/plugins/
%{_datadir}/%{name}/resources/
%{_datadir}/%{name}/schemas/
%{_datadir}/%{name}/scripting/
%{_datadir}/%{name}/template/
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/plugins/

%{python3_sitearch}/_pcbnew.so
%{python3_sitearch}/pcbnew.*
%{python3_sitearch}/__pycache__/*
