%define major 2
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

# (cg) Should be same version and rel + 1 as module-init-tools.
%define tools_ver 3.16
%define tools_rel 18

%bcond_without dietlibc
%bcond_without tools

Summary: Kernel modules management tools
Name: 	 kmod
Version: 33
Release: %mkrel 1
Source0: https://mirrors.edge.kernel.org/pub/linux/utils/kernel/%{name}/%{name}-%{version}.tar.xz
%if %{with tools}
Source1: modprobe.default
Source2: modprobe.preload
Source3: blacklist-mga.conf
Source4: ipw-no-associate.conf
# From Fedora module-init-tools package
Source5: blacklist-compat.conf
%endif

License: GPLv2+
Group: 	 System/Kernel and hardware
#Url1:	 https://politreco.com/2011/12/announce-kmod-1/
Url:	 https://git.kernel.org/cgit/utils/kernel/kmod/kmod.git
BuildRequires: pkgconfig(libzstd)
BuildRequires: pkgconfig(zlib)
BuildRequires: lzma-devel
BuildRequires: openssl-devel
BuildRequires: xsltproc
BuildRequires: scdoc
Requires(pre): filesystem >= 2.1.9-18
%if %{with tools}
Provides: module-init-tools = %{tools_ver}-%{tools_rel}
Obsoletes: module-init-tools < %{tools_ver}-%{tools_rel}
%endif

%description
Simple tools for managing kernel modules.

%package -n %{libname}
Summary: Kernel modules management library
Group:   System/Libraries
License: LGPLv2+
Requires(pre): filesystem >= 2.1.9-18

%description -n %{libname}
Dynamic libraries for %{name}.

The goal of the libkmod library is to offer to other programs the
needed flexibility and fine grained control over insertion, removal,
configuration and listing of kernel modules. Using the library, with
simple pieces of code it's possible to interact with kernel modules
and then there's no need to rely on other tools for that. This is a
thing lacking on Linux for a while and it's one of the items in the
Plumber's Wish List for Linux. Quoting it:

    provide a proper libmodprobe.so from module-init-tools:
    Early boot tools, installers, driver install disks want to access
    information about available modules to optimize boot up handling.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires(pre):	filesystem >= 2.1.9-18
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
License:	LGPLv2+

%description -n %{develname}
Development files and headers for %{name}.



%prep
%autosetup -p1

%build
%configure \
  --with-openssl \
  --with-zlib \
  --with-xz \
  --with-zstd \
  --enable-year2038
%make_build

%install
%make_install
rm -f %{buildroot}/%_libdir/libkmod.la

%if %{with tools}
  mkdir -p %{buildroot}%{_sbindir}
  pushd %{buildroot}%{_sbindir}
  for tool in modprobe modinfo insmod rmmod depmod lsmod; do
    rm -f %{buildroot}%{_bindir}/$tool
    ln -sf ../bin/kmod $tool
  done
  popd

  install -d -m755 %{buildroot}%{_sysconfdir}
  install -d -m755 %{buildroot}%{_sysconfdir}/depmod.d
  install -d -m755 %{buildroot}%{_sysconfdir}/modprobe.d/
  install -d -m755 %{buildroot}%{_sysconfdir}/modprobe.preload.d/
  touch %{buildroot}%{_sysconfdir}/modprobe.conf
  install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/modprobe.d/00_modprobe.conf
  install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}
  install -m 644 %{SOURCE3} %{SOURCE4} %{SOURCE5} %{buildroot}%{_sysconfdir}/modprobe.d

# (tmb) FIXME for mga3: mga tools still use /etc/modprobe.conf
ln -s  ../modprobe.conf %{buildroot}%{_sysconfdir}/modprobe.d/01_mga-config.conf

%else
  rm -rf %{buildroot}%{_mandir}
%endif

mv %{buildroot}%{_datadir}/pkgconfig/kmod.pc %{buildroot}%{_libdir}/pkgconfig/
rm -rf %{buildroot}%{_datadir}/pkgconfig

%if 0
%check
make check
%endif

%files
%doc NEWS
%_bindir/%{name}
%if %{with tools}
%dir /etc/depmod.d/
%dir %{_sysconfdir}/modprobe.preload.d/
%config(noreplace) %{_sysconfdir}/modprobe.preload
%config(noreplace) %{_sysconfdir}/modprobe.conf
%dir %{_sysconfdir}/modprobe.d/
%config(noreplace) %{_sysconfdir}/modprobe.d/*.conf
%_sbindir/*
%_datadir/bash-completion/completions/kmod
%{_mandir}/man5/depmod.d.5.*
%{_mandir}/man5/modprobe.d.5.*
%{_mandir}/man5/modules.dep.5.*
%{_mandir}/man5/modules.dep.bin.5.*
%{_mandir}/man8/depmod.8.*
%{_mandir}/man8/insmod.8.*
%{_mandir}/man8/kmod.8.*
%{_mandir}/man8/lsmod.8.*
%{_mandir}/man8/modinfo.8.*
%{_mandir}/man8/modprobe.8.*
%{_mandir}/man8/rmmod.8.*
%endif

%files -n %{libname}
%_libdir/libkmod.so.%{major}*

%files -n %{develname}
%_libdir/pkgconfig/*kmod.pc
%_includedir/libkmod.h
%_libdir/*.so
