# WARNING: Synchronized with Fedora!

# Mageia does not currently have a Koji instance
# available on its infrastructure yet, so for now,
# the patch for using it with the koji CLI client is
# disabled. (ngompa)
%bcond_with use_mga_cli_cfg

Name: koji
Version: 1.35.2
Release: %mkrel 1
License: LGPLv2
Summary: Build system tools
Group: System/Packaging
URL: https://koji.build/

Source: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.bz2

# Patches from upstream

# Mageia-specific patches
# Set up defaults for the Koji CLI client
Patch1001: mageia-koji-cli-config.patch

BuildArch: noarch

Requires: python3-%{name} = %{version}-%{release}

BuildRequires: python3-sphinx
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig
BuildRequires: sed

%description
Koji is a system for building and tracking RPMS.  The base package
contains the command-line interface.

%package -n python3-%{name}
Summary: Build system tools python library
Group: Development/Python
%{?python_provide:%python_provide python3-%{name}}
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: make
BuildRequires: python3-pip
BuildRequires: python3-wheel
Requires: python3-rpm
Requires: python3-requests
Requires: python3-requests-gssapi
Requires: python3-dateutil
Requires: python3-six
Requires: python3-libcomps
# Python 2 subpackage is dropped
Obsoletes: python2-%{name} < 1.17.0

%description -n python3-%{name}
Koji is a system for building and tracking RPMS.  This package
contains shared libraries.

%package -n python3-%{name}-cli-plugins
Summary: Koji client plugins
Group: System/Packaging
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
# Python 2 subpackage is dropped
Obsoletes: python2-%{name}-cli-plugins < 1.17.0

%description -n python3-%{name}-cli-plugins
Plugins to the koji command-line interface

%package hub
Summary: Koji XMLRPC interface
Group: System/Servers
License: LGPLv2 and GPLv2
# rpmdiff lib (from rpmlint) is GPLv2 (only)
Requires: apache
Requires: apache-python3-mod_wsgi
Requires: apache-mod_auth_gssapi
Requires: python3-psycopg2
Requires: python3-%{name} = %{version}-%{release}
Suggests: %{name}-hub-plugins

%description hub
koji-hub is the XMLRPC interface to the koji database

%package hub-plugins
Summary: Koji hub plugins
Group: System/Servers
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
Requires: %{name}-hub = %{version}-%{release}
# (ngompa): Cannot get qpid-proton to build
#Requires: python3-qpid-proton
Requires: cpio

%description hub-plugins
Plugins to the koji XMLRPC interface

%package builder
Summary: Koji RPM builder daemon
Group: System/Packaging
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
Requires: mock >= 0.9.14
Requires(pre): shadow-utils
Requires: squashfs-tools
Requires: python3-dnf
Requires: python3-librepo
Requires: python3-multilib
Requires: python3-cheetah
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: cvs
Requires: subversion
Requires: git-core
Requires: createrepo_c

%description builder
koji-builder is the daemon that runs on build machines and executes
tasks that come through the Koji system.

%package builder-plugins
Summary: Koji builder plugins
Group: System/Packaging
License: LGPLv2
Requires: %{name} = %{version}-%{release}
Requires: %{name}-builder = %{version}-%{release}
Enhances: %{name}-builder

%description builder-plugins
Plugins for the koji build daemon

%package vm
Summary: Koji virtual machine management daemon
Group: System/Servers
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: python3-libvirt
Requires: libxml2-python3
Requires: virt-clone
Requires: qemu-img

%description vm
koji-vm contains a supplemental build daemon that executes certain tasks in a
virtual machine. This package is not required for most installations.

%package utils
Summary: Koji Utilities
Group: System/Packaging
License: LGPLv2
Requires: python3-psycopg2
Requires: python3-%{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description utils
Utilities for the Koji system

%package web
Summary: Koji Web UI
Group: System/Servers
License: LGPLv2
Requires: apache
Requires: apache-python3-mod_wsgi
Requires: apache-mod_auth_gssapi
Requires: python3-psycopg2
Requires: python3-cheetah
Requires: python3-%{name} = %{version}-%{release}

%description web
koji-web is a web UI to the Koji system.

%prep
%autosetup -p1

%if ! %{with use_mga_cli_cfg}
%patch -P 1001 -p1 -R
%endif

# we'll be packaging these separately and don't want them registered
# to the wheel we will produce.
sed -e '/util\/koji/g' -e '/koji_cli_plugins/g' -i setup.py

%build
%py3_build_wheel

%install
%py3_install_wheel %{name}-%{version}-py3-none-any.whl
mkdir -p %{buildroot}/etc/koji.conf.d
cp cli/koji.conf %{buildroot}/etc/koji.conf
for D in kojihub builder plugins util www vm ; do
    pushd $D
    %make_install PYTHON=%{__python3}
    popd
done

# alter python interpreter in koji CLI
scripts='%{_bindir}/koji %{_sbindir}/kojid %{_sbindir}/kojira %{_sbindir}/koji-shadow
         %{_sbindir}/koji-gc %{_sbindir}/kojivmd %{_sbindir}/koji-sweep-db
         %{_sbindir}/koji-sidetag-cleanup'
for fn in $scripts ; do
    sed -i 's|#!/usr/bin/python2|#!/usr/bin/python3|' $RPM_BUILD_ROOT$fn
done

# handle extra byte compilation
extra_dirs='
    %{_prefix}/lib/koji-builder-plugins
    %{_prefix}/koji-hub-plugins
    %{_datadir}/koji-hub
    %{_datadir}/koji-web/lib/kojiweb
    %{_datadir}/koji-web/scripts'
for fn in $extra_dirs ; do
    %py_byte_compile %{__python3} %{buildroot}$fn
done

%files
%{_bindir}/*
%config(noreplace) %{_sysconfdir}/koji.conf
%dir %{_sysconfdir}/koji.conf.d
%doc docs Authors
%license COPYING LGPL

%files -n python3-%{name}
%{python3_sitelib}/%{name}
%{python3_sitelib}/koji_cli
%{python3_sitelib}/%{name}-%{version}.dist-info/

%files -n python3-%{name}-cli-plugins
%{python3_sitelib}/koji_cli_plugins
# we don't have config files for default plugins yet
#%%dir %{_sysconfdir}/koji/plugins
#%%config(noreplace) %{_sysconfdir}/koji/plugins/*.conf


%files hub
%{_datadir}/koji-hub
%{python3_sitelib}/kojihub
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojihub.conf
%dir %{_sysconfdir}/koji-hub
%config(noreplace) %{_sysconfdir}/koji-hub/hub.conf
%dir %{_sysconfdir}/koji-hub/hub.conf.d
%{_sbindir}/koji-sweep-db
%{_unitdir}/koji-sweep-db.service
%{_unitdir}/koji-sweep-db.timer

%files hub-plugins
%dir %{_prefix}/lib/koji-hub-plugins
%{_prefix}/lib/koji-hub-plugins/*.py*
%{_prefix}/lib/koji-hub-plugins/__pycache__/
%dir %{_sysconfdir}/koji-hub/plugins
%{_sysconfdir}/koji-hub/plugins/*.conf
# (ngompa): Cannot get qpid-proton to build
%exclude %{_prefix}/lib/koji-hub-plugins/protonmsg*
%exclude %{_prefix}/lib/koji-hub-plugins/__pycache__/protonmsg*
%exclude %{_sysconfdir}/koji-hub/plugins/protonmsg*

%files utils
%{_sbindir}/kojira
%{_unitdir}/kojira.service
%{_unitdir}/koji-gc.service
%{_unitdir}/koji-gc.timer
%dir %{_sysconfdir}/kojira
%config(noreplace) %{_sysconfdir}/kojira/kojira.conf
%{_sbindir}/koji-gc
%dir %{_sysconfdir}/koji-gc
%config(noreplace) %{_sysconfdir}/koji-gc/koji-gc.conf
%config(noreplace) %{_sysconfdir}/koji-gc/email.tpl
%{_sbindir}/koji-shadow
%dir %{_sysconfdir}/koji-shadow
%config(noreplace) %{_sysconfdir}/koji-shadow/koji-shadow.conf
%{_sbindir}/koji-sidetag-cleanup

%files web
%{_datadir}/koji-web
%dir %{_sysconfdir}/kojiweb
%config(noreplace) %{_sysconfdir}/kojiweb/web.conf
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojiweb.conf
%dir %{_sysconfdir}/kojiweb/web.conf.d

%files builder
%{_sbindir}/kojid
%defattr(-,root,root)
%{_unitdir}/kojid.service
%dir %{_sysconfdir}/kojid
%config(noreplace) %{_sysconfdir}/kojid/kojid.conf
%attr(-,kojibuilder,kojibuilder) %{_sysconfdir}/mock/koji

%files builder-plugins
%dir %{_sysconfdir}/kojid/plugins
%config(noreplace) %{_sysconfdir}/kojid/plugins/*.conf
%dir %{_prefix}/lib/koji-builder-plugins
%{_prefix}/lib/koji-builder-plugins/*.py*
%{_prefix}/lib/koji-builder-plugins/__pycache__


%pre builder
/usr/sbin/useradd -r -s /bin/bash -G mock -d /builddir -M kojibuilder 2>/dev/null ||:

%post builder
%systemd_post kojid.service

%preun builder
%systemd_preun kojid.service

%files vm
%{_sbindir}/kojivmd
%dir %{_datadir}/kojivmd
%{_datadir}/kojivmd/kojikamid
%{_unitdir}/kojivmd.service
%dir %{_sysconfdir}/kojivmd
%config(noreplace) %{_sysconfdir}/kojivmd/kojivmd.conf

%post vm
%systemd_post kojivmd.service

%preun vm
%systemd_preun kojivmd.service


%post utils
%systemd_post kojira.service

%preun utils
%systemd_preun kojira.service



