# comment out when not pre-release
#define prel	        beta1

%define rel	        2

%define major		5
%define libname		%mklibname kvilib %{major}
%define develname	%mklibname kvilib -d

%ifarch %{arm} %{ix86}
%bcond_with want_qtwebengine
%else
%bcond_without want_qtwebengine
%endif

Name:		kvirc
Version:	5.2.6
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	Qt IRC client
Group:		Networking/IRC
License:	GPLv2+ with exceptions
URL:		https://www.kvirc.net/
Source0:	https://github.com/kvirc/KVIrc/archive/%{version}%{?prel:-%prel}/%{name}-%{version}%{?prel:-%prel}.tar.gz
Source1:	kvirc-4.0.4-irc.protocol
Source2:	kvirc-4.0.4-irc6.protocol

# Upstream branch patches
# $ git format-patch ${version}

BuildRequires:	kf6-rpm-macros

BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Multimedia)
BuildRequires:	cmake(Qt6MultimediaWidgets)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6PrintSupport)
BuildRequires:	cmake(Qt6Sql)
BuildRequires:	cmake(Qt6Svg)
BuildRequires:	cmake(Qt6Widgets)
%if %{with want_qtwebengine}
BuildRequires:	cmake(Qt6WebEngineWidgets)
%endif
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	cmake(Phonon4Qt6)

BuildRequires:	cmake(KF6CoreAddons)
BuildRequires:	cmake(KF6I18n)
BuildRequires:	cmake(KF6XmlGui)
BuildRequires:	cmake(KF6WindowSystem)
BuildRequires:	cmake(KF6Notifications)
BuildRequires:	cmake(KF6Service)
BuildRequires:	cmake(KF6KIO)
BuildRequires:	cmake(KF6Parts)
BuildRequires:	cmake(KF6StatusNotifierItem)

BuildRequires:	doxygen
BuildRequires:	gettext
BuildRequires:	pkgconfig(audiofile)
BuildRequires:	pkgconfig(enchant-2)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(libv4l2)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	gsm-devel
BuildRequires:	perl-devel

Provides:	kvirc4 = %{version}-%{release}

%description
Qt5-based IRC client with support for themes, transparency, encryption,
many extended IRC features, and scripting.

%files -f %{name}.lang
%doc README.md RELEASES
%{_kf6_bindir}/%{name}
%{_kf6_libdir}/%{name}/
%{_kf6_applicationsdir}/net.%{name}.KVIrc5.desktop
%{_kf6_datadir}/pixmaps/%{name}.png
%{_kf6_services}/_irc*.protocol
%{_kf6_iconsdir}/hicolor/*/*/*.*
%{_kf6_mandir}/man1/*.1*
%dir %{_kf6_datadir}/%{name}
%dir %{_kf6_datadir}/%{name}/5.2
%dir %{_kf6_datadir}/%{name}/5.2/locale
%{_kf6_datadir}/%{name}/5.2/audio/
%{_kf6_datadir}/%{name}/5.2/config/
%{_kf6_datadir}/%{name}/5.2/defscript/
%{_kf6_datadir}/%{name}/5.2/help/
%{_kf6_datadir}/%{name}/5.2/modules/
%{_kf6_datadir}/%{name}/5.2/msgcolors/
%{_kf6_datadir}/%{name}/5.2/pics/
%{_kf6_datadir}/%{name}/5.2/themes/
%{_kf6_datadir}/%{name}/5.2/license/

# Translation man files
%lang(de) %{_kf6_mandir}/de/man1/%{name}.1.?z
%lang(fr) %{_kf6_mandir}/fr/man1/%{name}.1.?z
%lang(it) %{_kf6_mandir}/it/man1/%{name}.1.?z
%lang(pt) %{_kf6_mandir}/pt/man1/%{name}.1.?z
%lang(uk) %{_kf6_mandir}/uk/man1/%{name}.1.?z

#--------------------------------------------------------------------

%package -n %{libname}
Summary:	Shared library for KVirc
Group:		System/Libraries

%description -n %{libname}
Shared library provided by KVirc.

%files -n %{libname}
%{_kf6_libdir}/libkvilib.so.%{major}{,.*}

#--------------------------------------------------------------------

%package -n %{develname}
Summary:	Development headers for KVirc
Group:		Development/C++
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development headers for KVirc.

%files  -n %{develname}
%doc README.md RELEASES
%{_kf6_bindir}/%{name}-config
%{_kf6_libdir}/libkvilib.so

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n KVIrc-%{version}%{?prel:-%prel}

%build
%cmake_kf6 \
    -DWANT_DCC_VIDEO=ON \
    -DWANT_QTWEBKIT=OFF \
    %{!?with_want_qtwebengine:-DWANT_QTWEBENGINE:BOOL=OFF} \
    -DWANT_OGG_THEORA=ON
%cmake_build

%install
%cmake_install

# Zé: irc protocol handle
install -m755 -d %{buildroot}%{_kf6_services}
install -m644 %{S:1} %{buildroot}%{_kf6_services}/_irc.protocol
install -m644 %{S:2} %{buildroot}%{_kf6_services}/_irc6.protocol

# Language files; not under /usr/share/locale, need to be handled manually
  (cd %{buildroot} && find . -name '*.mo') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:' \
  >> %{name}.lang
