%global major 3
%global libname %mklibname lasso %{major}
%global devname %mklibname lasso -d

%global with_php 0
%global with_perl 1
%global with_python3 1
%global with_wsf 0

%global default_sign_algo "rsa-sha256"
%global min_hash_algo "sha256"

%if %{with_php}
%global ini_name     40-%{name}.ini
%endif

%global configure_args %{nil}

%global configure_args %{configure_args} --with-default-sign-algo=%{default_sign_algo}
%global configure_args %{configure_args} --with-min-hash-algo=%{min_hash_algo}

%if !%{with_perl}
  %global configure_args %{configure_args} --disable-perl
%endif

%if %{with_php}
  %global configure_args %{configure_args} --enable-php5=no --enable-php7=yes --with-php7-config-dir=%{php_inidir}
%else
  %global configure_args %{configure_args} --enable-php5=no --enable-php7=no
%endif

%if %{with_wsf}
  %global configure_args %{configure_args} --enable-wsf --with-sasl2=%{_prefix}/sasl2
%endif

%if !%{with_python3}
  %global configure_args %{configure_args} --disable-python
%endif


Summary: Liberty Alliance Single Sign On
Name: lasso
Version: 2.8.2
Release: %mkrel 18
License: GPL-2.0-or-later
Group: System/Libraries
URL: https://lasso.entrouvert.org/
Source: https://dev.entrouvert.org/lasso/lasso-%{version}.tar.gz

Patch01: fix-removed-xmlsec-deprecations.patch
Patch02: fix-openssl-implicit-declarations.patch
Patch3: lasso-libxml2.patch
# https://git.entrouvert.org/entrouvert/lasso/commit/253e8abe7b83d4d8f3d8dd5f886a54f4e173cc28
Patch4: 253e8abe7b83d4d8f3d8dd5f886a54f4e173cc28.patch
# https://git.entrouvert.org/entrouvert/lasso/commit/625bf7d9c11ec366c45514d5ec12ab1cdd8ce094
Patch5: 625bf7d9c11ec366c45514d5ec12ab1cdd8ce094.patch
# https://git.entrouvert.org/entrouvert/lasso/commit/3e6f9076e19368b29a932373955a5dccd2f3cc46
Patch6: 3e6f9076e19368b29a932373955a5dccd2f3cc46.patch
# https://dev.entrouvert.org/issues/92106
Patch7: lasso-2.8.2-python_313.patch
#
Patch100: lasso-2.8.2-python3.12-SyntaxWarning.patch
Patch101: 0001-xml-fix-uninitialized-local-variable-85339.patch
Patch102: 0002-misc-mute-warning-about-implicit-declaration-of-lass.patch
Patch103: 0003-xmlsec-replace-xmlSecCryptoAppKeyLoad-by-xmlSecCrypt.patch
Patch104: 0004-xmlsec-use-XMLSEC_KEYINFO_FLAGS_LAX_KEY_SEARCH-when-.patch
Patch105: 0005-xmlsec-re-enable-KeyValue-nodes-when-reading-KeyInfo.patch
Patch106: 0006-Fix-undefined-macro-in-if-conditional-85339.patch

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: check-devel
BuildRequires: gcc
BuildRequires: glib2-devel
BuildRequires: gtk-doc
BuildRequires: libtool
BuildRequires: libtool-ltdl-devel
BuildRequires: libxml2-devel
BuildRequires: make
BuildRequires: openssl-devel
%if %{with_python3}
BuildRequires: python3
BuildRequires: python3-six
BuildRequires: python3-setuptools
%endif
BuildRequires: swig
BuildRequires: xmlsec1-devel
BuildRequires: zlib-devel
%if %{with_wsf}
BuildRequires: cyrus-sasl-devel
%endif

%description
Lasso is a library that implements the Liberty Alliance Single Sign On
standards, including the SAML and SAML2 specifications. It allows to handle
the whole life-cycle of SAML based Federations, and provides bindings
for multiple languages.

%package -n %{libname}
Summary: Liberty Alliance Single Sign On library
Group: System/Libraries
Provides: lasso%{?_isa} = %{version}-%{release}
Provides: lasso = %{version}-%{release}

%description -n %{libname}
Lasso is a library that implements the Liberty Alliance Single Sign On
standards, including the SAML and SAML2 specifications. It allows to handle
the whole life-cycle of SAML based Federations, and provides bindings
for multiple languages.

%package -n %{devname}
Summary: Lasso development headers and documentation
Group: Development/Other
Requires: %{name}%{?_isa} = %{version}-%{release}
Provides: lasso-devel%{?_isa} = %{version}-%{release}
Provides: lasso-devel = %{version}-%{release}

%description -n %{devname}
This package contains the header files, static libraries and development
documentation for Lasso.

%if %{with_perl}
%package -n perl-Lasso
Summary: Liberty Alliance Single Sign On (lasso) Perl bindings
Group: Development/Perl
BuildRequires: perl-devel
BuildRequires: perl(Error)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(strict)
BuildRequires: perl(Test::More)
BuildRequires: perl(warnings)
BuildRequires: perl(XSLoader)
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n perl-Lasso
Perl language bindings for the lasso (Liberty Alliance Single Sign On) library.
%endif

%if %{with_php}
%package -n php-%{name}
Summary: Liberty Alliance Single Sign On (lasso) PHP bindings
Group: Development/PHP
BuildRequires: expat-devel
BuildRequires: php-devel
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: php(zend-abi) = %{php_zend_api}
Requires: php(api) = %{php_core_api}

%description -n php-%{name}
PHP language bindings for the lasso (Liberty Alliance Single Sign On) library.

%endif

%if %{with_python3}
%package -n python3-%{name}
%{?python_provide:%python_provide python3-%{name}}
Summary: Liberty Alliance Single Sign On (lasso) Python bindings
Group: Development/Python
BuildRequires: python3-devel
BuildRequires: python3-lxml
Requires: python3
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n python3-%{name}
Python language bindings for the lasso (Liberty Alliance Single Sign On)
library.
%endif

%prep
%autosetup -p1

# Remove any python script shebang lines (unless they refer to python3)
sed -i -E -e '/^#![[:blank:]]*(\/usr\/bin\/env[[:blank:]]+python[^3]?\>)|(\/usr\/bin\/python[^3]?\>)/d' \
  `grep -r -l -E '^#![[:blank:]]*(/usr/bin/python[^3]?)|(/usr/bin/env[[:blank:]]+python[^3]?)' *`

%build
./autogen.sh

%if 0%{?with_python3}
  %configure %{configure_args} --with-python=%{__python3}
%else
  %configure %{configure_args}
%endif
%make_build CFLAGS="%{optflags}"

%check
make check CK_TIMEOUT_MULTIPLIER=10

%install
%make_install exec_prefix=%{_prefix}
find %{buildroot} -type f -name '*.la' -exec rm -f {} \;
find %{buildroot} -type f -name '*.a' -exec rm -f {} \;

# Perl subpackage
%if %{with_perl}
find %{buildroot} \( -name perllocal.pod -o -name .packlist \) -exec rm -v {} \;
%endif

# PHP subpackage
%if %{with_php}
install -m 755 -d %{buildroot}%{_datadir}/php/%{name}
mv %{buildroot}%{_datadir}/php/lasso.php %{buildroot}%{_datadir}/php/%{name}

# rename the PHP config file when needed (PHP 5.6+)
if [ "%{name}.ini" != "%{ini_name}" ]; then
  mv %{buildroot}%{php_inidir}/%{name}.ini \
     %{buildroot}%{php_inidir}/%{ini_name}
fi
%endif

# Remove bogus doc files
rm -fr %{buildroot}%{_docdir}/%{name}

# fix debug info extraction
chmod u+w %{buildroot}%{perl_vendorarch}/auto/Lasso/Lasso.so

%files -n %{libname}
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/liblasso.so.%{major}{,.*}

%files -n %{devname}
%{_libdir}/liblasso.so
%{_libdir}/pkgconfig/lasso.pc
%{_includedir}/%{name}/

%if %{with_perl}
%files -n perl-Lasso
%{perl_vendorarch}/Lasso.pm
%{perl_vendorarch}/auto/Lasso/
%endif

%if %{with_php}
%files -n php-%{name}
%{php_extdir}/lasso.so
%config(noreplace) %{php_inidir}/%{ini_name}
%dir %{_datadir}/php/%{name}
%{_datadir}/php/%{name}/lasso.php
%endif

%if %{with_python3}
%files -n python3-%{name}
%pycached %{python3_sitearch}/lasso.py
%{python3_sitearch}/_lasso.so
%endif
