%global uver	3.6-0
%global ver	%(echo %{uver} | tr '-' '.')

Name:		lazarus
Version:	%{ver}
Release:	%mkrel 2
Summary:	Lazarus Component Library and IDE for Freepascal
Group:		Development/Other
# GNU Classpath style exception, see COPYING.modifiedLGPL
License:	GPLv2+ and MPLv1.1 and LGPLv2+ with exceptions
URL:		https://www.lazarus-ide.org/
Source0:	https://download.sourceforge.net/lazarus/%{name}-%{uver}.tar.gz
Source1:	lazarus-miscellaneousoptions

BuildRequires:	fpc-src >= 3.0.0
BuildRequires:	fpc >= 3.0.0
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	glibc
BuildRequires:	gdb
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	desktop-file-utils
Requires:	fpc-src >= 3.0.0
Requires:	fpc >= 3.0.0
Requires:	pkgconfig(gtk+-2.0)
Requires:	pkgconfig(gdk-pixbuf-2.0)
Requires:	gdb
Requires:	pkgconfig(glib-2.0)
Requires:	binutils
Requires:	glibc-devel
Requires:	make
Recommends:	pkgconfig(sqlite3)

%description
Lazarus is a free and opensource RAD tool for freepascal using the lazarus
component library - LCL, which is also included in this package.

%prep
%setup -q -c %{name}-%{version}

cd %{name}

# remove unneeded files
rm -rf debian
rm -rf tools/install/cross_unix/debian_crosswin32/
rm -f tools/install/cross_unix/*deb.*
rm -rf tools/install/debian_*
rm -rf tools/install/freebsd_*
rm -rf tools/install/macosx/
rm -rf tools/install/slacktgz/
rm -rf tools/install/win/
rm -f tools/install/*slacktgz.*
rm -f tools/install/*deb.*
find ./ -type f -name "*.bat" -delete -print

# remove scripts vulnerable to symlink-attacks (bug 460642)
rm -f tools/install/build_fpc_snaphot_rpm.sh
rm -f tools/install/check_fpc_dependencies.sh
rm -f tools/install/create_fpc_deb.sh
rm -f tools/install/create_fpc_export_tgz.sh
rm -f tools/install/create_fpc_rpm.sh
rm -f tools/install/create_fpc-src_rpm.sh
rm -f tools/install/create_fpc_tgz_from_local_dir.sh
rm -f tools/install/create_lazarus_export_tgz.sh

# fix lineencodings
sed -i 's/\r$//' examples/trayicon/frmtest.*
sed -i 's/\r$//' examples/trayicon/wndtray.*

%build
cd lazarus
# Remove the files for building other packages
rm -rf debian
cd tools
find install -depth -type d ! \( -path "install/linux/*" -o -path "install/linux" -o -path "install" \) -exec rm -rf '{}' \;
cd ..

export FPCDIR=%{_datadir}/fpcsrc/
fpcmake -Tall
cd components
fpcmake -Tall
cd ..
make bigide OPT='-gl -gw'
make tools OPT='-gl -gw'

# Compile the LCL base + extra components for GUI widgetsets
for WIDGETSET in gtk gtk2 gtk3 qt qt5 qt6; do
  make lcl basecomponents bigidecomponents OPT='-gl -gw' LCL_PLATFORM="${WIDGETSET}"
done

%install
LAZARUSDIR=%{_libdir}/%{name}
FPCDIR=%{_datadir}/fpcsrc/
mkdir -p %{buildroot}$LAZARUSDIR
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/pixmaps
mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/mime/packages
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_sysconfdir}/lazarus
cp -a lazarus/* %{buildroot}$LAZARUSDIR/
install -m 0644 lazarus/images/ide_icon48x48.png %{buildroot}%{_datadir}/pixmaps/lazarus.png
install -m 0644 lazarus/install/lazarus.desktop %{buildroot}%{_datadir}/applications/lazarus.desktop
install -m 0644 lazarus/install/lazarus-mime.xml $LazBuildDir%{buildroot}%{_datadir}/mime/packages/lazarus.xml
ln -sf $LAZARUSDIR/lazarus %{buildroot}%{_bindir}/lazarus-ide
ln -sf $LAZARUSDIR/startlazarus %{buildroot}%{_bindir}/startlazarus
ln -sf $LAZARUSDIR/lazbuild %{buildroot}%{_bindir}/lazbuild
cat lazarus/install/man/man1/lazbuild.1 | gzip > %{buildroot}%{_mandir}/man1/lazbuild.1.gz
cat lazarus/install/man/man1/lazarus-ide.1 | gzip > %{buildroot}%{_mandir}/man1/lazarus-ide.1.gz
cat lazarus/install/man/man1/startlazarus.1 | gzip > %{buildroot}%{_mandir}/man1/startlazarus.1.gz

# fix fpc and lazarus path
install lazarus/tools/install/linux/environmentoptions.xml %{buildroot}%{_sysconfdir}/lazarus/environmentoptions.xml
sed -i 's/\$(FPCVER)\///g' %{buildroot}%{_sysconfdir}/lazarus/environmentoptions.xml
sed -i 's/%LazarusVersion%//g' %{buildroot}%{_sysconfdir}/lazarus/environmentoptions.xml

# fix config path
sed -i 's#__LAZARUSDIR__#'$LAZARUSDIR/'#g' %{buildroot}%{_sysconfdir}/lazarus/environmentoptions.xml
sed -i 's#__FPCSRCDIR__#'$FPCDIR'#g' %{buildroot}%{_sysconfdir}/lazarus/environmentoptions.xml

chmod 755 %{buildroot}%{_libdir}/%{name}/components/lazreport/tools/localize.sh

pushd %{buildroot}%{_libdir}/%{name}
rm -f *.txt
rm -rf install
popd

install -m 755 %{SOURCE1} %{buildroot}%{_bindir}/

%postun
if [ $1 = 0 ]
then
rm -rf %{_libdir}/lazarus
fi

%files
%license lazarus/COPYING*
%doc lazarus/README*
%{_libdir}/%{name}/
%{_bindir}/%{name}-ide
%{_bindir}/startlazarus
%{_bindir}/lazbuild
%{_bindir}/%{name}-miscellaneousoptions
%{_datadir}/pixmaps/lazarus.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/lazarus.xml
%dir %{_sysconfdir}/lazarus
%config(noreplace) %{_sysconfdir}/lazarus/environmentoptions.xml
%{_mandir}/*/*
