# NOTE: you must rebuild the samba and sssd packages after updating this one

%global __brp_check_rpaths %nil

%define ldbmajor          2
%define libldb            %mklibname ldb %{ldbmajor}
%define ldbdevel          %mklibname ldb -d

%define pyldbmajor        2
%define libpyldbutil      %mklibname pyldb-util %{pyldbmajor}
%define libpyldbutildevel %mklibname pyldb-util -d

%define check_sig() export GNUPGHOME=%{_tmppath}/rpm-gpghome \
if [ -d "$GNUPGHOME" ] \
then echo "Error, GNUPGHOME $GNUPGHOME exists, remove it and try again"; exit 1 \
fi \
install -d -m700 $GNUPGHOME \
gpg --import %{1} \
gpg --trust-model always --verify %{2} %{?3} \
rm -Rf $GNUPGHOME \

# lmdb is not supported on 32 bit architectures
%if (0%{?__isa_bits} == 64)
%global with_lmdb 1
%else
%global without_lmdb_flags --without-ldb-lmdb
%endif

%global tdb_version 1.4.12
%global tevent_version 0.16.1
%global talloc_version 2.4.2

Name:          ldb
Epoch:         1
Version:       2.9.2
Release:       %mkrel 1
Summary:       Library implementing Samba's embedded database
Group:         System/Libraries
License:       GPLv2
URL:           https://ldb.samba.org/
Source0:       https://samba.org/ftp/ldb/ldb-%{version}.tar.gz
Source1:       https://samba.org/ftp/ldb/ldb-%{version}.tar.asc
Source2:       jelmer.asc
BuildRequires: openldap-devel
BuildRequires: pkgconfig(cmocka) >= 1.1.3
BuildRequires: pkgconfig(popt)
BuildRequires: pkgconfig(tevent) >= %{tevent_version}
BuildRequires: pkgconfig(talloc) >= %{talloc_version}
BuildRequires: pytalloc-util-devel >= %{talloc_version}
BuildRequires: pkgconfig(tdb) >= %{tdb_version}
BuildRequires: pkgconfig(python3)
BuildRequires: python3-tdb >= 1:%{tdb_version}
BuildRequires: python3-talloc >= 1:%{talloc_version}
BuildRequires: python3-tevent >= 1:%{tevent_version}
BuildRequires: xsltproc
%if 0%{?with_lmdb}
BuildRequires: lmdb-devel >= 0.9.16
%endif
BuildRequires: docbook-style-xsl

%description
Library implementing Samba's embedded database and utilities for backing up,
restoring and manipulating the database.

%package -n %{libldb}
Group:         System/Libraries
Summary:       Library implementing Samba's embedded database

# ease upgrade
Conflicts:     ldb-utils < 1:2.8.0-3

%description -n %{libldb}
Library implementing Samba's embedded database.

%package -n ldb-utils
Group:         Databases
Summary:       Tools for backing up, restoring, and manipulating Samba's embedded database

%description -n ldb-utils
Tools for backing up, restoring, and manipulating Samba's embedded database.

%package -n %{ldbdevel}
Group:         Development/C
Summary:       Library implementing Samba's embedded database
Provides:      ldb-devel = %{epoch}:%{version}-%{release}
Requires:      %{libldb} = %{epoch}:%{version}-%{release}

%description -n %{ldbdevel}
Library implementing Samba's embedded database.

%package -n python3-ldb
Summary: Python 3 bindings for the LDB library
Requires: python3-tdb%{?_isa} >= %{tdb_version}
%{?python_provide:%python_provide python3-ldb}

%description -n python3-ldb
Python 3 bindings for the LDB library.

%package -n %{libpyldbutil}
Group:         System/Libraries
Summary:       Utility library for using tdb functions in python 3

%description -n %{libpyldbutil}
Utility library for using tdb functions in python 3.

%package -n %{libpyldbutildevel}
Group:         Development/Python
Summary:       Development files for utility library for using tdb functions in python 3
Provides:      pyldb-util-devel = %{epoch}:%{version}-%{release}
Requires:      %{libpyldbutil} = %{epoch}:%{version}
Requires:      %{ldbdevel} = %{epoch}:%{version}-%{release}

%description -n %{libpyldbutildevel}
Development files for utility library for using tdb functions in python 3.

%prep
%autosetup -p1

perl -pi -e 's,http://docbook.sourceforge.net/release/xsl/current,/usr/share/sgml/docbook/xsl-stylesheets,g' docs/builddocs.sh buildtools/wafsamba/wafsamba.py buildtools/wafsamba/samba_conftests.py

# replace removed time.clock()
sed -i -e "s,time\.clock(),time.perf_counter(),g" buildtools/wafsamba/samba_deps.py

# fix for python3.8
sed -i -e "/all_flags/s,\('--libs'\),\1\, '--embed'," third_party/waf/waflib/Tools/python.py

cp -a ABI/ldb-2.6.1.sigs ABI/ldb-2.6.2.sigs

%build
%configure --disable-rpath --disable-rpath-install \
           --bundled-libraries=NONE \
           --with-modulesdir=%{_libdir} \
	   %{?without_lmdb_flags}
%make_build

%install
%make_install

%files -n %{libldb}
%{_libdir}/libldb.so.%{ldbmajor}{,.*}
%dir %{_libdir}/ldb/
%{_libdir}/ldb/asq.so
%{_libdir}/ldb/ldap.so
%{_libdir}/ldb/paged_searches.so
%{_libdir}/ldb/rdn_name.so
%{_libdir}/ldb/sample.so
%{_libdir}/ldb/server_sort.so
%{_libdir}/ldb/skel.so
%{_libdir}/ldb/tdb.so
%{_libdir}/ldb/ldb.so
%if 0%{?with_lmdb}
%{_libdir}/ldb/mdb.so
%{_libdir}/ldb/libldb-mdb-int.so
%endif
%{_libdir}/ldb/libldb-key-value.so
%{_libdir}/ldb/libldb-tdb-err-map.so
%{_libdir}/ldb/libldb-tdb-int.so

%files -n %{ldbdevel}
%{_libdir}/libldb.so
%{_libdir}/pkgconfig/ldb.pc
%{_includedir}/ldb*.h

%files -n ldb-utils
%{_bindir}/ldb*
%{_libdir}/ldb/libldb-cmdline.so
%{_mandir}/man1/ldb*.1%{_extension}
%{_mandir}/man3/ldb*.3%{_extension}

%files -n python3-ldb
%{python3_sitearch}/ldb.cpython-*.so
%{python3_sitearch}/_ldb_text.py
%{python3_sitearch}/__pycache__/_ldb_text.cpython-*.py*

%files -n %{libpyldbutil}
%{_libdir}/libpyldb-util.cpython-*.so.%{pyldbmajor}{,.*}

%files -n %{libpyldbutildevel}
%{_libdir}/libpyldb-util.cpython-*.so
%{_includedir}/pyldb.h
%{_libdir}/pkgconfig/pyldb-util.cpython-*.pc
