%define lib_major 1
%define lib_name  %mklibname lensfun %{lib_major}
%define lib_dev   %mklibname lensfun -d

# See https://github.com/darktable-org/darktable/issues/7380#issuecomment-768064808
# about why there are no newer versions in the upstream despite active git master

Name: lensfun
# Epoch added to facilitate update from buggy alpha 0.3.95 with breaking changes to
# new stable release 0.3.3. https://ml.mageia.org/l/arc/dev/2022-10/msg00221.html
Epoch: 1
Version: 0.3.4
Summary: A library to rectify defects introduced by photographic lenses
Release: %mkrel 5
License: LGPLv3 and CC-BY-SA
Group: System/Libraries
URL: https://github.com/lensfun/lensfun
Source0: https://github.com/lensfun/lensfun/archive/v%{version}.tar.gz?/%{name}-%{version}.tar.gz
Source2: README.urpmi
Patch0: 0001-Match-library-file-name-with-soname.patch
Patch7: lensfun-0.3.2-INSTALL_HELPER_SCRIPTS.patch
Patch8: fix-python-module-install.patch
BuildRequires: cmake >= 2.8
BuildRequires: doxygen
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(zlib)
BuildRequires: python3-devel
BuildRequires: python3-docutils

%description
The lensfun library provides an open source database of photographic lenses and
their characteristics. It not only provides a way to read and search the
database, but also provides a set of algorithms for correcting images based on
detailed knowledge of lens properties. Right now lensfun is designed to correct
distortion, transversal (also known as lateral) chromatic aberrations,
vignetting and color contribution of a lens.

%files
%{_datadir}/lensfun
%{_bindir}/lenstool
%{_bindir}/lensfun-add-adapter
%{_bindir}/lensfun-update-data
%{python3_sitelib}/lensfun/
%{python3_sitelib}/lensfun-%{version}.dist-info/
%{_docdir}/lensfun/*.css
%{_docdir}/lensfun/*.html
%{_docdir}/lensfun/*.js
%{_docdir}/lensfun/*.png
%{_docdir}/lensfun/*.svg
%{_mandir}/man1/lensfun-add-adapter.1*
%{_mandir}/man1/lensfun-update-data.1*
%doc README.urpmi

#------------------------------------------------------------------

%package -n %{lib_name}
Summary: A library to rectify defects introduced by photographic lenses
Group: System/Libraries
Requires: %{name}

%description -n	%{lib_name}
A library to rectify defects introduced by photographic lenses.

%files -n %{lib_name}
%{_libdir}/*.so.%{lib_major}

#------------------------------------------------------------------

%package -n	%{lib_dev}
Summary: Development tools for programs which will use the %{name}
Group: Development/C
Requires: %{lib_name} = %{epoch}:%{version}
Provides: %{name}-devel = %{epoch}:%{version}-%{release}

%description -n	%{lib_dev}
This package contains the header files and .so libraries for developing %{name}.

%files -n %{lib_dev}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/lensfun.pc

#------------------------------------------------------------------

%prep
%autosetup -p1

%py3_shebang_fix \
    apps/lensfun-add-adapter \
    apps/lensfun-update-data

%build
%cmake -DBUILD_TESTS:BOOL=OFF \
       -DBUILD_DOC:BOOL=ON \
       -DBUILD_LENSTOOL:BOOL=ON \
       -DCMAKE_BUILD_TYPE:STRING=Release \
       -DINSTALL_HELPER_SCRIPTS:BOOL=ON \
%ifarch x86_64
       -DBUILD_FOR_SSE=ON -DBUILD_FOR_SSE2=ON \
%else
       -DBUILD_FOR_SSE=OFF -DBUILD_FOR_SSE2=OFF \
%endif
       -DINSTALL_PYTHON_MODULE:BOOL=OFF

%cmake_build

pushd %{_vpath_builddir}/apps
%pyproject_wheel
popd

%install
%cmake_install

pushd %{_vpath_builddir}/apps
%pyproject_install
popd

# README.urpmi
install -Dm644 %{SOURCE2} .

## unpackaged files
# omit g-lensfun-update-data because it needs gksudo which we don't ship
rm -fv %{buildroot}%{_bindir}/g-lensfun-update-data \
       %{buildroot}%{_mandir}/man1/g-lensfun-update-data.*
