%global sum     A fast and lightweight key/value database library by Google

%define major   1
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

%undefine __cmake_in_source_build
Name:           leveldb
Version:        1.23
Release:        %mkrel 1
Summary:        %{sum}
Group:          Databases
License:        BSD
URL:            https://github.com/google/leveldb
Source0:        https://github.com/google/leveldb/archive/%{version}/%{name}-%{version}.tar.gz

# available in https://github.com/fusesource/leveldbjni/blob/leveldb.patch
Patch0001:      https://src.fedoraproject.org/rpms/leveldb/raw/rawhide/f/0001-Allow-leveldbjni-build.patch
# https://github.com/fusesource/leveldbjni/issues/34
# https://code.google.com/p/leveldb/issues/detail?id=184
# Add DB::SuspendCompactions() and DB:: ResumeCompactions() methods
Patch0002:      https://src.fedoraproject.org/rpms/leveldb/raw/rawhide/f/0002-Added-a-DB-SuspendCompations-and-DB-ResumeCompaction.patch
# Cherry-picked from Basho's fork
Patch0003:      https://src.fedoraproject.org/rpms/leveldb/raw/rawhide/f/0003-allow-Get-calls-to-avoid-copies-into-std-string.patch
# https://groups.google.com/d/topic/leveldb/SbVPvl4j4vU/discussion
Patch0004:      https://src.fedoraproject.org/rpms/leveldb/raw/rawhide/f/0004-bloom_test-failure-on-big-endian-archs.patch
# -fno-rtti breaks ABI compatibility
Patch0006:      https://src.fedoraproject.org/rpms/leveldb/raw/rawhide/f/0006-revert-no-rtti.patch

BuildRequires:  cmake
BuildRequires:  snappy-devel
BuildRequires:  sqlite3-devel

%description
LevelDB is a fast key-value storage library written at Google that provides an
ordered mapping from string keys to string values.

#----------------------------------------------------------------------------

%package -n     %{libname}
Summary:        %{summary}
Group:          System/Libraries

%description -n %{libname}
LevelDB is a fast key-value storage library written at Google that provides an
ordered mapping from string keys to string values.

%files -n       %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n     %{devname}
Summary:        Development files for LevelDB
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Provides:       leveldb-devel = %{version}-%{release}

%description -n %{devname}
LevelDB is a fast key-value storage library written at Google that provides an
ordered mapping from string keys to string values.

This package contains additional header files for development with LevelDB.

%files -n       %{devname}
%doc doc/ AUTHORS LICENSE README.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}/

#----------------------------------------------------------------------------

%prep
%autosetup -p1

cat > %{name}.pc << EOF
prefix=%{_prefix}
exec_prefix=${prefix}
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}
Description: %{summary}
Version: %{version}
Libs: -l%{name}
EOF

%build
%cmake \
	-DLEVELDB_BUILD_TESTS:BOOL=OFF \
	-DLEVELDB_BUILD_BENCHMARKS:BOOL=OFF
%cmake_build


%install
%cmake_install

mkdir -p %{buildroot}%{_libdir}/pkgconfig
cp -a %{name}.pc %{buildroot}%{_libdir}/pkgconfig/


%check
%ctest
