
%define major		6
%define libname		%mklibname lhapdf %{major}
%define develname	%mklibname lhapdf -d

Name:		lhapdf
Version:	6.5.4
Release:	%mkrel 2
Summary:	Les Houches Accord PDF Interface
Group:          Sciences/Mathematics

License:	GPL-3.0-only
URL:		https://lhapdf.hepforge.org/
Source0:	https://www.hepforge.org/archive/lhapdf/LHAPDF-%{version}.tar.gz
Patch0:		%{name}-soname.patch

BuildRequires:	gcc-c++
BuildRequires:	python3-cython
BuildRequires:	python3-devel
BuildRequires:	doxygen

%description
LHAPDF is a general purpose C++ interpolator, used for evaluating PDFs
from discretized data files. Previous versions of LHAPDF were written
in Fortran 77/90 and are documented at http://lhapdf.hepforge.org/lhapdf5/.

LHAPDF6 vastly reduces the memory overhead of the Fortran LHAPDF (from
gigabytes to megabytes!), entirely removes restrictions on numbers of
concurrent PDFs, allows access to single PDF members without needing
to load whole sets, and separates a new standardized PDF data format
from the code library so that new PDF sets may be created and released
easier and faster. The C++ LHAPDF6 also permits arbitrary parton
contents via the standard PDG ID code scheme, is computationally more
efficient (particularly if only one or two flavors are required at
each phase space point, as in PDF reweighting), and uses a flexible
metadata system which fixes many fundamental metadata and concurrency
bugs in LHAPDF5.

Compatibility routines are provided as standard for existing C++ and
Fortran codes using the LHAPDF5 and PDFLIB legacy interfaces, so you
can keep using your existing codes. But the new interface is much more
powerful and pleasant to work with, so we think you'll want to switch
once you've used it!

LHAPDF6 is documented in more detail in http://arxiv.org/abs/1412.7420

%package -n %{libname}
Summary:	Les Houches Accord PDF Interface
Group:		Sciences/Mathematics
Provides:	%{name} = %{version}-%{release}

%description -n %{libname}
LHAPDF is a general purpose C++ interpolator, used for evaluating PDFs
from discretized data files. Previous versions of LHAPDF were written
in Fortran 77/90 and are documented at http://lhapdf.hepforge.org/lhapdf5/.

LHAPDF6 vastly reduces the memory overhead of the Fortran LHAPDF (from
gigabytes to megabytes!), entirely removes restrictions on numbers of
concurrent PDFs, allows access to single PDF members without needing
to load whole sets, and separates a new standardized PDF data format
from the code library so that new PDF sets may be created and released
easier and faster. The C++ LHAPDF6 also permits arbitrary parton
contents via the standard PDG ID code scheme, is computationally more
efficient (particularly if only one or two flavors are required at
each phase space point, as in PDF reweighting), and uses a flexible
metadata system which fixes many fundamental metadata and concurrency
bugs in LHAPDF5.

Compatibility routines are provided as standard for existing C++ and
Fortran codes using the LHAPDF5 and PDFLIB legacy interfaces, so you
can keep using your existing codes. But the new interface is much more
powerful and pleasant to work with, so we think you'll want to switch
once you've used it!

LHAPDF6 is documented in more detail in http://arxiv.org/abs/1412.7420

%package -n %{develname}
Summary:	Les Houches Accord PDF Interface - development files
Group:		Sciences/Mathematics
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package provides development files of LHAPDF, including C++ bindings.

%package -n python%{python3_pkgversion}-%{name}
Summary:	Les Houches Accord PDF Interface - Python 3 module
%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}
Requires:	%{libname} = %{version}-%{release}

%description -n python%{python3_pkgversion}-%{name}
This package provides Python 3 bindings for LHAPDF.

%package doc
Summary:	Les Houches Accord PDF Interface - documentation
BuildArch:	noarch

%description doc
This package provides API documentation and examples for LHAPDF.

%prep
%autosetup -n LHAPDF-%{version} -p1


# Remove cython generated file
rm wrappers/python/lhapdf.cpp

# Fix python shebangs
sed 's!/usr/bin/env bash!/bin/bash!' -i bin/lhapdf-config.in
sed 's!/usr/bin/env python!/usr/bin/python3!' -i bin/lhapdf examples/*.py

%build
%configure --disable-static --disable-silent-rules PYTHON=%{__python3} --docdir=%{_pkgdocdir}
%make_build

# Build doxygen documentation
%make_build doxy

%install
%make_install PYTHON_PATH=%{python3_sitearch}

cat << EOF > %{buildroot}%{python3_sitearch}/%{name}-%{version}.egg-info
Name: %{name}
Version: %{version}
EOF

find %{buildroot}%{_libdir} -name '*.la' -delete

find %{buildroot}%{_pkgdocdir}/examples -type f -a '!' -name '*.*' -delete

%check
%make_build check

%ldconfig_scriptlets

%files
%{_bindir}/lhapdf

%files -n %{libname}
%{_libdir}/libLHAPDF-%{version}.so
%{_datadir}/LHAPDF
%doc AUTHORS ChangeLog
%license COPYING

%files -n %{develname}
%{_bindir}/%{name}-config
%{_includedir}/LHAPDF
%{_libdir}/libLHAPDF.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n python%{python3_pkgversion}-%{name}
%{python3_sitearch}/%{name}-%{version}.egg-info
%{python3_sitearch}/%{name}/

%files doc
%doc %{_pkgdocdir}/doxygen
%doc %{_pkgdocdir}/examples
%license COPYING
