%define major     0
%define libname   %mklibname aec %{major}
%define develname %mklibname aec -d

%define szmajor   2
%define libszname %mklibname sz %{szmajor}

Name:           libaec
Version:        1.1.3
Release:        %mkrel 1
Summary:        Adaptive Entropy Coding library
License:        BSD
Group:          System/Libraries
Url:            https://gitlab.dkrz.de/k202009/libaec
Source:         https://gitlab.dkrz.de/k202009/libaec/-/archive/v%{version}/%{name}-v%{version}.tar.gz
Patch0:         libaec-1.1.3-install-binary-and-manpage.patch

BuildRequires:  cmake

%description
Libaec provides fast loss-less compression of 1 up to 32 bit wide
signed or unsigned integers (samples). The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations. While floating point representations are not directly
supported, they can also be efficiently coded by grouping exponents
and mantissa.

Libaec implements Golomb Rice coding as defined in the Space Data
System Standard documents 121.0-B-2 and 120.0-G-2.

Libaec includes a free drop-in replacement for the SZIP
library (https://www.hdfgroup.org/doc_resource/SZIP).

#------------------------------------------------

%package -n     %{libname}
Summary:        Adaptive Entropy Coding library
Group:          System/Libraries

%description -n %{libname}
Libaec provides fast loss-less compression of 1 up to 32 bit wide
signed or unsigned integers (samples). The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations. While floating point representations are not directly
supported, they can also be efficiently coded by grouping exponents
and mantissa.

Libaec implements Golomb Rice coding as defined in the Space Data
System Standard documents 121.0-B-2 and 120.0-G-2.

Libaec includes a free drop-in replacement for the SZIP
library (https://www.hdfgroup.org/doc_resource/SZIP).

#------------------------------------------------

%package -n     %{libszname}
Summary:        Lossless compression library for scientific data
Group:          System/Libraries

%description -n %{libszname}
Libsz provides fast loss-less compression of 1 up to 32 bit wide
signed or unsigned integers (samples). The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations. While floating point representations are not directly
supported, they can also be efficiently coded by grouping exponents
and mantissa.

Libaec implements Golomb Rice coding as defined in the Space Data
System Standard documents 121.0-B-2 and 120.0-G-2.

Libaec includes a free drop-in replacement for the SZIP
library (https://www.hdfgroup.org/doc_resource/SZIP).

#------------------------------------------------

%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libszname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       szlib-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

rm %{buildroot}%{_libdir}/lib*.a
mv %{buildroot}%{_prefix}/cmake %{buildroot}%{_libdir}

%check
#test data missing in tarball for check_szcomp and sampledata.sh
LD_LIBRARY_PATH=%{buildroot}%{_libdir} \
make -C build test ARGS="-E \(check_szcomp\|sampledata.sh\)"

%files
%doc README.md README.SZIP CHANGELOG.md
%license doc/patent.txt
%{_bindir}/graec
%{_mandir}/man1/graec.1*

%files -n %{libname}
%{_libdir}/libaec.so.%{major}{,.*}

%files -n %{libszname}
%{_libdir}/libsz.so.%{szmajor}{,.*}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/lib*.so
%{_libdir}/cmake/%{name}-*.cmake
