%define	major	3
%define	mname	cgroup
%define	libname	%mklibname %{mname} %{major}
%define	devname	%mklibname %{mname} -d

%bcond_with tests

Name:		lib%{mname}
Summary:	Tools and libraries to control and monitor control groups
Group:		System/Base
Version:	3.1.0
Release:	%mkrel 1
License:	LGPLv2+
URL:		https://libcg.sourceforge.net/
Source0:	https://github.com/libcgroup/libcgroup/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source2:	cgconfig.service
Source3:	libcgroup-README2.Mageia
Patch0:		fedora-config.patch
Patch1:		libcgroup-0.37-chmod.patch
Patch2:		libcgroup-0.40.rc1-coverity.patch
Patch3:		libcgroup-0.40.rc1-fread.patch
Patch4:		libcgroup-0.40.rc1-templates-fix.patch

BuildRequires:	pam-devel
BuildRequires:	byacc
BuildRequires:	flex
BuildRequires:	coreutils
BuildRequires:	pkgconfig(libsystemd)
%if %{with tests}
BuildRequires:	pkgconfig(gtest)
%endif
Requires(pre):	shadow-utils

%description
Control groups infrastructure. The tools and library to manipulate, control,
administrate and monitor control groups and the associated controllers.

%package -n	%{mname}
Summary:	Tools to control and monitor control groups 
Group:		System/Base
Provides:	%{name} = %{version}-%{release}
Requires(post):	systemd
Requires(preun): systemd

%description -n	cgroup
Control groups infrastructure. The tools to manipulate, control, administrate
and monitor control groups and the associated controllers.

%package -n	pam_%{mname}
Summary:	A Pluggable Authentication Module for libcgroup
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n	pam_%{mname}
Linux-PAM module, which allows administrators to classify the user's login
processes to pre-configured control group.

%package -n	%{libname}
Summary:	Libraries to control and monitor control groups
Group:		System/Libraries
# binaries are statically linked, so while they don't require the library,
# anything linked against the library will require the config files etc.
# rovided by the main package
Requires:	%{mname} = %{version}-%{release}

%description -n	%{libname}
Control groups infrastructure. The library to manipulate, control, administrate
and monitor control groups and the associated controllers.

%package -n	%{devname}
Summary:	Development libraries to develop applications that utilize control groups
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
It provides API to create/delete and modify cgroup nodes. It will also in the
future allow creation of persistent configuration for control groups and
provide scripts to manage that configuration.

%prep
%setup -q
%patch -P 0 -p1 -b .config-patch
%patch -P 1 -p1 -b .chmod
%patch -P 2 -p1 -b .coverity
%patch -P 3 -p1 -b .fread
%patch -P 4 -p1 -b .templates-fix

cp %{SOURCE3} README.Mageia

%build
autoreconf -vif
%configure --enable-pam-module-dir=%{_libdir}/security \
           --enable-opaque-hierarchy="name=systemd" \
           --disable-daemon
%make_build

%install
%make_install

# install config files
install -m 644 samples/config/cgconfig.conf -D %{buildroot}%{_sysconfdir}/cgconfig.conf
install -m 644 samples/config/cgconfig.sysconfig -D %{buildroot}%{_sysconfdir}/sysconfig/cgconfig
install -m 644 samples/config/cgrules.conf -D %{buildroot}%{_sysconfdir}/cgrules.conf
install -m 644 samples/config/cgsnapshot_allowlist.conf -D %{buildroot}%{_sysconfdir}/cgsnapshot_allowlist.conf
install -m 644 samples/config/cgsnapshot_denylist.conf -D %{buildroot}%{_sysconfdir}/cgsnapshot_denylist.conf

# sanitize pam module, we need only pam_cgroup.so
rm -f %{buildroot}%{_libdir}/security/pam_cgroup.{,l}a

rm -f %{buildroot}%{_libdir}/*.{,l}a

rm -f %{buildroot}%{_libdir}/libcgroupfortesting.*

rm -f %{buildroot}%{_mandir}/man5/cgred.conf.5*
rm -f %{buildroot}%{_mandir}/man5/cgrules.conf.5*
rm -f %{buildroot}%{_mandir}/man8/cgrulesengd.8*

# install unit and sysconfig files
install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/
install -d %{buildroot}%{_sysconfdir}/sysconfig

%check
%if %{with tests}
make -C tests/gunit check
%endif

%post -n %{mname}
%_post_service cgconfig

%preun -n %{mname}
%_preun_service cgconfig

%triggerun -- cgroup < 0.41-6
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply cgconfig
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save cgconfig >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del cgconfig >/dev/null 2>&1 || :
/bin/systemctl try-restart cgconfig.service >/dev/null 2>&1 || :


%files -n %{mname}
%license COPYING
%doc README README_systemd README.Mageia
%config(noreplace) %{_sysconfdir}/sysconfig/cgconfig
%config(noreplace) %{_sysconfdir}/cgconfig.conf
%config(noreplace) %{_sysconfdir}/cgrules.conf
%config(noreplace) %{_sysconfdir}/cgsnapshot_allowlist.conf
%config(noreplace) %{_sysconfdir}/cgsnapshot_denylist.conf
%{_mandir}/man[158]/*.[158]*
%{_bindir}/cgcreate
%{_bindir}/cgget
%{_bindir}/cgset
%{_bindir}/cgxget
%{_bindir}/cgxset
%{_bindir}/cgdelete
%{_bindir}/lscgroup
%{_bindir}/lssubsys
%{_sbindir}/cgconfigparser
%{_bindir}/cgsnapshot
%{_bindir}/cgclassify
%{_bindir}/libcgroup_systemd_idle_thread
%attr(0755, root, root) %{_bindir}/cgexec
%{_unitdir}/cgconfig.service

%files -n pam_%{mname}
%license COPYING
%doc README
%attr(0755,root,root) %{_libdir}/security/pam_cgroup.so

%files -n %{libname}
%license COPYING
%doc README
%{_libdir}/lib%{mname}.so.%{major}{,.*}

%files -n %{devname}
%license COPYING
%doc README
%{_includedir}/libcgroup.h
%{_includedir}/libcgroup/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{mname}.so
