%define major		8
%define libname		%mklibname cryptopp %{major}
%define develname	%mklibname cryptopp -d

%define fver		%(echo %version |sed s/\\\\.//g)

%ifarch %{arm}
%define enable_tests	0
%else
%define enable_tests	1
%endif

Name:		libcryptopp
Version:	8.9.0
Release:	%mkrel 1
Summary:	C++ class library of cryptographic schemes
License:	Boost Software License 1.0
Group:		System/Libraries
URL:		https://www.cryptopp.com/
# https://www.cryptopp.com/cryptopp%%{fver}.zip
Source0:	https://github.com/weidai11/cryptopp/releases/download/CRYPTOPP_8_9_0/cryptopp%{fver}.zip
Source1:	cryptopp.pc
Source2:	cryptest.1

BuildRequires:	doxygen

%description
Crypto++ Library is a C++ class library of cryptographic schemes.
Currently the library consists of the following features:

    * AES(Rijndael) and AES candidates: RC6, MARS, Twofish, Serpent,
      CAST-256
    * other symmetric block ciphers: IDEA, DES, Triple-DES (DES-EDE2
      and DES-EDE3), DESX (DES-XEX3), RC2, RC5, Blowfish, TEA, XTEA,
      SAFER, 3-WAY, GOST, SHARK, CAST-128, Square, Skipjack, Camellia,
      SHACAL-2
    * generic block cipher modes: ECB, CBC, CBC ciphertext stealing
      (CTS), CFB, OFB, counter mode (CTR)
    * stream ciphers: Salsa20, Panama, ARC4, SEAL, WAKE, WAKE-OFB,
      BlumBlumShub
    * public-key cryptography: RSA, DSA, ElGamal, Nyberg-Rueppel (NR),
      Rabin, Rabin-Williams (RW), LUC, LUCELG, DLIES (variants of
      DHAES), ESIGN
    * padding schemes for public-key systems: PKCS#1 v2.0, OAEP, PSS,
      PSSR, IEEE P1363 EMSA2 and EMSA5
    * key agreement schemes: Diffie-Hellman (DH), Unified
      Diffie-Hellman (DH2), Menezes-Qu-Vanstone (MQV), LUCDIF, XTR-DH
    * elliptic curve cryptography: ECDSA, ECNR, ECIES, ECDH, ECMQV
    * one-way hash functions: SHA-1, MD2, MD4, MD5, HAVAL, RIPEMD-128,
      RIPEMD-256, RIPEMD-160, RIPEMD-320, Tiger, SHA-2 (SHA-224,
      SHA-256, SHA-384, and SHA-512), Panama, WHIRLPOOL
    * message authentication codes: MD5-MAC, HMAC, XOR-MAC, CBC-MAC,
      DMAC, Two-Track-MAC
    * cipher constructions based on hash functions: Luby-Rackoff, MDC
    * pseudo random number generators (PRNG): ANSI X9.17 appendix C,
      PGP's RandPool
    * password based key derivation functions: PBKDF1 and PBKDF2 from
      PKCS #5
    * Shamir's secret sharing scheme and Rabin's information dispersal
      algorithm (IDA)
    * DEFLATE (RFC 1951) compression/decompression with gzip (RFC
      1952) and zlib (RFC 1950) format support
    * fast multi-precision integer (bignum) and polynomial operations,
    * finite field arithmetics, including GF(p) and GF(2^n)
    * prime number generation and verification
    * various miscellaneous modules such as base 64 coding and 32-bit CRC


%package -n %{libname}
Group:		System/Libraries
Summary:	Base shared library part of %{name}
Provides:	%{name} = %{version}-%{release}

%description -n %{libname}
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{develname}
Summary:	Header files and development documentation for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	cryptopp-devel = %{version}-%{release}

%description -n %{develname}
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the header files and development documentation
for %{name}.

%package progs
Summary:	Programs for manipulating %{name} routines
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	cryptopp-progs = %{version}-%{release}

%description progs
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains programs for manipulating %{name} routines.

%prep
%autosetup -c -p1

perl -pi -e 's/\r$//g' License.txt Readme.txt

%build

# GCC 12 requires -fno-devirtualize
# https://github.com/weidai11/cryptopp/issues/1141

# Disable SSE2/3/4 on i586
%ifarch %ix86
%global crypto_cpp_flags "-DCRYPTOPP_DISABLE_ASM"
%else
%global crypto_cpp_flags %nil
%endif

%make_build -f	GNUmakefile \
		CXXFLAGS="%{optflags} -DNDEBUG -fPIC -DPIC -fno-devirtualize %{crypto_cpp_flags}" \
		LDFLAGS="%{ldflags}" \
		LDLIBS="-lpthread" \
		shared cryptest.exe
doxygen

%install
%make_install PREFIX="%{_prefix}" LIBDIR="%{_libdir}"

#we don't want these
find %{buildroot} -name '*.a' -delete

# Install the pkg-config file
install -D -m644 %{SOURCE1} %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc

# Install the man page
install -D -m644 %{SOURCE2} %{buildroot}%{_mandir}/man1/cryptest.1

# Fill in the variables
sed -i "s|@PREFIX@|%{_prefix}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@LIBDIR@|%{_libdir}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@INCLUDEDIR@|%{_includedir}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@VERSION@|%{version}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc

# Rename cryptest
mv %{buildroot}%{_bindir}/cryptest.exe %{buildroot}%{_bindir}/cryptest

%check
%if %{enable_tests}
./cryptest.exe v
%endif

%files -n %{libname}
%doc Readme.txt
%license  License.txt
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc html-docs/*
%{_includedir}/cryptopp/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/cryptopp.pc

%files progs
%{_bindir}/cryptest
%{_datadir}/cryptopp/
%{_mandir}/man1/cryptest.1*
