# WARNING: This package is synced with FC

%global _hardened_build 1

%define major   2
%define libname %mklibname cupsfilters %{major}
%define devname %mklibname cupsfilters -d

Name:           libcupsfilters
Version:        2.1.1
Release:        %mkrel 1
Summary:        Library for developing printing filters
Group:          System/Printing
# the CUPS exception text is the same as LLVM exception, so using that name with
# agreement from legal team
# https://lists.fedoraproject.org/archives/list/legal@lists.fedoraproject.org/message/A7GFSD6M3GYGSI32L2FC5KB22DUAEQI3/
License:        Apache-2.0 WITH LLVM-exception
URL:            https://github.com/OpenPrinting/libcupsfilters
Source0:        %{URL}/releases/download/%{version}/%{name}-%{version}.tar.gz


# Patches


# for generating configure and Makefile scripts in autogen.h
BuildRequires:  autoconf
# for generating configure and Makefile scripts in autogen.h
BuildRequires:  automake
# font for test script
BuildRequires:  fonts-ttf-dejavu
# most filter functions written in C
BuildRequires:  gcc
# pdftopdf written in C++
BuildRequires:  gcc-c++
# for generating configure and Makefile scripts in autogen.h
BuildRequires:  gettext-devel
# we use gs binary in filter functions, so it could be only runtime
# require, but there is a check in configure, which turns off GS
# support in case the binary is not found, so the binary has to be in
# buildroot
BuildRequires:  ghostscript >= 10.0.0
# for autosetup
BuildRequires:  git-core
# for generating configure and Makefile scripts in autogen.h
BuildRequires:  libtool
# uses Makefiles
BuildRequires:  make
# for pkg-config in configure and in SPEC file
BuildRequires:  pkgconf-pkg-config
# CUPS and IPP API functions
BuildRequires:  pkgconfig(cups) >= 2.2.2
# for communication with colord
BuildRequires:  pkgconfig(dbus-1)
# font support - configuration and customization
BuildRequires:  pkgconfig(fontconfig)
# color management engine in rastering filter functions
BuildRequires:  pkgconfig(lcms2)
# used for getting image resolution from images - they have
# EXIF data in them and library accesses it
BuildRequires:  pkgconfig(libexif)
# for jpeg file format support
BuildRequires:  pkgconfig(libjpeg)
# for png file format support
BuildRequires:  pkgconfig(libpng)
# for pdf filter functions
BuildRequires:  pkgconfig(libqpdf) >= 10.3.2
# for tiff image support
BuildRequires:  pkgconfig(libtiff-4)
# for pdftoraster filter
BuildRequires:  pkgconfig(poppler-cpp)

# have a fallback for fonts in texttopdf filter function (bz#1070729)
# but make it weak, so other monospace font can be used if requested
Recommends:     fonts-ttf-liberation

# we communicate with colord regarding color profiles
Requires:       colord
# for directory ownership of:
# /usr/share/cups
# /usr/share/cups/data
Requires:       cups-filesystem
# we call gs command in filter functions
Requires:       ghostscript >= 10.0.0


%description
Libcupsfilters provides a library, which implements common functions used
in cups-browsed daemon and printing filters, and additional files
as banner templates and character sets. The filters are used in CUPS daemon
and in printer applications.


%package -n %{libname}
Summary:        Library for developing printing filters
Group:          System/Libraries

%description -n %{libname}
Libcupsfilters provides a library, which implements common functions used
in cups-browsed daemon and printing filters, and additional files
as banner templates and character sets. The filters are used in CUPS daemon
and in printer applications.


%package -n %{devname}
Summary:        Development files for libcupsfilters
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       cupsfilters-devel = %{version}-%{release}

# remove once CentOS Stream 10 is released
Conflicts:      %{_lib}cups-filters-devel < 2.0
# remove once CentOS Stream 10 is released
#Obsoletes:      %%{_lib}cups-filters-devel < 2.0
# c2esp and perl-Net-CUPS requires cups-filters-devel
# remove once CentOS Stream 10 is released
#Provides:       %%{_lib}cups-filters-devel = %%{version}-%%{release}

%description -n %{devname}
Development files for OpenPrinting cupsfilters library.


%prep
%autosetup -S git


%build
# to get configure script
./autogen.sh

%configure --disable-mutool \
           --disable-rpath \
           --disable-silent-rules \
           --disable-static \
           --enable-dbus

# fix rpmlint error about linking to libraries, but not actually using their functions
# it happens when the required libraries uses pkgconfig - pkgconfig file doesn't know
# which specific functions our binary calls, so it tells us to link against every
# possibilities
# https://fedoraproject.org/wiki/Common_Rpmlint_issues#unused-direct-shlib-dependency
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

%make_build


%install
%make_install

find %{buildroot} -name '*.la' -delete

mkdir -p %{buildroot}%{_pkgdocdir}/fontembed/
install -p -m 0644 cupsfilters/fontembed/README %{buildroot}%{_pkgdocdir}/fontembed/README

# remove .odt files (we have their .pdf versions)
rm -f %{buildroot}%{_datadir}/cups/data/*.odt

# remove redundant files
rm -f %{buildroot}%{_pkgdocdir}/{INSTALL.md,ABOUT-NLS}

# license related files are already under /usr/share/licenses
rm -f %{buildroot}%{_pkgdocdir}/{LICENSE,COPYING,NOTICE}


%check
make check


%files
%license COPYING LICENSE NOTICE
%dir %{_datadir}/cups/banners
%{_datadir}/cups/banners/classified
%{_datadir}/cups/banners/confidential
%{_datadir}/cups/banners/form
%{_datadir}/cups/banners/secret
%{_datadir}/cups/banners/standard
%{_datadir}/cups/banners/topsecret
%{_datadir}/cups/banners/unclassified
%dir %{_datadir}/cups/charsets
%{_datadir}/cups/charsets/pdf.utf-8
%{_datadir}/cups/charsets/pdf.utf-8.heavy
%{_datadir}/cups/charsets/pdf.utf-8.simple
%{_datadir}/cups/data/classified.pdf
%{_datadir}/cups/data/confidential.pdf
%{_datadir}/cups/data/default-testpage.pdf
%{_datadir}/cups/data/default.pdf
%{_datadir}/cups/data/form_english.pdf
%{_datadir}/cups/data/form_russian.pdf
%{_datadir}/cups/data/secret.pdf
%{_datadir}/cups/data/standard.pdf
%{_datadir}/cups/data/testprint
%{_datadir}/cups/data/topsecret.pdf
%{_datadir}/cups/data/unclassified.pdf
%doc AUTHORS CHANGES.md CHANGES-1.x.md README.md
%dir %{_docdir}/%{name}/fontembed
%{_docdir}/%{name}/fontembed/README

%files -n %{libname}
%license COPYING LICENSE NOTICE
%{_libdir}/libcupsfilters.so.%{major}{,.*}

%files -n %{devname}
%{_docdir}/%{name}/CONTRIBUTING.md
%{_docdir}/%{name}/DEVELOPING.md
%dir %{_includedir}/cupsfilters
%{_includedir}/cupsfilters/*
%{_libdir}/libcupsfilters.so
%{_libdir}/pkgconfig/libcupsfilters.pc
