%global toolchain clang

# Opt out of https://fedoraproject.org/wiki/Changes/fno-omit-frame-pointer
# https://bugzilla.redhat.com/show_bug.cgi?id=2158587
%undefine _include_frame_pointers

%global maj_ver 19
%global libcxx_version %{maj_ver}.1.3
#global rc_ver 4
%global libcxx_srcdir libcxx-%{libcxx_version}%{?rc_ver:rc%{rc_ver}}.src
%global libcxxabi_srcdir libcxxabi-%{libcxx_version}%{?rc_ver:rc%{rc_ver}}.src
%global libunwind_srcdir libunwind-%{libcxx_version}%{?rc_ver:rc%{rc_ver}}.src

%define major        1
%define libname      %mklibname cxx %{major}
%define devname      %mklibname cxx -d
%define devname_s    %mklibname cxx -d -s

%define libcxxabi    %mklibname cxxabi %{major}
%define libcxxabi_d  %mklibname cxxabi -d
%define libcxxabi_s  %mklibname cxxabi -d -s

%define libunwind    %mklibname unwind %{major}
%define libunwind_d  %mklibname llvm-unwind -d
%define libunwind_s  %mklibname llvm-unwind -d -s

Name:		libcxx
Version:	%{libcxx_version}%{?rc_ver:~rc%{rc_ver}}
Release:	%mkrel 2
Summary:	C++ standard library targeting C++11
Group:		System/Libraries
License:	Apache-2.0 WITH LLVM-exception OR MIT OR NCSA
URL:		https://libcxx.llvm.org/
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/%{libcxx_srcdir}.tar.xz
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/%{libcxx_srcdir}.tar.xz.sig
Source2:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/%{libcxxabi_srcdir}.tar.xz
Source3:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/%{libcxxabi_srcdir}.tar.xz.sig
Source4:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/%{libunwind_srcdir}.tar.xz
Source5:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/%{libunwind_srcdir}.tar.xz.sig
Source6:	release-keys.asc
Source7:	CMakeLists.txt
Source8:	https://github.com/llvm/llvm-project/raw/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/runtimes/cmake/Modules/HandleFlags.cmake
Source9:	https://github.com/llvm/llvm-project/raw/llvmorg-%{libcxx_version}%{?rc_ver:-rc%{rc_ver}}/runtimes/cmake/Modules/WarningFlags.cmake

Patch0: standalone.patch
# The cmake dependencies for this target are somehow broken upstream.
# However, the libcxx.imp file is only needed for running include-what-you-use.
Patch1: do-not-install-libcxx.imp.patch

BuildRequires:	clang llvm-devel llvm-cmake-utils cmake ninja-build
# We need python3-devel for %%py3_shebang_fix
BuildRequires:	python3-devel

# For documentation
BuildRequires:	python3-sphinx

# For origin certification
BuildRequires:	gnupg2

%description
libc++ is a new implementation of the C++ standard library, targeting C++11.

%package -n %{libname}
Summary:	C++ standard library targeting C++11
Group:		System/Libraries

# to ease manually install needed by some steam games (mga#25825)
Provides:	libcxx1 = %{version}-%{release}
Provides:	libc++1 = %{version}-%{release}
Provides:	libcxx1%{?_isa} = %{version}-%{release}
Provides:	libc++1%{?_isa} = %{version}-%{release}

%description -n %{libname}
libc++ is a new implementation of the C++ standard library, targeting C++11.

%package -n %{devname}
Summary:	Headers and libraries for libcxx devel
Group:		Development/C++
Requires:	%{libname}%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	llvm-%{name}-devel = %{version}-%{release}
Requires:	%{libcxxabi_d} = %{version}-%{release}

%description -n %{devname}
Headers and libraries for libcxx devel.

%package -n %{devname_s}
Summary:	Static libraries for libcxx
Group:		Development/C++
Requires:	%{devname} = %{version}-%{release}
Provides:	%{name}-static = %{version}-%{release}

%description -n %{devname_s}
Static libraries for libcxx.

%package -n %{libcxxabi}
Summary:	Low level support for a standard C++ library
Group:		System/Libraries

# to ease manually install needed by some steam games (mga#25825)
Provides:	libcxxabi1 = %{version}-%{release}
Provides:	libc++abi1 = %{version}-%{release}
Provides:	libcxxabi1%{?_isa} = %{version}-%{release}
Provides:	libc++abi1%{?_isa} = %{version}-%{release}

%description -n %{libcxxabi}
libcxxabi provides low level support for a standard C++ library.

%package -n %{libcxxabi_d}
Summary:	Headers and libraries for libcxxabi devel
Group:		Development/C++
Requires:	%{libcxxabi}%{?_isa} = %{version}-%{release}
Provides:	%{name}abi-devel = %{version}-%{release}
Provides:	llvm-%{name}abi-devel = %{version}-%{release}

%description -n %{libcxxabi_d}
Headers and libraries for libcxxabi devel.

%package -n %{libcxxabi_s}
Summary:	Static library for libcxxabi
Group:		Development/C++
Requires:	%{libcxxabi_d} = %{version}-%{release}
Provides:	%{name}abi-static = %{version}-%{release}

%description -n %{libcxxabi_s}
Static library for libcxxabi.

%package -n %{libunwind}
Summary:	LLVM libunwind
Group:		System/Libraries

%description -n %{libunwind}
LLVM libunwind is an implementation of the interface defined by the HP libunwind
project. It was contributed Apple as a way to enable clang++ to port to
platforms that do not have a system unwinder. It is intended to be a small and
fast implementation of the ABI, leaving off some features of HP's libunwind
that never materialized (e.g. remote unwinding).

%package -n %{libunwind_d}
Summary:	LLVM libunwind development files
Group:		Development/C
Provides:	libunwind(major) = %{maj_ver}
Requires:	%{libunwind}%{?_isa} = %{version}-%{release}
Provides:	llvm-libunwind-devel = %{version}-%{release}

Obsoletes:	%{_lib}llvm-+unwind-devel < 15.0.6-2

%description -n %{libunwind_d}
Unversioned shared library for LLVM libunwind.

%package -n %{libunwind_s}
Summary:	Static library for LLVM libunwind
Group:		Development/C
Requires:	%{libunwind_d} = %{version}-%{release}
Provides:	llvm-libunwind-static = %{version}-%{release}

%description -n %{libunwind_s}
Static library for LLVM libunwind.

%package -n llvm-libunwind-doc
Summary:    libunwind documentation
Group:      Documentation
# jquery.js and langage_data.js are used in the HTML doc and under BSD License
License:    BSD AND (Apache-2.0 WITH LLVM-exception OR NCSA OR MIT)
BuildArch:  noarch

%description -n llvm-libunwind-doc
Documentation for LLVM libunwind.

%prep
%{gpgverify} --keyring='%{SOURCE6}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%{gpgverify} --keyring='%{SOURCE6}' --signature='%{SOURCE3}' --data='%{SOURCE2}'
%{gpgverify} --keyring='%{SOURCE6}' --signature='%{SOURCE5}' --data='%{SOURCE4}'

%setup -T -q -b 0 -n %{libcxx_srcdir}
%setup -T -q -b 2 -n %{libcxxabi_srcdir}
%setup -T -q -b 4 -n %{libunwind_srcdir}
%setup -T -c -n build

cp %{SOURCE7} .
mv ../%{libcxx_srcdir} libcxx
mv ../%{libcxxabi_srcdir} libcxxabi
mv ../%{libunwind_srcdir} libunwind
mkdir -p runtimes/cmake/Modules
cp %{SOURCE8} %{SOURCE9} runtimes/cmake/Modules/
%autopatch -p1

%py3_shebang_fix libcxx/utils/

%build

# Copy CFLAGS into ASMFLAGS, so -fcf-protection is used when compiling assembly files.
export ASMFLAGS=$CFLAGS

%cmake -GNinja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_MODULE_PATH="%{_libdir}/cmake/llvm;%{_datadir}/llvm/cmake/Modules" \
	-DCMAKE_POSITION_INDEPENDENT_CODE=ON \
%if 0%{?__isa_bits} == 64
	-DLIBCXX_LIBDIR_SUFFIX:STRING=64 \
	-DLIBCXXABI_LIBDIR_SUFFIX:STRING=64 \
	-DLIBUNWIND_LIBDIR_SUFFIX:STRING=64 \
%endif
	-DLIBCXX_INCLUDE_BENCHMARKS=OFF \
	-DLIBCXX_STATICALLY_LINK_ABI_IN_STATIC_LIBRARY=ON \
	-DLIBCXX_ENABLE_ABI_LINKER_SCRIPT=ON \
	-DLIBCXXABI_USE_LLVM_UNWINDER=OFF \
	-DLLVM_BUILD_DOCS=ON \
	-DLLVM_ENABLE_SPHINX=ON \
	-DLIBUNWIND_INCLUDE_DOCS=ON \
	-DLIBUNWIND_INSTALL_INCLUDE_DIR=%{_includedir}/llvm-libunwind \
	-DLIBUNWIND_INSTALL_SPHINX_HTML_DIR=%{_pkgdocdir}/html

%cmake_build

%install

%cmake_install

# We can't install the unversionned path on default location because that would conflict with
# https://src.fedoraproject.org/rpms/libunwind
#
# The versionned path has a different soname (libunwind.so.1 compared to
# libunwind.so.8) so they can live together in %%{_libdir}
#
# ABI wise, even though llvm-libunwind's library is named libunwind, it doesn't
# have the exact same ABI as gcc's libunwind (it actually provides a subset).
rm %{buildroot}%{_libdir}/libunwind.so
mkdir -p %{buildroot}/%{_libdir}/llvm-unwind/

pushd %{buildroot}/%{_libdir}/llvm-unwind
ln -s ../libunwind.so.1.0 libunwind.so
popd

rm %{buildroot}%{_pkgdocdir}/html/.buildinfo

%files -n %{libname}
%license libcxx/LICENSE.TXT
%doc libcxx/CREDITS.TXT libcxx/TODO.TXT
%{_libdir}/libc++.so.%{major}{,.*}

%files -n %{devname}
%dir %{_includedir}/c++
%{_includedir}/c++/v1/
%exclude %{_includedir}/c++/v1/cxxabi.h
%exclude %{_includedir}/c++/v1/__cxxabi_config.h
%{_libdir}/libc++.so
%{_libdir}/libc++.modules.json
%{_datadir}/libc++/v1/*

%files -n %{devname_s}
%license libcxx/LICENSE.TXT
%{_libdir}/libc++.a
%{_libdir}/libc++experimental.a

%files -n %{libcxxabi}
%license libcxxabi/LICENSE.TXT
%doc libcxxabi/CREDITS.TXT
%{_libdir}/libc++abi.so.%{major}{,.*}

%files -n %{libcxxabi_d}
%{_includedir}/c++/v1/cxxabi.h
%{_includedir}/c++/v1/__cxxabi_config.h
%{_libdir}/libc++abi.so

%files -n %{libcxxabi_s}
%{_libdir}/libc++abi.a

%files -n %{libunwind}
%license libunwind/LICENSE.TXT
%{_libdir}/libunwind.so.%{major}{,.*}

%files -n %{libunwind_d}
%dir %{_includedir}/llvm-libunwind
%{_includedir}/llvm-libunwind/__libunwind_config.h
%{_includedir}/llvm-libunwind/libunwind.h
%{_includedir}/llvm-libunwind/libunwind.modulemap
%{_includedir}/llvm-libunwind/mach-o/compact_unwind_encoding.h
%{_includedir}/llvm-libunwind/unwind.h
%{_includedir}/llvm-libunwind/unwind_arm_ehabi.h
%{_includedir}/llvm-libunwind/unwind_itanium.h
%dir %{_libdir}/llvm-unwind
%{_libdir}/llvm-unwind/libunwind.so

%files -n %{libunwind_s}
%{_libdir}/libunwind.a

%files -n llvm-libunwind-doc
%license libunwind/LICENSE.TXT
%doc %{_pkgdocdir}/html
