%define major		3
%define libname		%mklibname gd %{major}
%define develname	%mklibname gd -d
%define staticdevelname	%mklibname gd -d -s

Summary:	A library used to create PNG, JPEG, or WBMP images
Name:		libgd
Version:	2.3.3
Release:	%mkrel 9
License:	BSD-like
Group:		System/Libraries
URL:		https://www.libgd.org/
Source0:	https://github.com/libgd/libgd/releases/download/gd-%{version}/%{name}-%{version}.tar.xz
# Needed by PHP see https://github.com/libgd/libgd/pull/766
Patch0:		libgd-flip.patch
# Missing header see https://github.com/libgd/libgd/pull/766
Patch1:		libgd-iostream.patch
Patch2:		libgd-disable-heif-tests.patch
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freetype2) >= 9.8.3
BuildRequires:	pkgconfig(imagequant)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libwebp)
BuildRequires:	pkgconfig(xpm)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(raqm)
BuildRequires:	pkgconfig(libavif)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	gettext-devel
# for fontconfig/basic test
BuildRequires:	fonts-ttf-liberation
BuildRequires:	mercurial

%description
gd is a graphics library. It allows your code to quickly draw images complete
with lines, arcs, text, multiple colors, cut and paste from other images, and
flood fills, and write out the result as a PNG or JPEG file. This is
particularly useful in World Wide Webapplications, where PNG and JPEG are two
of the formats accepted for in-line images by most browsers.

gd is not a paint program. If you are looking for a paint program, you are
looking in the wrong place. If you are not a programmer, you are looking in the
wrong place.

gd does not provide for every possible desirable graphics operation. It is not
necessary or desirable for gd to become a kitchen-sink graphics package, but
version 1.7.3 incorporates most of the commonly requested features for an 8-bit
2D package.

%package -n	%{libname}
Summary:	A library used to create PNG, JPEG, or WBMP images
Group:		System/Libraries
Provides:	gd = %{version}-%{release}

%description -n	%{libname}
gd is a graphics library. It allows your code to quickly draw images complete
with lines, arcs, text, multiple colors, cut and paste from other images, and
flood fills, and write out the result as a PNG or JPEG file. This is
particularly useful in World Wide Webapplications, where PNG and JPEG are two
of the formats accepted for in-line images by most browsers.

gd is not a paint program. If you are looking for a paint program, you are
looking in the wrong place. If you are not a programmer, you are looking in the
wrong place.

gd does not provide for every possible desirable graphics operation. It is not
necessary or desirable for gd to become a kitchen-sink graphics package, but
version 1.7.3 incorporates most of the commonly requested features for an 8-bit
2D package.

This package contains the library needed to run programs dynamically linked
with libgd.

%package -n	%{develname}
Summary:	The development libraries and header files for gd
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	gd-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
These are the development libraries and header files for gd, the .png and .jpeg
graphics library. If you're installing the gd graphics library, you'll probably
want to install gd-devel.

%package -n	%{staticdevelname}
Summary:	Static GD library
Group:		Development/C
Requires:	%{develname} = %{version}
Provides:	libgd-static-devel = %{version}-%{release}
Provides:	gd-static-devel = %{version}-%{release}

%description -n	%{staticdevelname}
This package contains static gd library.

%package -n	gd-utils
Summary:	The Utils files for gd
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description -n	gd-utils
gd is a graphics library. It allows your code to quickly draw images complete
with lines, arcs, text, multiple colors, cut and paste from other images, and
flood fills, and write out the result as a PNG or JPEG file. This is
particularly useful in World Wide Webapplications, where PNG and JPEG are two
of the formats accepted for in-line images by most browsers.

gd is not a paint program. If you are looking for a paint program, you are
looking in the wrong place. If you are not a programmer, you are looking in the
wrong place.

gd does not provide for every possible desirable graphics operation. It is not
necessary or desirable for gd to become a kitchen-sink graphics package, but
version 1.7.3 incorporates most of the commonly requested features for an 8-bit
2D package.

This package contains various utilities utilizing the gd library.

%prep
%autosetup -p1 -n libgd-%{version}

%build
%ifarch %{ix86}
# see https://github.com/libgd/libgd/issues/242
CFLAGS="-msse -mfpmath=sse"
%endif

%ifarch aarch64
# workaround for https://bugzilla.redhat.com/show_bug.cgi?id=1359680
CFLAGS="$CFLAGS -ffp-contract=off"
%endif

# Provide a correct default font search path
CFLAGS="$CFLAGS -DDEFAULT_FONTPATH='\"\
/usr/share/fonts/TTF:\
/usr/share/fonts/TTF/dejavu:\
/usr/share/fonts/default/Type1:\
/usr/share/fonts/fonts/Type1:\
/usr/share/fonts/TTF/liberation\"'"

export CFLAGS="%{optflags} $CFLAGS"
autoreconf -fi
%configure --without-libiconv-prefix --enable-gd-formats
%make_build

%install
%make_install

%multiarch_includes %{buildroot}%{_includedir}/gd.h

install -m 0644 src/gdhelpers.h %{buildroot}%{_includedir}/


%check
# Workaround to https://github.com/libgd/libgd/issues/763
export TMPDIR=/tmp

%ifarch %{ix86}
# See https://github.com/libgd/libgd/issues/359
XFAIL_TESTS="gdimagegrayscale/basic $XFAIL_TESTS"
%endif

# When libg compiled with libraqm enabled (triggered by pkgconfig(raqm)
# in BuildRequires), this test fails. Skip it.
# See https://github.com/libgd/libgd/issues/613
XFAIL_TESTS="gdimagestringft/gdimagestringft_bbox $XFAIL_TESTS"

export XFAIL_TESTS

: Upstream test suite
make check ||:

%files -n %{libname}
%doc docs/README.TXT
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/*.so
%{_libdir}/pkgconfig/gdlib.pc
%{_includedir}/*.h
%multiarch %{multiarch_includedir}/*.h

%files -n %{staticdevelname}
%{_libdir}/lib*.a

%files -n gd-utils
%{_bindir}/annotate
%{_bindir}/bdftogd
%{_bindir}/gd2copypal
%{_bindir}/gd2topng
%{_bindir}/gdparttopng
%{_bindir}/gdtopng
%{_bindir}/pngtogd
%{_bindir}/pngtogd2
%{_bindir}/webpng
%{_bindir}/gd2togif
%{_bindir}/gdcmpgif
%{_bindir}/giftogd2
