# Note - push to core and tainted

%global pixbuf_moduledir	%(pkg-config gdk-pixbuf-2.0 --variable=gdk_pixbuf_moduledir)

%define         major      1
%define         libname    %mklibname heif %{major}
%define         pluginname %mklibname heif-plugins
%define         devname    %mklibname heif -d


#define         extra 20190816_gite6ecace

%define build_x265 0
%if "%distro_section" == "tainted"
%global build_x265 1
%endif

%define         rel 1

Name:           libheif
Version:        1.19.7
Release:        %mkrel %{?extra:0.%{extra}.}%{rel}
Summary:        libheif is a ISO/IEC 23008-12:2017 HEIF file format decoder and encoder
Group:          System/Libraries
License:        LGPLv2 and GPLv2
URL:            https://www.libheif.org/
%if 0%{?extra}
Source0:        https://github.com/strukturag/libheif/archive/master/%{name}-%{version}%{?extra:-%{extra}}.tar.gz
%define dldir master
%else
Source0:        https://github.com/strukturag/libheif/releases/download/v%{version}/%{name}-%{version}.tar.gz
%define dldir %{version}
%endif

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(libde265)
%if %{build_x265}
BuildRequires:  pkgconfig(x265)
%endif
Requires:       libde265
BuildRequires:  pkgconfig(aom)
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(kvazaar)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(rav1e)
BuildRequires:  pkgconfig(SvtAv1Enc)
BuildRequires:  doxygen
BuildRequires:  ffmpeg-devel

%description
Libheif is an ISO/IEC 23008-12:2017 HEIF file format decoder and encoder.

HEIF is a new image file format that can potentially employ HEVC
(h.265) image coding for efficient compression ratios, but not
only. Alternative codecs for, e.g., AVC and JPEG, PNG can be used.

%if %{build_x265}
Because libheif makes use of libde265 for the actual image decoding
and x265 for encoding, the version using these codecs is impaired by
patents and is in the tainted repository.
%endif

%package        -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       heif-devel = %{version}-%{release}

%description    -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.

%package        -n %{libname}
Summary:        Shared libraries for %{name}
Group:          System/Libraries
Recommends:     %{name}-plugins%{?_isa} >= %{version}-%{release}
Requires:       heif-pixbuf-loader%{?_isa} >= %{version}-%{release}

%description    -n %{libname}
Shared libraries for %{name}.

%package        -n heif-pixbuf-loader
Summary:        HEIF image loader for GTK+ applications
Group:          Development/Tools
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
Requires:       gdk-pixbuf2.0

Conflicts:      libheif < 1.17.6-4
Conflicts:      %{_lib}heif1 < 1.17.6-4

%description -n	heif-pixbuf-loader
Heif-pixbuf-loader contains a plugin to load HEIF images in GTK+ applications.

%package -n %{pluginname}
Summary:        Codec plugins for %{name}
Group:          System/Libraries
Provides:       %{name}-plugins%{?_isa} = %{version}-%{release}
Provides:       %{name}-plugins = %{version}-%{release}
Conflicts:      %{_lib}heif1 < 1.19.5-5

%description -n %{pluginname}
Codec backend plugins for %{name}.

%prep
%autosetup -n %{name}-%{dldir} -p1

%build
%cmake -GNinja \
       -DCMAKE_COMPILE_WARNING_AS_ERROR=OFF \
       -DENABLE_PLUGIN_LOADING=ON \
       -DWITH_AOM_DECODER=ON \
       -DWITH_AOM_DECODER_PLUGIN=OFF \
       -DWITH_AOM_ENCODER=ON \
       -DWITH_AOM_ENCODER_PLUGIN=OFF \
       -DWITH_DAV1D=ON \
       -DWITH_DAV1D_PLUGIN=ON \
       -DWITH_LIBDE265=ON \
       -DWITH_LIBDE265_PLUGIN=OFF \
       -DWITH_RAV1E=ON \
       -DWITH_RAV1E_PLUGIN=ON \
       -DWITH_SvtEnc=ON \
       -DWITH_SvtEnc_PLUGIN=ON \
%if 0%{?build_x265}
       -DWITH_X265=ON \
       -DWITH_X265_PLUGIN=OFF \
%else
       -DWITH_X265=OFF \
       -DWITH_X265_PLUGIN=OFF \
%endif
       -DWITH_JPEG_DECODER=ON \
       -DWITH_JPEG_DECODER_PLUGIN=ON \
       -DWITH_JPEG_ENCODER=ON \
       -DWITH_JPEG_ENCODER_PLUGIN=ON \
       -DWITH_UNCOMPRESSED_CODEC=ON \
       -DWITH_KVAZAAR=ON \
%if 0%{?build_x265}
       -DWITH_KVAZAAR_PLUGIN=ON \
%else
       -DWITH_KVAZAAR_PLUGIN=OFF \
%endif
       -DWITH_OpenJPEG_DECODER=ON \
       -DWITH_OpenJPEG_DECODER_PLUGIN=ON \
       -DWITH_OpenJPEG_ENCODER=ON \
       -DWITH_OpenJPEG_ENCODER_PLUGIN=ON \
       -DWITH_OPENJPH_ENCODER=OFF \
       -DWITH_FFMPEG_DECODER=ON \
       -DWITH_FFMPEG_DECODER_PLUGIN=ON \
       -DWITH_OpenH264_DECODER=OFF \
       -DWITH_OpenH264_DECODER_PLUGIN=OFF \
       -DWITH_UVG266=OFF \
       -DWITH_UVG266_PLUGIN=OFF \
       -DWITH_VVDEC=OFF \
       -DWITH_VVDEC_PLUGIN=OFF \
       -DWITH_VVENC=OFF \
       -DWITH_VVENC_PLUGIN=OFF
%cmake_build

%install
%cmake_install

%files
%doc README.md
%license COPYING
%{_bindir}/heif*
%{_mandir}/man1/heif*

%files -n %{libname}
%license COPYING
%dir %{_libdir}/%{name}
%{_libdir}/%{name}.so.%{major}
%{_libdir}/%{name}.so.%{version}

%files -n %{pluginname}
%{_libdir}/%{name}/libheif-dav1d.so
%{_libdir}/%{name}/libheif-ffmpegdec.so
%{_libdir}/%{name}/libheif-jpegdec.so
%{_libdir}/%{name}/libheif-jpegenc.so
%{_libdir}/%{name}/libheif-j2kdec.so
%{_libdir}/%{name}/libheif-j2kenc.so
%if 0%{?build_x265}
%{_libdir}/%{name}/libheif-kvazaar.so
%endif
%{_libdir}/%{name}/libheif-rav1e.so
%{_libdir}/%{name}/libheif-svtenc.so

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/*%{name}*.so
%{_libdir}/pkgconfig/libheif.pc
%{_libdir}/cmake/libheif/

%files -n heif-pixbuf-loader
%license COPYING
%{pixbuf_moduledir}/libpixbufloader-heif.so
%{_datadir}/thumbnailers/heif.thumbnailer
