%bcond_with doc

%define _smp_ncpus_max 4

Name:           libical
Version:        3.0.20
Release:        %mkrel 1
Summary:        An implementation of basic iCAL protocols
License:        LGPL-2.1-only OR MPL-2.0
Group:          System/Libraries
Url:            https://github.com/libical/libical
Source0:        https://github.com/libical/libical/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  cmake
%if %{with doc}
BuildRequires:  gtk-doc
%endif
BuildRequires:  icu-devel
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libxml++-2.6)

%description
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

#------------------------------------------------------

%define major 3
%define libname %mklibname ical %{major}

%package -n %{libname}
Summary:        Files for developing applications that use libical
Group:          System/Libraries

%description -n %{libname}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libname}
%{_libdir}/libical.so.%{major}{,.*}
%{_libdir}/libical_cxx.so.%{major}{,.*}

#------------------------------------------------------

%define girmajor 3.0
%define girname %mklibname ical-gir %{girmajor}

%package -n %{girname}
Summary:        GObject Introspection interface description for ICal
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Conflicts:      %{_lib}ical3 < 3.0.5-5

%description -n %{girname}
GObject Introspection interface description for ICal.

%files -n %{girname}
%{_libdir}/girepository-1.0/ICal-%{girmajor}.typelib

#------------------------------------------------------

%define libnamess %mklibname icalss %{major}

%package -n %{libnamess}
Summary:        Files for developing applications that use libical
Group:          System/Libraries

%description -n %{libnamess}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libnamess}
%{_libdir}/libicalss.so.%{major}{,.*}
%{_libdir}/libicalss_cxx.so.%{major}{,.*}

#------------------------------------------------------

%define libnameglib %mklibname ical-glib %{major}

%package -n %{libnameglib}
Summary:        Files for developing applications that use libical
Group:          System/Libraries

%description -n %{libnameglib}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libnameglib}
%{_libdir}/libical-glib.so.%{major}{,.*}

#------------------------------------------------------

%define girmajorglib 3.0
%define girnameglib %mklibname icalglib-gir %{girmajorglib}

%package -n %{girnameglib}
Summary:        GObject Introspection interface description for ICalGLib
Group:          System/Libraries
Requires:       %{libnameglib} = %{version}-%{release}
Conflicts:      %{_lib}ical-glib3 < 3.0.5-5

%description -n %{girnameglib}
GObject Introspection interface description for ICalGLib.

%files -n %{girnameglib}
%{_libdir}/girepository-1.0/ICalGLib-%{girmajorglib}.typelib

#------------------------------------------------------

%define libnamevcal %mklibname icalvcal %{major}

%package -n %{libnamevcal}
Summary:        Files for developing applications that use libical
Group:          System/Libraries

%description -n %{libnamevcal}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libnamevcal}
%{_libdir}/libicalvcal.so.%{major}{,.*}

#------------------------------------------------------

%define develname %mklibname ical -d

%package -n %{develname}
Summary:	Files for developing applications that use libical
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libnamess} = %{version}-%{release}
Requires:	%{libnamevcal} = %{version}-%{release}
Requires:	%{libnameglib} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Requires:	%{girnameglib} = %{version}-%{release}
Conflicts:	%{_lib}ical3 < 3.0.5-5
Conflicts:	%{_lib}ical-glib3 < 3.0.5-5

%description -n %{develname}
The header files and libtool library for
developing applications that use libical.

%files -n %{develname}
%doc TODO TEST THANKS
%doc doc/UsingLibical*
%if %{with doc}
%doc %{_datadir}/gtk-doc/html/%{name}-glib/
%endif
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_libdir}/cmake/LibIcal
%{_datadir}/gir-1.0/ICal-%{girmajor}.gir
%{_datadir}/gir-1.0/ICalGLib-%{girmajorglib}.gir
%{_datadir}/vala/vapi/libical-glib.vapi

#------------------------------------------------------

%prep
%autosetup -p1

%build
%cmake \
  -DICAL_ERRORS_ARE_FATAL:BOOL=false \
  -DGOBJECT_INTROSPECTION:BOOL=true \
  -DSHARED_ONLY:BOOL=true \
  -DENABLE_GTK_DOC:BOOL=%{?with_doc:true}%{?!with_doc:false} \
  -DICAL_GLIB_VAPI:BOOL=true

%cmake_build

%install
%cmake_install

# This is just a private build tool, not meant to be installed
rm %{buildroot}%{_libexecdir}/libical/ical-glib-src-generator
