%define	major		12
%define libname		%mklibname idn %{major}
%define develname	%mklibname idn -d

# this is needed to avoid make check failures
%define _disable_ld_as_needed 1

Summary:	Internationalized string processing library
Name:		libidn
Version:	1.43
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		https://www.gnu.org/software/libidn/
Source0:	https://ftp.gnu.org/gnu/libidn/%{name}-%{version}.tar.gz
Source1:	https://ftp.gnu.org/gnu/libidn/%{name}-%{version}.tar.gz.sig
BuildRequires:	texinfo
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	help2man
BuildRequires:	autoconf-archive
BuildRequires:	valgrind
BuildRequires:	javapackages-tools
BuildRequires:	java-devel
BuildRequires:	antlr
BuildRequires:	javapackages-local
BuildRequires:	mvn(com.google.guava:guava)
BuildRequires:	mvn(junit:junit)
# disable on arm for now. test it again on real hardware. qemu doesn't like it
%ifnarch %arm aarch64
BuildRequires:	mono-core
%endif

%description
GNU Libidn is an implementation of the Stringprep, Punycode and
IDNA specifications defined by the IETF Internationalized Domain
Names (IDN) working group, used for internationalized domain
names.

%package -n %{libname}
Summary:	Internationalized string processing library
Group:		System/Libraries

%description -n	%{libname}
GNU Libidn is an implementation of the Stringprep, Punycode and
IDNA specifications defined by the IETF Internationalized Domain
Names (IDN) working group, used for internationalized domain
names.

%package -n %{develname}
Summary:	Development files for the %{libname} library
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Provides:	idn-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	pkgconfig

%description -n	%{develname}
Development files for the %{libname} library.

%package -n idn
Summary:	Commandline interface to the %{libname} library
Group:		System/Servers

%description -n idn
This package provides the commandline interface to the
%{libname} library.

%package -n %{libname}-java
Summary:	Java support for the %{name}
Group:		Development/Java
Provides:	%{name}-java = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n %{libname}-java
Java support for the %{name}.


%package javadoc
Summary:       Javadoc for %{name}-java
BuildArch:     noarch

%description javadoc
This package contains javadoc for %{name}-java.


%ifnarch %arm aarch64
%package -n %{libname}-mono
Summary:	Mono support for the %{name}
Group:		Development/Other
Provides:	%{name}-mono = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n %{libname}-mono
Mono support for the %{name}.
%endif

%prep
%autosetup -p1

# Cleanup
find . -name '*.jar' -print -delete
find . -name '*.class' -print -delete

# Not available test dep
%pom_remove_dep com.google.caliper:caliper java/pom.xml.in
# Unused dependency
%pom_remove_dep com.google.code.findbugs:annotations java/pom.xml.in

%build
autoreconf -vfi
%configure \
	--disable-static \
	--enable-java \
	--disable-valgrind-tests \
%ifnarch %arm aarch64
	--enable-csharp=mono \
%endif
	--disable-rpath

%make_build

%check
# without RPATH this needs to be set to test the compiled library
export LD_LIBRARY_PATH=$(pwd)/lib/.libs
%make_build -C tests check VALGRIND=env

%install
%make_install

# fix "invalid-lc-messages-dir":
rm -rf %{buildroot}%{_datadir}/locale/en@*quot

%find_lang %{name}

#(tpg) really not needed... also got lzma'd :)

rm -rf %{buildroot}%{_infodir}/*.png*

# this fixes a file clash in a mixed arch env
mv %{buildroot}%{_infodir}/%{name}.info %{buildroot}%{_infodir}/%{libname}.info


# regenerate java documentation
rm -rf doc/java/*
%javadoc -d doc/java $(find java/src/main/java -name "*.java")
# generate maven depmap
rm -rf %{buildroot}%{_javadir}/libidn*.jar
%mvn_artifact java/pom.xml java/libidn-%{version}.jar
%mvn_file org.gnu.inet:libidn libidn
%mvn_install -J doc/java

%files -n idn -f %{name}.lang
%doc ChangeLog FAQ README THANKS
%{_bindir}/idn
%{_mandir}/man1/idn.1*
%{_datadir}/emacs/site-lisp/*.el

%files -n %{libname}
%{_libdir}/libidn.so.%{major}{,.*}
%{_infodir}/%{libname}.info*

%files -n %{develname}
%doc libc/example.c examples/README examples/Makefile.*
%{_libdir}/libidn.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

%files -n %{libname}-java -f .mfiles

%files javadoc -f .mfiles-javadoc
%license COPYING* java/LICENSE-2.0.txt

%ifnarch %arm aarch64
%files -n %{libname}-mono
%{_libdir}/*.dll
%endif
