%define major   1
%define libname %mklibname kolab %major

%define php_extdir %(php-config --extension-dir 2>/dev/null || echo %{_libdir}/php)
%{!?php_inidir: %global php_inidir %{_sysconfdir}/php.d/}

# Filter out private python and php libs. Does not work on EPEL5,
# therefor we use it conditionally
%{?filter_setup:
%filter_provides_in %{python2_sitearch}/.*\.so$
%filter_provides_in %{php_extdir}/.*\.so$
%filter_setup
}

# FTBFS on mga7
%global with_php 0

Name:           libkolab
Version:        1.0.2
Release:        %mkrel 10
Summary:        Kolab Object Handling Library
Group:          System/Servers
License:        LGPLv3+
URL:            https://cgit.kolab.org/libkolab
Source0:        https://cgit.kolab.org/%{name}/snapshot/%{name}-%{version}.tar.gz
Patch1:         Q_DECL_IMPORT.patch
Patch2:         libkolab-1.0.2-fix-FindSWIG.cmake.patch
Patch3:         libkolab-1.0.2-kdatetime.h.patch
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  libkolabxml-devel >= 1.0
%if 0%{?with_php}
BuildRequires:  php-devel
%endif
BuildRequires:  pkgconfig(python2)
BuildRequires:  php-cli
BuildRequires:  swig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  cmake
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5CalendarCore)
BuildRequires:  cmake(KF5CalendarUtils)
BuildRequires:  cmake(KF5Mime)
BuildRequires:  cmake(KF5AkonadiNotes)
BuildRequires:  cmake(KF5KDELibs4Support)

%description
The libkolab library is an advanced library to  handle Kolab objects.

%package -n %{libname}
Summary:        Kolab Object Handling Library
Group:          System/Libraries
Obsoletes:      %{name} < %version
%rename         %{_lib}kolab0

%description -n %{libname}
The libkolab library is an advanced library to handle Kolab objects.

%package devel
Summary:        Kolab library development headers
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       libkolabxml-devel >= 1.1.0

%description devel
Development headers for the Kolab object libraries.

%if 0%{?with_php}
%package -n php-kolab
Summary:        PHP Bindings for libkolab
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       php-kolabformat >= 1.0.0

%description -n php-kolab
PHP Bindings for libkolab.
%endif

%package -n python2-kolab
Summary:        Python 2 bindings for libkolab
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       python2-kolabformat >= 1.0.0

Obsoletes:      python-kolab < 1.0.2-9
Provides:       python-kolab = %{version}-%{release}

%description -n python2-kolab
Python 2 bindings for libkolab.

%prep
%setup -q
%autopatch -p1

%build
%cmake_qt5 \
    -DINCLUDE_INSTALL_DIR=%{_includedir} \
%if 0%{?with_php}
    -DPHP_BINDINGS=ON \
    -DPHP_INSTALL_DIR=%{php_extdir} \
%endif
    -DPYTHON_BINDINGS=ON \
    -DPYTHON_INSTALL_DIR=%{python2_sitearch}

%cmake_build

%install
%cmake_install

%if 0%{?with_php}
mkdir -p %{buildroot}%{_datadir}/php
mv %{buildroot}/%{php_extdir}/*.php %{buildroot}%{_datadir}/php/.

mkdir -p %{buildroot}/%{php_inidir}
cat >%{buildroot}/%{php_inidir}/kolab.ini <<EOF
extension=kolabcalendaring.so
extension=kolabicalendar.so
extension=kolabobject.so
extension=kolabshared.so
EOF

# Workaround for #2050
# We need to test first if needed for Mageia
#cat >%%{buildroot}/%%{php_inidir}/kolabdummy.ini <<EOF
#; Kolab libraries
#extension=dummy.so
#EOF
%endif

touch %{buildroot}%{python2_sitearch}/kolab/__init__.py


%check
pushd build/tests
./benchmarktest || :
./calendaringtest || :
./formattest || :
./freebusytest || :
./icalendartest || :
./kcalconversiontest || :
./upgradetest || :
popd

%files -n %{libname}
%{_libdir}/%{name}.so.%{major}
%{_libdir}/%{name}.so.%{major}.*

%files devel
%{_libdir}/%{name}.so
%{_libdir}/cmake/Libkolab
%{_includedir}/kolab

%if 0%{?with_php}
%files -n php-kolab
%config(noreplace) %{php_inidir}/kolab.ini
%{_datadir}/php/kolabcalendaring.php
%{php_extdir}/kolabcalendaring.so
%{_datadir}/php/kolabicalendar.php
%{php_extdir}/kolabicalendar.so
%{_datadir}/php/kolabobject.php
%{php_extdir}/kolabobject.so
%{_datadir}/php/kolabshared.php
%{php_extdir}/kolabshared.so
%{_datadir}/php/dummy.php
%{php_extdir}/dummy.so
%endif

%files -n python2-kolab
%dir %{python2_sitearch}/kolab
%{python2_sitearch}/kolab/__init__.py*
%{python2_sitearch}/kolab/_calendaring.so
%{python2_sitearch}/kolab/calendaring.py*
%{python2_sitearch}/kolab/_icalendar.so
%{python2_sitearch}/kolab/icalendar.py*
%{python2_sitearch}/kolab/_shared.so*
%{python2_sitearch}/kolab/shared.py*
%{python2_sitearch}/kolab/_kolabobject.so
%{python2_sitearch}/kolab/kolabobject.py*
