%define major 1
%define libname %mklibname kolabxml %major

%global with_java 1
%global with_php 0
%global with_python 1

%if 0%{?with_php}
%{!?php_inidir: %global php_inidir %{_sysconfdir}/php.d/}
%{!?php_extdir: %global php_extdir %(php-config --extension-dir 2>/dev/null || echo %{_libdir}/php)}
%endif

%if 0%{?with_python}
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}%{python3_sitearch}/.*\.so$
%endif

%if 0%{?with_php}
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}%{php_extdir}/.*\.so$
%endif

Name:           libkolabxml
Version:        1.2.1
Release:        %mkrel 9
Summary:        Kolab XML format collection parser library

Group:          System/Libraries
License:        LGPLv3+
URL:            https://git.kolab.org/diffusion/LKX/
Source0:        https://cgit.kolab.org/libkolabxml/snapshot/%{name}-%{version}.tar.gz
Patch0:         libkolabxml-0.8.4-link.patch
Patch1:         libkolabxml-1.1.6-pthread.patch
# Debian patches:
Patch10:        libkolabxml-1.1.4-fix-race-condition.patch
Patch11:        libkolabxml-1.1.4-fix-parallel-build.patch

BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.6
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  swig
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  xsd
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
# Mageia needs this
BuildRequires:  xsd-devel
BuildRequires:  cmake(ECM)

%description
The libkolabxml parsing library interprets Kolab XML formats (xCal, xCard)
with bindings for Python, PHP and other languages. The language bindings
are available through sub-packages.

%package -n %{libname}
Summary:	Kolab XML format collection parser library
Group:		System/Libraries

%description -n %{libname}
The libkolabxml parsing library interprets Kolab XML formats (xCal, xCard)
with bindings for Python, PHP and other languages. The language bindings
are available through sub-packages.

%package devel
Summary:        Kolab XML library development headers
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}

%description devel
Development headers for the Kolab XML libraries.

%if 0%{?with_java}
%package -n java-kolabformat
Summary:        Java Bindings for libkolabxml
Group:          System/Libraries

%description -n java-kolabformat
Java bindings for libkolabxml.
%endif

%if 0%{?with_php}
%package -n php-kolabformat
Summary:        PHP bindings for libkolabxml
Group:          System/Libraries
BuildRequires:  php-devel >= 5.4
BuildRequires:	php-cli

%description -n php-kolabformat
The PHP kolabformat package offers a comprehensible PHP library using the
bindings provided through libkolabxml.
%endif

%if 0%{?with_python}
%package -n python3-kolabformat
Summary:        Python bindings for libkolabxml
Group:          System/Libraries
BuildRequires:  pkgconfig(python3)
%{?python_provide:%python_provide python3-kolabformat}

%description -n python3-kolabformat
The PyKolab format package offers a comprehensive Python library using
the bindings provided through libkolabxml.
%endif

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -Wno-deprecated-declarations"
%cmake_qt5 \
%if 0%{?with_java}
    -DJAVA_BINDINGS=ON \
    -DJAVA_INSTALL_DIR=%{_datadir}/%{name}/java/ \
%endif
%if 0%{?with_php}
    -DPHP_BINDINGS=ON \
    -DPHP_INSTALL_DIR=%{php_extdir} \
%endif
%if 0%{?with_python}
    -DPYTHON_BINDINGS=ON \
    -DPYTHON_INSTALL_DIR=%{python3_sitearch} \
%endif
    -DQT5_BUILD=ON
%cmake_build

%install
%cmake_install

%if 0%{?with_php}
mkdir -p %{buildroot}%{_datadir}/php
mv %{buildroot}/%{php_extdir}/kolabformat.php %{buildroot}%{_datadir}/php/kolabformat.php

mkdir -p %{buildroot}/%{php_inidir}/
cat >%{buildroot}/%{php_inidir}/kolabformat.ini <<EOF
extension=kolabformat.so
EOF
%endif


%check
pushd build
# Make sure libkolabxml.so.* is found, otherwise the tests fail
export LD_LIBRARY_PATH=$( pwd )/src/
pushd tests
./bindingstest ||:
./conversiontest ||:
./parsingtest ||:
popd
%if 0%{?with_php}
php -d enable_dl=On -dextension=src/php/kolabformat.so src/php/test.php ||:
%endif
%if 0%{?with_python}
%{__python3} src/python/test.py ||:
%endif
popd

%files -n %{libname}
%doc DEVELOPMENT NEWS README
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{major}.*

%files devel
%{_includedir}/kolabxml
%{_libdir}/*.so
%{_libdir}/cmake/Libkolabxml

%if 0%{?with_java}
%files -n java-kolabformat
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/java
%endif

%if 0%{?with_php}
%files -n php-kolabformat
%config(noreplace) %{php_inidir}/kolabformat.ini
%{_datadir}/php/kolabformat.php
%{php_extdir}/kolabformat.so
%endif

%if 0%{?with_python}
%files -n python3-kolabformat
%{python3_sitearch}/__pycache__/*
%{python3_sitearch}/kolabformat.py*
%{python3_sitearch}/_kolabformat.so
%endif
