%define major     4
%define libname   %mklibname lerc %{major}
%define develname %mklibname lerc -d

%bcond_without mingw

Name:           liblerc
Version:        4.0.0
Release:        %mkrel 1
Summary:        Library for Limited Error Raster Compression
Group:          System/Libraries
License:        Apache-2.0
URL:            https://github.com/Esri/lerc
Source0:        https://github.com/Esri/lerc/archive/v%{version}/lerc-%{version}.tar.gz
# Add version suffix to mingw dll
Patch0:         lerc-dllver.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(python3)

%if %{with mingw}
BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
%endif

%description
LERC is an open-source image or raster format which supports rapid encoding and
decoding for any pixel type (not just RGB or Byte). Users set the maximum
compression error per pixel while encoding, so the precision of the original
input image is preserved (within user defined error bounds).


%package -n     %{libname}
Summary:        Library for Limited Error Raster Compression
Group:          System/Libraries

%description -n %{libname}
LERC is an open-source image or raster format which supports rapid encoding and
decoding for any pixel type (not just RGB or Byte). Users set the maximum
compression error per pixel while encoding, so the precision of the original
input image is preserved (within user defined error bounds).


%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       lerc-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.


%if %{with mingw}
%package -n mingw32-%{name}
Summary:       MinGW Windows %{name} library
BuildArch:     noarch

%description -n mingw32-%{name}
MinGW Windows %{name} library.


%package -n mingw64-%{name}
Summary:       MinGW Windows %{name} library
BuildArch:     noarch

%description -n mingw64-%{name}
MinGW Windows %{name} library.
%endif


%prep
%autosetup -p1 -n lerc-%{version}

# Fix line endings
sed -i 's/\r$//' NOTICE README.md doc/MORE.md


%build
# Native build
%cmake
%cmake_build

%if %{with mingw}
# MinGW build
%mingw_cmake
%mingw_make_build
%endif


%install
%cmake_install

%if %{with mingw}
%mingw_make_install
%endif


%files -n %{libname}
%license LICENSE
%doc README.md CHANGELOG.md NOTICE
%{_libdir}/libLerc.so.%{major}{,.*}

%files -n %{develname}
%doc doc/*
%{_includedir}/Lerc_c_api.h
%{_includedir}/Lerc_types.h
%{_libdir}/libLerc.so
%{_libdir}/pkgconfig/Lerc.pc

%if %{with mingw}
%files -n mingw32-%{name}
%license LICENSE
%{mingw32_bindir}/libLerc-4.dll
%{mingw32_includedir}/Lerc_c_api.h
%{mingw32_includedir}/Lerc_types.h
%{mingw32_libdir}/libLerc.dll.a
%{mingw32_libdir}/pkgconfig/Lerc.pc

%files -n mingw64-%{name}
%license LICENSE
%{mingw64_bindir}/libLerc-4.dll
%{mingw64_includedir}/Lerc_c_api.h
%{mingw64_includedir}/Lerc_types.h
%{mingw64_libdir}/libLerc.dll.a
%{mingw64_libdir}/pkgconfig/Lerc.pc
%endif
