%define major		10
%define libname		%mklibname linphone %{major}
%define devname		%mklibname linphone -d

%define libnamepp	%mklibname linphone++ %{major}

%bcond_without docs
%bcond_without linphonepp

Name:           liblinphone
Version:        5.3.5
Release:        %mkrel 4
Summary:        Voice over IP Application
License:        GPLv2+
Group:          Communications/Telephony
URL:            https://www.linphone.org/
Source0:       	https://gitlab.linphone.org/BC/public/liblinphone/-/archive/%{version}/liblinphone-%{version}.tar.gz
Patch0:         0001-Use-system-CA-Bundle.patch
Patch1:         linphone-cmake-config-location.patch
Patch2:         liblinphone-system-xsd.patch
Patch3:         liblinphone-jsoncpp-dep.patch
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  doxygen graphviz
BuildRequires:  ffmpeg-devel
BuildRequires:  gsm-devel
BuildRequires:  readline-devel
BuildRequires:  vim-common
BuildRequires:  python3-pystache
BuildRequires:  python3-six
BuildRequires:  soci-mysql-devel
BuildRequires:  soci-sqlite3-devel
BuildRequires:  xsd-devel
BuildRequires:  cmake(Mediastreamer2)
BuildRequires:  cmake(BCToolbox)
BuildRequires:  cmake(BelCard)
BuildRequires:  cmake(BelleSIP)
BuildRequires:  cmake(Ortp)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libosip2)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libupnp) >= 1.6
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(spandsp)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(zxing)

%description
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

%package -n linphone-cli
Summary:        Command Line Interface for %{name}
Group:          Communications/Telephony
Requires:       liblinphone-data >= %{version}-%{release}
Conflicts:      linphone < 3.12.0-2

%description -n linphone-cli
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

This package contains the command line interface.

%package -n linphone-daemon
Summary:        Daemonfor %{name}
Group:          Communications/Telephony
Requires:       liblinphone-data >= %{version}-%{release}
Conflicts:      linphone < 3.12.0-2
Conflicts:      linphone-cli < 5.3.5

%description -n linphone-daemon
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

This package contains the daemon.

%package data
Summary:        Data files for %{name}
Group:          Communications/Telephony
BuildArch:      noarch
Conflicts:      linphone < 3.12.0-2

%description data
Linphone is an open source SIP Phone, available on mobile and desktop
environments.

This package contains data files such as sounds.

%package -n %{libname}
Summary:        Primary library for %{name}
Group:          System/Libraries
Requires:       liblinphone-data >= %{version}-%{release}
Requires:       soci-sqlite3%{_isa}
Requires:       soci-mysql%{_isa}

%description -n %{libname}
Primary library for %{name}.

%package -n %{libnamepp}
Summary:        C++ wrapper library for %{name}
Group:          System/Libraries

%description -n %{libnamepp}
C++ wrapper library for %{name}.

%package -n %{devname}
Summary:        Header files and development libraries from %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
%if %{with linphonepp}
Requires:       %{libnamepp} = %{version}-%{release}
%endif
Requires:       %{name}-data >= %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      linphone < 3.12.0

%description -n %{devname}
Libraries and includes files for developing programs based on %{name}.

%prep
%setup -q
%autopatch -p1

find '(' -name '*.c' -o -name '*.h' ')' -print0 | xargs -0 sed -i -e 's,\r$,,'

# Fix version
sed -i -e '/project/s/\(VERSION\)\s\+"*[0-9]\+\(\.[0-9]\+\)\+"*/\1 "%{version}"/' CMakeLists.txt

# Drop bundled xsd
rm -rf libxsd

# Fix XSD runtime version mismatch
sed -i -e '/XSD_INT_VERSION/s/!=/</g' $(grep -r -l XSD_INT_VERSION)

%build
%global build_cxxflags %optflags -fpermissive
%cmake -GNinja \
    -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES \
    -DENABLE_CONSOLE_UI:BOOL=YES \
    -DENABLE_DAEMON:BOOL=YES \
    -DENABLE_STATIC:BOOL=NO \
    -DENABLE_ROOTCA_DOWNLOAD:BOOL=NO \
    -DENABLE_GTK_UI:BOOL=NO \
    -DENABLE_TOOLS:BOOL=NO \
    -DENABLE_STRICT:BOOL=NO \
    -DENABLE_UNIT_TESTS:BOOL=NO \
    -DENABLE_DB_STORAGE:BOOL=YES \
    -DENABLE_LIME_X3DH:BOOL=NO \
    -DENABLE_DOC:BOOL=%{?with_docs:YES}%{?!with_docs:NO} \
    -DENABLE_CXX_WRAPPER:BOOL=%{?with_linphonepp:YES}%{?!with_linphonepp:NO}
%cmake_build

%install
%cmake_install

# plugins
mkdir -p %{buildroot}%{_libdir}/%{name}/plugins

# remove unwanted docs, generated if doxygen is installed
rm -rf %{buildroot}%{_docdir}/ortp %{buildroot}%{_docdir}/mediastreamer*

%files -n linphone-cli
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_bindir}/linphonec*

%files -n linphone-daemon
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_bindir}/linphone-daemon*

%files data
%{_datadir}/sounds/linphone/
%{_datadir}/belr/grammars/*_grammar
%dir %{_datadir}/linphone/
%{_datadir}/linphone/rootca.pem

%files -n %{libname}
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_libdir}/liblinphone.so.%{major}{,.*}

%dir %{_libdir}/%{name}/plugins

%if %{with linphonepp}
%files -n %{libnamepp}
%license LICENSE*
%doc README* CHANGELOG* NEWS*
%{_libdir}/liblinphone++.so.%{major}{,.*}
%endif

%files -n %{devname}
%if %{with docs}
%doc %{_docdir}/%{name}-%{version}/c/
%endif
%{_includedir}/linphone/
%{_libdir}/liblinphone.so
%{_libdir}/cmake/LibLinphone/

%if %{with linphonepp}
%if %{with docs}
%doc %{_docdir}/%{name}-%{version}/cpp/
%endif
%{_includedir}/linphone++/
%{_libdir}/liblinphone++.so
%{_libdir}/cmake/LinphoneCxx/
%endif
