# Initial import from Fedora for conda

%define major   2
%define libname %mklibname mamba %{major}
%define devname %mklibname mamba -d

Name:           libmamba
Version:        1.5.8
Release:        %mkrel 2
Summary:        C++ API for mamba depsolving library

Group:          System/Libraries
License:        BSD-3-Clause
URL:            https://github.com/mamba-org/mamba
Source0:        https://github.com/mamba-org/mamba/archive/%{name}-%{version}/%{name}-%{version}.tar.gz
# Force the install to be arch dependent
Source1:        setup.py
# Upstream fix for csh file
Patch0:         libmamba-csh.patch
# https://github.com/mamba-org/mamba/pull/3016
Patch1:         libmamba-deps.patch
# Use Fedora versions of yaml-cpp and zstd
Patch2:         libmamba-fedora.patch
# fmt 11 support - https://github.com/mamba-org/mamba/pull/3386
Patch3:         libmamba-fmt11.patch
# Fix armv7hl build
Patch4:         0001-Fix-armv7hl-build.patch

BuildRequires:  cmake
BuildRequires:  cmake(doctest)
BuildRequires:  cmake(tl-expected)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libcurl)
# Need CONDA_ADD_USE_ONLY_TAR_BZ2
BuildRequires:  pkgconfig(libsolv)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(reproc)
BuildRequires:  pkgconfig(spdlog)
BuildRequires:  pkgconfig(yaml-cpp)
BuildRequires:  pybind11-devel
BuildRequires:  cmake(zstd)


%description
libmamba is a reimplementation of the conda package manager in C++.

* parallel downloading of repository data and package files using multi-
  threading
* libsolv for much faster dependency solving, a state of the art library used
  in the RPM package manager of Red Hat, Fedora and OpenSUSE
* core parts of mamba are implemented in C++ for maximum efficiency


%package -n  %{libname}
Summary:        C++ API for mamba depsolving library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Provides:       %{name}%{?_isa} = %{version}-%{release}

%description -n %{libname}
libmamba is a reimplementation of the conda package manager in C++.

* parallel downloading of repository data and package files using multi-
  threading
* libsolv for much faster dependency solving, a state of the art library used
  in the RPM package manager of Red Hat, Fedora and OpenSUSE
* core parts of mamba are implemented in C++ for maximum efficiency


%package -n  %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
License:        MIT
Requires:       %{libname} = %{version}-%{release}
Requires:       cmake
Requires:       pkgconfig(nlohmann_json)
Requires:       pkgconfig(spdlog)
Requires:       cmake(tl-expected)
Provides:       %{name}-devel = %{version}-%{release}

%description  -n  %{devname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%if 0
%package -n     micromamba
Summary:        Tiny version of the mamba package manager
BuildRequires:  cli11-devel
# Generate a simple man page until https://github.com/mamba-org/mamba/issues/3032 is addressed
BuildRequires:  help2man
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n micromamba
micromamba is a tiny version of the mamba package manager. It is a C++
executable with a separate command line interface. It does not need a base
environment and does not come with a default version of Python.
%endif


%package -n     python3-libmambapy
Summary:        Python 3 bindings for libmamba
Group:          Development/Python
BuildRequires:  python3-devel

%description -n python3-libmambapy
Python3 bindings for libmamba.


%prep
%autosetup -p1 -n mamba-libmamba-%{version}

cp -p %SOURCE1 libmambapy/setup.py
sed -i '/LIBRARY DESTINATION/s,\${CMAKE_CURRENT_SOURCE_DIR},${Python_STDARCH}/site-packages,' libmambapy/CMakeLists.txt


%build
%cmake \
   -DBUILD_LIBMAMBA=ON \
   -DBUILD_LIBMAMBAPY=ON \
   -DBUILD_MICROMAMBA=OFF \
   -DBUILD_SHARED=ON \
   -DBUILD_STATIC=OFF \
   -DBUILD_LIBMAMBA_TESTS=OFF
%cmake_build

cd libmambapy
%pyproject_wheel
cd -
# help2man %%{_vpath_builddir}/micromamba/micromamba > %%{_vpath_builddir}/micromamba/micromamba.1


%install
%cmake_install

cd libmambapy
%pyproject_install
%pyproject_save_files libmambapy
cd -

%if 0
# Install init scripts
mkdir -p %{buildroot}/etc/profile.d
for shell in csh sh 
do
  sed -e 's,\$MAMBA_EXE,%{_bindir}/micromamba,' < libmamba/data/micromamba.$shell > %{buildroot}/etc/profile.d/micromamba.$shell
done
mkdir -p %{buildroot}%{_datadir}/fish/vendor_conf.d
sed -e 's,\$MAMBA_EXE,%{_bindir}/micromamba,' < libmamba/data/mamba.fish > %{buildroot}%{_datadir}/fish/vendor_conf.d/micromamba.fish

# man page
mkdir -p %{buildroot}%{_mandir}/man1
cp -p %{_vpath_builddir}/micromamba/micromamba.1 %{buildroot}%{_mandir}/man1/
%endif

%check
%ctest


%files -n %{libname}
%license LICENSE
%doc CHANGELOG.md README.md
%{_libdir}/libmamba.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/mamba/
%{_libdir}/libmamba.so
%{_libdir}/cmake/%{name}/

%if 0
%files -n micromamba
# TODO - better ownership of vendor_conf.d
%dir %{_datadir}/fish/vendor_conf.d
%{_datadir}/fish/vendor_conf.d/micromamba.fish
%{_sysconfdir}/profile.d/micromamba.sh
%{_sysconfdir}/profile.d/micromamba.csh
%{_bindir}/micromamba
%{_mandir}/man1/micromamba.1*
%endif

%files -n python3-libmambapy -f %{pyproject_files}
%doc CHANGELOG.md README.md
%{python3_sitearch}/libmambapy/bindings.*
