%define api	7.10

%bcond_without doc

Summary:	The official C++ client API for PostgreSQL
Name:		libpqxx
Version:	7.10.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Development/Databases
Url:		https://pqxx.org/
Source0:	https://github.com/jtv/libpqxx/archive/%version/%name-%version.tar.gz
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	pkgconfig(libpq)
%if %{with doc}
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	xmlto
%endif

%description
This library works on top of the C-level API library, libpq. You will need
libpq in order to use libpqxx.

The first thing you're likely to notice in programming with libpqxx is that
unlike other libraries, it revolves entirely around transactions. Transactions
are a central concept in database management systems, but they are widely
underappreciated among application developers. Another well-known open source
database system, MySQL, never even got around to implementing them at all in
their own engine, relying on a third-party replacement engine (now owned by
Oracle) to provide this functionality instead.

%package devel
Summary:        Headers for developing programs that will use %{name}
Group:          Development/C++
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%if %{with doc}
%package doc
Summary:        Developer documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description doc
Developer documentation for %{name}.
%endif

%prep
%autosetup -p1

# fix spurious permissions
chmod -x COPYING

%build
%cmake -G Ninja \
        %if %{with doc}
        -DBUILD_DOC=ON
        %endif
%cmake_build

%install
%cmake_install

%files
%doc AUTHORS NEWS README.md VERSION
%license COPYING
%_libdir/libpqxx-%{api}.so

%files devel
%_includedir/pqxx/
%_libdir/libpqxx.so
%_libdir/pkgconfig/libpqxx.pc
%_libdir/cmake/libpqxx/

%if %{with doc}
%files doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/accessing-results.md
%{_docdir}/%{name}/datatypes.md
%{_docdir}/%{name}/escaping.md
%{_docdir}/%{name}/getting-started.md
%{_docdir}/%{name}/mainpage.md
%{_docdir}/%{name}/performance.md
%{_docdir}/%{name}/prepared-statement.md
%{_docdir}/%{name}/streams.md
%{_docdir}/%{name}/thread-safety.md
%{_docdir}/%{name}/html
%{_docdir}/%{name}/binary-data.md
%{_docdir}/%{name}/parameters.md
%endif
