%define oname	pwquality

%define major	1
%define libname %mklibname %{oname} %{major}
%define devname	%mklibname %{oname} -d

Summary:	Library for password quality checking and generating random passwords
Name:		libpwquality
Version:	1.4.5
Release:	%mkrel 4
# The package is BSD licensed with option to relicense as GPL+
# - this option is redundant as the BSD license allows that anyway.
License:	BSD or GPL+
Group:		System/Libraries
URL:		https://github.com/libpwquality/libpwquality/
Source0:	https://github.com/libpwquality/libpwquality/releases/download/libpwquality-%{version}/libpwquality-%{version}.tar.bz2
# Use setuptools instead of distutils
# This fixes the build with Python 3.12+
# https://bugzilla.redhat.com/2165572
# Upstream PR: https://github.com/libpwquality/libpwquality/pull/74
Patch1:		setuptools.patch

BuildRequires:	gettext-devel
BuildRequires:	libcrack-devel
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(setuptools)

%description
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

The library also provides a function for generating random passwords with good
pronounceability. The library supports reading and parsing of a configuration
file.

%package tools
Group:		System/Base
Summary:	Tools for password quality checking and generating random passwords
Requires:	cracklib-dicts
Provides:	%{oname} = %{version}-%{release}
Provides:	%{name} = %{version}-%{release}

%description tools
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

The library also provides a function for generating random passwords with good
pronounceability. The library supports reading and parsing of a configuration
file.

%package -n %{libname}
Group:		System/Libraries
Summary:	Shared libraries for %{oname}
Requires:	%{name}-tools >= %{version}-%{release}

%description -n %{libname}
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

%package -n %{devname}
Group:		Development/Other
Summary:	Files needed for developing PAM-aware applications and modules for PAM
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}
Conflicts:	%{name}-tools < 1.3.0

%description -n %{devname}
Files needed for development of applications using the libpwquality library.

%package -n python3-pwquality
Group:		Development/Python
Summary:	Python 3 bindings for the libpwquality library
%{?python_provide:%python_provide python3-pwquality}

%description -n python3-pwquality
This is pwquality Python module that provides Python3 bindings for the
libpwquality library. These bindings can be used for easy password quality
checking and generation of random pronounceable passwords from Python
applications.

%package -n pam_%{oname}
Summary:	PAM module to perform password quality checking
Group:		System/Libraries
Provides:	pam-%{oname} = %{version}-%{release}
Conflicts:	%{name}-tools < 1.3.0
Conflicts:	%{_lib}pwquality1 < 1.3.0

%description -n pam_%{oname}
PAM module that can be used instead of pam_cracklib to disallow weak new
passwords when user's login password is changed.

%prep
%autosetup -p1

%build
#update autotool files
autoreconf -vfi
%configure \
	--with-securedir=%{_libdir}/security \
	--disable-static \
	--disable-rpath
%make_build

%install
%make_install

install -d %{buildroot}%{_sysconfdir}/security/pwquality.conf.d/

%find_lang %{name}

%files tools -f %{name}.lang
%license COPYING
%doc README NEWS AUTHORS
%config(noreplace) %{_sysconfdir}/security/%{oname}.conf
%dir %{_sysconfdir}/security/pwquality.conf.d/
%{_bindir}/pwmake
%{_bindir}/pwscore
%{_mandir}/man1/pwmake.1*
%{_mandir}/man1/pwscore.1*
%{_mandir}/man5/pwquality.conf.5*

%files -n %{libname}
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n pam_%{oname}
%{_libdir}/security/pam_pwquality.so
%{_mandir}/man8/pam_pwquality.8*

%files -n %{devname}
%{_includedir}/%{oname}.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{oname}.pc
%{_mandir}/man3/pwquality.3*

%files -n python3-pwquality
%{python3_sitearch}/pwquality-%{version}-py%{python3_version}.egg-info
%{python3_sitearch}/%{oname}.*.so
