%define softname  libQGLViewer
%define packname  qglviewer

%define major     2
%define docname   %{name}-doc

Name:		libqglviewer
Summary:	Qt based OpenGL generic 3D viewer library
Group:		System/Libraries
Version:	2.9.1
Release:	%mkrel 2
License:	GPLv2 with exceptions or GPLv3 with exceptions
URL:		https://github.com/GillesDebunne/libQGLViewer
Source0:	https://github.com/GillesDebunne/libQGLViewer/archive/v%{version}/%{softname}-%{version}.tar.gz
# QGLViewer/VRender/gpc.cpp uses exit(0) to "abort" from a failure of malloc
# Use abort() instead.
Patch0:         libQGLViewer-2.9.1-exit.patch
# libQGLViewer .pro files explicitely remove "-g" from compile flags. Make
# them back.
Patch1:         libQGLViewer-2.6.3-dbg.patch
BuildRequires:  pkgconfig(glu)

%description
%{softname} is a C++ library based on Qt that eases the creation of OpenGL
3D viewers. It provides some of the typical 3D viewer functionality, such
as the possibility to move the camera using the mouse, which lacks in most
of the other APIs. Other features include mouse manipulated frames,
interpolated keyFrames, object selection, stereo display, screenshot saving
and much more. It can be used by OpenGL beginners as well as to create
complex applications, being fully customizable and easy to extend.

#------------------------------------------------------------------------------

%define libname_qt5 %mklibname %{packname}-qt5_ %{major}
%define devname_qt5 %mklibname %{packname}-qt5 -d

%package -n	%{libname_qt5}
Summary:	Qt5 based OpenGL generic 3D viewer library
Group:		System/Libraries
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Designer)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)

%description -n	%{libname_qt5}
%{softname} is a C++ library based on Qt5 that eases the creation of OpenGL
3D viewers. It provides some of the typical 3D viewer functionality, such
as the possibility to move the camera using the mouse, which lacks in most
of the other APIs. Other features include mouse manipulated frames,
interpolated keyFrames, object selection, stereo display, screenshot saving
and much more. It can be used by OpenGL beginners as well as to create
complex applications, being fully customizable and easy to extend.

%files	-n	%{libname_qt5}
%doc README LICENCE CHANGELOG GPL_EXCEPTION
%{_libdir}/libQGLViewer-qt5.so.%{major}{,.*}

#------------------------------------------------------------------------------

%package -n	%{devname_qt5}
Summary:	Development files for %{softname}
Group:		Development/KDE and Qt
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{packname}-qt5-devel = %{version}-%{release}
Provides:	lib%{packname}-qt5-devel = %{version}-%{release}

%description -n	%{devname_qt5}
The %{devname_qt5} package contains libraries and header files for
developing applications that use %{softname}.

%files	-n	%{devname_qt5}
%{_qt5_includedir}/QGLViewer/
%{_libdir}/libQGLViewer-qt5.so
%{_libdir}/libQGLViewer-qt5.prl
%{_qt5_plugindir}/designer/libqglviewerplugin.so

#------------------------------------------------------------------------------

%package -n	%{docname}
Summary:	API documentation for %{softname}
Group:		Development/KDE and Qt
Requires:	%{packname}-qt5-devel >= %{version}-%{release}
BuildArch:	noarch

%description -n	%{docname}
API documentation for %{softname}.

%files -n	%{docname}
%doc doc

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{softname}-%{version}

%build
pushd QGLViewer
%qmake_qt5 LIB_DIR=%{_libdir} DOC_DIR=%{_docdir} INCLUDE_DIR=%{_qt5_includedir}
%make_build
popd

pushd designerPlugin
%qmake_qt5 LIB_DIR=../QGLViewer
%make_build
popd

%install
pushd QGLViewer
make -f Makefile -e INSTALL_ROOT=%{buildroot} install_target install_include
popd

pushd designerPlugin
make -e INSTALL_ROOT=%{buildroot} install
popd
