%define realname qwt
%define major    6.2

%bcond_without  qt5
%bcond_without  qt6

Name:           libqwt
Version:        6.2.0
Release:        %mkrel 4
Summary:        2D plotting widget extension to the Qt GUI
License:        Qwt License 1.0
Group:          System/Libraries
Url:            https://qwt.sourceforge.io/
Source:         https://downloads.sourceforge.net/%{realname}/%{realname}-%{version}.tar.bz2
## upstream patches

## upstreamable patches
# fix pkgconfig support
Patch50:        qwt-pkgconfig.patch
# use QT_INSTALL_ paths instead of custom prefix
Patch51:        qwt-6.1.5-qt_install_paths.patch
# parallel-installable qt5 and qt6 version
Patch52:        qwt-qt5.patch
#
Patch53:        qwt-6.1.3-no_rpath.patch

%if %{with qt5}
### Qt5 BuildRequires
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
%endif

%if %{with qt6}
### Qt6 BuildRequires
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Designer)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
%endif

%description
Qwt is an extension to the Qt GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

#------------------------------------------------------------------------------
%if %{with qt5}

%define libname_qt5 %mklibname %realname-qt5_ %{major}

%package -n     %{libname_qt5}
Summary:        2D plotting widget extension to the Qt5 GUI
Group:          System/Libraries

%description -n %{libname_qt5}
Qwt is an extension to the Qt5 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname_qt5}
%doc CHANGES* README
%license COPYING
%{_qt5_libdir}/libqwt-qt5.so.%{major}{,.*}

#------------------------------------------------------------------------------

%define libname_qt5_designer %{_lib}qwt-qt5-designer-plugin

%package -n     %{libname_qt5_designer}
Summary:        Qwt designer plugin
Group:          Development/KDE and Qt
Provides:       qt5-designer-plugin-qwt = %{version}-%{release}
Provides:       qt5designer-qwt-plugin = %{version}-%{release}
%ifarch %ix86 %arm32
Obsoletes:      lib64qwt-qt5-designer-plugin < 6.2.0-4
%endif
Conflicts:      %{_lib}qwt-qt5_6 < 6.2.0
Conflicts:      %{_lib}qwt-qt5_6.2 < 6.2.0-2

%description -n %{libname_qt5_designer}
Qwt is an extension to the Qt5 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides Qwt plugin for Qt5 designer.

%files -n %{libname_qt5_designer}
%{_qt5_plugindir}/designer/libqwt_designer_plugin.so

#------------------------------------------------------------------------------

%define libnamedev_qt5 %mklibname qwt-qt5 -d

%package -n     %{libnamedev_qt5}
Summary:        Development tools for programs which uses Qt5 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname_qt5} = %{version}
Provides:       libqwt-qt5-devel = %{version}-%{release}

%description -n %{libnamedev_qt5}
The %{libnamedev_qt5} package contains the header files and static libraries
necessary for developing programs using the Qt5 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt-qt5 package.

%files -n %{libnamedev_qt5}
%doc COPYING
%doc examples
%docdir %{_qt5_docdir}/html/
%{_qt5_docdir}/html/qwt/
%{_qt5_includedir}/qwt/
%{_qt5_libdir}/libqwt-qt5.so
%{_qt5_libdir}/pkgconfig/Qt5Qwt6.pc
%{_qt5_archdatadir}/mkspecs/*
%{_mandir}/man3/*
%endif

#------------------------------------------------------------------------------
%if %{with qt6}

%define libname_qt6 %mklibname %realname-qt6_ %{major}

%package -n     %{libname_qt6}
Summary:        2D plotting widget extension to the Qt6 GUI
Group:          System/Libraries

%description -n %{libname_qt6}
Qwt is an extension to the Qt6 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname_qt6}
%doc CHANGES* README
%license COPYING
%{_qt6_libdir}/libqwt-qt6.so.%{major}{,.*}

#------------------------------------------------------------------------------

%define libname_qt6_designer %{_lib}qwt-qt6-designer-plugin

%package -n     %{libname_qt6_designer}
Summary:        Qwt designer plugin
Group:          Development/KDE and Qt
Provides:       qt6-designer-plugin-qwt = %{version}-%{release}
Provides:       qt6designer-qwt-plugin = %{version}-%{release}
%ifarch %ix86 %arm32
Obsoletes:      lib64qwt-qt6-designer-plugin < 6.2.0-4
%endif

%description -n %{libname_qt6_designer}
Qwt is an extension to the Qt6 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientific purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides Qwt plugin for Qt6 designer.

%files -n %{libname_qt6_designer}
%{_qt6_plugindir}/designer/libqwt_designer_plugin.so

#------------------------------------------------------------------------------

%define libnamedev_qt6 %mklibname qwt-qt6 -d

%package -n     %{libnamedev_qt6}
Summary:        Development tools for programs which uses Qt6 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname_qt6} = %{version}
Provides:       libqwt-qt6-devel = %{version}-%{release}
Provides:       qwt-qt6-devel = %{version}-%{release}

%description -n %{libnamedev_qt6}
The %{libnamedev_qt6} package contains the header files and static libraries
necessary for developing programs using the Qt6 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt-qt6 package.

%files -n %{libnamedev_qt6}
%doc COPYING
%doc examples
%docdir %{_qt6_docdir}/html/
%{_qt6_docdir}/html/qwt/
%{_qt6_includedir}/qwt/
%{_qt6_libdir}/libqwt-qt6.so
%{_qt6_libdir}/pkgconfig/Qt6Qwt6.pc
%{_qt6_archdatadir}/mkspecs/*
%{_mandir}/man3/*
%endif
#------------------------------------------------------------------------------

%prep
%setup -q -n %{realname}-%{version}
%autopatch -p1

%build
### Qt5 Build ###
mkdir -p qt5
pushd qt5
%qmake_qt5 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

### Qt6 Build ###
mkdir -p qt6
pushd qt6
%qmake_qt6 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

%install
### Qt5 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt5

rm -rf %{buildroot}%{_qt5_libdir}/libqwt-qt5.so.%(echo %{major} | cut -d. -f1)

mv %{buildroot}%{_qt5_docdir}/html/html %{buildroot}%{_qt5_docdir}/html/qwt
mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_qt5_docdir}/html/man/man3 %{buildroot}%{_mandir}/

### Qt6 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt6

rm -rf %{buildroot}%{_qt6_libdir}/libqwt-qt6.so.%(echo %{major} | cut -d. -f1)

# Last build "wins"
rm -rf %{buildroot}%{_mandir}/*
mv %{buildroot}%{_qt6_docdir}/html/html %{buildroot}%{_qt6_docdir}/html/qwt
mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_qt6_docdir}/html/man/man3 %{buildroot}%{_mandir}/
