%define fakename	qwtplot3d

%define commit		b2655743d30ed3185f3c0e2626b33a1d29655216
%define commitdate	20210828

# Qt5 libraries
%define major_qt5	0.3
%define libname_qt5	%mklibname %{fakename}-qt5_ %{major_qt5}
%define libnamedev_qt5	%mklibname %{fakename}-qt5 -d
# Qt6 libraries
%define major_qt6	0.3
%define libname_qt6	%mklibname %{fakename}-qt6_ %{major_qt6}
%define libnamedev_qt6	%mklibname %{fakename}-qt6 -d

%bcond_without	qt5
%bcond_without	qt6

%define rel	2

Name:		libqwtplot3d
Version:	0.3.1a
Release:	%mkrel 2.git%{commitdate}.%{rel}
Summary:	3D plotting widget extension to the Qt GUI
License:	zlib
Group:		System/Libraries
Url:		https://github.com/SciDAVis/qwtplot3d
Source0:	%{url}/archive/%{commit}/%{fakename}-%{commit}.tar.gz

Patch0:		%{fakename}-qt6-build.patch
Patch1:		%{fakename}-qt5-build.patch

### Qt6 build dependencies
%if %{with qt6}
BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6OpenGL)
BuildRequires:	cmake(Qt6OpenGLWidgets)
%endif
### Qt5 build dependencies
%if %{with qt5}
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5OpenGL)
%endif
#
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(vulkan)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	gl2ps-devel
BuildRequires:	chrpath

%description
QwtPlot3D is not a program, but a feature-rich Qt/OpenGL-based C++
programming library, providing essentially a bunch of 3D-widgets for
programmers.

#------------------------------------------------------------------------------
### Qt5 ###

%if %{with qt5}
%package -n	%{libname_qt5}
Summary:	Extended version of the original QwtPlot3D Qt5 library
Group:		System/Libraries

# drop old and no more needed Qt4 libs
Obsoletes:	%{_lib}qwtplot3d0 < 0.2.7-17

%description -n	%{libname_qt5}
QwtPlot3D is not a program, but a feature-rich Qt/OpenGL-based C++
programming library, providing essentially a bunch of 3D-widgets for
programmers.

%package -n	%{libnamedev_qt5}
Summary:	Development tools for programs which uses QwtPlot3D Widget set
Group:		Development/Other
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{fakename}-qt5-devel = %{version}-%{release}
Provides:	%{fakename}-qt5-devel = %{version}-%{release}

# drop old and no more needed Qt4 libs
Obsoletes:	%{_lib}qwtplot3d-devel < 0.2.7-17

%description -n	%{libnamedev_qt5}
The %{libnamedev_qt5} package contains Qt5 libraries and header files for
developing applications that use %{fakename}-qt5.
%endif

#------------------------------------------------------------------------------
### Qt6 ###

%if %{with qt6}
%package -n	%{libname_qt6}
Summary:	Extended version of the original QwtPlot3D Qt6 library
Group:		System/Libraries

%description -n	%{libname_qt6}
QwtPlot3D is not a program, but a feature-rich Qt/OpenGL-based C++
programming library, providing essentially a bunch of 3D-widgets for
programmers.

%package -n	%{libnamedev_qt6}
Summary:	Development tools for programs which uses QwtPlot3D Widget set
Group:		Development/Other
Requires:	%{libname_qt6} = %{version}-%{release}
Provides:	%{fakename}-qt6-devel = %{version}-%{release}
Provides:	%{fakename}-qt6-devel = %{version}-%{release}

%description -n	%{libnamedev_qt6}
The %{libnamedev_qt6} package contains Qt6 libraries and header files for
developing applications that use %{fakename}-qt6.
%endif

#------------------------------------------------------------------------------

%prep
%setup -qc -n %{fakename}-%{commit}

# Unbundle gl2ps
rm -rf %{fakename}-%{commit}/3rdparty/gl2ps

cp -a %{fakename}-%{commit} %{fakename}-qt5
mv %{fakename}-%{commit} %{fakename}-qt6

%if %{with qt6}
pushd %{fakename}-qt6
%patch -P 0 -p1 -b .backup
popd
%endif

%if %{with qt5}
pushd %{fakename}-qt5
%patch -P 1 -p1 -b .backup
popd
%endif

%build
%if %{with qt6}
pushd %{fakename}-qt6
export CXXFLAGS="%{build_cxxflags}"
%cmake \
 -DPKG_CONFIG_ARGN:STRING="%(pkg-config --cflags Qt6Gui) %(pkg-config --cflags Qt6Core) %(pkg-config --cflags Qt6OpenGL)" \
 -DCMAKE_SHARED_LINKER_FLAGS_RELEASE:STRING="%{__global_ldflags} -lGLU" \
 -DCMAKE_INSTALL_LIBDIR:PATH=%{_qt6_libdir} \
 -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_qt6_headerdir}/%{fakename}-qt6
%cmake_build
popd
%endif

%if %{with qt5}
pushd %{fakename}-qt5
export CXXFLAGS="%{build_cxxflags}"
%cmake \
 -DPKG_CONFIG_ARGN:STRING="%(pkg-config --cflags Qt5Gui) %(pkg-config --cflags Qt5Core) %(pkg-config --cflags Qt5OpenGL)" \
 -DCMAKE_SHARED_LINKER_FLAGS_RELEASE:STRING="%{__global_ldflags} -lGLU" \
 -DCMAKE_INSTALL_LIBDIR:PATH=%{_qt5_libdir} \
 -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_qt5_headerdir}/%{fakename}-qt5
%cmake_build
popd
%endif

%install
%if %{with qt6}
pushd %{fakename}-qt6
%cmake_install
# Install executable examples files
mkdir -p %{buildroot}%{_libexecdir}/%{fakename}-qt6
install -pm 755 %{_vpath_builddir}/examples/simpleplot/simpleplot \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/axes/axes \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/enrichments/enrichments \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/autoswitch/autoswitch \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/
install -pm 755 %{_vpath_builddir}/examples/mesh2/mesh2 \
                %{buildroot}%{_libexecdir}/%{fakename}-qt6/

mkdir -p %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6
install -pm 644 include/*  %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/
mv %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h.in %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MAJOR@|0|g' -i %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MINOR@|3|g' -i %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_PATCH@|0|g' -i %{buildroot}%{_qt6_headerdir}/%{fakename}-qt6/qwt3d_version.h

# Remove rpaths
chrpath -d %{buildroot}%{_libexecdir}/%{fakename}-qt6/*
popd
%endif

%if %{with qt5}
pushd %{fakename}-qt5
%cmake_install
# Install executable examples files
mkdir -p %{buildroot}%{_libexecdir}/%{fakename}-qt5
install -pm 755 %{_vpath_builddir}/examples/simpleplot/simpleplot \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/axes/axes \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/enrichments/enrichments \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/autoswitch/autoswitch \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/
install -pm 755 %{_vpath_builddir}/examples/mesh2/mesh2 \
                %{buildroot}%{_libexecdir}/%{fakename}-qt5/

mkdir -p %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5
install -pm 644 include/*  %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/
mv %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h.in %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MAJOR@|0|g' -i %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_MINOR@|3|g' -i %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h
sed -e 's|@PROJECT_VERSION_PATCH@|0|g' -i %{buildroot}%{_qt5_headerdir}/%{fakename}-qt5/qwt3d_version.h

# Remove rpaths
chrpath -d %{buildroot}%{_libexecdir}/%{fakename}-qt5/*
popd
%endif

# Qt6
%if %{with qt6}
%files -n %{libname_qt6}
%license %{fakename}-qt6/COPYING %{fakename}-qt6/LICENSE
%doc %{fakename}-qt6/README.md
%{_qt6_libdir}/lib%{fakename}-qt6.so.%{major_qt6}{,.*}

%files -n %{libnamedev_qt6}
%{_qt6_headerdir}/%{fakename}-qt6/
%{_qt6_libdir}/lib%{fakename}-qt6.so
%{_libexecdir}/%{fakename}-qt6/
%endif
#

# Qt5
%if %{with qt5}
%files -n %{libname_qt5}
%license %{fakename}-qt5/COPYING %{fakename}-qt5/LICENSE
%doc %{fakename}-qt5/README.md
%{_qt5_libdir}/lib%{fakename}-qt5.so.%{major_qt5}{,.*}

%files -n %{libnamedev_qt5}
%{_qt5_headerdir}/%{fakename}-qt5/
%{_qt5_libdir}/lib%{fakename}-qt5.so
%{_libexecdir}/%{fakename}-qt5/
%endif
#
