%define srcname	LibreCAD

# comment out if not pre release
#define prel	rc4

# rel for bumping
%define rel	2

%define dxfrw_includedir %(pkg-config --cflags-only-I libdxfrw | sed 's|-I||g')

# exclude plugin .so from provides
%global __provides_exclude_from %{_libdir}/librecad/plugins/.*\\.so

%bcond_with	bundled_libdxfrw

Name:		librecad
Summary:	An generic 2D CAD program
Version:	2.2.1
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Group:		Graphics/3D
License:	GPLv2
URL:		https://www.librecad.org/
Source0:	https://github.com/LibreCAD/LibreCAD/archive/%{version}%{?prel:-%prel}/%{srcname}-%{version}%{?prel:-%prel}.tar.gz
# Originally from Fedora:
%if %{without bundled_libdxfrw}
Patch1:		LibreCAD-2.1.1-use-system-libdxfrw.patch
%else
Source10:	LibreCAD-2.1.1-use-system-libdxfrw.patch
%endif
Patch2:		0001-Add-3rd-argument-to-DRW_Coord.patch
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(muparser)
BuildRequires:	pkgconfig(shapelib)
%if %{without bundled_libdxfrw}
BuildRequires:	libdxfrw-devel >= 2.2.0-3
%endif
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	qttools5
Recommends:	%{name}-data
Recommends:	%{name}-parts
Recommends:	%{name}-doc
Recommends:	%{name}-plugins

%description
LibreCAD is a Qt5 application to design 2D cad drawing based on the community
edition of QCad.

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_metainfodir}/org.librecad.%{name}.appdata.xml
%{_datadir}/mime/packages/*.xml
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/%{name}.1*
%dir %{_datadir}/%{name}
%dir %{_libdir}/%{name}

#-----------------------------------------------------------------------------

%package	data
Summary:	Data platform independent files for %{name}
Requires:	%{name}
BuildArch:	noarch

%description	data
LibreCAD is an application for computer aided design (CAD) in two
dimensions (2D).

This package contains platform independent files for LibreCAD, including
fonts, patterns, and interface translations.

%files		data
%{_datadir}/%{name}/qm/
%{_datadir}/%{name}/fonts/
%{_datadir}/%{name}/patterns/

#------------------------------------------------------------------------------

%package	parts
Summary:	Parts collection for %{name}
Requires:	%{name}
BuildArch:	noarch

%description	parts
Collection of parts for %{name}, a Qt5 application to design 2D cad drawing
based on the community edition of QCad.

%files		parts
%{_datadir}/%{name}/library

#------------------------------------------------------------------------------

%package	plugins
Group:		Graphics/3D
Summary:	Plugins libraries files for %{name}
Requires:	%{name}

%description	plugins
Contains the plugins files for LibreCAD.

%files		plugins
%{_libdir}/%{name}/plugins/

#------------------------------------------------------------------------------

%package	doc
Summary:	Documentation for %{name}
BuildArch:	noarch

%description	doc
LibreCAD is an application for computer aided design (CAD) in two dimensions
(2D).

This package contains documentation for LibreCAD.

%files		doc
%doc README.md
%doc %{_datadir}/doc/%{name}/html/
%dir %{_datadir}/doc/%{name}

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{srcname}-%{version}%{?prel:-%prel}

echo 'MUPARSER_DIR = %{_prefix}' >> settings_linux.pro
echo 'BOOST_DIR = %{_includedir}' >> settings_linux.pro
echo 'BOOST_LIBDIR = %{_libdir}' >> settings_linux.pro

%if %{without bundled_libdxfrw}
sed -i 's|$${DXFRW_INCLUDEDIR}|%{dxfrw_includedir}|g' librecad/src/src.pro
rm -rf libraries/libdxfrw
%endif

# drop bundled libs and use system ones
rm -rf libraries/muparser

# fix version info
sed -i -e 's/^LC_VERSION=\".*\"/LC_VERSION=\"%{version}%{?prel:-%prel}\"/' librecad/src/src.pro

%build
export PATH=%_qt5_bindir:$PATH
%qmake_qt5 librecad.pro
%make_build

%install
# Let's create the directory structure
mkdir -p %{buildroot}%{_datadir}/%{name}/{fonts,patterns,qm,library/misc,library/templates,doc}
mkdir -p %{buildroot}%{_datadir}/doc/%{name}/html/{classref/html/,img,imgs}
mkdir -p %{buildroot}%{_datadir}/applications/
mkdir -p %{buildroot}%{_libdir}/%{name}/plugins

# Now install all files
install -Dm 0755 unix/%{name} %{buildroot}%{_bindir}/%{name}
install -Dm 0644 desktop/media/icons/%{name}_icon.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
install -m 0644 unix/resources/patterns/*.dxf %{buildroot}%{_datadir}/%{name}/patterns/
install -m 0644 unix/resources/fonts/* %{buildroot}%{_datadir}/%{name}/fonts/
install -m 0644 unix/resources/library/misc/* %{buildroot}%{_datadir}/%{name}/library/misc/
install -m 0644 unix/resources/library/templates/* %{buildroot}%{_datadir}/%{name}/library/templates/
install -m 0644 unix/resources/qm/*.qm %{buildroot}%{_datadir}/%{name}/qm/
install -m 0755 unix/resources/plugins/* %{buildroot}%{_libdir}/%{name}/plugins/

# Install documentation files
install -m 0644 librecad/support/doc/*.html %{buildroot}%{_datadir}/doc/%{name}/html/

# appdata
install -Dpm 0644 desktop/org.librecad.librecad.appdata.xml %{buildroot}%{_metainfodir}/org.librecad.librecad.appdata.xml

# manpage
install -Dpm 0644 desktop/librecad.1 %{buildroot}%{_mandir}/man1/%{name}.1

# Create the desktop file
mkdir -p  %{buildroot}%{_datadir}/applications/
desktop-file-install \
	--dir %{buildroot}%{_datadir}/applications \
	--add-category="Qt" \
	--remove-mime-type="image/vnd.dxf" \
	--add-mime-type="image/vnd.dxf" \
		desktop/librecad.desktop

install -m 0644 -D desktop/librecad.sharedmimeinfo %{buildroot}%{_datadir}/mime/packages/%{name}.xml
