# Use bundled deps as we don't ship the exact right versions for all the
# required rust libraries
%global bundled_rust_deps 0

%bcond_without check

%define api_version	2
%define lib_major	2
%define gir_major	2.0
%define lib_name	%mklibname rsvg %{api_version} %{lib_major}
%define girname		%mklibname rsvg-gir %{gir_major}
%define libnamedev	%mklibname rsvg %{api_version} -d

Name:		librsvg
Summary:	Raph's SVG library
Version:	2.60.0
Release: 	%mkrel 1
License: 	LGPLv2+ and GPLv2+
Group:		Graphics/Utilities
URL: 		https://wiki.gnome.org/action/show/Projects/LibRsvg
Source0: 	https://download.gnome.org/sources/librsvg/%{url_ver}/%{name}-%{version}.tar.xz
%dnl Source1:	%{name}-%{version}-vendor.tar.xz

%if ! 0%{?bundled_rust_deps}
# Patches to build with Fedora-packaged rust crates
Patch1:		0001-Fedora-Drop-dependencies-required-for-benchmarking.patch
Patch2:		0002-bump-dependencies-to-markup5ever-0.14-xml5ever-0.20.patch
Patch3:		0003-drop-avif-feature-and-unsatisfiable-dependencies.patch
# Mageia patches
Patch4:		0001-Bump-itertools-to-0.14.patch
Patch5:		0001-Bump-thiserror-to-2.patch
%endif

BuildRequires:	meson
BuildRequires:	cargo-c
BuildRequires:	cargo-rpm-macros
BuildRequires:	pkgconfig(cairo) >= 1.15.10
BuildRequires:	pkgconfig(cairo-png)
# avif disabled
#BuildRequires: 	pkgconfig(dav1d)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(pangocairo)
BuildRequires:	pkgconfig(pangoft2)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(vapigen)
BuildRequires:	vala-tools
BuildRequires:	gi-docgen
BuildRequires:	python3dist(docutils)
%if %{with check}
# For rsvg_convert tests
BuildRequires:  fonts-ttf-dejavu
%endif

Provides:	rsvg = %{version}-%{release}
Provides:	rsvg%{?_isa} = %{version}-%{release}
Provides:	rsvg-convert = %{version}-%{release}
Provides:	rsvg-convert%{?_isa} = %{version}-%{release}

%description
A library that uses libart and pango to render svg files.

#-----------------------------------------------------------

%package -n %{lib_name}
Summary:	Raph's SVG library
Group:		System/Libraries
Provides:	%{name}%{api_version} = %{version}-%{release}
Provides:	%{name}%{api_version}%{?_isa} = %{version}-%{release}
Requires:	rsvg-pixbuf-loader = %{version}-%{release}

%description -n %{lib_name}
A library that uses libart and pango to render svg files.

#-----------------------------------------------------------

%package -n %{libnamedev}
Summary:	Libraries and include files for developing with librsvg
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Provides:	%{name}%{api_version}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{libnamedev}
This package provides the necessary development libraries and include
files to allow you to develop with librsvg.

#-----------------------------------------------------------

%package -n %{girname}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{lib_name} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

#-----------------------------------------------------------

%package -n rsvg-pixbuf-loader
Summary:	SVG image loader for gdk-pixbuf
Group:		Graphics/Utilities
Requires:	%{name}%{?_isa} >= %{version}-%{release}

# ease upgrade mga9 -> mga10
Conflicts:	%{_lib}rsvg2_2 < 2.56.0-3
Conflicts:	librsvg < 2.56.0-3

%description -n rsvg-pixbuf-loader
This package provides a gdk-pixbuf plugin for loading SVG
images in GTK apps.

#-----------------------------------------------------------

%prep
%if ! 0%{?bundled_rust_deps}
# use packaged Rust dependencies
%autosetup -p1 -n librsvg-%{version}
%cargo_prep
%else
# use vendored Rust dependencies
%autosetup -N -n librsvg-%{version} -a1
%cargo_prep -v vendor
%endif

# Ensure we build without --locked, as %%cargo_prep removes
# the lock file (Cargo.lock), allowing more wiggle room when
# providing Rust dependencies.
sed -i 's/, "--locked"//g' meson/cargo_wrapper.py

%if ! 0%{?bundled_rust_deps}
%generate_buildrequires
# cargo-c requires all optional dependencies to be available
%cargo_generate_buildrequires -a
%endif

%build
%meson -Davif=disabled
%meson_build

%install
%meson_install

# Not useful in this package.
rm -f %{buildroot}%{_pkgdocdir}/COMPILING.md

%if %{with check}
%check
%meson_test
%endif

%files
%doc AUTHORS NEWS README.md
%license COPYING.LIB
%{_bindir}/rsvg-convert
%{_mandir}/man1/*.1*

%files -n %{lib_name}
%license COPYING.LIB
%{_libdir}/librsvg-%{api_version}.so.%{lib_major}{,.*}

%files -n %{girname}
%{_libdir}/girepository-1.0/Rsvg-%{gir_major}.typelib

%files -n %{libnamedev}
%doc %{_docdir}/Rsvg-2.0/
%{_libdir}/librsvg-%{api_version}.so
%{_includedir}/librsvg-2.0
%{_libdir}/pkgconfig/*
%{_datadir}/gir-1.0/Rsvg-%{gir_major}.gir
%{_datadir}/vala/vapi/librsvg-2.0.{deps,vapi}

%files -n rsvg-pixbuf-loader
%license COPYING.LIB
%{_libdir}/gdk-pixbuf-2.0/*/loaders/libpixbufloader_svg.so
%{_datadir}/thumbnailers/librsvg.thumbnailer
