%define major           7
%define libname_orig    libltdl
%define libname         %mklibname ltdl %{major}
%define libname_devel   %mklibname ltdl -d
%define staticdevelname %mklibname ltdl -d -s

%bcond_without tests

# for the testsuite:
%define _disable_ld_no_undefined 1
%define _disable_ld_as_needed 1

# allow --with bootstrap
%define bootstrap 0
%{?_with_bootstrap: %global bootstrap 1}

# define fortran compiler
%define fortran_compiler gfortran

# uncomment if stable
#define prerel	1

Summary:        GNU tool for simplifying the use of shared libraries
Name:           libtool
Version:        2.5.4
Release:        %mkrel 1
License:        GPLv2+
Group:          Development/Other
URL:            https://www.gnu.org/software/libtool/libtool.html

Source:         https://%{?prerel:alpha}%{?!prerel:ftp}.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:        https://%{?prerel:alpha}%{?!prerel:ftp}.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz.sig

# (Abel) Patches please only modify ltmain.in and don't touch ltmain.sh
# otherwise ltmain.sh will not be regenerated, and patches will be lost

Patch12:        do-not-link-against-deplibs.patch
Patch13:        drop-ld-no-undefined-for-shared-lib-modules.patch
Patch14:        fix-checking-libltdl-is-installed-installable.patch

# (cjw) in the libltdl install test, use --enable-ltdl-install to make sure
#       the library is built even if it is installed on the system
Patch17:        libtool-2.2.6b-libltdl-install-test-fix.patch
# (cjw) mdemo test may fail because file sizes are incorrect in 'before'
#       file list
Patch18:        libtool-2.4-dryrun-sleepmore.patch
# (wally) we are not shipping libltdl.la anymore,
#         patch originaly from Gentoo:
#         https://bugs.gentoo.org/show_bug.cgi?id=293921#c10
Patch19:        libtool-2.4.6-fix-building-without-libltdl.la.patch
# (proyvind) add /lib64 & /usr/lib64 to system library path in order to
#            prevent from being added to rpath
Patch20:        libtool-2.5.2-rpath.patch
#
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  help2man
# For test 37 to succeed
BuildRequires:  locales-de
%if ! %{bootstrap}
BuildRequires:  gcc-%{fortran_compiler}
%ifarch ia64 %ix86 x86_64
BuildRequires:  quadmath-devel
%endif
%endif
Requires:       %{name}-base = %{version}-%{release}

%description
The libtool package contains the GNU libtool, a set of shell scripts
which automatically configure UNIX and UNIX-like architectures to
generically build shared libraries.  Libtool provides a consistent,
portable interface which simplifies the process of using shared
libraries.

If you are developing programs which will use shared libraries, you
should install libtool.

%package base
Group:          Development/C
Summary:        Basic package for %{name}
Requires:       file

%description base
The libtool package contains the GNU libtool, a set of shell scripts
which automatically configure UNIX and UNIX-like architectures to
generically build shared libraries.  Libtool provides a consistent,
portable interface which simplifies the process of using shared
libraries.

If you are developing programs which will use shared libraries, you
should install libtool.

%package -n %{libname}
Group:          Development/C
Summary:        Shared library files for libtool
License:        LGPLv2+
Provides:       %{libname_orig} = %{version}-%{release}
# old libextractor wrongly provided its own libltdl:
Conflicts:      %{_lib}extractor1 < 0.5.18a

%description -n %{libname}
Shared library files for libtool DLL library from the libtool package.

%package -n %{libname_devel}
Group:          Development/C
Summary:        Development files for libtool
License:        LGPLv2+
Requires:       %{name} = %{version}
Requires:       %{libname} = %{version}
Provides:       %{libname_orig}-devel = %{version}-%{release}
Provides:       libtool-ltdl-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{libname_devel}
Development headers, and files for development from the libtool package.

%package -n %{staticdevelname}
Summary:        libtldl - static library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{libname_orig}-static-devel = %{version}-%{release}
Obsoletes:      %{_lib}libltdl-static-devel < 2.4.6-8

%description -n %{staticdevelname}
Static library (.a) version of libtldl.

%prep
%autosetup -p1

# Fix libtool to pass -Wl,xxx options before libraries
sed -i \
 -e 's,$deplibs $compiler_flags,$compiler_flags $deplibs,' \
 -e 's,$deplibs $postdep_objects $compiler_flags,$compiler_flags $deplibs $postdep_objects,' \
 m4/libtool.m4

# Force -Wl,--as-needed in libtool to workaround libtool bug (cf https://lists.gnu.org/archive/html/libtool-patches/2004-06/msg00002.html)
sed -i \
 -e "s/^\([ \t]*tmp_sharedflag\)='-shared'/\1='-shared -Wl,--as-needed'/" \
 m4/libtool.m4

%build
%configure
make

# Do not use -nostdlib to build libraries, and so no need to hardcode gcc path (mdvbz#44616)
# (taken from debian, https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=206356)
# ([PIX] this is not done as a patch since the patch would be too big to maintain)
sed -i -e 's/^\(predep_objects\)=.*/\1=""/' \
       -e 's/^\(postdep_objects\)=.*/\1=""/' \
       -e 's/^\(compiler_lib_search_path\)=.*/\1=""/' \
       -e 's:^\(sys_lib_search_path_spec\)=.*:\1="/lib/ /usr/lib/ /usr/X11R6/lib/ /usr/local/lib/":' \
       -e 's/^\(archive_cmds=\".*\) -nostdlib /\1 /' \
       -e 's/^\(archive_expsym_cmds=\".*\) -nostdlib /\1 /' \
       libtool
# should "compiler_lib_search_dirs" be cleaned too?

%if %{with tests}
%check
set +x
echo ====================TESTING=========================
set -x
# all tests must pass here
# disabling icecream since some tests check the output of gcc
ICECC=no %__make check VERBOSE=yes | tee make_check.log 2>&1 # || (cat make_check.log && false)
set +x
echo ====================TESTING END=====================
set -x
%endif

%install
%make_install

rm -f %{buildroot}%{_libdir}/*.la

%files
%doc AUTHORS NEWS README
%doc THANKS TODO
%{_bindir}/libtool
%{_mandir}/man1/libtool.1.*

%files base
%doc AUTHORS NEWS README
%doc THANKS TODO
%{_bindir}/libtoolize
%{_infodir}/libtool.info*
%{_datadir}/libtool/
%{_datadir}/aclocal/*.m4
%{_mandir}/man1/libtoolize.*

%files -n %{libname}
%doc libltdl/README
%{_libdir}/libltdl.so.%{major}{,.*}

%files -n %{libname_devel}
%{_includedir}/*
%{_libdir}/*.so

%files -n %{staticdevelname}
%{_libdir}/*.a
