#
# spec file for package libxcrypt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2024 Mageia.Org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

%define major         1
%define libname       %mklibname xcrypt %{major}
%define devellibname  %mklibname xcrypt -d
%define staticlibname %mklibname xcrypt -d -s


Name:           libxcrypt
Version:        4.4.37
Release:        %mkrel 1
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
URL:            https://github.com/besser82/libxcrypt
Source0:        https://github.com/besser82/libxcrypt/releases/download/v%{version}/%{name}-%{version}.tar.xz

# Patch 0000 - 2999: Backported patches from upstream.

# Patch 3000 - 5999: Backported patches from pull requests.

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
# (tmb) temp force new gcc
BuildRequires:  gcc >= 10.1.0-1
# (tmb) force latest binutils
BuildRequires:  binutils >= 1:2.34-10


%description
libxcrypt is a modern library for one-way hashing of passwords. It supports
DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password hashes, and provides
the traditional Unix 'crypt' and 'crypt_r' interfaces, as well as a set of
extended interfaces pioneered by Openwall Linux, 'crypt_rn', 'crypt_ra',
'crypt_gensalt', 'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{libname}
Summary:        Extended crypt library for DES, MD5, Blowfish and others
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          System/Libraries
Provides:       libxcrypt = %{version}-%{release}
Provides:       libxcrypt%{?_isa} = %{version}-%{release}

%description -n %{libname}
libxcrypt is a modern library for one-way hashing of passwords. It supports
DES, MD5, SHA-2-256, SHA-2-512, and bcrypt-based password hashes, and provides
the traditional Unix 'crypt' and 'crypt_r' interfaces, as well as a set of
extended interfaces pioneered by Openwall Linux, 'crypt_rn', 'crypt_ra',
'crypt_gensalt', 'crypt_gensalt_rn', and 'crypt_gensalt_ra'.

%package -n %{devellibname}
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
Requires:       libxcrypt%{?_isa} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Provides:       xcrypt-devel = %{version}-%{release}
Provides:       xcrypt-devel%{?_isa} = %{version}-%{release}

%description  -n %{devellibname}
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.

%package  -n %{staticlibname}
Summary:        Static library for -static linking with %{name}
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/C
Provides:       libxcrypt-static-devel = %{version}-%{release}
Provides:       libxcrypt-static-devel%{?_isa} = %{version}-%{release}
Requires:       %{devellibname} = %{version}-%{release}
Requires:       glibc-static-devel

%description -n %{staticlibname}
This package contains the libxcrypt static libraries for -static linking. You
don't need this, unless you link statically, which is highly discouraged.

%prep
%autosetup -p 1

%build
# Disable arc4random_buf on purpose, so we are able
# to run test/getrandom-fallback from testsuite.
%configure           \
  ac_cv_func_arc4random_buf=no \
  --disable-silent-rules \
  --enable-shared        \
  --enable-static        \
  --enable-obsolete-api  \
  --enable-hashes=all    \
  --with-pkgconfigdir=%{_libdir}/pkgconfig
%make_build
%make_build test-programs

%install
%make_install

%check
%make_build check || \
  {
    rc=$?;
    echo "-----BEGIN TESTLOG-----";
    cat test-suite.log;
    echo "-----END TESTLOG-----";
    exit $rc;
  }

%files -n %{libname}
%license COPYING.LIB LICENSING
%doc AUTHORS NEWS README THANKS
%{_libdir}/libcrypt.so.%{major}{,.*}
%{_libdir}/libowcrypt.so.%{major}

%files -n %{devellibname}
%doc TODO
%{_includedir}/crypt.h
%{_includedir}/xcrypt.h
%{_libdir}/libcrypt.so
%{_libdir}/libowcrypt.so
%{_libdir}/libxcrypt.so
%{_libdir}/pkgconfig/libcrypt.pc
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/crypt.3.*
%{_mandir}/man3/crypt_checksalt.3.*
%{_mandir}/man3/crypt_gensalt.3.*
%{_mandir}/man3/crypt_gensalt_ra.3.*
%{_mandir}/man3/crypt_gensalt_rn.3.*
%{_mandir}/man3/crypt_preferred_method.3.*
%{_mandir}/man3/crypt_r.3.*
%{_mandir}/man3/crypt_ra.3.*
%{_mandir}/man3/crypt_rn.3.*
%{_mandir}/man5/crypt.5.*

%files -n %{staticlibname}
%{_libdir}/libcrypt.a
%{_libdir}/libowcrypt.a
%{_libdir}/libxcrypt.a
