# Taken from pango spec
%define biarchs_32 %{ix86}
%define biarchs_64 x86_64 aarch64
%define query_modules_suffix %{nil}
%ifarch %{biarchs_32}
%define query_modules_suffix -32
%endif
%ifarch %{biarchs_64}
%define query_modules_suffix -64
%endif
%define query_modules pango-querymodules%{query_modules_suffix}

# for python modules
%define _disable_ld_no_undefined 1
# Turn off the brp-python-bytecompile automagic
%global _python_bytecompile_extra 0

Name:           lilypond
Version:        2.24.4
Release:        %mkrel 1
Summary:        Program for printing sheet music
License:        GPLv3
Group:          Publishing
URL:            https://lilypond.org/
Source0:        https://gitlab.com/lilypond/lilypond/-/archive/v%{version}/lilypond-v%{version}.tar.bz2
Source2:        https://gitlab.com/lilypond/lilypond/-/releases/v%{version}/downloads/lilypond-%{version}-documentation.tar.xz
Recommends:     %{name}-doc = %{version}
Requires:       ghostscript
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(post): findutils
Requires(post): mkfontscale
# (Abel) bib2html or bibtex2html -- pick either one
BuildRequires:  bib2html
BuildRequires:  texi2html
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  fontforge >= 1.0-0.20110222
BuildRequires:  gettext-devel
BuildRequires:  ghostscript
BuildRequires:  groff-for-man
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(guile-2.2)
BuildRequires:  guile2.2
BuildRequires:  mftrace
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(python3)
BuildRequires:  texinfo-tex
BuildRequires:  texlive-collection-basic
# for Cyrillic characters support in TeX (fikparm.mf)
BuildRequires:  texlive-fonts-sources
BuildRequires:  netpbm
BuildRequires:  zip
BuildRequires:  imagemagick
BuildRequires:  dblatex
BuildRequires:  help2man
BuildRequires:  rsync

%description
LilyPond is a music typesetter.  It produces beautiful sheet music using a
high level description file as input.  LilyPond is part of the GNU project.

LilyPond is split into two packages.  The package "lilypond" provides the
core package, containing the utilities for converting the music source
(.ly) files into printable output.  The package "lilypond-doc"
provides the full documentation, example .ly files for various features and
the Mutopia project files (musical equivalent of the Gutenberg project - see
http://www.mutopiaproject.org for details).

If you are new to lilypond, you will almost certainly want to install the
"lilypond-doc" package and take a look at tutorials under
%{_docdir}/lilypond-doc.

%package doc
Summary:        LilyPond documentation, examples and Mutopia files
Group:          Publishing
Obsoletes:      %{name}-manual
Provides:       %{name}-manual
BuildArch:      noarch

%description doc
The documentation of LilyPond, both in HTML and PostScript, along with
example input files and the files from the Mutopia project. If you
want to try the examples or score files from Mutopia project, please
also install LilyPond main package.


%prep
%setup -q -n %{name}-v%{version}

mkdir -p %{name}-documentation-%{version}
cd %{name}-documentation-%{version}
xz -dcq %SOURCE2 | tar -xf -
cd -

# Remove version constraint on texi2html
sed -e 's|1.82, 1.82|1.82|g' -i configure.ac

%build
export PYTHON=%{__python3}
# Don't try to use options with autogen as config.sub needs an update which is only done when calling the configure mga macro
./autogen.sh --noconf
%configure \
        --with-texgyre-dir=%{_datadir}/texmf-dist/fonts/opentype/public/tex-gyre/
%make_build

# Doesn't work out of the box for this version.
#%%make_build  web

%install
%make_install

#
# web doc
#
# Doesn't work out of the box for this version.
#%%{__make} out=www web-install DESTDIR=%%{buildroot}

#
# move emacs file to our location
#
%{__install} -D -m 644 elisp/lilypond-init.el %{buildroot}%{_sysconfdir}/emacs/site-start.d/lilypond-init.el

#
# move vim stuff to our location
#
%{__mv} %{buildroot}%{_datadir}/lilypond/%{version}/vim %{buildroot}%{_datadir}/vim

#
# some more house cleaning
#
%{_bindir}/find %{buildroot} -path '*%{_datadir}/lilypond/%{version}/fonts' -prune -type f -o -name 'fonts.cache-1' -print0 | %{_bindir}/xargs -r -0 %{__rm}
%{_bindir}/find %{buildroot}%{_docdir} -name '*.png' -empty -print0 | %{_bindir}/xargs -r -0 %{__rm}
%{_bindir}/find %{buildroot}%{_datadir}/lilypond/%{version} -xtype l -print0 | %{_bindir}/xargs -r -0 %{__rm}

#
# Create symlinks to lilypond folder under TeX directory, so that TeX can
# use lilypond files natively, courtesy of Michael Brown's great hacks
# Necessary for tex backend to work, since startup profile is gone -- Abel
#
%{__mkdir_p} %{buildroot}%{_datadir}/texmf/dvips \
         %{buildroot}%{_datadir}/texmf/fonts/source \
         %{buildroot}%{_datadir}/lilypond/%{version}/fonts/type1
pushd %{buildroot}%{_datadir}/texmf > /dev/null
ln -s ../../lilypond/%{version}/ps dvips/lilypond
ln -s ../../../lilypond/%{version}/fonts/source fonts/source/lilypond
popd > /dev/null

%{find_lang} %{name}

mkdir -p %{buildroot}%_sysconfdir/X11/fontpath.d/
ln -s ../../..%_datadir/lilypond/%{version}/fonts/type1 \
    %{buildroot}%_sysconfdir/X11/fontpath.d/lilypond:pri=50

%post
%{_bindir}/find /var/lib/texmf \( -name 'feta*.pk' -or -name 'feta*.tfm' -or -name 'parmesan*.pk' -or -name 'parmesan*.tfm' \) -print0 | %{_bindir}/xargs -r -0 %{__rm} -f

if [ -x %{_bindir}/texhash ] ; then
    %{_bindir}/texhash > /dev/null
fi

%{_bindir}/mkfontdir %{_datadir}/lilypond/%{version}/fonts/type1

%preun
%{__rm} -f %{_datadir}/lilypond/%{version}/fonts/type1/fonts.dir

%postun
if [ -x %{_bindir}/texhash ] ; then
    %{_bindir}/texhash > /dev/null
fi

%files -f %{name}.lang
%doc README.md DEDICATION ROADMAP LICENSE LICENSE.DOCUMENTATION
%license COPYING
%{_bindir}/*
%{_datadir}/emacs/site-lisp/lilypond*
%{_datadir}/%{name}/
%{_datadir}/texmf/dvips/lilypond
%{_datadir}/texmf/fonts/source/lilypond
%{_datadir}/vim/*/*
%{_mandir}/man?/*
%{_infodir}/*.info*
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*
%{_sysconfdir}/X11/fontpath.d/lilypond:pri=50

%files doc
%doc %{name}-documentation-%{version}/*
