# Note from upstream:
# the SDL playback plugin is now deprecated in favour of the openGL playback plugin.
# For one thing the program will crash if you use the SDL plugin and projectM plugin at the same time.
# If you have both SDL 1 and SDL 2 installed, LiVES will detect both, since it will use SDL2 for projectM and SDL1 for the SDL playback plugin.
# Use 'SDL2' and 'projectM' together.
%bcond_without SDL2_projectM

# LiVES is not ready for FFMpeg-5* yet
%if 0%{?mageia} > 8
%bcond_with ffmpeg
%endif

%define major		0
%define libname		%mklibname weed %{major}
%define develname	%mklibname weed -d

Summary:	Linux Video Editing System
Name:		lives
Version:	3.2.0
Release:	%mkrel 8
License:	GPLv3+
Group:		Video/Editors and Converters
URL:		http://lives-video.com/
Source0:	http://lives-video.com/releases/LiVES-%{version}.tar.bz2
Patch1:		lives-3.2.0-opencv4.patch

BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(fftw3f)
BuildRequires:	pkgconfig(frei0r)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glee)
BuildRequires:	pkgconfig(glib-2.0) >= 2.14.0
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:	pkgconfig(libavc1394)
%if %{with ffmpeg}
BuildRequires:	pkgconfig(libavcodec) >= 53.0.0
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
%endif
BuildRequires:	pkgconfig(libdv)
BuildRequires:	pkgconfig(liboil-0.3) >= 0.3.9
BuildRequires:	pkgconfig(libpng) > 1.2.0
BuildRequires:	pkgconfig(libpulse) >= 0.9.14
BuildRequires:	pkgconfig(libraw1394)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libunicap)
BuildRequires:	pkgconfig(libvisual-0.4) >= 0.4.0
BuildRequires:	pkgconfig(mjpegtools) >= 1.6.2
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(opencv) >= 2.3.1
BuildRequires:	pkgconfig(schroedinger-1.0)
BuildRequires:  pkgconfig(libtirpc)
%if %{with SDL2_projectM}
BuildRequires:	pkgconfig(libprojectM)
BuildRequires:	pkgconfig(sdl2)
%endif
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xrender)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	bison
BuildRequires:	ladspa-devel
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(jack)
BuildRequires:	libv4l-devel
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(fftw3)
%if %{with ffmpeg}
Requires:	ffmpeg
%endif
Requires:	mplayer sox imagemagick
Requires:	cdrecord-cdda2wav
Requires:	xset
Requires:	libvisual-plugins
#This are not mandatory dependencies according to README
Recommends:	cdrkit-icedax
Recommends:	dvgrab
Recommends:	frei0r
Recommends:	lame
Recommends:	ladspa
Recommends:	mkvtoolnix
Recommends:	mpv
Recommends:	vorbis-tools
Recommends:	x264
Recommends:	yt-dlp

%description
The Linux Video Editing System (LiVES) is intended to be a simple yet powerful
video effects and editing system.  It uses common tools for most of its work
(mplayer, ImageMagick, GTK+, sox).

%package -n %{libname}
Summary:	Linux Video Editing System - shared libs
Group:		Video/Editors and Converters

%description -n %{libname}
This package contains shared libs for LiVES.

%package -n %{develname}
Summary:	Linux Video Editing System - Development files
Group:		Video/Editors and Converters
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains development files needed to build LiVES plugins.

%prep
%autosetup -p1

# update manually the library paths in libweed/*.pc files on a 64 bit system
%ifarch x86_64 aarch64
sed -i 's|\${exec_prefix}/lib|\${exec_prefix}/lib64|' libweed/*.pc
%endif

%build
%define _disable_ld_no_undefined 1
%configure \
           %if %{without SDL2_projectM}
           --disable-sdl2 --disable-projectM \
           %endif
           %if %{without ffmpeg}
           --disable-ffmpeg \
           %endif
           --enable-threads=posix
%make_build CPPFLAGS="$(pkg-config --cflags libtirpc)"

%install
%make_install

%find_lang %{name}

rm -fr %{buildroot}%{_datadir}/doc
rm -f %{buildroot}%{_datadir}/pixmaps/%{name}.xpm

# fix symlink
rm -rf %{buildroot}%{_bindir}/%{name}
ln -s %{_bindir}/%{name}-exe %{buildroot}%{_bindir}/%{name}

# don't ship .a or .la
find %{buildroot} -name '*.a' -delete
find %{buildroot} -name '*.la' -delete

# python shebang
%py3_shebang_fix \
  %{buildroot}%{_libdir}/lives/plugins/encoders/* \
  %{buildroot}%{_bindir}/lives_*

%files -f %{name}.lang
%doc AUTHORS C* docs/*.txt FEATURES GETTING*
%doc NEWS OMC/*.txt README RFX/*
%{_bindir}/*
%{_datadir}/%{name}
%{_libdir}/%{name}
%{_datadir}/applications/LiVES.desktop
%{_datadir}/app-install/icons/lives.png
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/lives.png

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/weed
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
