%define lib_name_orig lib%{name}
%define major 5
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s

%define hyphvers %(echo %{version}|sed -e 's/\\./\\-/g')

Summary: Utilities for lm_sensors
Name:    lm_sensors
Epoch:   1
Version: 3.6.0
Release: %mkrel 4
License: GPLv2+
Group:   System/Kernel and hardware
URL:     https://github.com/lm-sensors/lm-sensors
Source0: https://github.com/lm-sensors/lm-sensors/archive/V%{hyphvers}/lm-sensors-%{hyphvers}.tar.gz
Source3: sensord.service
Source4: lm_sensors.sysconfig
Patch1:  0001-egrep-is-obsolete-replacing-with-grep-E.patch
BuildRequires: bison
BuildRequires: chrpath
BuildRequires: flex
BuildRequires: pkgconfig(librrd)
BuildRequires: libsysfs-devel
Requires(post): rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
This package contains a collection of user space tools for general SMBus
access and hardware monitoring. SMBus, also known as System Management Bus,
is a protocol for communicating through a I2C ('I squared C') bus. Many modern
mainboards have a System Management Bus. There are a lot of devices which can
be connected to a SMBus; the most notable are modern memory chips with EEPROM
memories and chips for hardware monitoring.

Most modern mainboards incorporate some form of hardware monitoring chips.
These chips read things like chip temperatures, fan rotation speeds and
voltage levels. There are quite a few different chips which can be used
by mainboard builders for approximately the same results.

%package -n %{libname}
Summary: Libraries needed for lm_sensors
Group:   System/Libraries

%description -n	%{libname}
Libraries to access lm_sensors internal data.

%package -n %{develname}
Summary: Development libraries and header files for lm_sensors
Group:   Development/C
Requires(pre): %{libname} = %{epoch}:%{version}-%{release}
Requires(postun): %{libname} = %{epoch}:%{version}-%{release}
Requires: %{libname} = %{epoch}:%{version}-%{release}
Provides: lib%{name}-devel = %{epoch}:%{version}-%{release}
Provides: %{name}-devel = %{epoch}:%{version}-%{release}
Obsoletes: %{name}-devel < %{epoch}:%{version}-%{release}

%description -n %{develname}
Development libraries and header files for lm_sensors.

You might want to use this package while building applications that might
take advantage of lm_sensors if found.

%package -n %{staticname}
Summary: Static libraries for lm_sensors
Group:   Development/C
Requires(pre): %{develname} = %{epoch}:%{version}-%{release}
Requires(postun): %{develname} = %{epoch}:%{version}-%{release}
Provides: lib%{name}-static-devel = %{epoch}:%{version}-%{release}
Obsoletes: %{name}-static-devel < %{epoch}:%{version}-%{release}

%description -n %{staticname}
This package contains static libraries for lm_sensors.

%prep
%autosetup -p1 -n lm-sensors-%{hyphvers}

# fix runstatedir
sed -i -e 's,/var/run,%{_rundir},g' $(grep -rl /var/run)

%build
%set_build_flags
%define _MAKE_DEFS COMPILE_KERNEL=0 WARN=1 PREFIX=%{_prefix} ETCDIR=%{_sysconfdir} MANDIR=%{_mandir} PROG_EXTRA:=sensord LIBDIR=%{_libdir}
%define MAKE_DEFS %{_MAKE_DEFS}

# (tpg) get rid of custom ldflags, rpath
sed -i -e 's/EXLDFLAGS :=.*/EXLDFLAGS :=$(LDFLAGS)/g' Makefile

%make_build %{MAKE_DEFS} user

%install
%define MAKE_DEFS %{_MAKE_DEFS}

%make_install %{MAKE_DEFS} user_install

%{__mkdir_p} %{buildroot}%{_initrddir}
%{_bindir}/chrpath -d %{buildroot}%{_sbindir}/sensord
%{_bindir}/chrpath -d %{buildroot}%{_bindir}/sensors
%ifnarch ppc %arm %mips aarch64
%{_bindir}/chrpath -d %{buildroot}%{_sbindir}/isadump
%{_bindir}/chrpath -d %{buildroot}%{_sbindir}/isaset
%endif

%{__cat} > README.urpmi << EOF
* To use this package, you'll have to launch "sensors-detect" as root, and answer a few questions.
  No need to modify startup files as shown at the end, all will be done.
EOF

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/sensord.service
install -m 644 prog/init/lm_sensors.service %{buildroot}%{_unitdir}

# placeholder
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/lm_sensors

%post
MIGRATE=
[ ! -f %{_sysconfdir}/systemd/system/multi-user.target.wants/lm_sensors.service ] && MIGRATE=yes
%_post_service lm_sensors
%_post_service sensord
# (cg) Deal with a quirk of packaging... enable sensord if lm_sensors is enabled
if [ "$MIGRATE" = "yes" -a -f %{_sysconfdir}/systemd/system/multi-user.target.wants/lm_sensors.service ]; then
  ln -sf %{_unitdir}/sensord.service %{_sysconfdir}/systemd/system/multi-user.target.wants/sensord.service
fi

%preun
%_preun_service lm_sensors
%_preun_service sensord

%files
%doc CHANGES CONTRIBUTORS README doc README.urpmi
%config(noreplace) %{_sysconfdir}/sensors3.conf
%config(noreplace) %{_sysconfdir}/sysconfig/lm_sensors
%{_unitdir}/sensord.service
%{_unitdir}/lm_sensors.service
%{_bindir}/sensors
%{_bindir}/sensors-conf-convert
%ifnarch ppc %arm %mips aarch64
%{_sbindir}/isadump
%{_sbindir}/isaset
%endif
%{_sbindir}/sensors-detect
%{_sbindir}/sensord
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/fancontrol
%{_sbindir}/pwmconfig

%files -n %{libname}
%{_libdir}/libsensors.so.%{major}
%{_libdir}/libsensors.so.%{major}.*

%files -n %{develname}
%{_libdir}/libsensors.so
%dir %{_includedir}/sensors
%{_includedir}/sensors/*
%{_mandir}/man3/*

%files -n %{staticname}
%{_libdir}/libsensors.a
