%define         major 1
%define         libname %mklibname luv %{major}
%define         devname %mklibname luv -d

%define         dlver 1.48.0-2
%define         ver %(echo %{dlver} | tr - .)

#bcond_without  = lua
#bcond_with     = luajit
%bcond_without  lua

%{!?lua_compat_version: %global lua_compat_version 5.1}
%{!?lua_compat_libdir: %global lua_compat_libdir %{_libdir}/lua/%{lua_compat_version}}
%{!?lua_compat_pkgdir: %global lua_compat_pkgdir %{_datadir}/lua/%{lua_compat_version}}
%{!?lua_compat_builddir: %global lua_compat_builddir %{_builddir}/lua%{lua_compat_version}-luv-%{version}-%{release}}

# Shared library and development files are build against
# compat lua 5.1 if compat build is enabled
%bcond_without compat

Name:           lua-luv
Version:        %{ver}
Release:        %mkrel 1
Summary:        Bare libuv bindings for lua
Group:          Development/Other
License:        ASL 2.0
URL:            https://github.com/luvit/luv
Source0:        https://github.com/luvit/luv/releases/download/%{dlver}/luv-%{dlver}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        lua-luv-compat5.1.patch
Patch1:         linking.patch
Patch2:         lua-luv-module-location.patch
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(libuv)
%if %{with lua}
BuildRequires:  lua-devel
%else
BuildRequires:  luajit-devel
%endif
%if %{with compat}
BuildRequires:  lua%{lua_compat_version}-devel
%endif

%description
libuv bindings for %{?with_lua:lua %{lua_version}}%{!?with_lua:luajit}.

This library makes libuv available to lua scripts. It was made for the luvit
project but should usable from nearly any lua project.

%package -n lua%{lua_compat_version}-luv
Summary:        Bare libuv bindings for lua %{lua_compat_version}
Group:          Development/Other

%description -n lua%{lua_compat_version}-luv
libuv bindings for luajit and lua %{lua_compat_version}.

This library makes libuv available to lua scripts. It was made for the luvit
project but should usable from nearly any lua project.

%package -n %{libname}
Summary:        Bare libuv bindings for lua %{?with_compat:%{lua_compat_version}}
Group:          System/Libraries

%description -n %{libname}
libuv bindings for luajit and lua %{?with_compat:%{lua_compat_version}}.

This library makes libuv available to lua scripts. It was made for the luvit
project but should usable from nearly any lua project.

%package -n %{devname}
Summary:        Bare libuv bindings for lua %{?with_compat:%{lua_compat_version}}
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       lua%{?with_compat:%{lua_compat_version}}-luv-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 1.34.2.2-2

%description -n %{devname}
Development package for LUV.

libuv bindings for luajit and lua %{?with_compat:%{lua_compat_version}}.

This library makes libuv available to lua scripts. It was made for the luvit
project but should usable from nearly any lua project.

%prep
%autosetup -n luv-%{dlver} -p1

%if %{with compat}
rm -rf %{lua_compat_builddir}
cp -a . %{lua_compat_builddir}
pushd %{lua_compat_builddir}
patch -p1 < %{_sourcedir}/lua-luv-compat5.1.patch
popd
%endif

%build
%cmake -GNinja \
    -DBUILD_MODULE:BOOL=ON \
    -DBUILD_SHARED_LIBS:BOOL=%{?with_compat:OFF}%{?!with_compat:ON} \
    -DWITH_LUA_ENGINE:STRING=%{?with_lua:Lua}%{?!with_lua:LuaJIT} \
    -DWITH_SHARED_LIBUV:BOOL=ON \
    -DLUA_BUILD_TYPE:STRING=System \
    -DSHAREDLIBS_INSTALL_LIB_DIR:PATH=%{_libdir}
%cmake_build

%if %{with compat}
pushd %{lua_compat_builddir}
%cmake -GNinja \
    -DBUILD_MODULE:BOOL=ON \
    -DBUILD_SHARED_LIBS:BOOL=ON \
    -DWITH_LUA_ENGINE:STRING=%{?with_lua:Lua}%{?!with_lua:LuaJIT} \
    -DWITH_SHARED_LIBUV:BOOL=ON \
    -DLUA_BUILD_TYPE:STRING=System \
    -DSHAREDLIBS_INSTALL_LIB_DIR:PATH=%{_libdir}
%cmake_build
popd
%endif

%install
%cmake_install

%if %{with compat}
pushd %{lua_compat_builddir}
%cmake_install
popd
%endif

%files
%license LICENSE.txt
%doc README.md
%{lua_libdir}/luv.so

%if %{with compat}
%files -n lua%{lua_compat_version}-luv
%license LICENSE.txt
%doc README.md
%{lua_compat_libdir}/luv.so
%endif

%files -n %{libname}
%license LICENSE.txt
%doc README.md docs.md
%{_libdir}/libluv.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/luv/
%{_libdir}/libluv.so
%{_libdir}/pkgconfig/libluv.pc
