%define rcnum   rc1
%define rel     15

%bcond_without compat
%{!?lua_compat_version: %global lua_compat_version 5.1}
%{!?lua_compat_libdir: %global lua_compat_libdir %{_libdir}/lua/%{lua_compat_version}}
%{!?lua_compat_pkgdir: %global lua_compat_pkgdir %{_datadir}/lua/%{lua_compat_version}}
%{!?lua_compat_builddir: %global lua_compat_builddir %{_builddir}/lua%{lua_compat_version}-%{name}-%{version}-%{release}}

Summary:        Network access library for the Lua programming language
Name:           lua-socket
Version:        3.0
Release:        %mkrel -c %{rcnum} %{rel}
License:        MIT
Group:          Development/Other
URL:            https://www.impa.br/~diego/software/luasocket
Source0:        https://github.com/diegonehab/luasocket/archive/v%{version}-%{rcnum}.tar.gz

Patch1:         luasocket-3.0-settimeout.patch

# All changes in the upstream repo from %{baseversion} tag to the
# current master.
Patch10:        luasocket-no-global-vars.patch
# Fix for lua 5.3
Patch11:	luasocket-3.0-checkint.patch

BuildRequires:  pkgconfig(lua)
Requires:       lua%{lua_version}

%description
LuaSocket is a Lua extension library that is composed by two parts: a
C layer that provides support for the TCP and UDP transport layers,
and a set of Lua modules that add support for the SMTP (sending
e-mails), HTTP (WWW access) and FTP (uploading and downloading files)
protocols.

%if %{with compat}
%package -n lua%{lua_compat_version}-socket
Summary:        Network support for the Lua %{lua_compat_version} language
Obsoletes:      lua-socket%{lua_compat_version} < 3.0-0.rc1.11
Provides:       lua-socket%{lua_compat_version} = %{version}-%{release}
Requires:       lua(abi) = %{lua_compat_version}
Requires:       lua%{lua_compat_version}
BuildRequires:  lua%{lua_compat_version}-devel

%description -n lua%{lua_compat_version}-socket
LuaSocket is a Lua %{lua_compat_version} extension library that is composed by two parts: The
C core that provides support for the TCP and UDP transport layers, and the
set of Lua %{lua_compat_version} modules that add support for functionality commonly needed by
applications that deal with the Internet.

Among the support modules, the most commonly used implement the SMTP, HTTP
and FTP. In addition there are modules for MIME, URL handling and LTN12.
%endif

%prep
%setup -n luasocket-%{version}-%{rcnum}
%patch -P 1 -p1
%patch -P 11 -p1

%if %{with compat}
rm -rf %{lua_compat_builddir}
cp -a . %{lua_compat_builddir}
%endif

%patch -P 10 -p1

%build
%set_build_flags
%make_build linux \
  LUAV=%{lua_version} \
  OPTFLAGS="%{optflags} -fPIC -DLUA_COMPAT_APIINTCASTS"

%if %{with compat}
pushd %{lua_compat_builddir}
%make_build linux \
  LUAV=%{lua_compat_version} \
  LUAINC_linux=%{_includedir}/lua-%{lua_compat_version} \
  OPTFLAGS="%{optflags} -fPIC"
popd
%endif

%install
%set_build_flags
make install-unix OPTFLAGS="%{optflags}" INSTALL_TOP=%{buildroot} \
    INSTALL_TOP_CDIR=%{buildroot}%{lua_libdir} \
    INSTALL_TOP_LDIR=%{buildroot}%{lua_pkgdir}

%if %{with compat}
pushd %{lua_compat_builddir}
make install-unix OPTFLAGS="%{optflags}" INSTALL_TOP=%{buildroot} \
    INSTALL_TOP_CDIR=%{buildroot}%{lua_compat_libdir} \
    INSTALL_TOP_LDIR=%{buildroot}%{lua_compat_pkgdir}
popd
%endif

%files
%doc NEW README doc/*
%{lua_libdir}/mime/
%{lua_libdir}/socket/
%{lua_pkgdir}/*.lua
%{lua_pkgdir}/socket/

%if %{with compat}
%files -n lua%{lua_compat_version}-socket
%license LICENSE
%doc NEW README doc/*
%{lua_compat_libdir}/mime/
%{lua_compat_libdir}/socket/
%{lua_compat_pkgdir}/*.lua
%{lua_compat_pkgdir}/socket/
%endif
