%global major_version 5.4
# Normally, this is the same as version, but... not always.
%global test_version 5.4.7
# If you are incrementing major_version, enable bootstrapping and adjust accordingly.
# Version should be the latest prior build. If you don't do this, RPM will break and
# everything will grind to a halt.
%global bootstrap 0
%global bootstrap_major_version 5.3
%global bootstrap_version 5.3.6

%define compatname %mklibname %{name} %{bootstrap_major_version}

%define major %{major_version}
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s

Name:           lua
Version:        5.4.7
Release:        %mkrel 1
Summary:        Powerful light-weight programming language
License:        MIT
Group:          Development/Other
URL:            https://www.lua.org/
Source0:        https://www.lua.org/ftp/lua-%{version}.tar.gz
# copied from doc/readme.html on 2014-07-18
Source1:        mit.txt
%if 0%{?bootstrap}
Source2:        https://www.lua.org/ftp/lua-%{bootstrap_version}.tar.gz
%endif
Source3:        https://www.lua.org/tests/lua-%{test_version}-tests.tar.gz
# multilib
Source4:        luaconf.h
Patch0:         lua-5.4.0-beta-autotoolize.patch
Patch1:         lua-5.4.6-idsize.patch
Patch3:         lua-5.2.2-configure-linux.patch
Patch4:         lua-5.3.0-configure-compat-module.patch
Patch5:         lua-5.3.0-autotoolize.patch
Patch6:         lua-5.3.5-luac-shared-link-fix.patch
# https://www.lua.org/bugs.html
Patch7:         lua-5.4.7-bug1.patch
Patch8:         lua-5.4.7-bug2.patch
Patch9:         lua-5.4.7-bug3.patch

# Mga patches
Patch100:       lua-5.2.1-dynlib.patch

BuildRequires:  automake autoconf libtool readline-devel ncurses-devel
BuildRequires:  make
Provides:       lua%{major_version} = %{version}-%{release}
Conflicts:      lua5.1 < 5.1.5-18

%description
Lua is a powerful light-weight programming language designed for
extending applications. Lua is also frequently used as a
general-purpose, stand-alone language. Lua is free software.
Lua combines simple procedural syntax with powerful data description
constructs based on associative arrays and extensible semantics. Lua
is dynamically typed, interpreted from bytecodes, and has automatic
memory management with garbage collection, making it ideal for
configuration, scripting, and rapid prototyping.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/Other
Requires:       %{name}%{?_isa}  = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
# The RPM related dependencies bring nothing to a non-RPM Lua developer
# But we want them when packages BuildRequire lua-devel
Requires:       lua-rpm-macros
Requires:       pkgconfig
Provides:       lua-devel = %{version}-%{release}
Provides:       lua%{lua_version}-devel = %{version}-%{release}
Obsoletes:      %{_lib}lua5.3-devel < 5.4
Conflicts:      %{_lib}lua5.1-devel < 5.1.5-18

%description -n %{develname}
This package contains development files for %{name}.

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          System/Libraries
Provides:       lua(abi) = %{major_version}

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n %{staticname}
Summary:        Static library for %{name}
Group:          Development/Other
Requires:       %{develname} = %{version}-%{release}
Obsoletes:      %{_lib}lua5.3-static-devel < 5.4

%description -n %{staticname}
This package contains the static version of liblua for %{name}.

%package -n %{compatname}
Summary:        Libraries for %{name} %{bootstrap_major_version}
Group:          System/Libraries
Provides:       lua(abi) = %{bootstrap_major_version}
Obsoletes:      lua%{bootstrap_major_version} < %{major_version}
Provides:       lua%{bootstrap_major_version} = %{bootstrap_version}

%description -n %{compatname}
This package contains the shared libraries for %{name} %{bootstrap_major_version}.

%prep
%if 0%{?bootstrap}
%setup -q -a 2 -a 3 -n %{name}-%{version}
%else
%setup -q -a 3
%endif
cp %{SOURCE1} .
mv src/luaconf.h src/luaconf.h.template.in
%patch -P0 -p1 -E -z .autoxxx
%patch -P1 -p1 -z .idsize
%patch -P3 -p1 -z .configure-linux
%patch -P7 -p1 -b .bug1
%patch -P8 -p1 -b .bug2
%patch -P9 -p1 -b .bug3

# Put proper version in configure.ac, patch0 hardcodes 5.3.0
sed -i '/AC_INIT/s|5.[0-9].[0-9]|%{version}|g' configure.ac

%if 0%{?bootstrap}
pushd lua-%{bootstrap_version}/
%patch -P6 -p1 -b .luac-shared-link-fix
%patch -P100 -p1 -b .dynlib
sed -i -e "s|\$(V)|%{bootstrap_major_version}|g" src/Makefile
popd
%endif

%build
autoreconf -fi
%configure --with-readline --with-compat-module

# Autotools give me a headache sometimes.
sed -i 's|@pkgdatadir@|%{_datadir}|g' src/luaconf.h.template

%make_build LIBS="-lm -ldl"

%if 0%{?bootstrap}
pushd lua-%{bootstrap_version}
sed -i 's/-lncurses/-lncursesw/g' */Makefile*
# (tv) enable compat module (fix building rpm with lua-5.2):
%make_build linux CFLAGS="%{optflags} -fPIC -DLUA_USE_LINUX -DLUA_COMPAT_MODULE -DLUA_COMPAT_BITLIB -DLUA_COMPAT_APIINTCASTS"
popd
%endif

%check
cd ./lua-%{test_version}-tests/

# Dont skip the fully portable or ram-hungry tests:
# sed -i.orig -e '
#     /attrib.lua/d;
#     /files.lua/d;
#     /db.lua/d;
#     /errors.lua/d;
#     ' all.lua
# LD_LIBRARY_PATH=%%{buildroot}%%{_libdir} %%{buildroot}%%{_bindir}/lua all.lua

# Removing tests that fail under mock/koji
sed -i.orig -e '
    /db.lua/d;
    /errors.lua/d;
    ' all.lua
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %{buildroot}%{_bindir}/lua -e"_U=true" all.lua

%install
%make_install

mkdir -p %{buildroot}%{_libdir}/lua/%{major_version}
mkdir -p %{buildroot}%{_datadir}/lua/%{major_version}

# Rename luaconf.h to luaconf-<arch>.h to avoid file conflicts on
# multilib systems and install luaconf.h wrapper
mv %{buildroot}%{_includedir}/luaconf.h %{buildroot}%{_includedir}/luaconf-%{_arch}.h
install -p -m 644 %{SOURCE4} %{buildroot}%{_includedir}/luaconf.h

%if 0%{?bootstrap}
pushd lua-%{bootstrap_version}
install -Dpm755 src/liblua.so.%{bootstrap_major_version} %{buildroot}%{_libdir}/
mkdir -p %{buildroot}%{_libdir}/lua/%{bootstrap_major_version}
mkdir -p %{buildroot}%{_datadir}/lua/%{bootstrap_major_version}
popd
%endif

# add compat pkgconfig files
ln -s lua.pc %{buildroot}%{_libdir}/pkgconfig/lua%{major_version}.pc
ln -s lua.pc %{buildroot}%{_libdir}/pkgconfig/lua-%{major_version}.pc

# TODO: Remove after mga9
# Needed with %%ghost and scriptlets to silent update-alternatives warnings when updating:
# warning: %postun(lua5.3-5.3.6-3.mga9.x86_64) scriptlet failed, exit status 2
# ERROR: 'script' failed for lua5.3-5.3.6-3.mga9.x86_64
touch %{buildroot}%{_bindir}/lua5.{2,3}

%triggerun -- lua < 5.4
if [[ -e  %{_localstatedir}/lib/alternatives/lua ]]; then
   %{_sbindir}/update-alternatives --remove-all lua 2> /dev/null ||:
fi
touch %{_bindir}/lua5.2

%triggerun -- lua5.3 < 5.4
if [[ -e  %{_localstatedir}/lib/alternatives/lua ]]; then
   %{_sbindir}/update-alternatives --remove-all lua 2> /dev/null ||:
fi
touch %{_bindir}/lua5.3

%triggerpostun -- lua < 5.4
if [[ -f %{_bindir}/lua5.2 ]]; then
 rm -rf %{_bindir}/lua5.2
fi

%triggerpostun -- lua5.3 < 5.4
if [[ -f %{_bindir}/lua5.3 ]]; then
 rm -rf %{_bindir}/lua5.3
fi

%files
%{!?_licensedir:%global license %%doc}
%license mit.txt

%doc README doc/*.html doc/*.css doc/*.gif doc/*.png
%{_bindir}/lua
%ghost %{_bindir}/lua5.?
%{_bindir}/luac
%{_mandir}/man1/lua*.1*

%files -n %{libname}
%dir %{_libdir}/lua/
%dir %{_libdir}/lua/%{major_version}/
%{_libdir}/liblua-%{major_version}.so
%dir %{_datadir}/lua/
%dir %{_datadir}/lua/%{major_version}/

%if 0%{?bootstrap}
%files -n %{compatname}
%dir %{_libdir}/lua/%{bootstrap_major_version}/
%{_libdir}/liblua.so.%{bootstrap_major_version}
%dir %{_datadir}/lua/%{bootstrap_major_version}/
%endif

%files -n %{develname}
%{_includedir}/l*.h
%{_includedir}/l*.hpp
%{_libdir}/liblua.so
%{_libdir}/pkgconfig/*.pc

%files -n %{staticname}
%{_libdir}/*.a
