%global somajor 3
%global libname %mklibname %{name} %{somajor}
%global devname %mklibname %{name} -d

Summary: Lightweight C++ API library for Lua
Name: lutok
Version: 0.4
Release: %mkrel 20
License: BSD
Group: Development/Other
URL: https://code.google.com/p/lutok/
Source0: http://lutok.googlecode.com/files/lutok-%{version}.tar.gz
Source1: README.Fedora
BuildRequires: libatf-c++-devel >= 0.20
BuildRequires: atf-sh-devel
BuildRequires: pkgconfig(lua)

%define _testsdir %{_libexecdir}/lutok/tests

%description
Lutok provides thin C++ wrappers around the Lua C API to ease the
interaction between C++ and Lua.  These wrappers make intensive use of
RAII to prevent resource leakage, expose C++-friendly data types, report
errors by means of exceptions and ensure that the Lua stack is always
left untouched in the face of errors.  The library also provides a small
subset of miscellaneous utility functions built on top of the wrappers.

Lutok focuses on providing a clean and safe C++ interface; the drawback
is that it is not suitable for performance-critical environments.  In
order to implement error-safe C++ wrappers on top of a Lua C binary
library, Lutok adds several layers or abstraction and error checking
that go against the original spirit of the Lua C API and thus degrade
performance.

%prep
%setup -q

# Put the README.Fedora file in the top-level directory of the source tree so
# that the %doc call below can pick it up.
cp -p %{SOURCE1} README.Fedora

%build
# fix build on aarch64
autoreconf -vfi

%configure --docdir=%{_defaultdocdir}/lutok-doc-%{version} \
           --disable-static \
           --htmldir=%{_defaultdocdir}/lutok-doc-%{version}/html \
           --without-doxygen
make %{?_smp_mflags} testsdir=%{_testsdir}

%check
# In order to enable this, we need to add a BuildRequires on kyua-cli.  The
# problem is that kyua-cli depends on lutok.  Introducing a circular dependency
# for this minor benefit does not seem like the best move.  After all, we can
# always install lutok-tests later and run the tests post-install.
#make check testsdir=%{_testsdir}

%install
%make_install doc_DATA= testsdir=%{_testsdir}

# we don't want these
find %{buildroot} -name '*.la' -delete

%package -n %{libname}
Summary: Lightweight C++ API library for Lua
Group: System/Libraries

%description -n %{libname}
Lutok provides thin C++ wrappers around the Lua C API to ease the
interaction between C++ and Lua.  These wrappers make intensive use of
RAII to prevent resource leakage, expose C++-friendly data types, report
errors by means of exceptions and ensure that the Lua stack is always
left untouched in the face of errors.  The library also provides a small
subset of miscellaneous utility functions built on top of the wrappers.

Lutok focuses on providing a clean and safe C++ interface; the drawback
is that it is not suitable for performance-critical environments.  In
order to implement error-safe C++ wrappers on top of a Lua C binary
library, Lutok adds several layers or abstraction and error checking
that go against the original spirit of the Lua C API and thus degrade
performance.

%files -n %{libname}
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/liblutok.so.%{somajor}
%{_libdir}/liblutok.so.%{somajor}.*

%package -n %{devname}
Summary: Libraries and header files for Lutok development
Group: Development/C++
Provides: %{name}-devel%{?_isa} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Requires: %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
Provides the libraries and header files to develop applications that
use the Lutok C++ API to Lua.

%files -n %{devname}
%{_includedir}/lutok
%{_libdir}/liblutok.so
%{_libdir}/pkgconfig/lutok.pc

%package doc
Summary: API documentation of the Lutok library and example programs
Group: Documentation
BuildArch: noarch

%description doc
Provides HTML documentation describing the API of the Lutok library
and a collection of sample source programs to demonstrate the use
of the library.

%files doc
%{_defaultdocdir}/lutok-doc-%{version}

%package tests
Summary: Run-time tests of the Lutok library
Group: Development/Tools
Requires: %{libname} = %{version}-%{release}
Requires: %{devname} = %{version}-%{release}

%description tests
This package installs the run-time tests for the Lutok library.
Please see the README.Fedora file in the documentation directory for further
details on how to run the installed tests.

%files tests
%doc README.Fedora
%{_testsdir}

