%define major		1
%define libname		%mklibname lxc %{major}
%define develname	%mklibname lxc -d

Name:		lxc
Epoch:		1
Version:	6.0.4
Release:	%mkrel 1
Summary:	Linux Containers
Group:		System/Kernel and hardware
License:	LGPLv2+ and GPLv2
URL:		https://linuxcontainers.org
Source0:	https://linuxcontainers.org/downloads/%{name}/%{name}-%{version}.tar.gz
Patch1:		lxc-4.0.6-fix-bootorder.patch

BuildRequires:	meson
BuildRequires:	docbook-utils
BuildRequires:	docbook-dtd30-sgml
BuildRequires:	docbook2x
BuildRequires:	doxygen
BuildRequires:	kernel-headers
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(libseccomp)
BuildRequires:	pkgconfig(libselinux)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	graphviz

# lxc-extra subpackage not needed anymore, lxc-ls has been rewriten in
# C and does not depend on the Python3 binding anymore
Provides:	lxc-extra = %{epoch}:%{version}-%{release}
Obsoletes:	lxc-extra < 1:1.1.5-7

%{!?_pkgdocdir: %global _pkgdocdir %_defaultdocdir/%name}

%description
The package "%{name}" provides the command lines to create and manage
containers.  It contains a full featured container with the isolation
/ virtualization of the pids, the ipc, the utsname, the mount points,
/proc, /sys, the network and it takes into account the control groups.
It is very light, flexible, and provides a set of tools around the
container like the monitoring with asynchronous events notification,
or the freeze of the container. This package is useful to create
Virtual Private Server, or to run isolated applications like bash or
sshd.

%package -n	%{libname}
Summary:	Library for LXC
Group:		System/Libraries

%description -n %{libname}
Library for the Linux Kernel Containers.


%package -n	%{develname}
Summary:	Development files for LXC
Group:		Development/C
Requires:	%{libname} >= %{epoch}:%{version}-%{release}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}

%description -n %{develname}
Development files for the Linux Kernel Containers.


%package	doc
Summary:	Documentation for %{name}
Group:		Documentation
BuildArch:	noarch

%description    doc
This package contains documentation for %{name}.


%prep
%autosetup -p1

%build
%meson -D runtime-path=%{_rundir} \
       -D init-script=systemd \
       -D systemd-unitdir=%{_unitdir} \
       -D apparmor=false \
       -D man=true \
       -D pam-cgroup=true \
       -D capabilities=true \
       -D seccomp=true \
       -D openssl=true \
       -D selinux=true \
       -D seccomp=true

%meson_build

pushd doc/api
doxygen .
popd

%install
%meson_install

mkdir -p %{buildroot}%{_sharedstatedir}/%{name}

# remove static files
find %{buildroot}%{_libdir} -name '*.a' -delete

# cache dir
mkdir -p %{buildroot}%{_localstatedir}/cache/%{name}

# docs
mkdir -p %{buildroot}%{_pkgdocdir}/api
cp -a doc/api/html/* %{buildroot}%{_pkgdocdir}/api/

%find_lang %{name} --with-man --all-name

%check
%meson_test

%post
%_post_service %{name}
%_post_service %{name}-net
%_post_service %{name}-monitord

%preun
%_preun_service %{name}
%_preun_service %{name}-net
%_preun_service %{name}-monitord

%files -f %{name}.lang
%doc AUTHORS README.md
%{_bindir}/%{name}-*
%{_sbindir}/*%{name}*
%{_libexecdir}/%{name}/
%{_datadir}/%{name}/
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/default.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_libdir}/%{name}/rootfs/
%{_libdir}/security/pam_cgfs.so
%{_unitdir}/%{name}-net.service
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}-monitord.service
%{_datadir}/bash-completion/completions/%{name}*
%{_datadir}/bash-completion/completions/_%{name}
%{_mandir}/man[157]/%{name}*
%{_mandir}/man8/pam_cgfs.8.*
%dir %{_sharedstatedir}/%{name}/
%dir %{_localstatedir}/cache/%{name}

%files -n %{libname}
%doc AUTHORS README.md
%license COPYING
%{_libdir}/lib%{name}.so.%{major}{,.*}
%dir %{_libdir}/%{name}

%files -n %{develname}
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so

%files doc
%dir %{_pkgdocdir}
# README, AUTHORS and COPYING intentionally duplicated because -doc
# can be installed on its own.
%{_pkgdocdir}/*
%license COPYING
