%define lyxver  %(echo %{version} | cut -d. -f1,2)

Name:           lyx
Version:        2.4.3
Release:        %mkrel 1
Summary:        A word processor for the Desktop Environment
Group:          Office/Word processor
License:        GPLv2+
URL:            https://www.lyx.org/
Source0:        https://ftp.lip6.fr/pub/lyx/stable/%{lyxver}.x/%{name}-%{version}.tar.xz
Source1:        README.install.urpmi
## upstreamable patches

# From debian

Patch4:		lyx-PIC.patch

BuildRequires:  bc
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  dvips
BuildRequires:  gettext-devel
BuildRequires:  ghostscript
BuildRequires:  groff-for-man
BuildRequires:  imagemagick
BuildRequires:  ninja
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  texlive-collection-basic
BuildRequires:  latex
BuildRequires:  magic-devel
# let's build it without hunspell as enchant defaults to hunspell
# building with hunspell doesn't find the dictionary
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(mythes)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  sgml-tools
BuildRequires:  texinfo
BuildRequires:  xvkbd
BuildRequires:  locales-en

BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6SvgWidgets)
BuildRequires:  cmake(Qt6Widgets)

Requires:       cmsuper
Requires:       dvips
Requires:       fonts-ttf-latex
Requires:       latex
Requires:       texlive
Requires:       texlive-dist
Requires:       xdg-utils

Recommends:     biber

# Some stuff needed for LyX's documentation:
Recommends:     texlive-collection-basic
Recommends:     texlive-fontsextra

%description
LyX is a modern approach of writing documents with a computer which breaks
with the tradition of the obsolete typewriter concept.  It is designed for
people who want a professional output with a minimum of time effort, without
becoming specialists in typesetting.  Compared to common word processors LyX
will increase the productivity a lot, since most of the typesetting will be
done by the computer, not the author.  With LyX the author can concentrate on
the contents of their writing, since the computer will take care of the look.

%prep
%autosetup -p1

# prefer xdg-open over alternatives in configuration
for prog in xv firefox kghostview pdfview xdvi
do
    sed -i -e "s/'$prog'/'xdg-open', '$prog'/" lib/configure.py
done

# find hunspell
sed -i 's|hunspell-1.2|hunspell-1.7|' development/cmake/modules/FindHUNSPELL.cmake

cp -a %{SOURCE1} README.install.urpmi

%build
%cmake_qt6 \
 -GNinja \
 -DLYX_CXX_FLAGS_EXTRA="%{build_cxxflags}" \
 -DLYX_EXTERNAL_BOOST=ON \
 -DLYX_ENCHANT=ON \
 -DLYX_RELEASE=ON \
 -DLYX_PACKAGE_SUFFIX=OFF \
 -DLYX_PROGRAM_SUFFIX=OFF

cp -af po/* build/po/

%cmake_build

%install
%cmake_install

## Set up the lyx-specific class files where TeX can see then
TEXMF=%{_datadir}/texmf
mkdir -p %{buildroot}${TEXMF}/tex/latex
mv %{buildroot}%{_datadir}/%{name}/tex %{buildroot}${TEXMF}/tex/latex/%{name}

%find_lang %{name}

# icon
install -p -D -m644 lib/images/lyx.png \
  %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/lyx.png

install -p -D -m644 lib/images/lyx.svg \
  %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/lyx.svg

# ghost'd files
touch %{buildroot}%{_datadir}/lyx/lyxrc.defaults
touch %{buildroot}%{_datadir}/lyx/{packages,textclass}.lst

# fonts
install -m 0755 -d %{buildroot}%{_fontdir}
mv %{buildroot}%{_datadir}/lyx/fonts/*.ttf %{buildroot}%{_fontdir}/
rm -rf %{buildroot}%{_datadir}/lyx/fonts

# missing stuff
pushd lib/doc
for doc in $(find *  -type f); do
        install -Dm0644 $doc %{buildroot}%{_datadir}/lyx/doc/$doc
done
popd

## Now configure LyX
pushd %{buildroot}%{_datadir}/%{name}
%{__python3} configure.py > /dev/null
## Remove buildroot definition
sed -i -e 's,%{buildroot},,g' configure.log
popd

# bash completion
install -p -D -m 0644 lib/scripts/bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

# appdata
install -p -D -m 0644 lib/org.lyx.LyX.metainfo.xml %{buildroot}%{_metainfodir}/org.lyx.LyX.metainfo.xml

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
# tests/test_filetools error bogus ( see https://bugzilla.redhat.com/723938 )
make -C build -k check ||:

%postun
if [ $1 -eq 0 ] ; then
  texhash >& /dev/null
fi

%posttrans
texhash >& /dev/null

%files -f %{name}.lang
%doc README{,.*} ANNOUNCE RELEASE-NOTES README.install.urpmi
%{_bindir}/%{name}
%{_bindir}/lyxclient
%{_bindir}/tex2lyx
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/texmf/tex/latex/%{name}
%{_sysconfdir}/bash_completion.d/%{name}
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/48x48/apps/%{name}.png
%{_metainfodir}/org.lyx.LyX.metainfo.xml
