%global git_revision 9ae8768
%global date 20141027
%define rel 41

%bcond_with evolution

Name:           mail-notification
Version:        5.4
Release:        %mkrel %{rel}.%{date}.git.%{git_revision}
Summary:        Status icon that informs you if you have new mail

Group:          Networking/Mail
License:        GPLv3+
URL:            https://www.nongnu.org/mailnotify/
#Source0:        https://savannah.nongnu.org/download/mailnotify/mail-notification-%%{version}.tar.bz2
# Upstream isn't alive any more, use a github forked copy which contains all patches which
# have been collected over the past years: https://github.com/epienbroek/mail-notification
#
# To regenerate source tarball:
# wget https://github.com/epienbroek/mail-notification/tarball/$git_revision -O mail-notification-$git_revision.tar.gz
Source0:        mail-notification-%{git_revision}.tar.gz
# jb build system is turning on -Werror to build itself.  This patch fixes a
# warning with current gcc
Patch0: mail-notification-jb-gcc-format.patch

# Support aarch64
# https://bugzilla.redhat.com/show_bug.cgi?id=926114
Patch1:         mail-notification-aarch64.patch

# build break when building with evolution 3.11.2
Patch2:         mail-notification-evo3_11_2.patch

# Fix FTBFS against latest glibc
Patch3:         mail-notification-dont-link-against-bsd-compat.patch

# Build against evolution-data-server 3.23.2
Patch4:         mail-notification-eds3_23_2.patch

# Use gstreamer-1.0 to play sound
Patch5:		mail-notification-gstreamer1.patch

Patch6:		mail-notification-jb-c99.patch
Patch7:		mail-notification-incompatible-pointer-types.patch
Patch8:		mail-notification-maybe-uninitialized.patch
Patch9:		mail-notification-libxml2.patch

BuildRequires:  gettext
BuildRequires:  desktop-file-utils, scrollkeeper
BuildRequires:  pkgconfig(openssl) >= 0.9.6
BuildRequires:  pkgconfig(libsasl2) >= 2.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.14
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(libgnome-2.0)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(libnotify) >= 0.4.1
BuildRequires:  pkgconfig(gmime-2.6) >= 2.4
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  perl-XML-Parser
BuildRequires:  gob2 >= 2.0.17
%if %{with evolution}
BuildRequires:  evolution-devel >= 3.45.1
BuildRequires:  evolution-data-server-devel >= 3.45.1
%endif

# needed for the gtk-builder-convert tool
BuildRequires:  pkgconfig(gtk+-2.0)

# needed for the GConf RPM macros
BuildRequires:  GConf2

Requires:         hicolor-icon-theme

Requires(pre):    GConf2
Requires(post):   GConf2, scrollkeeper
Requires(preun):  GConf2
Requires(postun): scrollkeeper


%description
Mail Notification is a status icon (aka tray icon) that informs you if you
have new mail. It works with system trays implementing the freedesktop.org
System Tray Specification, such as the GNOME Panel Notification Area, the
Xfce Notification Area and the KDE System Tray.


%if %{with evolution}
%package        evolution-plugin
Summary:        Evolution plugin for Mail Notification
Group:          Networking/Mail
Requires:       %{name} = %{version}-%{release}

%description	evolution-plugin
Evolution support for Mail Notification.
%endif


%prep
%setup -q -n epienbroek-%{name}-%{git_revision}

%patch -P0 -p1
%patch -P2 -p1 -b .evo3_11_2
%patch -P3 -p0
%patch -P4 -p1 -b .eds3_23_2
%patch -P5 -p1
%patch -P6 -p1
%patch -P7 -p1 -b .incompatible-pointer-types
%patch -P8 -p1 -b .maybe-uninitialized
%patch -P9 -p1 -b .libxml2

# update config.{guess,sub} manually
cp -p /usr/lib/rpm/mageia/config.{guess,sub} jbsrc/tools/


%build
# Temporary build without any optimalisations so we
# can get better stacktraces for RHBZ #531088
CFLAGS=$(echo $RPM_OPT_FLAGS | sed s/O2/O0/)

jb_cflags="$RPM_OPT_FLAGS" jb_ldflags="$RPM_LD_FLAGS" \
./jb configure \
  cc="%{__cc}" \
  cflags="$CFLAGS" \
  cppflags="-D_GNU_SOURCE -Wno-deprecated-declarations" \
  ldflags="$RPM_LD_FLAGS" \
  destdir=$RPM_BUILD_ROOT \
  prefix=%{_prefix} \
  bindir=%{_bindir} \
  libdir=%{_libdir} \
  libexecdir=%{_libexecdir} \
  datadir=%{_datadir} \
  sysconfdir=%{_sysconfdir} \
  localstatedir=%{_localstatedir} \
  gtk3=yes \
%if %{with evolution}
  evolution=yes \
%else
  evolution=no \
%endif
  install-gconf-schemas=no

./jb build

# The build command above hides away all gcc commands and their warnings
# As they can be interesting show the build log manually
cat build/build.log


%install
# For GConf apps: prevent schemas from being installed at this stage
export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL=1

./jb install

#  clear /var/lib/scrollkeeper stuff here
rm -rf $RPM_BUILD_ROOT%{_localstatedir}

find $RPM_BUILD_ROOT -type f -name "*.la" -exec rm -f {} ';'

%if %{with evolution}
chmod +x $RPM_BUILD_ROOT%{_libdir}/evolution/plugins/*.so
%endif

desktop-file-install \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/gnome/autostart/  \
  --delete-original                                    \
  ${RPM_BUILD_ROOT}%{_sysconfdir}/xdg/autostart/mail-notification.desktop

desktop-file-install \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/applications      \
  --delete-original                                    \
  --add-category X-GNOME-NetworkSettings               \
  ${RPM_BUILD_ROOT}%{_datadir}/applications/mail-notification-properties.desktop

%find_lang %{name}

%post
/usr/bin/scrollkeeper-update -q -o %{_datadir}/omf/%{name} || :

touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :


%preun
%preun_uninstall_gconf_schemas %{name}


%postun
/usr/bin/scrollkeeper-update -q ||:

touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :


%files -f %{name}.lang
%doc AUTHORS NEWS README TODO
%license COPYING
%{_sysconfdir}/gconf/schemas/mail-notification.schemas
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/gnome/autostart/*mail-notification.desktop
%{_datadir}/applications/*mail-notification-properties.desktop
%{_datadir}/gnome/help/mail-notification/
%dir %{_datadir}/omf/mail-notification/
%{_datadir}/omf/mail-notification/mail-notification-C.omf
%{_datadir}/icons/hicolor/*/apps/mail-notification.*


%if %{with evolution}
%files evolution-plugin
%{_libdir}/evolution/plugins/*
%endif
