# (doktor5000) this package buildrequires other packages for their original/untranslated man pages
# those are then used to check and generate the localised versions of the contained man pages
# missing original man pages, for which localised version would be present, can be checked e.g. via
# bl man-pages-de.spec 2>&1 | grep "could not be found" | sort -u

%define	srcname manpages-l10n

%global distribution_ mageia-cauldron

%global translations \
    cs:    "Czech" \
    da:    "Danish" \
    de:    "German" \
    el:    "Greek" \
    es:    "Spanish" \
    fi:    "Finnish" \
    fr:    "French" \
    hu:    "Hungarian" \
    id:    "Indonesian" \
    it:    "Italian" \
    ko:    "Korean" \
    mk:    "Macedonian" \
    nb:    "Norwegian Bokmål" \
    nl:    "Dutch" \
    pl:    "Polish" \
    pt_BR: "Brazilian Portuguese" \
    ro:    "Romanian" \
    ru:    "Russian" \
    sr:    "Serbian" \
    sv:    "Swedish" \
    uk:    "Ukrainian" \
    vi:    "Vietnamese"

Name:		man-pages-l10n
# Bumping epoch as a consequence of replacing man-pages-ko standalone package that has higher version (Obsoletes/Provides not needed)
Epoch:          1
Version:	4.26.0
Release:	%mkrel 1
Summary:	Translations man (manual) pages from the Linux Documentation Project
License:	GPLv3
Group:		System/Internationalization
Url:		https://salsa.debian.org/manpages-l10n-team/manpages-l10n
Source0:	https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/archive/%{version}/%{srcname}-%{version}.tar.bz2
BuildArch:	noarch
BuildRequires:	man-db
BuildRequires:	po4a

%description
This project provides an infrastructure for translating manpages to different
languages. Currently we support the following languages:


  * cs    - Czech
  * da    - Danish
  * de    - German
  * el    - Greek
  * es    - Spanish
  * fi    - Finnish
  * fr    - French
  * hu    - Hungarian
  * id    - Indonesian
  * it    - Italian
  * ko:   - Korean
  * mk    - Macedonian
  * nb    - Norwegian Bokmål
  * nl    - Dutch
  * pl    - Polish
  * pt_BR - Brazilian Portuguese
  * ro    - Romanian
  * ru    - Russian
  * sr    - Serbian
  * sv    - Swedish
  * uk    - Ukrainian
  * vi    - Vietnamese

For a complete list of the supported packages, see https://salsa.debian.org/
manpages-l10n-team/manpages-l10n/-/raw/master/upstream/mageia-cauldron/packages.txt.

Note that not all man pages from the listed packages are already translated
into your language.

# generate subpackages
%{lua: for code, name in rpm.expand('%{translations}'):gmatch('(%S+):%s+(%b"")') do
    name = name:gsub('"', '')

    print('%package -n man-pages-' .. code .. '\n')
    print('Summary: ' .. name .. ' man (manual) pages from the Linux Documentation Project\n')
    print('Group:          System/Internationalization\n')
    print('Requires: man\n')
    print('Requires: locales-' .. code .. '\n')
    print('Provides: man-' .. code .. ' = ' .. rpm.expand('%{version}-%{release}') .. '\n')

    print('%description -n man-pages-' .. code .. '\n')
    print('Manual pages from the Linux Documentation Project, translated into ' .. name .. '.\n')
end}


%prep
%autosetup -p1 -n %{srcname}-%{version}

%build
autoreconf -fi
%configure --enable-distribution=%{distribution_}
%make_build

%install
%make_install

# prevent conflict with net-tools
rm %{buildroot}%{_mandir}/de/man5/ethers.5*

# create a mandb index for the below check
for lang in $(sed -n 's/^SUBDIRS\s\+=\s\+\(.*\)/\1/p' po/Makefile.am); do
LANG=$lang DESTDIR=%{buildroot} %{_bindir}/mandb %{buildroot}%{_mandir}/${lang}
# basic check if any man pages have been generated at all
# checks that size of generated mandb index is nonzero
[[ -s %{buildroot}%{_mandir}/${lang}/index.db ]] && rm -f %{buildroot}%{_mandir}/${lang}/index.db || exit 1
done

# remove conflicting files between xz-5.2.5 and man-pages-de-4.0.0 (mga#26447)
rm -rf %{buildroot}%{_mandir}/de/man1/xz.1{,.*} \
       %{buildroot}%{_mandir}/de/man1/xzdec.1{,.*} \
       %{buildroot}%{_mandir}/de/man1/xzdiff.1{,.*} \
       %{buildroot}%{_mandir}/de/man1/xzgrep.1{,.*} \
       %{buildroot}%{_mandir}/de/man1/xzless.1{,.*} \
       %{buildroot}%{_mandir}/de/man1/xzmore.1{,.*}

# generate %%files sections
%{lua: for code in rpm.expand('%{translations}'):gmatch('(%S+):%s+%b""') do
    print('%files -n man-pages-' .. code .. '\n')
    print('%license LICENSE COPYRIGHT.md\n')
    print('%doc AUTHORS.md CHANGES.md README.md\n')
    print(rpm.expand('%{_mandir}') .. '/' .. code .. '/man*/*\n')
end}

