%define major     0
%define libname   %mklibname %{name} %major
%define develname %mklibname %{name} -d

%bcond_without perl
%bcond_without python
%bcond_with ruby

Name:           marisa
Version:        0.2.6
Release:        %mkrel 3
Summary:        Matching Algorithm with Recursively Implemented StorAge
License:        LGPL-2.1-or-later OR BSD-2-Clause
Group:          System/Libraries
URL:            https://github.com/s-yata/marisa-trie/
Source:         https://github.com/s-yata/marisa-trie/archive/v%{version}/%{name}-trie-%{version}.tar.gz
Patch0:         marisa-0.2.6-fix-python-bindings-version.patch
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  swig

%description
Matching Algorithm with Recursively Implemented StorAge (MARISA) is a
static and space-efficient trie data structure. And libmarisa is a C++
library to provide an implementation of MARISA. Also, the package of
libmarisa contains a set of command line tools for building and
operating a MARISA-based dictionary.

A MARISA-based dictionary supports not only lookup but also reverse
lookup, common prefix search and predictive search.

%package -n %{libname}
Summary:        Matching Algorithm with Recursively Implemented StorAge
Group:          System/Libraries

%description -n %{libname}
Matching Algorithm with Recursively Implemented StorAge (MARISA) is a
static and space-efficient trie data structure. And libmarisa is a C++
library to provide an implementation of MARISA. Also, the package of
libmarisa contains a set of command line tools for building and
operating a MARISA-based dictionary.

A MARISA-based dictionary supports not only lookup but also reverse
lookup, common prefix search and predictive search.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.

%if %{with perl}
%package -n perl-marisa
Summary:        Perl bindings for %{name}
Group:          Development/Perl
BuildRequires:  perl-devel
Requires:       %{name} = %{version}

%description -n perl-marisa
Perl bindings for %{name}.
%endif

%if %{with python}
%package -n python3-marisa
Summary:        Python3 bindings for %{name}
Group:          Development/Python
BuildRequires:  python3-devel
Requires:       %{name} = %{version}

%description -n python3-marisa
Python3 bindings for %{name}.
%endif

%if %{with ruby}
%package -n ruby-marisa
Summary:        Ruby bindings for %{name}
Group:          Development/Ruby
BuildRequires:  ruby-devel
Requires:       ruby
Requires:       %{name} = %{version}

%description -n ruby-marisa
Ruby bindings for %{name}.
%endif

%prep
%autosetup -p1 -n marisa-trie-%{version}

%build
autoreconf -fiv
%configure --disable-static
%make_build

%if %{with perl}
# build perl
pushd bindings/perl
%{__perl} Makefile.PL INC="-I%{_builddir}/%{name}-trie-%{version}/include" LIBS="-L%{_builddir}/%{name}-trie-%{version}/lib/%{name}/.libs -lmarisa" INSTALLDIRS=vendor
%make_build
popd
%endif

%if %{with python}
# Regenerate Python bindings
%make_build --directory=bindings swig-python
# build python
pushd bindings/python
%{__python3} setup.py build_ext --include-dirs="%{_builddir}/%{name}-trie-%{version}/include" --library-dirs="%{_builddir}/%{name}-trie-%{version}/lib/%{name}/.libs"
%py3_build
popd
%endif

%if %{with ruby}
# Regenerate Ruby bindings
%make_build --directory=bindings swig-ruby
# build ruby
pushd bindings/ruby
ruby extconf.rb --with-opt-include="%{_builddir}/%{name}-trie-%{version}/include" --with-opt-lib="%{_builddir}/%{name}-trie-%{version}/lib/%{name}/.libs" --vendor
%make_build
popd
%endif

%install
%make_install

%if %{with perl}
# install perl
pushd bindings/perl
%make_install
rm -rf %{buildroot}%{perl_vendorarch}/auto/marisa/.packlist
rm -rf %{buildroot}%{perl_vendorarch}/benchmark.pl
rm -rf %{buildroot}%{perl_vendorarch}/sample.pl
%{_fixperms} -c %{buildroot}%{perl_vendorarch}/*
popd
%endif

%if %{with python}
# install python
pushd bindings/python
%py3_install
popd
%endif

%if %{with ruby}
# install ruby
pushd bindings/ruby
%make_install hdrdir=%{_includedir}/ruby-%{rb_ver} rubyhdrdir=%{_includedir}/ruby-%{rb_ver}
popd
%endif

%files
%doc AUTHORS README.md
%license COPYING.md
%{_bindir}/%{name}-benchmark
%{_bindir}/%{name}-build
%{_bindir}/%{name}-common-prefix-search
%{_bindir}/%{name}-dump
%{_bindir}/%{name}-lookup
%{_bindir}/%{name}-predictive-search
%{_bindir}/%{name}-reverse-lookup

%files -n %{libname}
%{_libdir}/libmarisa.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_includedir}/%{name}.h
%{_libdir}/libmarisa.so
%{_libdir}/pkgconfig/%{name}.pc

%if %{with perl}
%files -n perl-marisa
%dir %{perl_vendorarch}/auto/
%{perl_vendorarch}/auto/marisa
%{perl_vendorarch}/marisa.pm
%endif

%if %{with python}
%files -n python3-marisa
%{python3_sitearch}/_marisa.*.so
%{python3_sitearch}/marisa.py
%{python3_sitearch}/marisa-%{version}-py%{python3_version}.egg-info
%{python3_sitearch}/__pycache__/marisa*
%endif

%if %{with ruby}
%files -n ruby-marisa
%{rb_vendorarchdir}/%{name}.so
%endif
