# workaround debug-id conflicts (with clisp)
# https://bugs.mageia.org/show_bug.cgi?id=22545
# https://bugzilla.redhat.com/show_bug.cgi?id=1458416
%global _build_id_links none
# debuginfo.list ends up empty/blank anyway. disable
%global debug_package   %{nil}
# Inhibit automatic compressing of info files.
# Compressed info files break maxima's internal help.
%global __spec_install_post %{nil}

%define enable_pdfdoc    1

%define enable_tests     1

%define enable_gcl       1
%define enable_ecl       1
%define enable_clisp     1
%define enable_sbcl      1
%define enable_sbcl_exec 1
%define defaultlisp      sbcl

%ifarch aarch64
  %define enable_gcl     0
%endif

%if %enable_clisp
  %define clisp_flags	--enable-clisp
%else
  %define clisp_flags	--disable-clisp
%endif

%if %enable_gcl
  %define gcl_flags	--enable-gcl
%else
  %define gcl_flags	--disable-gcl
%endif

%if %enable_sbcl
  %if %enable_sbcl_exec
    %define sbcl_flags	--enable-sbcl-exec
  %else
    %define sbcl_flags  --enable-sbcl
  %endif
%else
  %define sbcl_flags	--disable-sbcl
%endif

%if %enable_ecl
  %define ecl_flags	--enable-ecl
%else
  %define ecl_flags	--disable-ecl
%endif

Name:           maxima
Version:        5.47.0
Release:        %mkrel 2
Summary:        Symbolic Computation Program
License:        GPLv2
Group:          Sciences/Mathematics
URL:            https://maxima.sourceforge.net/
Source0:        https://downloads.sourceforge.net/maxima/%{name}-%{version}.tar.gz
Source1:        icons-maxima.tar.bz2
Patch0:         maxima-5.45.1-xdg-utils.patch
Patch1:         maxima-fix-contrib-docs.patch
Patch2:         maxima-5.47.0-pdf-manual-a4-paper-size.patch

# From FC
## upstreamable patches
# https://bugzilla.redhat.com/show_bug.cgi?id=837142
# https://sourceforge.net/tracker/?func=detail&aid=3539587&group_id=4933&atid=104933
Patch50:	maxima-5.37.1-clisp-noreadline.patch

# handle multiple ldflags in ecl build
Patch52:	maxima-ecl_ldflags.patch

# Invoke python3 instead of python
Patch53:	maxima-5.47.0-python3.patch

# From Arch
Patch100:	matrixexp.patch
Source101:	maxima-sbcl-gmp.patch

BuildRequires:  desktop-file-utils
BuildRequires:  emacs
BuildRequires:  git
BuildRequires:  python3
BuildRequires:  recode
BuildRequires:  texinfo
BuildRequires:  texinfo-tex
BuildRequires:  texlive
BuildRequires:  time
BuildRequires:  tk

%if %{enable_clisp}
BuildRequires:  clisp
%endif

%if %{enable_gcl}
BuildRequires:  gcl
%else
Obsoletes:      %{name}-runtime-gcl < %{version}-%{release}
%endif

%if %{enable_sbcl}
BuildRequires:  sbcl
%define sbcl_version %(sbcl --version 2>/dev/null | cut -d' ' -f2)
%endif

%if %{enable_ecl}
BuildRequires:  ecl
BuildRequires:	pkgconfig(atomic_ops)
%else
Obsoletes:	%{name}-runtime-ecl < %{version}-%{release}
%endif

Requires:       %{name}-runtime-%{defaultlisp} = %{version}-%{release}
Requires:       gnuplot
Requires:	rlwrap

Recommends:     tk
Recommends:     tcl


%description
Maxima is a full symbolic computation program.  It is full featured doing
symbolic manipulation of polynomials, matrices, rational functions,
integration, Todd-coxeter, graphing, bigfloats.  It has a symbolic debugger
source level debugger for maxima code.  Maxima is based on the original Macsyma
developed at MIT in the 1970's. It is quite reliable, and has good garbage
collection, and no memory leaks. It comes with hundreds of self tests.


#--------------------------------------------------------------------

%package gui
Summary:        Tcl/Tk GUI interface to Maxima
Group:          Sciences/Mathematics
Requires:       %{name}
Requires:       tk
Provides:       x%{name} = %{version}-%{release}

%description gui
Tcl/Tk GUI interface to Maxima.


%files gui
%{_bindir}/x%{name}
%{_datadir}/applications/mageia-%{name}.desktop
%{_iconsdir}/hicolor/*/apps/*.png

#--------------------------------------------------------------------

%if %{enable_clisp}
%package runtime-clisp
Summary:        Maxima compiled with clisp
Group:          Sciences/Mathematics
Requires:       clisp
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-clisp
Maxima compiled with clisp.


%files runtime-clisp
%dir %{_libdir}/%{name}/%{version}/binary-clisp
%{_libdir}/%{name}/%{version}/binary-clisp/*
%endif

#--------------------------------------------------------------------

%if %{enable_gcl}
%package runtime-gcl
Summary:        Maxima compiled with GCL
Group:          Sciences/Mathematics
Requires:       %{name} = %{version}-%{release}
Recommends:     rlwrap
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-gcl
Maxima compiled with Gnu Common Lisp.


%files runtime-gcl
%{_bindir}/r%{name}
%dir %{_libdir}/%{name}/%{version}/binary-gcl
%{_libdir}/%{name}/%{version}/binary-gcl/*
%endif

#--------------------------------------------------------------------
%if %{enable_sbcl}
%package runtime-sbcl
Summary:        Maxima compiled with SBCL
Group:          Sciences/Mathematics
%if ! %enable_sbcl_exec
Requires:       sbcl = %{sbcl_version}
%endif
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-sbcl
Maxima compiled with SBCL.


%files runtime-sbcl
%dir %{_libdir}/%{name}/%{version}/binary-sbcl
%{_libdir}/%{name}/%{version}/binary-sbcl/*
%endif

%if %{enable_ecl}
%package runtime-ecl
Summary:        Maxima compiled with ECL
Group:          Sciences/Mathematics
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-runtime = %{version}-%{release}

%description runtime-ecl
Maxima compiled with ECL.


%files runtime-ecl
%dir %{_libdir}/%{name}/%{version}/binary-ecl
%{_libdir}/%{name}/%{version}/binary-ecl/*
%endif

#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
export PYTHON=%{__python3}

# suppress warnings
autoreconf -vfi

%configure \
	%{clisp_flags} \
	--disable-cmucl \
	%{ecl_flags} \
	%{gcl_flags} \
	%{sbcl_flags} \
	--with-default-lisp=%{defaultlisp}

%make_build

%if %{enable_pdfdoc}
make -C doc/info pdf
%endif

%if %{enable_tests}
%check
make -k check ||:
%endif

%install
export EXCLUDE_FROM_COMPRESS='maxima-index\.lisp|maxima\.info'
%make_install

# menu
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop << EOF
[Desktop Entry]
Name=Maxima
Comment=Tcl/Tk interface to Maxima
Exec=%{_bindir}/x%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Science;Math;
EOF

# icons
mkdir -p %{buildroot}%{_iconsdir}
tar xjf %{SOURCE1} -C %{buildroot}%{_iconsdir}

# remove /usr/share/info/dir generated file
rm -f %{buildroot}%{_datadir}/info/dir

%find_lang %{name} --with-man

%files -f %{name}.lang
%doc AUTHORS COPYING README
%if %{enable_clisp}
%doc README-lisps.md
%endif
%if %{enable_pdfdoc}
%doc doc/info/%{name}.pdf
%endif
%{_bindir}/%{name}
%{_bindir}/r%{name}
%{_bindir}/x%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/net.sourceforge.maxima.x%{name}.desktop
%{_metainfodir}/net.sourceforge.maxima.x%{name}.appdata.xml
%{_datadir}/bash-completion/completions/*maxima
%{_datadir}/mime/packages/x-ma*.xml
%{_datadir}/emacs/site-lisp/*
%{_datadir}/pixmaps/*%{name}*.png
%{_datadir}/pixmaps/*%{name}*.svg
%{_infodir}/*.info*
%{_infodir}/%{name}-index*.lisp*
%{_libexecdir}/%{name}/
%{_mandir}/man1/%{name}.1*
