%define major        11
%define major_0      0
%define libname      %mklibname med %{major}
%define libnamec     %mklibname medc %{major}
%define libmedimport %mklibname medimport %{major_0}
%define libmedfwrap  %mklibname medfwrap %{major}
%define devname      %mklibname med -d

Name:           med
Version:        5.0.0
Release:        %mkrel 3
Summary:        Library to exchange meshed data
Group:          System/Libraries
License:        LGPLv3+
URL:            https://www.salome-platform.org/
Source0:        https://files.salome-platform.org/Salome/medfile//%{name}-%{version}.tar.bz2
# - Install headers in %%_includedir/med
# - Use LIB_SUFFIX
# - Install cmake config files to %%_libdir/cmake
# - Install doc to %%_pkgdocdir
Patch1:         med_cmake.patch

Patch2:         med-hdf5-1.14.patch
# fix for python 3.13
Patch3:         med-py3.13.patch

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-gfortran
BuildRequires:  hdf5-devel >= 1.14.0
BuildRequires:  hdf5 >= 1.14.0
BuildRequires:  python3-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(zlib)


%description
MED-fichier (Modélisation et Echanges de Données, in English Modelisation
and Data Exchange) is a library to store and exchange meshed data or
computation results. It uses the HDF5 file format to store the data.


%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
The python3-%{name} package contains python3 bindings for %{name}.


%package        tools
Summary:        Runtime tools for %{name}
Requires:       tk

%description    tools
This package contains runtime tools for %{name}:
  - mdump: a tool to dump MED files
  - xmdump: graphical version of mdump
  - medconforme: a tool to validate a MED file
  - medimport: a tool to convert a MED v2.1 or v2.2 file into a MED v2.3 file


%package -n     %{libname}
Summary:        Library to exchange meshed data
Group:          System/Libraries

%description -n %{libname}
MED-fichier (Modélisation et Echanges de Données, in English Modelisation
and Data Exchange) is a library to store and exchange meshed data or
computation results. It uses the HDF5 file format to store the data.


%package -n     %{libnamec}
Summary:        C++ API library to exchange meshed data
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Obsoletes:      med < 4.1.0-3

%description -n %{libnamec}
MED-fichier (Modélisation et Echanges de Données, in English Modelisation
and Data Exchange) is a library to store and exchange meshed data or
computation results. It uses the HDF5 file format to store the data.


%package -n     %{libmedimport}
Summary:        MED import library to exchange meshed data
Group:          System/Libraries

%description -n %{libmedimport}
MED-fichier (Modélisation et Echanges de Données, in English Modelisation
and Data Exchange) is a library to store and exchange meshed data or
computation results. It uses the HDF5 file format to store the data.


%package -n     %{libmedfwrap}
Summary:        Fortran API library to exchange meshed data
Group:          System/Libraries

%description -n %{libmedfwrap}
MED-fichier (Modélisation et Echanges de Données, in English Modelisation
and Data Exchange) is a library to store and exchange meshed data or
computation results. It uses the HDF5 file format to store the data.


%package -n     %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libnamec} = %{version}-%{release}
Requires:       %{libmedimport} = %{version}-%{release}
Requires:       %{libmedfwrap} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      med-devel < 4.1.0-3

%description -n %{devname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
The %{name}-doc package contains the documentation for %{name}.


%prep
%autosetup -p1

# Fix build with SWIG 4.3
sed -i -e 's/SWIG_Python_AppendOutput/SWIG_AppendOutput/g' $(grep -rl SWIG_Python_AppendOutput)

# Fix file not utf8
iconv --from=ISO-8859-1 --to=UTF-8 ChangeLog > ChangeLog.new && \
touch -r ChangeLog ChangeLog.new && \
mv ChangeLog.new ChangeLog


%build
%cmake \
    -DMEDFILE_BUILD_PYTHON=ON \
    -DPYTHON_EXECUTABLE=%{python3} \
    -DMEDFILE_BUILD_TESTS=OFF \
%cmake_build

%install
%cmake_install

%check
ctest -V || :

%files -n %{libname}
%doc AUTHORS ChangeLog README
%license COPYING.LESSER
%{_libdir}/libmed.so.1*

%files -n %{libnamec}
%doc AUTHORS ChangeLog README
%license COPYING.LESSER
%{_libdir}/libmedC.so.%{major}{,.*}

%files -n %{libmedimport}
%license COPYING.LESSER
%{_libdir}/libmedimport.so.%{major_0}{,.*}

%files -n %{libmedfwrap}
%license COPYING.LESSER
%{_libdir}/libmedfwrap.so.%{major}{,.*}

%files -n python3-%{name}
%license COPYING
%{python3_sitearch}/%{name}/

%files tools
%license COPYING
%{_bindir}/*mdump*
%{_bindir}/medconforme
%{_bindir}/medimport

%files  -n %{devname}
%{_libdir}/*.so
%{_libdir}/cmake/MEDFile/
%{_includedir}/%{name}/

%files doc
%license COPYING.LESSER
%doc %{_pkgdocdir}
