%global libzen_version	0.4.41

Name:		mediainfo
Version:	25.03
Release:	%mkrel 1
Summary:	Supplies technical and tag information about a video or audio file
Group:		Sound/Utilities
License:	BSD
URL:		https://mediaarea.net/
Source0:	https://mediaarea.net/download/source/mediainfo/%{version}/mediainfo_%{version}.tar.bz2
BuildRequires:	pkgconfig(libmediainfo) >= %{version}
BuildRequires:	pkgconfig(libzen) >= %{libzen_version}
BuildRequires:	pkgconfig(zlib)
BuildRequires:	dos2unix
BuildRequires:	wxgtk-devel
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
%ifarch aarch64 x86_64
BuildRequires:	cmake(Qt6WebEngineWidgets)
%endif
BuildRequires:	imagemagick
BuildRequires:	python3

%description
MediaInfo supplies technical and tag information about a video or audio file.

What information can I get from MediaInfo?
* General: title, author, director, album, track number, date, duration...
* Video: codec, aspect, fps, bitrate...
* Audio: codec, sample rate, channels, language, bitrate...
* Text: language of subtitle
* Chapters: number of chapters, list of chapters

AV1, DivX, XviD, H263, H.263, H264, x264, ASP, AVC, iTunes, MPEG-1,
MPEG1, MPEG-2, MPEG2, MPEG-4, MPEG4, MP4, M4A, M4V, QuickTime,
RealVideo, RealAudio, RA, RM, MSMPEG4v1, MSMPEG4v2, MSMPEG4v3,
VOB, DVD, WMA, VMW, ASF, 3GP, 3GPP, 3GP2

What format (container) does MediaInfo support?
* Video: MKV, OGM, AVI, DivX, WMV, QuickTime, Real, MPEG-1,
  MPEG-2, MPEG-4, DVD (VOB) (Codecs: DivX, XviD, MSMPEG4, ASP,
  H.264, AVC...)
* Audio: OGG, MP3, WAV, RA, AC3, DTS, AAC, M4A, AU, AIFF
* Subtitles: SRT, SSA, ASS, SAMI

%package gui-wx
Summary:	wx-based GUI for %{name}
Group:		Sound/Utilities
Requires:	%{name}-gui-common = %{version}-%{release}
Provides:	%{name}-gui = %{version}-%{release}

%description gui-wx
wx-based graphical user interface for %{name}.

%package gui-qt
Summary:	Qt-based GUI for %{name}
Group:		Sound/Utilities
Requires:	%{name}-gui-common = %{version}-%{release}
Provides:	%{name}-gui = %{version}-%{release}
#The PLASMA service menu runs kdialog
Recommends:	kdialog

%description gui-qt
Qt-based graphical user interface for %{name}.

%package gui-common
Summary:	Common files for %{name} GUIs
Group:		Sound/Utilities
BuildArch:	noarch

%description gui-common
Common files for %{name} GUI packages.

%prep
%setup -q -n MediaInfo

# fix EOLs and rights
dos2unix License.html History_*.txt
chmod 644 *.html *.txt Release/*.txt

%build
# build CLI
pushd Project/GNU/CLI
	autoreconf -vfi
	%configure --disable-static
	%make_build
popd

# now build GUI
pushd Project/GNU/GUI
	autoreconf -vfi
	%configure --disable-static
	%make_build
popd

%ifarch aarch64 x86_64
# Generate translations files before build (#1039)
sh Source/GUI/Qt/Qt_Translations_Updater/update_Qt_translations.sh
# now build Qt GUI
pushd Project/QMake/GUI
	%qmake_qt6
	%make_build
popd
%endif

%install
pushd Project/GNU/CLI
	%make_install
popd

pushd Project/GNU/GUI
	%make_install
popd

%ifarch aarch64 x86_64
pushd Project/QMake/GUI
	# as of 18.08.1 it overwrites the Wx binary
	#make_install INSTALL_ROOT=%%{buildroot}
	install -m 755 %{name}-gui %{buildroot}%{_bindir}/%{name}-qt
popd
%endif

# icon
for i in 16 32 48 64 128; do
	mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/
	convert -scale ${i} Source/Resource/Image/MediaInfo.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

%ifarch aarch64 x86_64
# menu-entry for QT gui
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}-qt.desktop << EOF
[Desktop Entry]
Type=Application
Name=MediaInfo
Comment=Supplies technical and tag information about a video or audio file
Comment[fr]=fournit des informations techniques et les tags à propos de vos fichiers video et audio
Icon=%{name}
Exec=%{name}-qt %f
Terminal=false
Categories=AudioVideo;AudioVideoEditing;Qt;
MimeType=video/mpeg;video/x-mpeg;video/msvideo;video/quicktime;video/x-anim;video/x-avi;video/x-ms-asf;video/x-ms-wmv;video/x-msvideo;video/x-nsv;video/x-flc;video/x-fli;video/x-flv;video/vnd.rn-realvideo;video/mp4;video/mp4v-es;video/mp2t;application/ogg;application/x-ogg;video/x-ogm+ogg;audio/x-vorbis+ogg;application/x-matroska;audio/x-matroska;video/x-matroska;video/webm;audio/webm;audio/x-mp3;audio/x-mpeg;audio/mpeg;audio/x-wav;audio/x-mpegurl;audio/x-scpls;audio/x-m4a;audio/x-ms-asf;audio/x-ms-asx;audio/x-ms-wax;application/vnd.rn-realmedia;audio/x-real-audio;audio/x-pn-realaudio;application/x-flac;audio/x-flac;application/x-shockwave-flash;audio/vnd.rn-realaudio;audio/x-pn-aiff;audio/x-pn-au;audio/x-pn-wav;audio/x-pn-windows-acm;application/x-extension-mp4;audio/mp4;audio/amr;audio/amr-wb;application/x-shorten;audio/x-ape;audio/x-wavpack;audio/x-tta;audio/x-opus+ogg;
Keywords=mediainfo;metadata;tag;video;audio;subtitles;chapters;codec;mkv;mpeg;mp3;h264;avc;h265;hevc;avi;
EOF

# fix service menu
mkdir -p %{buildroot}%{_datadir}/kio/servicemenus
mv %{buildroot}%{_datadir}/kservices5/ServiceMenus/%{name}-gui.desktop \
  %{buildroot}%{_datadir}/kio/servicemenus/%{name}-qt.desktop

sed -i \
  -e 's|\(^Exec=\).*|\1kdialog -msgbox "$\(mediainfo-qt %u\)"|g' \
  -e 's|%{name}-gui|%{name}-qt|g' \
    %{buildroot}%{_datadir}/kio/servicemenus/%{name}-qt.desktop
%endif

# unneeded
rm -rf %{buildroot}%{_datadir}/apps/konqueror/servicemenus/%{name}-gui.desktop
rm -rf %{buildroot}%{_datadir}/kde4/services/ServiceMenus/%{name}-gui.desktop
%ifarch %{arm32} %{ix86}
rm -rf %{buildroot}%{_datadir}/kservices5/ServiceMenus/%{name}-gui.desktop
%endif

%files
%doc Release/ReadMe_CLI_Linux.txt
%doc License.html History_CLI.txt
%{_bindir}/mediainfo

%files gui-wx
%doc Release/ReadMe_GUI_Linux.txt
%doc License.html History_GUI.txt
%{_bindir}/%{name}-gui
%{_datadir}/applications/%{name}-gui.desktop

%files gui-common
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/mediainfo.svg
%{_datadir}/pixmaps/mediainfo.xpm
%{_metainfodir}/%{name}-gui.metainfo.xml

%ifarch aarch64 x86_64
%files gui-qt
%{_bindir}/%{name}-qt
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/kio/servicemenus/%{name}-qt.desktop
%endif
