%define abi     0.10
%define libname %mklibname %{name} %{abi}
%define devname %mklibname %{name} -d

Name:           mgba
Version:        0.10.3
Release:        %mkrel 2
Summary:        Fast and accurate Game Boy Advance emulator
Group:          Emulators
License:        MPLv2.0
URL:            https://mgba.io
Source0:        https://github.com/mgba-emu/mgba/archive/%{version}/%{name}-%{version}.tar.gz
Patch1:         mgba-0.9.3-unbundle-inih.patch
# fix for bundled rapidjson (P11->P16)
# https://github.com/Tencent/rapidjson/pull/719
Patch11:        0001-Removed-non-compiling-assignment-operator.-Fixed-718.patch
# https://github.com/Tencent/rapidjson/pull/719
Patch12:        0002-Explicitly-disable-copy-assignment-operator.patch
# https://github.com/Tencent/rapidjson/pull/1137
Patch13:        0003-Three-way-comparison-for-CLang-10-fix-1679.patch
# https://github.com/Tencent/rapidjson/pull/1679
Patch14:        0004-Fix-recursive-operator-call-in-C-20-1846.patch
# https://github.com/Tencent/rapidjson/pull/1847
Patch15:        0005-gate-definition-of-symmetric-equality-operators-on-i.patch
# https://github.com/Tencent/rapidjson/pull/2091
Patch16:        0006-do-not-define-operator-in-C-20.patch

BuildRequires:  cmake
BuildRequires:  ffmpeg-devel
# TODO: Unbundled lzma.
#BuildRequires:  lzma-devel
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Help)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(inih)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(MagickWand)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sqlite3)

Recommends:     %{name}-qt

Provides:       bundled(discord-rpc)
Provides:       bundled(rapidjson) = 1.1.0

%description
mGBA is an emulator for running Game Boy Advance games. It aims to be
faster and more accurate than many existing Game Boy Advance emulators,
as well as adding features that other emulators lack. It also supports
Game Boy and Game Boy Color games.

This package contains the command-line SDL 2 frontend for mGBA; the
"%{name}-qt" package contains a full-featured graphical Qt 5 frontend.

%package qt
Summary:        Qt frontend for the mGBA emulator
Group:          Emulators

%description qt
This package contains the Qt frontend of the mGBA emulator. The
lighter weight command-line SDL 2 frontend is provided by the "%{name}"
package.

%package -n %{libname}
Summary:        Shared data and library used by mGBA's Qt and SDL frontends
Group:          System/Libraries

%description -n %{libname}
This package contains the mGBA library and data files used by both the
Qt and SDL frontends of the mGBA emulator.

%package -n %{devname}
Summary:        Development files for libmgba
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for libmgba, the library for the mGBA emulator.

%prep
%autosetup -p1

# Unbundle thirdparty libs
rm -rf src/third-party/{inih,libpng,sqlite3,zlib}

%build
# FIXME:
# Workaround GCC 14 build error
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"
%cmake
%cmake_build

%install
%cmake_install

%files
%doc CHANGES README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man6/%{name}.6*

%files qt
%doc CHANGES README.md
%license LICENSE
%{_bindir}/%{name}-qt
%{_datadir}/%{name}/
%{_datadir}/applications/io.mgba.mGBA.desktop
%{_iconsdir}/hicolor/*/apps/io.mgba.mGBA.png
%{_mandir}/man6/%{name}-qt.6*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{abi}
%{_libdir}/lib%{name}.so.%{version}

%files -n %{devname}
%doc %{_docdir}/mGBA/
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}/
%{_includedir}/%{name}-util/
