# define intel date once for reuse
%define    debian_date 20180312
%define    intel_date 20250211

Summary:   Intel / AMD CPU Microcode
Name:      microcode
Version:   0.%{intel_date}
Release:   %mkrel 2
Group:     System/Kernel and hardware
License:   Distributable
# use the debian way to get microcodes for older CPUs as Intel removes old firmwares from recent releases
Source0:   https://ftp.debian.org/debian/pool/non-free/i/intel-microcode/intel-microcode_3.%{debian_date}.1.tar.xz
# from https://downloadcenter.intel.com/download/27431/Linux-Processor-Microcode-Data-File
# that points to: https://github.com/intel/Intel-Linux-Processor-Microcode-Data-Files/
Source1:   https://github.com/intel/Intel-Linux-Processor-Microcode-Data-Files/archive/microcode-%{intel_date}.tar.gz
# AMD now pushes their microcode to upstream linux-firmware git
# so this is a tarball of: https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/tree/amd-ucode
Source2:   amd-ucode-latest.tar.xz
# AMD SEV Firmware
Source3:   https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amd/amd_sev_fam17h_model0xh.sbin
Source4:   https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amd/amd_sev_fam17h_model3xh.sbin
Source5:   https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amd/amd_sev_fam19h_model0xh.sbin
Source6:   https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amd/amd_sev_fam19h_model1xh.sbin
Source7:   https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amd/amd_sev_fam19h_modelaxh.sbin
Source8:   https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amd/amd_sev_fam1ah_model0xh.sbin

Buildarch: noarch
BuildRequires: iucode-tool
BuildRequires: microcode_ctl
# (tmb) conflict lock elision enabled glibc as it will crash
Conflicts: glibc < 6:2.20-11

%description
Since PentiumPro, Intel CPU are made of a RISC chip and of a microcode whose
purpose is to decompose "old" ia32 instruction into new RISC ones.
P6 family is concerned: PPro, PII, Celeron, PIII, Celeron2.
Recent kernels have the ability to update this microcode.

The microcode update is volatile and needs to be uploaded on each system
boot, i.e. it doesn't reflash your cpu permanently.
Reboot and it reverts back to the old microcode.

This package contains microcode for Intel and Amd CPUs.

%prep
%setup -q -T -c

%build

# build the microcode file from several old ones
tar xvf %{SOURCE0}
pushd intel-microcode-3.%{debian_date}.1
  make
  mkdir intel-ucode
  /sbin/iucode_tool -Kintel-ucode intel-microcode.bin
popd

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}/lib/firmware/intel-ucode
pushd intel-microcode-3.%{debian_date}.1
install -m 644 intel-ucode/* %{buildroot}/lib/firmware/intel-ucode

# Intel microcodes not in  debian
tar xf %{SOURCE1} -C %{buildroot}/lib/firmware --strip-components=1
# move the "caveat" firmware in place as we have all needed microcode
# patches and are using early firmware loading
mv %{buildroot}/lib/firmware/intel-ucode-with-caveats/06-4f-01 %{buildroot}/lib/firmware/intel-ucode/
# remove unwanted stuff
rm -rf %{buildroot}/lib/firmware/intel-ucode-with-caveats/
rm -rf %{buildroot}/lib/firmware/linux-kernel-patches/
rm -f %{buildroot}/lib/firmware/microcode.dat
# move doc and license files
mkdir -p %{buildroot}/usr/share/doc/%{name}
mv %{buildroot}/lib/firmware/README.md %{buildroot}/usr/share/doc/%{name}/
mv %{buildroot}/lib/firmware/releasenote.md %{buildroot}/usr/share/doc/%{name}/
mv %{buildroot}/lib/firmware/security.md %{buildroot}/usr/share/doc/%{name}/
mkdir -p %{buildroot}/usr/share/licenses/%{name}
mv %{buildroot}/lib/firmware/license %{buildroot}/usr/share/licenses/%{name}/

# Amd microcodes
tar xf %{SOURCE2} -C %{buildroot}/lib/firmware
# Amd SEV Firmware
mkdir -p %{buildroot}/lib/firmware/amd
install -m 644 %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6} %{SOURCE7} %{SOURCE8} %{buildroot}/lib/firmware/amd
# add compat symlink for older kernels
pushd %{buildroot}/lib/firmware/amd
ln -s amd_sev_fam17h_model0xh.sbin sev.fw
popd

%post
if [ -z "$DURING_INSTALL" ] ; then
  kernel=$(uname -r)
  if [ -d /usr/lib/modules/$kernel ] ; then
    # rebuild initrd for currently running kernel
    /usr/bin/dracut -fq
  else
    # rebuild initrd for most recently installed kernel
    kernel=$(ls -1t /usr/lib/modules | head -1)
    /usr/bin/dracut -fq /boot/initrd-$kernel.img $kernel
  fi
fi

%clean

%files
%defattr(-,root,root,-)
%doc README.md
%doc releasenote.md
%doc security.md
%license license
/lib/firmware/amd/
/lib/firmware/amd-ucode/
/lib/firmware/intel-ucode/
