%{?mingw_package_header}

%global majorver1 8
%global majorver2 6
%global majorver %{majorver1}.%{majorver2}
%global	vers %{majorver}.15

%global pkgname tcl

Name: mingw-%{pkgname}
Version: %{vers}
Release: %mkrel 1
Summary: MinGW Windows Tool Command Language, pronounced tickle
Group:   Development/Other

License: TCL
URL: https://tcl.sourceforge.net/
Source0: https://downloads.sourceforge.net/sourceforge/tcl/%{pkgname}-core%{version}-src.tar.gz
BuildArch: noarch

BuildRequires: make
BuildRequires: autoconf
BuildRequires: file
BuildRequires: m4
BuildRequires: net-tools
BuildRequires: tcl
BuildRequires: mingw32-binutils
BuildRequires: mingw32-filesystem
BuildRequires: mingw32-gcc
BuildRequires: mingw32-zlib

BuildRequires: mingw64-binutils
BuildRequires: mingw64-filesystem
BuildRequires: mingw64-gcc
BuildRequires: mingw64-zlib

Patch0: tcl-8.6.15-autopath.patch
Patch1: tcl-8.6.15-conf.patch
Patch2: tcl-8.6.13-tcltests-path-fix.patch
Patch3: tcl-8.6.13-configure-c99.patch
Patch4: tcl-mingw.patch
Patch5: tcl-nativetclsh.patch
Patch6: tcl-mingw-w64-compatibility.patch
Patch7: tcl-nativezlib.patch


%description
The Tcl (Tool Command Language) provides a powerful platform for
creating integration applications that tie together diverse
applications, protocols, devices, and frameworks. When paired with the
Tk toolkit, Tcl provides a fastest and powerful way to create
cross-platform GUI applications.  Tcl can also be used for a variety
of web-related tasks and for creating powerful command languages for
applications.


%package -n mingw32-%{pkgname}
Summary: MinGW Windows Tool Command Language, pronounced tickle

%description -n mingw32-%{pkgname}
The Tcl (Tool Command Language) provides a powerful platform for
creating integration applications that tie together diverse
applications, protocols, devices, and frameworks. When paired with the
Tk toolkit, Tcl provides a fastest and powerful way to create
cross-platform GUI applications.  Tcl can also be used for a variety
of web-related tasks and for creating powerful command languages for
applications.

%package -n mingw64-%{pkgname}
Summary: MinGW Windows Tool Command Language, pronounced tickle

%description -n mingw64-%{pkgname}
The Tcl (Tool Command Language) provides a powerful platform for
creating integration applications that tie together diverse
applications, protocols, devices, and frameworks. When paired with the
Tk toolkit, Tcl provides a fastest and powerful way to create
cross-platform GUI applications.  Tcl can also be used for a variety
of web-related tasks and for creating powerful command languages for
applications.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n %{pkgname}%{version}
chmod -x generic/tclThreadAlloc.c

%build
pushd win
autoconf
%mingw_configure --disable-threads --enable-shared
%mingw_make_build TCL_LIBRARY=%{mingw32_datadir}/%{pkgname}%{majorver}
popd


%install
make install -C win/build_win32 INSTALL_ROOT=%{buildroot} TCL_LIBRARY=%{mingw32_datadir}/%{pkgname}%{majorver}
make install -C win/build_win64 INSTALL_ROOT=%{buildroot} TCL_LIBRARY=%{mingw64_datadir}/%{pkgname}%{majorver}

mv %{buildroot}%{mingw32_bindir}/tclsh%{majorver1}.%{majorver2} %{buildroot}%{mingw32_bindir}/tclsh%{majorver1}%{majorver2}.exe
mv %{buildroot}%{mingw64_bindir}/tclsh%{majorver1}.%{majorver2} %{buildroot}%{mingw64_bindir}/tclsh%{majorver1}%{majorver2}.exe
ln -s tclsh%{majorver1}%{majorver2}.exe %{buildroot}%{mingw32_bindir}/tclsh.exe
ln -s tclsh%{majorver1}%{majorver2}.exe %{buildroot}%{mingw64_bindir}/tclsh.exe

# for linking with -lib%%{pkgname}
ln -s lib%{pkgname}%{majorver1}%{majorver2}.dll.a %{buildroot}%{mingw32_libdir}/lib%{pkgname}.dll.a
ln -s lib%{pkgname}%{majorver1}%{majorver2}.dll.a %{buildroot}%{mingw64_libdir}/lib%{pkgname}.dll.a

ln -s ../share/%{pkgname}%{majorver} %{buildroot}/%{mingw32_libdir}/%{pkgname}%{majorver}
ln -s ../share/%{pkgname}%{majorver} %{buildroot}/%{mingw64_libdir}/%{pkgname}%{majorver}

# postgresql and maybe other packages too need tclConfig.sh
# paths don't look at /usr/lib for efficiency, so we symlink into tcl8.5 for now
ln -s %{mingw32_libdir}/%{pkgname}Config.sh %{buildroot}/%{mingw32_libdir}/%{pkgname}%{majorver}/%{pkgname}Config.sh
ln -s %{mingw32_libdir}/%{pkgname}Config.sh %{buildroot}/%{mingw64_libdir}/%{pkgname}%{majorver}/%{pkgname}Config.sh

mkdir -p %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/{generic,win}
mkdir -p %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/{generic,win}
find generic win -name "*.h" -exec cp -p '{}' %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/'{}' ';'
find generic win -name "*.h" -exec cp -p '{}' %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/'{}' ';'
( cd %{buildroot}/%{mingw32_includedir}
	for i in *.h ; do
		[ -f %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/generic/$i ] && ln -sf ../../$i %{buildroot}/%{mingw32_includedir}/%{pkgname}-private/generic ;
	done
) || true
( cd %{buildroot}/%{mingw64_includedir}
	for i in *.h ; do
		[ -f %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/generic/$i ] && ln -sf ../../$i %{buildroot}/%{mingw64_includedir}/%{pkgname}-private/generic ;
	done
) || true

# fix executable bits
chmod a-x %{buildroot}/%{mingw32_datadir}/%{pkgname}%{majorver}/encoding/*.enc
chmod a-x %{buildroot}/%{mingw64_datadir}/%{pkgname}%{majorver}/encoding/*.enc
chmod a-x %{buildroot}/%{mingw32_libdir}/*/pkgIndex.tcl
chmod a-x %{buildroot}/%{mingw64_libdir}/*/pkgIndex.tcl

# remove buildroot traces
sed -i -e "s|$PWD/win|%{_libdir}|; s|$PWD|%{_includedir}/%{name}-private|" %{buildroot}/%{mingw32_libdir}/%{pkgname}Config.sh
sed -i -e "s|$PWD/win|%{_libdir}|; s|$PWD|%{_includedir}/%{name}-private|" %{buildroot}/%{mingw64_libdir}/%{pkgname}Config.sh
rm -rf %{buildroot}/%{mingw32_datadir}/%{pkgname}%{majorver}/tclAppInit.c
rm -rf %{buildroot}/%{mingw64_datadir}/%{pkgname}%{majorver}/tclAppInit.c
rm -rf %{buildroot}/%{mingw32_datadir}/%{pkgname}%{majorver}/ldAix
rm -rf %{buildroot}/%{mingw64_datadir}/%{pkgname}%{majorver}/ldAix

# move windows packages to where tcl85.dll will find them
mv %{buildroot}/%{mingw32_libdir}/dde* %{buildroot}/%{mingw32_libdir}/%{pkgname}%{majorver}/
mv %{buildroot}/%{mingw64_libdir}/dde* %{buildroot}/%{mingw64_libdir}/%{pkgname}%{majorver}/
mv %{buildroot}/%{mingw32_libdir}/reg* %{buildroot}/%{mingw32_libdir}/%{pkgname}%{majorver}/
mv %{buildroot}/%{mingw64_libdir}/reg* %{buildroot}/%{mingw64_libdir}/%{pkgname}%{majorver}/

# remove local zlib
rm -f %{buildroot}/%{mingw32_bindir}/zlib1.dll
rm -f %{buildroot}/%{mingw64_bindir}/zlib1.dll


%files -n mingw32-%{pkgname}
%{mingw32_bindir}/%{pkgname}sh.exe
%{mingw32_bindir}/%{pkgname}sh%{majorver1}%{majorver2}.exe
%{mingw32_bindir}/%{pkgname}%{majorver1}%{majorver2}.dll
%{mingw32_libdir}/lib%{pkgname}%{majorver1}%{majorver2}.dll.a
%{mingw32_libdir}/lib%{pkgname}stub%{majorver1}%{majorver2}.a
%{mingw32_libdir}/lib%{pkgname}.dll.a
%{mingw32_libdir}/%{pkgname}Config.sh
%{mingw32_datadir}/%{pkgname}%{majorver}
%exclude %{mingw32_datadir}/%{pkgname}%{majorver}/dde1.4/tcldde14.dll.debug
%exclude %{mingw32_datadir}/%{pkgname}%{majorver}/reg1.3/tclreg13.dll.debug
%{mingw32_datadir}/%{pkgname}%{majorver1}
%{mingw32_includedir}/*
%{mingw32_libdir}/%{pkgname}%{majorver}
%doc changes
%doc license.terms

%files -n mingw64-%{pkgname}
%{mingw64_bindir}/%{pkgname}sh.exe
%{mingw64_bindir}/%{pkgname}sh%{majorver1}%{majorver2}.exe
%{mingw64_bindir}/%{pkgname}%{majorver1}%{majorver2}.dll
%{mingw64_libdir}/lib%{pkgname}%{majorver1}%{majorver2}.dll.a
%{mingw64_libdir}/lib%{pkgname}stub%{majorver1}%{majorver2}.a
%{mingw64_libdir}/lib%{pkgname}.dll.a
%{mingw64_libdir}/%{pkgname}Config.sh
%{mingw64_datadir}/%{pkgname}%{majorver}
%exclude %{mingw64_datadir}/%{pkgname}%{majorver}/dde1.4/tcldde14.dll.debug
%exclude %{mingw64_datadir}/%{pkgname}%{majorver}/reg1.3/tclreg13.dll.debug
%{mingw64_datadir}/%{pkgname}%{majorver1}
%{mingw64_includedir}/*
%{mingw64_libdir}/%{pkgname}%{majorver}
%doc changes
%doc license.terms


