%define major_teredo 5
%define major_tun6 0
%define libteredo %mklibname teredo %{major_teredo}
%define libtun6 %mklibname tun 6 %{major_tun6}

%define develname %mklibname miredo -d

Name:		miredo
Version:	1.2.6
Release:	%mkrel 6
Summary:	Tunneling of IPv6 over UDP through NATs

Group:		Networking/Other
License:	GPLv2+
URL:		https://www.remlab.net/miredo/
Source0:	https://www.remlab.net/files/miredo/miredo-%{version}.tar.xz
Source1:	miredo-client.service
Source2:	miredo-server.service
Patch0:		miredo-config-not-exec
Patch1:		reread-resolv-before-resolv-ipv4.patch
Patch2:		systemd_unit_dir_libdir.patch

BuildRequires:	pkgconfig(libcap)
BuildRequires:	gettext-devel

Requires(pre):	shadow-utils

Requires(post):		rpm-helper
Requires(preun):	rpm-helper

Requires(preun):	initscripts
Requires(postun):	initscripts

%description
Miredo is an implementation of the "Teredo: Tunneling IPv6 over UDP
through NATs" proposed Internet standard (RFC4380). It can serve
either as a Teredo client, a stand-alone Teredo relay, or a Teredo
server. Please install the miredo-server or miredo-client appropriately.
It is meant to provide IPv6 connectivity to hosts behind NAT
devices, most of which do not support IPv6, and not even
IPv6-over-IPv4 (including 6to4).

%package -n	%{libteredo}
Summary:	Tunneling of IPv6 over UDP through NATs
Group:		Networking/Other

%description -n	%{libteredo}
Miredo is an implementation of the "Teredo: Tunneling IPv6 over UDP
through NATs" proposed Internet standard (RFC4380). It can serve
either as a Teredo client, a stand-alone Teredo relay, or a Teredo
server. Please install the miredo-server or miredo-client appropriately.
It is meant to provide IPv6 connectivity to hosts behind NAT
devices, most of which do not support IPv6, and not even
IPv6-over-IPv4 (including 6to4).


%package -n %{libtun6}
Summary:	Tunneling of IPv6 over UDP through NATs
Group:		Networking/Other
Obsoletes:	%{_lib}libtun6_0 < 1.2.5-3

%description -n %{libtun6}
Miredo is an implementation of the "Teredo: Tunneling IPv6 over UDP
through NATs" proposed Internet standard (RFC4380). It can serve
either as a Teredo client, a stand-alone Teredo relay, or a Teredo
server. Please install the miredo-server or miredo-client appropriately.
It is meant to provide IPv6 connectivity to hosts behind NAT
devices, most of which do not support IPv6, and not even
IPv6-over-IPv4 (including 6to4).

%package -n	%{develname}
Summary:	Header files, libraries and development documentation for %{name}
Group:		Networking/Other
Requires:	%{libteredo} = %{version}-%{release}
Requires:	%{libtun6} = %{version}-%{release}

%description -n	%{develname}
This package contains the header files, development libraries and development
documentation for %{name}. If you would like to develop programs using %{name},
you will need to install %{name}-devel.

%package server
Summary:	Tunneling server for IPv6 over UDP through NATs
Group:		Networking/Other

%description server
Miredo is an implementation of the "Teredo: Tunneling IPv6 over UDP
through NATs" proposed Internet standard (RFC4380). This offers the server
part of miredo. Most people will need only the client part.

%package client
Summary:	Tunneling client for IPv6 over UDP through NATs
Group:		Networking/Other
Provides:	%{name} = %{version}-%{release}
Requires:	%{name}-common = %{version}-%{release}
Obsoletes:	%{name} <= 1.1.6


%description client
Miredo is an implementation of the "Teredo: Tunneling IPv6 over UDP
through NATs" proposed Internet standard (RFC4380). This offers the client
part of miredo. Most people only need the client part.


%package	common
Summary:	Tunneling client for IPv6 over UDP through NATs
Group:		Networking/Other
Provides:	%{name}-common = %{version}-%{release}
Obsoletes:	%{name}-common <= 1.1.6

%description common
Miredo is an implementation of the "Teredo: Tunneling IPv6 over UDP
through NATs" proposed Internet standard (RFC4380). This offers the client
part of miredo. Most people only need the client part.
Common package, that contains miredo-client and miredo-server


%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p0

%build
autoreconf -fi
%configure \
		--disable-static \
		--disable-rpath \
		--enable-miredo-user \

# rpath does not really work
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make_build


%install
%make_install

%find_lang %{name}

mkdir rpmdocs
mv %{buildroot}%{_docdir}/miredo/examples rpmdocs/
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/miredo-client.service
install -p -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/miredo-server.service
rm -f %{buildroot}%{_libdir}/lib*.la
touch %{buildroot}%{_sysconfdir}/miredo/miredo-server.conf

%pre common
%_pre_useradd miredo /var/empty /bin/true

%_post_service client

%_post_service server

%_preun_service client

%preun server
%_preun_service server

%postun common
%_postun_userdel miredo

%files -n %{libteredo}
%{_libdir}/libteredo.so.%{major_teredo}{,.*}

%files -n %{libtun6}
%{_libdir}/libtun6.so.%{major_tun6}{,.*}

%files -n %{develname}
%{_includedir}/libteredo/
%{_includedir}/libtun6/
%{_libdir}/libteredo.so
%{_libdir}/libtun6.so

%files server
%ghost %config(noreplace,missingok) %{_sysconfdir}/miredo/miredo-server.conf
%{_bindir}/teredo-mire
%{_sbindir}/miredo-server
%{_sbindir}/miredo-checkconf
%{_unitdir}/miredo-server.service
%doc %{_mandir}/man1/teredo-mire*
%doc %{_mandir}/man?/miredo-server*
%doc %{_mandir}/man?/miredo-checkconf*


%files client
%{_sbindir}/miredo
%doc %{_mandir}/man?/miredo.*
%{_unitdir}/miredo-client.service

%files common -f %{name}.lang
%{_unitdir}/miredo.service
%_libexecdir/miredo/
%dir %{_sysconfdir}/miredo
%config(noreplace) %{_sysconfdir}/miredo/miredo.conf
%config(noreplace) %{_sysconfdir}/miredo/client-hook
