%global toxenv py

Name:           mirrormanager2
Version:        1.0.0
Release:        7%{?dist}
Summary:        Mirror management application

# Most MirrorManager files are licensed under the MIT license. Some
# imported/derivated parts like zebra-dump-parser or the the script
# to generate the worldmaps are licensed under GPLv2 and GPLv2+
License:        MIT and GPLv2+ and GPLv2
URL:            https://github.com/fedora-infra/mirrormanager2/
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# Fedora has patched the original flask-xml-rpc instead of packaging the -re version.
Patch0:         mirrormanager2-flask-xml-rpc.patch

BuildArch:      noarch
# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch: %{ix86}

BuildRequires:  systemd-rpm-macros
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  protobuf-compiler
# Testing
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(responses)
BuildRequires:  rsync
BuildRequires:  python%{python3_pkgversion}-pyrpmmd

Requires:  %{name}-lib = %{version}-%{release}
Requires:  %{name}-filesystem = %{version}-%{release}

%description
MirrorManager keeps track of the public and private mirrors, that carry
Fedora, EPEL, and RHEL content. It is used by the Fedora infrastructure as
well as rpmfusion.org, a third-party repository.
It automatically selects the “best” mirror for a given user based on a set
of fallback heuristics (such as network, country or continent).


%package lib
Summary:        Library to interact with MirrorManager's database
BuildArch:      noarch

Requires:  %{name}-filesystem = %{version}-%{release}
Requires:  python%{python3_pkgversion}-IPy
Requires:  python%{python3_pkgversion}-dns
Requires:  python%{python3_pkgversion}-sqlalchemy >= 0.7
Requires:  python%{python3_pkgversion}-sqlalchemy
Requires:  python%{python3_pkgversion}-pyrpmmd
Requires:  python%{python3_pkgversion}-protobuf

%description lib
Library to interact with MirrorManager's database


%package crawler
Summary:        Crawler for MirrorManager
BuildArch:      noarch

Requires:  %{name}-filesystem = %{version}-%{release}
Requires:  %{name}-lib = %{version}-%{release}
Requires:  python%{python3_pkgversion}-geoip2
Requires:  logrotate
Requires(pre):  shadow-utils

%description crawler
Install the crawler for MirrorManager, crawling all the mirrors to find out
if they are up to date or not


%package backend
Summary:        Backend scripts for MirrorManager
BuildArch:      noarch

Requires:  %{name}-filesystem = %{version}-%{release}
Requires:  %{name}-lib = %{version}-%{release}
Requires:  logrotate
Requires(pre):  shadow-utils

%description backend
Install a number of utility scripts to be used manually or in cron jobs to
run MirrorManager.

%package client
Summary:        Fedora mirror management system downstream mirror tools
BuildArch:      noarch

Requires:  %{name}-filesystem = %{version}-%{release}
Requires:  logrotate
Requires:  systemd

Obsoletes: mirrormanager-client <= 1.4.4-6
Provides:  mirrormanager-client = %{version}-%{release}

%description client
Client-side, run on each downstream mirror, to report back to the
MirrorManager database a description of the content carried by that
mirror.

%package statistics
Summary:        Scripts to generate MirrorManager statistics
BuildArch:      noarch

Requires:  %{name}-filesystem = %{version}-%{release}
Requires:  %{name}-lib = %{version}-%{release}
Requires:  python%{python3_pkgversion}-geoip2
Requires:  python%{python3_pkgversion}-matplotlib
Requires:  python%{python3_pkgversion}-basemap

%description statistics
A collection of different statistics script which are analyzing
MirrorManager content or log files. It contains scripts to analyze
the mirrorlist server connections, draws maps of all available mirrors
and can also visualize how fast the master data propagates to all the
mirrors. As it depends on matplotlib it has a rather large dependency
tree.

%package filesystem
Summary:        Base directories used by multiple subpackages
BuildArch:      noarch

%description filesystem
Base directories used by multiple subpackages


%prep
%autosetup -p1


%generate_buildrequires
%pyproject_buildrequires

%build
# Recreating protobuf output
protoc --python_out=mirrorlist mirrormanager.proto
protoc --python_out=mirrormanager2/lib mirrormanager.proto
%pyproject_wheel


%install
%pyproject_install

# Create directories needed
# Apache configuration files
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/httpd/conf.d/
# MirrorManager configuration file
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/mirrormanager
# MirrorManager crawler log rotation
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d
# for .wsgi files mainly
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/mirrormanager2
# Stores temp files (.sock & co)
mkdir -p $RPM_BUILD_ROOT/%{_sharedstatedir}/mirrormanager
# Results and homedir
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/mirrormanager
# Lock files
mkdir -p $RPM_BUILD_ROOT/run/lock/mirrormanager
# Stores lock and pid info
mkdir -p $RPM_BUILD_ROOT/run/mirrormanager
# Log files
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/log/mirrormanager/crawler

# Install apache configuration file
install -m 644 utility/mirrormanager.conf.sample \
    $RPM_BUILD_ROOT/%{_sysconfdir}/httpd/conf.d/mirrormanager.conf

# Install configuration file
install -m 644 utility/mirrormanager2.cfg.sample \
    $RPM_BUILD_ROOT/%{_sysconfdir}/mirrormanager/mirrormanager2.cfg

# Install crawler logrotate definition
install -m 644 utility/mm2_crawler.logrotate \
    $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/mm2_crawler

# Install umdl logrotate definition
install -m 644 utility/mm2_umdl.logrotate \
    $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/mm2_umdl

# Install WSGI file
install -m 644 utility/mirrormanager2.wsgi \
    $RPM_BUILD_ROOT/%{_datadir}/mirrormanager2/mirrormanager2.wsgi

# Install the createdb script
install -m 755 createdb.py \
    $RPM_BUILD_ROOT/%{_datadir}/mirrormanager2/mirrormanager2_createdb.py

# Install the tmpfile creating the /run/mirrormanager folder upon reboot
mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 utility/backend_tempfile.conf \
    $RPM_BUILD_ROOT/%{_tmpfilesdir}/%{name}-backend.conf

# Install the alembic files
cp -r alembic $RPM_BUILD_ROOT/%{_datadir}/mirrormanager2/
install -m 644 utility/alembic.ini $RPM_BUILD_ROOT/%{_sysconfdir}/mirrormanager/alembic.ini

# Install the zebra-dump-parser perl module
cp -r utility/zebra-dump-parser $RPM_BUILD_ROOT/%{_datadir}/mirrormanager2/

# Install the client files
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/mirrormanager-client
install -m 0644 client/report_mirror.conf \
    $RPM_BUILD_ROOT/%{_sysconfdir}/mirrormanager-client/report_mirror.conf

# Install the country_continent file from MaxMind
install -m 0644 utility/country_continent.csv \
    $RPM_BUILD_ROOT/%{_datadir}/mirrormanager2/country_continent.csv

# Fix the shebang for various scripts
sed -e "s|#!/usr/bin/env python.*|#!%{__python3}|" -i \
    $RPM_BUILD_ROOT/%{_bindir}/* \
    $RPM_BUILD_ROOT/%{_datadir}/mirrormanager2/*.py \
    $RPM_BUILD_ROOT/%{python3_sitelib}/mirrormanager2/lib/umdl.py


%pre crawler
getent group mirrormanager >/dev/null || groupadd -r mirrormanager
getent passwd mirrormanager >/dev/null || \
    useradd -r -g mirrormanager -d %{_localstatedir}/lib/mirrormanager -s /sbin/nologin \
    -c "MirrorManager" mirrormanager
exit 0

%pre backend
getent group mirrormanager >/dev/null || groupadd -r mirrormanager
getent passwd mirrormanager >/dev/null || \
    useradd -r -g mirrormanager -d %{_localstatedir}/lib/mirrormanager -s /sbin/nologin \
    -c "MirrorManager" mirrormanager
exit 0

%check
# Exclude test_ui_app.py as it requires network connectivity
MM2_SKIP_NETWORK_TESTS=1 %{pytest} tests

%files
%doc README.rst doc/
%config(noreplace) %{_sysconfdir}/httpd/conf.d/mirrormanager.conf
%config(noreplace) %{_sysconfdir}/mirrormanager/mirrormanager2.cfg

%dir %{_sysconfdir}/mirrormanager/
%dir %{python3_sitelib}/%{name}/
%dir %{python3_sitelib}/%{name}/__pycache__

%config(noreplace) %{_sysconfdir}/mirrormanager/alembic.ini

%{_datadir}/mirrormanager2/mirrormanager2.wsgi
%{_datadir}/mirrormanager2/mirrormanager2_createdb.py
%{_datadir}/mirrormanager2/alembic/

%{python3_sitelib}/%{name}/*.py
%{python3_sitelib}/%{name}/__pycache__/*
%{python3_sitelib}/%{name}/templates/
%{python3_sitelib}/%{name}/static/
%{python3_sitelib}/%{name}*.dist-info

%files filesystem
%license LICENSE-MIT-X11 LICENSE-GPLv2
%dir %{python3_sitelib}/%{name}
%dir %{_datadir}/mirrormanager2
%{_datadir}/mirrormanager2/country_continent.csv

%files lib
%{python3_sitelib}/%{name}/lib/
%{python3_sitelib}/%{name}/__init__.py
%{python3_sitelib}/%{name}/__pycache__/__init__.*.py*


%files crawler
%config(noreplace) %{_sysconfdir}/logrotate.d/mm2_crawler
%attr(755,mirrormanager,mirrormanager) %dir %{_localstatedir}/lib/mirrormanager
%attr(755,mirrormanager,mirrormanager) %dir %{_localstatedir}/log/mirrormanager
%attr(755,mirrormanager,mirrormanager) %dir %{_localstatedir}/log/mirrormanager/crawler
%{_bindir}/mm2_crawler


%files backend
%config(noreplace) %{_sysconfdir}/logrotate.d/mm2_umdl
%attr(755,mirrormanager,mirrormanager) %dir /run/lock/mirrormanager
%attr(755,mirrormanager,mirrormanager) %dir %{_localstatedir}/lib/mirrormanager
%attr(755,mirrormanager,mirrormanager) %dir %{_localstatedir}/log/mirrormanager
%attr(755,mirrormanager,mirrormanager) %dir /run/mirrormanager
%{_tmpfilesdir}/%{name}-backend.conf
%{_datadir}/mirrormanager2/zebra-dump-parser/
%{_bindir}/mm2_emergency-expire-repo
%{_bindir}/mm2_get_global_netblocks
%{_bindir}/mm2_get_internet2_netblocks
%{_bindir}/mm2_move-devel-to-release
%{_bindir}/mm2_move-to-archive
%{_bindir}/mm2_update-EC2-netblocks
%{_bindir}/mm2_update-master-directory-list
%{_bindir}/mm2_umdl2
%{_bindir}/mm2_create_install_repo
%{_bindir}/mm2_upgrade-install-repo


%files client
%dir %{_sysconfdir}/mirrormanager-client
%config(noreplace) %{_sysconfdir}/mirrormanager-client/report_mirror.conf
%{_bindir}/report_mirror

%files statistics
%{_bindir}/mm2_generate-worldmap
%{_bindir}/mm2_propagation
%{_bindir}/mirrorlist_statistics


