Name:           mkosi
Version:        25.2
Release:        %mkrel 2
Summary:        Create bespoke OS images
Group:          Development/Tools
License:        LGPLv2+
URL:            https://github.com/systemd/mkosi
Source0:        https://github.com/systemd/mkosi/archive/v%{version}/%{name}-%{version}.tar.gz
ExclusiveArch:	x86_64
BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-pytest
BuildRequires:  python3dist(setuptools-scm)

Recommends:     dnf
Recommends:     gnupg
Recommends:     xz
Recommends:     tar
Recommends:     e2fsprogs
Recommends:     squashfs-tools
Recommends:     cryptsetup
Recommends:     binutils
Recommends:     debootstrap
Recommends:     arch-install-scripts
Recommends:     edk2-ovmf
Recommends:     btrfs-progs
Recommends:     dosfstools
Recommends:     cpio
Recommends:     zstd
Recommends:     python3dist(argcomplete)
Recommends:     python3dist(cryptography)
Recommends:     python3dist(pexpect)

%description
A fancy wrapper around "dnf --installroot", "apt", "pacman", and "zypper" that
generates disk images with a number of bells and whistles.

Generated images are tailored to the purpose: GPT partitions,
systemd-boot or grub2, images for containers, VMs, initrd, and extensions.

Mkosi can boot an image via QEMU or systemd-nspawn, or simply start a shell in
chroot, burn the image to a device, connect to a running VM via ssh, extract
logs and coredumps, and also serve an image over HTTP.

See https://mkosi.systemd.io/ for documentation.

%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires

%build
%if ! 0%{?mageia}
tools/make-man-page.sh
%endif

%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files mkosi

%if ! 0%{?mageia}
mkdir -p %{buildroot}%{_mandir}/man1
ln -s -t %{buildroot}%{_mandir}/man1/ \
         ../../../..%{python3_sitelib}/mkosi/resources/mkosi.1
%endif

%files -f %pyproject_files
%license LICENSES/*
%doc README.md
%_bindir/mkosi
%_bindir/mkosi-initrd
%_bindir/mkosi-addon
%_bindir/mkosi-sandbox
#%%_mandir/man1/mkosi.1*

%check
%if %{with tests}
%pytest tests/ -v

# just a smoke test for syntax or import errors
%py3_test_envvars %{buildroot}%{_bindir}/mkosi --help >/dev/null
%endif

