# (kamil) walk-around GCC bug
%bcond_with buildoptimization

%define _bindir   /bin

Summary:	  MirBSD enhanced version of the Korn Shell
Name:		  mksh
Version:	  59c
Release:	  %mkrel 3
# BSD (setmode.c), ISC (strlcpy.c), MirOS (the rest)
License:	  BSD and ISC and MirOS
Group:		  Shells
URL:		  https://www.mirbsd.org/mksh.htm
Source0:	  https://www.mirbsd.org/MirOS/dist/mir/%{name}/%{name}-R%{version}.tgz
Source1:	  https://www.mirbsd.org/MirOS/dist/hosted/other/prt.mkshrc
Source2:	  rtchecks.expected
Source3:	  dot-mkshrc
Provides:	  /bin/lksh
Provides:	  /bin/mksh
Requires(post):	  grep
BuildRequires:	  ed
Requires(postun): sed
BuildRequires:	  util-linux
Requires(postun):	rpm-helper
Requires(post):	  rpm-helper

%description
mksh is the MirBSD enhanced version of the Public Domain Korn shell (pdksh),
a Bourne-compatible shell which is largely similar to the original
AT&T Korn shell; mksh is the only pdksh derivate currently being actively
developed.  It includes bug fixes and feature improvements, in order to produce
a modern, robust shell good for interactive and especially script use. mksh has
UTF-8 support (in substring operations and the Emacs editing mode).

%prep
%setup -q -n %{name}

# we'll need this later
cat >rtchecks <<'EOF'
typeset -i sari=0
typeset -Ui uari=0
typeset -i x=0
print -r -- $((x++)):$sari=$uari. #0
let --sari --uari
print -r -- $((x++)):$sari=$uari. #1
sari=2147483647 uari=2147483647
print -r -- $((x++)):$sari=$uari. #2
let ++sari ++uari
print -r -- $((x++)):$sari=$uari. #3
let --sari --uari
let 'sari *= 2' 'uari *= 2'
let ++sari ++uari
print -r -- $((x++)):$sari=$uari. #4
let ++sari ++uari
print -r -- $((x++)):$sari=$uari. #5
sari=-2147483648 uari=-2147483648
print -r -- $((x++)):$sari=$uari. #6
let --sari --uari
print -r -- $((x++)):$sari=$uari. #7
(( sari = -5 >> 1 ))
((# uari = -5 >> 1 ))
print -r -- $((x++)):$sari=$uari. #8
(( sari = -2 ))
((# uari = sari ))
print -r -- $((x++)):$sari=$uari. #9
EOF

%build
# Work around RHBZ #922974 on Fedora 19 and later
CFLAGS="%{optflags} -DMKSH_DISABLE_EXPERIMENTAL" \
LDFLAGS="%{ldflags}" sh Build.sh -r \
%if %{with optimization}
	-c lto
%endif

cp test.sh test_mksh.sh
export HAVE_PERSISTENT_HISTORY=0
# Work around RHBZ #922974 on Fedora 19 and later
CFLAGS="%{optflags} -DMKSH_DISABLE_EXPERIMENTAL" \
LDFLAGS="%{ldflags}" sh Build.sh -L -r \
%if %{with optimization}
	-c lto
%endif

cp -f test.sh test_lksh.sh

%install
install -D -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m 0755 lksh %{buildroot}%{_bindir}/lksh
install -D -m 0644 %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -D -m 0644 lksh.1 %{buildroot}%{_mandir}/man1/lksh.1
install -D -p -m 0644 dot.mkshrc %{buildroot}%{_sysconfdir}/mkshrc
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/skel/.mkshrc
#install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/skel/.mkshrc

%check
./mksh rtchecks >rtchecks.got 2>&1
if ! cmp --quiet rtchecks.got %{SOURCE2}
then
  echo "rtchecks failed"
  diff -Naurp %{SOURCE2} rtchecks.got
  exit 1
fi

for tf in test_mksh.sh test_lksh.sh
do
  echo > test.wait
  script -qc "./$tf"' -v; x=$?; rm -f test.wait; exit $x'
  maxwait=0
  while test -e test.wait; do
    sleep 1
    maxwait=$(expr $maxwait + 1)
    test $maxwait -lt 900 || break
  done
done

# (kamil) Recommended by upstream: never install bare lksh to /etc/shells
%post
if [ $1 -eq 1 ]; then
   %{_add_shell_helper} %{name} $1 /bin/mksh
fi

%postun
if [ $1 -eq 0  ]; then
   %{_del_shell_helper} %{name} $1 /bin/mksh
fi

%files
%doc dot.mkshrc
%{_bindir}/%{name}
%{_bindir}/lksh
%config(noreplace) %{_sysconfdir}/mkshrc
%config(noreplace) %{_sysconfdir}/skel/.mkshrc
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/lksh.1*

