%define api            1.0
%define major          0
%define libname        %mklibname mongoc %{api} %{major}
%define develname      %mklibname mongoc -d

%define bson_api       1.0
%define bson_major     0
%define bson_libname   %mklibname bson %{bson_api} %{bson_major}
%define bson_develname %mklibname bson -d

#global up_prever    rc0

# disabled as require a MongoDB server
%bcond_with tests

# disable for bootstrap (libmongocrypt needs libbson)
%bcond_with libmongocrypt

%bcond_without man

Name:		mongo-c-driver
Summary:	Client library written in C for MongoDB
Version:	1.30.2
Release:	%mkrel 1
License:	ASL 2.0
Group:		System/Libraries
URL:		https://github.com/mongodb/mongo-c-driver
Source0:	https://github.com/mongodb/mongo-c-driver/releases/download/%{version}/mongo-c-driver-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libsasl2)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(snappy)
BuildRequires:	pkgconfig(libutf8proc)
BuildRequires:	pkgconfig(libzstd)
%if %{with tests}
BuildRequires:	mongodb-server
BuildRequires:	openssl
%endif
%if %{with libmongocrypt}
BuildRequires:	cmake(mongocrypt) >= 1.5.2
%endif
# For man pages
BuildRequires:	python3-sphinx

%description
%{name} is a client library written in C for MongoDB.

%package -n %{libname}
Group:		System/Libraries
Summary:	Shared libraries for %{name}
Obsoletes:	%{_lib}mongoc1.0 < 1.8.2-2

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n %{develname}
Group:		Development/C
Summary:	Libraries and header files for %{name}
Requires:	%{libname} = %{version}-%{release}

%description -n %{develname}
This package contains the header files and development libraries
for %{name}.

%package -n %{bson_libname}
Group:		System/Libraries
Summary:	Building, parsing, and iterating BSON documents

%description -n %{bson_libname}
This is a library providing useful routines related to building, parsing,
and iterating BSON documents <http://bsonspec.org/>.

%package -n %{bson_develname}
Group:		Development/C
Summary:	Libraries and header files for %{name}
Requires:	%{bson_libname} = %{version}

%description -n %{bson_develname}
This package contains libraries and header files needed for developing
applications that use %{name}.

%prep
%autosetup -p1
# src/libmongoc/doc/mongoc_apm_command_failed_get_error.rst:21:unknown document: bson_error_t
perl -pi -e 's/-qEW/-qE/' build/cmake/SphinxBuild.cmake

%build
%cmake \
    -DBUILD_VERSION=%{version}%{?up_prever:-%{up_prever}} \
    -DENABLE_MONGOC:BOOL=ON \
    -DENABLE_SHM_COUNTERS:BOOL=ON \
    -DENABLE_SSL:STRING=OPENSSL \
    -DENABLE_SASL:STRING=CYRUS \
    -DENABLE_MONGODB_AWS_AUTH:STRING=ON \
    -DENABLE_AUTOMATIC_INIT_AND_CLEANUP:BOOL=OFF \
    -DENABLE_CRYPTO_SYSTEM_PROFILE:BOOL=ON \
    -DENABLE_MAN_PAGES:BOOL=ON \
    -DENABLE_SHARED:BOOL=ON \
    -DENABLE_STATIC:STRING=OFF \
    -DENABLE_ZLIB:STRING=SYSTEM \
    -DENABLE_ZSTD:STRING=ON \
    -DENABLE_SNAPPY:STRING=ON \
%if %{with tests}
    -DENABLE_TESTS:BOOL=ON \
%else
    -DENABLE_TESTS:BOOL=OFF \
%endif
    -DENABLE_EXAMPLES:BOOL=OFF \
    -DENABLE_UNINSTALL:BOOL=OFF \
%if %{with libmongocrypt}
    -DENABLE_CLIENT_SIDE_ENCRYPTION:BOOL=ON \
%else
    -DENABLE_CLIENT_SIDE_ENCRYPTION:BOOL=OFF \
%endif
    -DCMAKE_SKIP_RPATH:BOOL=ON \
    -DUSE_BUNDLED_UTF8PROC:BOOL=OFF \
    -DENABLE_SRV:BOOL=ON \
    -DENABLE_MONGODB_AWS_AUTH:STRING=ON \
    -S .

%cmake_build

%install
%cmake_install
rm -f  %{buildroot}%{_libdir}/*.a
rm -rf %{buildroot}%{_libdir}/cmake/*static*
rm -rf %{buildroot}%{_libdir}/pkgconfig/*static*
rm -rf %{buildroot}%{_datadir}/%{name}

%check
ret=0

%if %{with tests}
: Run a server
mkdir dbtest
mongod \
  --journal \
  --ipv6 \
  --unixSocketPrefix /tmp \
  --logpath     $PWD/server.log \
  --pidfilepath $PWD/server.pid \
  --dbpath      $PWD/dbtest \
  --fork

: Run the test suite
export MONGOC_TEST_OFFLINE=on
export MONGOC_TEST_SKIP_MOCK=on
#export MONGOC_TEST_SKIP_SLOW=on

make check || ret=1

: Cleanup
[ -s server.pid ] && kill $(cat server.pid)
%endif

if grep -r static %{buildroot}%{_libdir}/cmake; then
  : cmake configuration file contain reference to static library
  ret=1
fi
exit $ret

%files
%{_bindir}/mongoc-stat

%files -n %{libname}
%doc NEWS README.rst THIRD_PARTY_NOTICES
%license COPYING
%{_libdir}/libmongoc-%{api}.so.%{major}{,.*}

%files -n %{develname}
%doc src/libmongoc/examples
%{_includedir}/libmongoc-%{api}/
%{_libdir}/libmongoc-%{api}.so
%{_libdir}/pkgconfig/libmongoc-%{api}.pc
%{_libdir}/pkgconfig/libmongoc-ssl-%{api}.pc
%{_libdir}/cmake/libmongoc-%{api}/
%{_libdir}/cmake/mongoc-%{api}/
%{_mandir}/man3/mongoc*

%files -n %{bson_libname}
%license COPYING
%{_libdir}/libbson-%{bson_api}.so.%{bson_major}{,.*}

%files -n %{bson_develname}
%doc src/libbson/examples
%{_includedir}/libbson-%{bson_api}/
%{_libdir}/libbson-%{api}.so
%{_libdir}/pkgconfig/libbson-%{api}.pc
%{_libdir}/cmake/libbson-%{bson_api}/
%{_libdir}/cmake/bson-%{bson_api}/
%{_mandir}/man3/bson*
%{_mandir}/man3/libbson*.3*
