%define debug_package %{nil}

%global version 5.10.0
%global tarballpath 5.10
%global fileversion 5.10.0.871

Name:		monodevelop
Version:	%{version}
Release:	%mkrel 17
Summary:        A full-featured IDE for Mono and Gtk#
Group:		Development/Other
License:        GPLv2+
URL:            https://monodevelop.com/
Source0:        https://download.mono-project.com/sources/monodevelop/monodevelop-%{fileversion}.tar.bz2
# Fedora patches:
Patch0:         monodevelop-avoidgiterrors.patch
Patch1:         monodevelop-downgrade_to_mvc3.patch
Patch2:         monodevelop-nuget-unbundle.patch
Patch3:         monodevelop-no-nuget-packages.patch
BuildRequires:  pkgconfig(mono) >= 3.0.4
BuildRequires:  pkgconfig(mono-addins) >= 0.6
BuildRequires:  pkgconfig(nunit2) >= 2.6.3
BuildRequires:  pkgconfig(monodoc)
BuildRequires:	pkgconfig(glade-sharp-2.0)
BuildRequires:	pkgconfig(gnome-sharp-2.0)
BuildRequires:	desktop-file-utils
BuildRequires:	intltool
BuildRequires:  pkgconfig(nuget-core)
BuildRequires:  pkgconfig(libssh2)
BuildRequires:  newtonsoft-json
BuildRequires:  cmake
BuildRequires:  git
Requires:       mono-core >= 3.0.4
Requires:       mono-addins >= 0.6
# Using system nunit, but dependency not automatically picked up by RPM
Requires:       mono(nunit.core)
Requires:       mono(nunit.framework)
Requires:       mono-locale-extras
Requires:	subversion monodoc
Requires:       hicolor-icon-theme shared-mime-info
Requires:       gtk-sharp2
Requires:	gnome-sharp2
Requires:	git
Requires:	xsp


%description
This package provides MonoDevelop, a full-featured IDE for Mono with
syntax coloring, code completion, debugging, project management and
support for C sharp, Visual Basic.NET, Java, Boo, Nemerle and MSIL.


%package        devel
Summary:        Development files for monodevelop
Group:		Development/Other
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig
Requires:       newtonsoft-json
Conflicts:      monodevelop <= 5.10.0-5.mga6

%description devel
Development files for %{name}.


%prep
%setup -qn %{name}-%{tarballpath}
%autopatch -p1

for f in tests/TestRunner/TestRunner.csproj tests/UserInterfaceTests/UserInterfaceTests.csproj src/addins/NUnit/NUnitRunner/NUnitRunner.csproj src/addins/NUnit/MonoDevelop.NUnit.csproj external/nrefactory/ICSharpCode.NRefactory.Tests/ICSharpCode.NRefactory.Tests.csproj
do
  echo $f
  sed -i "s#<HintPath>.*nunit\..*</HintPath>##g" $f
done

sed -i "s#<HintPath>.*Newtonsoft\.Json\.dll</HintPath>#<Package>newtonsoft-json</Package><Private>True</Private>#g" tests/UserInterfaceTests/UserInterfaceTests.csproj

# Delete shipped *.dll files
find -name '*.dll' -exec rm -f {} \;

#Fixes for Mono 4
sed -i "s#gmcs#mcs#g; s#dmcs#mcs#g" configure
sed -i "s#gmcs#mcs#g; s#dmcs#mcs#g" configure.in
sed -i "s#mono-nunit#nunit#g" configure.in
find . -name "*.sln" -print -exec sed -i 's/Format Version 10.00/Format Version 11.00/g' {} \;
find . -name "*.csproj" -print -exec sed -i 's#ToolsVersion="3.5"#ToolsVersion="4.0"#g; s#<TargetFrameworkVersion>.*</TargetFrameworkVersion>##g; s#<PropertyGroup>#<PropertyGroup><TargetFrameworkVersion>v4.5</TargetFrameworkVersion>#g' {} \;

# reference newtonsoft-json properly
sed -i "s#-r:\${libdir}/bin/Newtonsoft.Json.dll#-r:/usr/lib/mono/newtonsoft-json/Newtonsoft.Json.dll#g" monodevelop.pc.in

%build
%configure --enable-git --disable-update-mimedb --disable-update-desktopdb

cd ./external/libgit2sharp/Lib/CustomBuildTasks
xbuild CustomBuildTasks.csproj
mv bin/Debug/* .
cd ../../../../

make

%check
make check

%install
%make_install

mkdir -p $RPM_BUILD_ROOT/%{_prefix}/lib/monodevelop/AddIns/NUnit
ln -s ../../../mono/nunit2/nunit.core.dll $RPM_BUILD_ROOT/%{_prefix}/lib/monodevelop/AddIns/NUnit
ln -s ../../../mono/nunit2/nunit.core.interfaces.dll $RPM_BUILD_ROOT/%{_prefix}/lib/monodevelop/AddIns/NUnit
ln -s ../../../mono/nunit2/nunit.framework.dll $RPM_BUILD_ROOT/%{_prefix}/lib/monodevelop/AddIns/NUnit
ln -s ../../../mono/nunit2/nunit.util.dll $RPM_BUILD_ROOT/%{_prefix}/lib/monodevelop/AddIns/NUnit

desktop-file-install \
                     --dir $RPM_BUILD_ROOT%{_datadir}/applications \
                     --delete-original \
  $RPM_BUILD_ROOT%{_datadir}/applications/monodevelop.desktop

mkdir -p $RPM_BUILD_ROOT/%{_libdir}/pkgconfig
test "%{_libdir}" = "%{_prefix}/lib" || mv $RPM_BUILD_ROOT/%{_prefix}/lib/pkgconfig/* $RPM_BUILD_ROOT/%{_libdir}/pkgconfig

# already installed in %{_datadir}/locale ?
rm -rf %{buildroot}%{_prefix}/lib/monodevelop/locale

# Register as an application to be visible in the software center
#
# NOTE: It would be *awesome* if this file was maintained by the upstream
# project, translated and installed into the right place during `make install`.
#
# See https://www.freedesktop.org/software/appstream/docs/ for more details.
#
mkdir -p $RPM_BUILD_ROOT%{_datadir}/appdata
cat > $RPM_BUILD_ROOT%{_datadir}/appdata/%{name}.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2014 Richard Hughes <richard@hughsie.com> -->
<!--
BugReportURL: https://bugzilla.xamarin.com/show_bug.cgi?id=23288
SentUpstream: 2014-09-23
-->
<application>
  <id type="desktop">monodevelop.desktop</id>
  <metadata_license>CC0-1.0</metadata_license>
  <description>
    <p>
      MonoDevelop is a cross-platform IDE primarily designed for C# and other
      .NET languages.
      MonoDevelop enables developers to quickly write desktop and ASP.NET Web
      applications on Linux, Windows and Mac OSX.
    </p>
    <p>
      MonoDevelop makes it easy for developers to port .NET applications created
      with Visual Studio to Linux and Mac OSX maintaining a single code base for
      all platforms.
    </p>
  </description>
  <url type="homepage">https://monodevelop.com/</url>
  <screenshots>
    <screenshot type="default">https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/monodevelop/a.png</screenshot>
  </screenshots>
  <!-- FIXME: change this to an upstream email address for spec updates
  <updatecontact>someone_who_cares@upstream_project.org</updatecontact>
   -->
</application>
EOF

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING README
%{_bindir}/m*
%{_prefix}/lib/monodevelop
%{_mandir}/man1/m*
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mime/packages/monodevelop.xml

%files devel
%{_libdir}/pkgconfig/monodevelop*.pc
