# comment out if not pre release
#define prel a7

# rel for bumping
%define rel 2

Name:           mopidy
Version:        3.4.2
Release:        %mkrel %{?prel:0.%prel.}%{rel}
Group:          Sound/Players
Summary:        Music server with MPD and Spotify support
License:        ASL 2.0
URL:            https://www.mopidy.com/
Source0:        https://github.com/mopidy/mopidy/archive/v%{version}%{?prel}/%{name}-%{version}%{?prel}.tar.gz
BuildArch:      noarch
BuildRequires:  python3-devel
# for docs
BuildRequires:  python3dist(sphinx)
Requires:       gstreamer1.0-python
Requires:       gstreamer1.0-plugins-base
Requires:       gstreamer1.0-plugins-good
Requires:       gstreamer1.0-plugins-ugly


%description
Mopidy is an extensible music server written in Python.
Mopidy plays music from local disk, Spotify, SoundCloud, Google Play Music, and
more. You edit the playlist from any phone, tablet, or computer using a range
of MPD and web clients.

Vanilla Mopidy only plays music from your local disk and radio streams.
Through extensions, Mopidy can play music from cloud services like Spotify,
SoundCloud, and Google Play Music.

With Mopidy's extension support, backends for new music sources can be easily
added.


%prep
%autosetup -p1 -n %{name}-%{version}%{?prel}

# without this, mopidy must be installed for docs to be able to be built.
# Note: jodal promised to remove the necessity for this hack in a future version
sed -i 's/^__version__ = .*$/__version__ = "%{version}"/' mopidy/__init__.py

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

make SPHINXBUILD=sphinx-build-3 html man -C docs
rm docs/_build/html/.buildinfo

%install
%pyproject_install
%pyproject_save_files mopidy

# mopidyctl
install -Dpm755 extra/mopidyctl/mopidyctl %{buildroot}%{_bindir}/mopidyctl
install -Dpm644 extra/mopidyctl/mopidyctl.8 %{buildroot}%{_mandir}/man8/mopidyctl.8

# man page
install -Dpm644 docs/_build/man/mopidy.1 %{buildroot}%{_mandir}/man1/mopidy.1

# systemd .service
install -Dpm644 extra/systemd/mopidy.service %{buildroot}%{_unitdir}/mopidy.service

# system user home dir
install -dm755 %{buildroot}%{_tmpfilesdir}
cat >> %{buildroot}%{_tmpfilesdir}/%{name}.conf << EOF
d %{_sharedstatedir}/%{name} 0755 mopidy mopidy
EOF

# cache dir
install -dm755 %{buildroot}%{_var}/cache/%{name}

# configs
install -dm755 %{buildroot}%{_sysconfdir}/%{name}
touch %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
install -dm755 %{buildroot}%{_datadir}/%{name}/conf.d
cat >> %{buildroot}%{_datadir}/%{name}/conf.d/%{name}.conf << EOF
# This is the %{_vendor} specific default configuration for Mopidy.
# Your changes should go into /etc/mopidy/mopidy.conf
[core]
cache_dir = /var/cache/mopidy
config_dir = /etc/mopidy
data_dir = /var/lib/mopidy
EOF

%pre
%_pre_useradd mopidy %{_sharedstatedir}/%{name} %{_sbindir}/nologin
%_pre_groupadd mopidy

%post
%_tmpfilescreate mopidy
%systemd_post mopidy.service

%preun
%systemd_preun mopidy.service

%files -f %{pyproject_files}
%doc docs/_build/html
%{_bindir}/mopidy
%{_mandir}/man1/mopidy.1*
%{_bindir}/mopidyctl
%{_mandir}/man8/mopidyctl.8*
%{_unitdir}/mopidy.service
%{_tmpfilesdir}/%{name}.conf

%attr(-,mopidy,mopidy) %dir %{_var}/cache/%{name}/

%attr(-,mopidy,mopidy) %dir %{_sysconfdir}/%{name}/
%ghost %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf

%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/conf.d/
%{_datadir}/%{name}/conf.d/%{name}.conf
