%define major     1
%define libname   %mklibname %{name} %{major}
%define libnamepp %mklibname %{name}pp %{major}
%define develname %mklibname %{name} -d

%define _disable_ld_no_undefined 1

Name:           mosquitto
Version:        2.0.21
Release:        %mkrel 1
Summary:        An Open Source MQTT Broker
Group:          System/Libraries
License:        EPL-2.0
URL:            https://mosquitto.org/
Source0:        https://mosquitto.org/files/source/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  tcp_wrappers-devel
BuildRequires:  uthash-devel >= 2.1.0
BuildRequires:  pkgconfig(libcjson)
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(uuid)

Requires(pre):  shadow-utils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
Eclipse Mosquitto is an open source message broker that implements the MQTT
protocol versions 5.0, 3.1.1 and 3.1. Mosquitto is lightweight and is suitable
for use on all devices from low power single board computers to full servers.

The MQTT protocol provides a lightweight method of carrying out messaging using
a publish/subscribe model. This makes it suitable for Internet of Things
messaging such as with low power sensors or mobile devices such as phones,
embedded computers or microcontrollers.

The Mosquitto project also provides a C library for implementing MQTT clients,
and the very popular mosquitto_pub and mosquitto_sub command line MQTT clients.

#------------------------------------------------

%package -n     %{libname}
Summary:        An Open Source MQTT Broker
Group:          System/Libraries

%description -n %{libname}
Eclipse Mosquitto is an open source message broker that implements the MQTT
protocol versions 5.0, 3.1.1 and 3.1. Mosquitto is lightweight and is suitable
for use on all devices from low power single board computers to full servers.

The MQTT protocol provides a lightweight method of carrying out messaging using
a publish/subscribe model. This makes it suitable for Internet of Things
messaging such as with low power sensors or mobile devices such as phones,
embedded computers or microcontrollers.

#------------------------------------------------

%package -n     %{libnamepp}
Summary:        An Open Source MQTT Broker
Group:          System/Libraries

%description -n %{libnamepp}
Eclipse Mosquitto is an open source message broker that implements the MQTT
protocol versions 5.0, 3.1.1 and 3.1. Mosquitto is lightweight and is suitable
for use on all devices from low power single board computers to full servers.

The MQTT protocol provides a lightweight method of carrying out messaging using
a publish/subscribe model. This makes it suitable for Internet of Things
messaging such as with low power sensors or mobile devices such as phones,
embedded computers or microcontrollers.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libnamepp} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%prep
%autosetup -p1

# Set the install prefix to /usr
sed -i "s|prefix?=/usr/local|prefix?=/usr|" config.mk
# Don't strip binaries on install: rpmbuild will take care of it
sed -i "s|(INSTALL) -s|(INSTALL)|g" lib/Makefile src/Makefile client/Makefile

%build
%cmake -DWITH_BUNDLED_DEPS=OFF -DWITH_SYSTEMD=ON -DWITH_WEBSOCKETS=ON -DWITH_SRV=ON
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 service/systemd/%{name}.service.notify %{buildroot}%{_unitdir}/%{name}.service

%check
#make test

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_sysconfdir}/%{name} -s /sbin/nologin \
    -c "Mosquitto Broker" %{name}
exit 0

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_service %{name}

%files
%doc ChangeLog.txt CONTRIBUTING.md README.md
%license LICENSE.txt
%{_bindir}/*
%{_sbindir}/*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config %{_sysconfdir}/%{name}/*.example
%{_unitdir}/%{name}.service
%{_mandir}/man1/*.1.*
%{_mandir}/man5/*.5.*
%{_mandir}/man7/*.7.*
%{_mandir}/man8/*.8.*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}.so.%{version}

%files -n %{libnamepp}
%{_libdir}/lib%{name}pp.so.%{major}{,.*}
%{_libdir}/lib%{name}pp.so.%{version}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3.*
