Name:		mozc
Summary:	Japanese Input Method Editor (IME) designed for multi-platform
Version:	2.25.4190.102
Release:	%mkrel 5
Group:		System/Internationalization
License:	BSD-like
URL:		https://github.com/google/mozc
# data/unicode/: UCD
#  Copyright (c) 1991-2008 Unicode, Inc.
# data/test/stress_test/sentences.txt: Public Domain
# data/dictionary_oss/: mecab-ipadic and BSD
#   See http://code.google.com/p/mozc/issues/detail?id=20
#   also data/installer/credits_en.html

##Source0:	http://mozc.googlecode.com/files/mozc-%%{version}.tar.bz2
# No upstream releases downloadable from the download services due to:
#   https://google-opensource.blogspot.jp/2013/05/a-change-to-google-code-download-service.html
#
# How to checkout the tree from the repository:
#   https://github.com/google/mozc/blob/master/docs/build_mozc_in_docker.md
#
# How to make a tarball after updating:
#   (cd src;
#    python build_mozc.py gyp --target_platform=Linux
#   )
#   major=$(grep MAJOR src/mozc_version.txt|sed -e 's/MAJOR=//g')
#   minor=$(grep MINOR src/mozc_version.txt|sed -e 's/MINOR=//g')
#   build=$(grep BUILD src/mozc_version.txt|sed -e 's/BUILD=//g')
#   rev=$(grep REVISION src/mozc_version.txt|sed -e 's/REVISION=//g')
#   version="$major.$minor.$build.$rev"
#   (cd src;
#    for f in $(find -type f -regex '.*.[ch]' -o -regex '.*.html' -o -regex '.*README*'); do chmod a-x $f; done
#    tar -a --exclude-vcs --exclude third_party/gyp* -cf ../mozc-$version.tar.bz2 *
#   )
#
Source0:	%{name}-%{version}.tar.bz2
Source1:	mozc-init.el
# Public Domain
Source2:	https://www.post.japanpost.jp/zipcode/dl/kogaki/zip/ken_all.zip
Source3:	https://www.post.japanpost.jp/zipcode/dl/jigyosyo/zip/jigyosyo.zip
Source4:	ibus-setup-mozc-jp.desktop
Patch0:		mozc-build-ninja.patch
## to avoid undefined symbols with clang.
Patch1:		mozc-build-gcc.patch
Patch2:		mozc-build-verbosely.patch
Patch3:		mozc-build-id.patch
Patch4:		mozc-build-gcc-common.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=1419949
ExcludeArch:	ppc ppc64 sparcv9 sparc64 s390x

BuildRequires:	clang
BuildRequires:	emacs
BuildRequires:	gettext
BuildRequires:	gyp
BuildRequires:	ninja
BuildRequires:	subversion
BuildRequires:	zinnia-tomoe-ja
BuildRequires:	gtest-devel
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(gdk-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(ibus-1.0) >= 1.3.9
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(libprotobuf-c)
BuildRequires:	pkgconfig(zinnia)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xt)
BuildRequires:  python3-six

Requires:	zinnia-tomoe-ja
Requires:	emacs >= %{_emacs_version}

%description
Mozc is a Japanese Input Method Editor (IME) designed for
multi-platform such as Chromium OS, Windows, Mac and Linux.
This open-source project originates from Google Japanese Input.

%package -n	ibus-mozc
Group:		System/Internationalization
Summary:	The mozc engine for IBus input platform
Requires:	ibus
Requires:	%{name} = %{version}

%description -n	ibus-mozc
Mozc is a Japanese Input Method Editor (IME) designed for
multi-platform such as Chromium OS, Windows, Mac and Linux.

This package contains the Input Method Engine for IBus.

%package	tools
Group:		System/Internationalization
Summary:	Mozc config tools
Requires:	%{name} = %{version}
Requires:	qt5-common

%description tools
Mozc config tools.

%prep
%setup -q -c -n %{name}-%{version} -a 2 -a 3
#patch -P 0 -p1 -b .0-ninja
%patch -P 1 -p1 -b .1-gcc
%patch -P 2 -p1 -b .2-verbose
%patch -P 3 -p1 -b .3-build-id
%patch -P 4 -p1 -b .8-gcc-common

(cd data/dictionary_oss;
PYTHONPATH="${PYTHONPATH}:../.." python ../../dictionary/gen_zip_code_seed.py --zip_code=../../KEN_ALL.CSV --jigyosyo=../../JIGYOSYO.CSV >> dictionary09.txt;
)

%build
%set_build_flags

# replace compiler flags to build with the proper debugging information
t=`mktemp /tmp/mozc.gyp-XXXXXXXX`
opts=$(for i in $(echo $RPM_OPT_FLAGS|sed -e 's/-fstack-clash-protection//g'); do
	echo "i \\"
	echo "\"$i\","
done)
sed -ne "/'linux_cflags':/{p;n;p;:a;/[[:space:]]*\],/{\
$opts
p;b b};n;b a;};{p};:b" gyp/common.gypi > $t && mv $t gyp/common.gypi || exit 1
GYP_DEFINES="use_libprotobuf=1 use_libzinnia=1 zinnia_model_file=%{_prefix}/lib/zinnia/model/tomoe/handwriting-ja.model ibus_mozc_path=%{_libexecdir}/ibus-engine-mozc ibus_mozc_icon_path=%{_datadir}/ibus-mozc/product_icon.png" python build_mozc.py gyp --gypdir=%{_bindir} --server_dir=%{_libexecdir}/mozc --target_platform=Linux
python build_mozc.py build -c Release unix/ibus/ibus.gyp:ibus_mozc unix/emacs/emacs.gyp:mozc_emacs_helper server/server.gyp:mozc_server gui/gui.gyp:mozc_tool renderer/renderer.gyp:mozc_renderer

%install
install -d %{buildroot}%{_libexecdir}/mozc
install -d %{buildroot}%{_libexecdir}/mozc/documents
install -p -m0755 out_linux/Release/mozc_server %{buildroot}%{_libexecdir}/mozc
install -p -m0755 out_linux/Release/mozc_tool %{buildroot}%{_libexecdir}/mozc
install -p -m0755 out_linux/Release/mozc_renderer %{buildroot}%{_libexecdir}/mozc
install -p -m0644 data/installer/credits_en.html %{buildroot}%{_libexecdir}/mozc/documents

# ibus-mozc
install -d %{buildroot}%{_datadir}/ibus/component
install -d %{buildroot}%{_datadir}/ibus-mozc
install -p -m0755 out_linux/Release/ibus_mozc %{buildroot}%{_libexecdir}/ibus-engine-mozc
install -p -m0644 out_linux/Release/gen/unix/ibus/mozc.xml %{buildroot}%{_datadir}/ibus/component/
(cd data/images/unix;
install -p -m0644 ime_product_icon_opensource-32.png %{buildroot}%{_datadir}/ibus-mozc/product_icon.png
for i in ui-*.png; do
	install -p -m0644 $i %{buildroot}%{_datadir}/ibus-mozc/${i//ui-/}
done)
desktop-file-install --dir=%{buildroot}%{_datadir}/applications  %{SOURCE4}

install -d %{buildroot}%{_iconsdir}/hicolor/128x128/apps
install -p -m0644 data/images/product_icon_32bpp-128.png %{buildroot}%{_iconsdir}/hicolor/128x128/apps/product_icon.png

# emacs-common-mozc
install -d %{buildroot}%{_bindir}
install -p -m0755 out_linux/Release/mozc_emacs_helper %{buildroot}%{_bindir}

# emacs-mozc*
install -d %{buildroot}%{_emacs_sitelispdir}/mozc
install -d %{buildroot}%{_emacs_sitestartdir}
install -p -m0644 unix/emacs/mozc.el %{buildroot}%{_emacs_sitelispdir}/mozc
install -p -m0644 %{SOURCE1} %{buildroot}%{_emacs_sitestartdir}

emacs -batch -f batch-byte-compile %{buildroot}%{_emacs_sitelispdir}/mozc/mozc.el

# Register as an AppStream component to be visible in the software center
#
# NOTE: It would be *awesome* if this file was maintained by the upstream
# project, translated and installed into the right place during `make install`.
#
# See https://www.freedesktop.org/software/appstream/docs/ for more details.
#
install -d -m 0755 %{buildroot}%{_metainfodir}
cat > %{buildroot}%{_metainfodir}/mozc.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<component type="inputmethod">
  <id>mozc.xml</id>
  <metadata_license>CC0-1.0</metadata_license>
  <name>Mozc</name>
  <summary>Japanese input method</summary>
  <description>
    <p>
      The Mozc input method is designed for entering Japanese text.
      It is multi-platform and is available on Chromium OS, Windows, Mac and Linux.
    </p>
    <p>
      Input methods are typing systems allowing users to input complex languages.
      They are necessary because these contain too many characters to simply be laid
      out on a traditional keyboard.
    </p>
  </description>
  <url type="homepage">https://github.com/google/mozc</url>
  <url type="bugtracker">https://github.com/google/mozc/issues</url>
  <url type="help"><!-- https://code.google.com/p/ibus/wiki/FAQ --></url>
  <languages>
    <lang percentage="100">ja</lang>
  </languages>
  <update_contact><!-- upstream-contact_at_email.com --></update_contact>
</component>
EOF

%files
%dir %{_libexecdir}/mozc
%{_bindir}/mozc_emacs_helper
%{_libexecdir}/mozc/mozc_server
%{_libexecdir}/mozc/documents
%dir %{_emacs_sitelispdir}/mozc
%{_emacs_sitelispdir}/mozc/*.elc
%{_emacs_sitestartdir}/*.el
%{_emacs_sitelispdir}/mozc/*.el

%files -n ibus-mozc
%dir %{_datadir}/ibus-mozc
%{_libexecdir}/ibus-engine-mozc
%{_libexecdir}/mozc/mozc_renderer
%{_datadir}/ibus/component/mozc.xml
%{_datadir}/ibus-mozc/*.png

%files tools
%{_libexecdir}/mozc/mozc_tool
%{_metainfodir}/*.appdata.xml
%{_datadir}/applications/ibus-setup-mozc-jp.desktop
%{_iconsdir}/hicolor/128x128/apps/product_icon.png
