%define build_plf 0
%if "%{?distro_section}" == "tainted"
%define build_plf 1
%endif
%define minver %(echo %version | cut -d. -f1,2)

Name:           mpd
Version:        0.23.17
Release:        %mkrel 1

Summary:        MPD, the Music Player Daemon
License:        GPLv2+
Group:          Sound/Players
Url:            https://www.musicpd.org/
Source0:        https://www.musicpd.org/download/mpd/%{minver}/%{name}-%{version}.tar.xz
Source1:        %{name}.conf
Source2:        %{name}.logrotate
Source3:        README.urpmi.2
Patch1:         mpd-gcc14.patch

BuildRequires: meson
BuildRequires: ninja
BuildRequires: pkgconfig(adplug)
BuildRequires: pkgconfig(alsa) >= 0.9.0
BuildRequires: pkgconfig(ao)
BuildRequires: pkgconfig(audiofile) >= 0.1.7
BuildRequires: pkgconfig(avahi-client)
BuildRequires: pkgconfig(avahi-glib)
BuildRequires: boost-devel
BuildRequires: pkgconfig(flac) >= 1.1
BuildRequires: pkgconfig(fluidsynth) >= 1.1
BuildRequires: pkgconfig(fmt) >= 9
BuildRequires: pkgconfig(glib-2.0) >= 2.16
BuildRequires: pkgconfig(gthread-2.0)
BuildRequires: pkgconfig(icu-uc)
BuildRequires: pkgconfig(id3tag)
BuildRequires: pkgconfig(jack) >= 0.100
BuildRequires: pkgconfig(libavcodec) >= 52.20
BuildRequires: pkgconfig(libavformat) >= 52.31
BuildRequires: pkgconfig(libavutil) >= 49.15
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(libchromaprint)
BuildRequires: pkgconfig(libffado)
BuildRequires: pkgconfig(libgme)
BuildRequires: pkgconfig(libmms) >= 0.4
BuildRequires: pkgconfig(libmodplug)
BuildRequires: pkgconfig(libmpg123)
BuildRequires: pkgconfig(libmpdclient)
BuildRequires: pkgconfig(libnfs)
BuildRequires: pkgconfig(libopenmpt)
BuildRequires: pkgconfig(libpcre2-8)
BuildRequires: pkgconfig(libpipewire-0.3)
BuildRequires: pkgconfig(libpulse)
BuildRequires: pkgconfig(libsidplay2)
BuildRequires: pkgconfig(libsidplayfp)
BuildRequires: pkgconfig(libsidutils)
BuildRequires: pkgconfig(libupnp)
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(mad)
BuildRequires: pkgconfig(libmikmod)
BuildRequires: pkgconfig(ogg)
BuildRequires: pkgconfig(openal)
BuildRequires: pkgconfig(samplerate) >= 0.0.15
BuildRequires: pkgconfig(shout)
BuildRequires: pkgconfig(smbclient)
BuildRequires: pkgconfig(sndfile)
BuildRequires: pkgconfig(sndio)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(soxr)
BuildRequires: pkgconfig(liburing)
BuildRequires: pkgconfig(vorbis)
BuildRequires: pkgconfig(vorbisenc)
BuildRequires: pkgconfig(vorbisfile)
BuildRequires: pkgconfig(wavpack)
BuildRequires: pkgconfig(wildmidi)
BuildRequires: pkgconfig(yajl) >= 2.0
BuildRequires: pkgconfig(zziplib) >= 0.13
BuildRequires: lame-devel
BuildRequires: musepack-devel
%if %build_plf
BuildRequires: pkgconfig(faad2)
%endif
BuildRequires: pkgconfig(libcdio_paranoia)
BuildRequires: pkgconfig(libiso9660)
BuildRequires: python3dist(sphinx)

Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
Music Player Daemon (MPD) allows remote access for playing music (MP3, Ogg
Vorbis, FLAC, Mod, and wave files) and managing playlists. MPD is designed
for integrating a computer into a stereo system that provides control for music
playback over a local network. It is also makes a great desktop music player,
especially if you're a console junkie, like frontend options, or restart X
often.
%if %build_plf
This package is in the 'tainted' section because it is built with AAC support
of libfaad2.
%endif

%prep
%autosetup -p1

%build
%meson \
%if %build_plf
  -Dfaad=enabled \
%else
  -Dfaad=disabled \
%endif
  -Dmpcdec=enabled \
  -Dshine=disabled \
  -Dtremor=disabled

%meson_build

%install
%meson_install

mkdir -p %{buildroot}/var/lib/mpd
touch %{buildroot}%{_localstatedir}/lib/mpd/mpd.db
touch %{buildroot}%{_localstatedir}/lib/mpd/mpdstate
mkdir -p %{buildroot}/var/log/mpd
touch %{buildroot}/var/log/mpd/mpd.log
touch %{buildroot}/var/log/mpd/mpd.error
mkdir -p %{buildroot}%{_localstatedir}/lib/mpd/playlists
mkdir -p %{buildroot}%{_localstatedir}/lib/mpd/music

install -D %{SOURCE1} %{buildroot}/etc/mpd.conf
install -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install %{SOURCE3} doc/README.urpmi
rm -rf %{buildroot}%{_docdir}/mpd

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/mpd 0755 mpd audio
EOF

install -d -m 0755 %{buildroot}%{_rundir}/%{name}

%pre
%_pre_useradd %name %{_localstatedir}/lib/%{name} /bin/false
usermod -g audio %{name}

%post
%_tmpfilescreate %{name}
if [ $1 -eq 1 ]
then
%create_ghostfile %{_localstatedir}/lib/mpd/mpd.db mpd audio 644
%create_ghostfile %{_localstatedir}/lib/mpd/mpdstate mpd audio 644
%create_ghostfile /var/log/mpd/mpd.log mpd audio 644
%create_ghostfile /var/log/mpd/mpd.error mpd audio 644
fi
#echo If you want to run mpd as a service, please read
#echo /usr/share/doc/mpd-%%{version}/README.MDK
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files
%doc README.md AUTHORS NEWS doc/mpdconf.example doc/*.urpmi
%{_bindir}/%{name}
%{_iconsdir}/hicolor/scalable/apps/mpd.svg
%{_mandir}/man1/mpd.1*
%{_mandir}/man5/mpd.conf.5*
%{_unitdir}/mpd.service
%{_unitdir}/mpd.socket
%{_userunitdir}/mpd.service
%{_userunitdir}/mpd.socket
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(-,mpd,root) %config(noreplace) %{_sysconfdir}/%{name}.conf
%{_tmpfilesdir}/%{name}.conf
%defattr(644,mpd,audio)
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd/music
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd/playlists
%ghost %{_localstatedir}/lib/mpd/mpd.db
%ghost %{_localstatedir}/lib/mpd/mpdstate
%attr(755,mpd,audio) %dir /var/log/mpd
%ghost /var/log/mpd/mpd.log
%ghost /var/log/mpd/mpd.error
%dir %ghost %attr(0755,mpd,audio) %{_rundir}/mpd
%ghost %attr(0660, -, -) %{_rundir}/mpd/mpd.pid
