# fix conflict between libopenmpi-devel and libmpi-devel
# both provides devel(libmpi(64bit)) so let's only openmpi keeping it
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}devel\\(libmpi\\)
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}devel\\(libmpi\\(64bit\\)\\)
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libmpi.*

%define	major		12
%define	libname		%mklibname mpi %{major}
%define devname 	%mklibname mpi -d
%define mpihome		/home/mpi

Name: 		mpich
Version: 	3.4.1
Release: 	%mkrel 6
License:	MIT
Group:          System/Cluster
Summary: 	A high-performance implementation of MPI
URL:		https://www.mpich.org
Source0: 	https://www.mpich.org/static/downloads/%{version}/%{name}-%{version}.tar.gz
Source1:	mpich.macros
Source3:	mpich.pth.py3
Patch0:		mpich-modules.patch
Patch1:		0001-Drop-real128.patch
Patch2:		mpich-3.4.1-json-c-test-fix.patch
BuildRequires:	gcc-gfortran
BuildRequires:	hwloc-devel >= 2.0
# For python3_sitearch
BuildRequires:	python3-devel
Provides:	mpich2 = %{version}-%{release}
Obsoletes:	mpich2 < 3.0

%description
MPICH is a high-performance and widely portable implementation of the Message
Passing Interface (MPI) standard (MPI-1, MPI-2 and MPI-3). The goals of MPICH
are: (1) to provide an MPI implementation that efficiently supports different
computation and communication platforms including commodity clusters (desktop
systems, shared-memory systems, multicore architectures), high-speed networks
(10 Gigabit Ethernet, InfiniBand, Myrinet, Quadrics) and proprietary high-end
computing systems (Blue Gene, Cray) and (2) to enable cutting-edge research in
MPI through an easy-to-extend modular framework for other derived
implementations.

The mpich binaries in this RPM packages were configured to use the default
process manager (Hydra) using the default device (ch3). The ch3 device
was configured with support for the nemesis channel that allows for
shared-memory and TCP/IP sockets based communication.

%package -n %{devname}
Summary:        Development files for mpich
Group:          System/Cluster
Requires:	%{libname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	mpich2-devel = %{version}-%{release}
Obsoletes:	%{_lib}mpich2-devel < 3.0

%description -n %{devname}
Contains development headers and libraries for mpich.

%package doc
Summary:        Documentations and examples for mpich
Group:          Documentation
Obsoletes:      mpich2-doc < 3.0

%description doc
Contains documentations, examples and man-pages for mpich.

%package -n python3-mpich
Summary:        mpich support for Python 3
Group:          Development/Python

%description -n python3-mpich
mpich support for Python 3.

%package -n %{libname}
Summary:	Shared Libraries for MPICH
Group:		System/Cluster
Provides:	lib%{name} = %{version}-%{release}
Conflicts:	%{_lib}openmpi12 < 2.0.1
Obsoletes:	%{_lib}mpich2_1.2 < 1.2.1-11

%description  -n %{libname}
Shared Libraries for MPICH.

%package -n mpicc
Summary:	The MPICH wrapper over the C compiler
Group:		Development/C
Requires:	gcc >= 3.2
Requires:	%{devname} = %{version}-%{release}
Obsoletes:	mpi2cc < 3.0

%description -n mpicc
MPICH is a freely available, portable implementation of MPI, the Standard
for message-passing libraries.

This package provides the shell script mpicc, with headers, which allows to
compile C programs using the MPICH libraries.

%package -n mpicxx
Summary:	The MPICH wrapper over the C++ compiler
Group:		Development/C++
Requires:	gcc-c++ >= 3.2
Requires:	%{devname} = %{version}-%{release}
Obsoletes:	mpi2cxx < 3.0

%description -n mpicxx
MPICH is a freely available, portable implementation of MPI, the Standard
for message-passing libraries.

This package provides the shell script mpiCC, with headers, which allows to
compile C++ programs using the MPICH libraries.

%package -n mpif90
Summary:	The MPICH wrapper over the Fortran 90 compiler
Group:		System/Cluster
Requires:	gcc-gfortran >= 3.2
Requires:	%{devname} = %{version}-%{release}
Obsoletes:	mpi2f90 < 3.0
Obsoletes:	mpi2f77 < 3.0

%description -n mpif90
MPICH is a freely available, portable implementation of MPI, the Standard
for message-passing libraries.

This package provides the shell script mpif90, with headers, which allows to
compile Fortran 90 (NOT Fortran 77!) programs using the MPICH libraries.

# We only compile with gcc, but other people may want other compilers.
# Set the compiler here.
%{!?opt_cc: %global opt_cc gcc}
%{!?opt_fc: %global opt_fc gfortran}
%{!?opt_f77: %global opt_f77 gfortran}
# Optional CFLAGS to use with the specific compiler...gcc doesn't need any,
# so uncomment and undefine to NOT use
%{!?opt_cc_cflags: %global opt_cc_cflags %{optflags}}
%{!?opt_fc_fflags: %global opt_fc_fflags %{optflags}}
#%%{!?opt_fc_fflags: %%global opt_fc_fflags %%{optflags} -I%%{_fmoddir}}
%{!?opt_f77_fflags: %global opt_f77_fflags %{optflags}}

%ifarch s390
%global m_option -m31
%else
%global m_option -m%{__isa_bits}
%endif

%ifarch %{arm} aarch64 %{mips}
%global m_option ""
%endif

%global selected_channels ch3:nemesis

%ifarch %{ix86} x86_64 s390 %{arm} aarch64
%global XFLAGS -fPIC
%endif

%prep
%setup -q
%patch -P 0 -p1
%patch -P 2 -p1

%ifarch %{arm}
%patch -P 1 -p1
%endif

%build
%configure							\
	--enable-sharedlibs=gcc					\
	--enable-shared						\
	--enable-static=no					\
	--enable-lib-depend					\
	--disable-rpath						\
	--disable-silent-rules					\
	--enable-fc						\
	--with-device=%{selected_channels}			\
	--with-pm=hydra:gforker					\
	--includedir=%{_includedir}/%{name}-%{_arch}		\
	--bindir=%{_bindir}					\
	--libdir=%{_libdir}					\
	--datadir=%{_datadir}/%{name}				\
	--mandir=%{_mandir}					\
	--docdir=%{_datadir}/%{name}/doc			\
	--htmldir=%{_datadir}/%{name}/doc/html			\
	--with-hwloc-prefix=system				\
	FC=%{opt_fc}						\
	F77=%{opt_f77}						\
	CFLAGS="%{m_option} -O2 %{?XFLAGS}"			\
	CXXFLAGS="%{m_option} -O2 %{?XFLAGS}"			\
	FCFLAGS="%{m_option} -O2 %{?XFLAGS}"			\
	FFLAGS="%{m_option} -O2 %{?XFLAGS} -fallow-argument-mismatch" \
	LDFLAGS="%{ldflags} -Wl,-z,noexecstack"			\
	MPICHLIB_CFLAGS="%{?opt_cc_cflags}"			\
	MPICHLIB_CXXFLAGS="%{optflags}"				\
	MPICHLIB_FCFLAGS="%{?opt_fc_fflags}"			\
	MPICHLIB_FFLAGS="%{?opt_f77_fflags}"

# work-around libtool error: cannot determine absolute directory name of 'system/lib'
mkdir -p system/lib

%make_build

%install
%make_install

# Install the RPM macros
install -pDm0644 %{SOURCE1} %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name}

cat > README.urpmi <<EOF
Post-installation procedure:
- create a user with constant uid/gid and shared home directory on all nodes
- ensure this user has rsh/ssh access to all nodes
For instance, a solution could be:
	# groupadd -g 12384 -r -f mpi
	# useradd -u 12384 -g mpi -d %{mpihome} -r -s /bin/bash mpi -p "" -m
	# mkpasswd -l 32 | passwd --stdin mpi 2>&1 > /dev/null
	# ssh-keygen -f %{mpihome}/.ssh/id_dsa -t dsa -N "" 2>&1 > /dev/null
	# chown mpi:mpi %{mpihome}/.ssh/id_dsa
	# chmod 600 %{mpihome}/.ssh/id_dsa
EOF

# Install the .pth files
mkdir -p %{buildroot}%{python3_sitearch}/%{name}
install -pDm0644 %{SOURCE3} %{buildroot}%{python3_sitearch}/%{name}.pth

rm -fr %{buildroot}%{_libdir}/pkgconfig/yaksa.pc

find %{buildroot} -type f -name "*.la" -delete

%check
%ifnarch %{arm}
make check VERBOSE=1 || :
%endif

%files
%doc COPYRIGHT README.urpmi
%{_bindir}/hydra*
%{_bindir}/mpichversion
%{_bindir}/mpiexec*
%{_bindir}/mpirun
%{_bindir}/mpivars
%{_bindir}/parkill
%{_mandir}/man1/hydra_*.1*
%{_mandir}/man1/mpiexec.1*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{devname}
%doc COPYRIGHT
%{_includedir}/%{name}-%{_arch}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_rpmconfigdir}/macros.d/macros.%{name}
%{_mandir}/man3/*.3*

%files doc
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/doc/

%files -n mpicc
%doc COPYRIGHT
%{_bindir}/mpicc
%{_mandir}/man1/mpicc.1*

%files -n mpicxx
%doc COPYRIGHT
%{_bindir}/mpicxx
%{_bindir}/mpic++
%{_mandir}/man1/mpicxx.1*

%files -n mpif90
%doc COPYRIGHT
%{_bindir}/mpifort
%{_bindir}/mpif90
%{_bindir}/mpif77
%{_mandir}/man1/mpifort.1*
%{_mandir}/man1/mpif77.1*

%files -n python3-mpich
%dir %{python3_sitearch}/%{name}
%{python3_sitearch}/%{name}.pth
