%define shortver %(echo %{version}|cut -d. -f1,2)

%global fontdir %{_datadir}/fonts/mscore

# Upstream use a patched original fluidsynth:
# - removed dependency on glib (added define NO_GLIB)
%bcond_with fluidsynth

Summary:        Linux MusE Score Typesetter
Name:           mscore
Version:        4.4.3
Release:        %mkrel 2
# (Fedora) rtf2html is LGPLv2+
# paper4.png paper5.png are LGPLv3
# the rest is GPLv2
# Soundfont is MIT
# Bravura and gootville are OFL
License:        GPLv2 and LGPLv2+ and LGPLv3 and CC-BY and MIT and OFL
Url:            https://musescore.org
Group:          Publishing
Source0:        https://github.com/musescore/MuseScore/archive/v%{version}/MuseScore-%{version}.tar.gz

# For mime types
Source1:        %{name}.xml
# Add metainfo file for font to show in gnome-software
Source2:        %{name}.metainfo.xml
Source3:        Findlame.cmake

# Use Mageia's default soundfont instead of the removed one:
# Patch0:         mscore-3.6.2-use-default-soundfont.patch
# We don't build the common files (font files, wallpapers, demo song, instrument
# list) into the binary executable to reduce its size. This is also useful to
# inform the users about the existence of different choices for common files.
# The font files need to be separated due to the font packaging guidelines.
# Patch1:         mscore-3.5.1-separate-commonfiles.patch
# Fix desktop file. The Version= field is for the Desktop File Specification version
# not the version of MuseScore
# Patch3:         mscore-3.6.2-fix-desktop-file.patch
# Use CXXFLAGS for precompiled header
# Patch4:         mscore-3.6.2-fix-flags-for-precompiled-header.patch
# Use system lame
Patch10:        0001-mscore4.3.2-system-lame.patch
# Use system gtest, stb and utf8
Patch11:        mscore-4.3.2-system-gtest-and-utf8-and-stb.patch
# Disable for now as it needs more love
Source14:       mscore-system-fluidsynth.patch

## Upstream patches

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  qttools6-assistant
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  perl(Pod::Usage)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flac++)
%if %{with fluidsynth}
BuildRequires:  pkgconfig(fluidsynth)
%endif
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(libopusenc)
BuildRequires:  cmake(utf8cpp)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6NetworkAuth)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Qml)
BuildRequires:  cmake(Qt6QuickControls2)
BuildRequires:  cmake(Qt6QuickTemplates2)
BuildRequires:  cmake(Qt6QuickWidgets)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6StateMachine)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6WebSockets)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(stb)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  ffmpeg-devel
BuildRequires:  lame-devel
BuildRequires:  git

Requires:       qt6-qtdeclarative
Requires:       %{name}-fonts = %{version}-%{release}
Requires:       soundfont2-default

Provides:       musescore = %{version}-%{release}

# The following products have been modified from their upstream versions,
# or MuseScore uses internal (non-public) APIs
Provides:       bundled(beatroot-vamp) = 1.0
Provides:       bundled(liblouis) = 3.24.0
Provides:       bundled(intervaltree) = 0.1
Provides:       bundled(rtf2html) = 0.2.0
Provides:       bundled(KDDockWidgets) = 1.5.0
%if ! %{with fluidsynth}
Provides:       bundled(fluidsynth) = 2.3.3
%endif
# FIXME: it might be possible to unbundle these
Provides:       bundled(kors_async) = 1.3
Provides:       bundled(kors_modularity) = 1.2
Provides:       bundled(kors_profiler) = 1.2
Provides:       bundled(kors_logger) = 1.3
Provides:       bundled(picojson) = 1.3.0

# Doxygen documentation is huge and it is for musescore development only.
# Hence we don't build it for now. Otherwise it needs:
# BuildRequires: graphviz doxygen texlive-latex texlive-dvips

%description
MuseScore stands for Linux MusE Score Typesetter.

Features:
 - WYSIWYG design, notes are entered on a "virtual notepaper"
 - TrueType font(s) for printing & display allows for high quality
   scaling to all sizes
 - easy & fast note entry
 - many editing functions
 - MusicXML import/export
 - Midi (SMF) import/export
 - MuseData import
 - Midi input for note entry
 - integrated sequencer and software synthesizer to
   play the score
 - print or create pdf files

%package doc
Summary:        MuseScore documentation
Group:          Development/Other
License:        CC-BY
Requires:       %{name} >= %{version}-%{release}
BuildArch:      noarch

%description doc
MuseScore is a free cross platform WYSIWYG music notation program.

This package contains the user manual of MuseScore in different languages.

%package fonts
Summary:        MuseScore fonts
Group:          Publishing
License:        GPL+ with exceptions and OFL
BuildArch:      noarch
BuildRequires:  fontforge
BuildRequires:  texlive
BuildRequires:  texlive-texmf
BuildRequires:  t1utils


%description fonts
MuseScore is a free cross platform WYSIWYG music notation program.

This package contains the musical notation fonts for use of MuseScore.

%prep
%autosetup -p1 -n MuseScore-%{version}

mkdir -p src/framework/audio/CMakeModules
cp %{_sourcedir}/Findlame.cmake src/framework/audio/CMakeModules/

# Remove bundled stuff
rm -vrf src/framework/audio/thirdparty/lame
rm -vrf src/framework/audio/thirdparty/opus{,enc}
rm -vrf src/framework/audio/thirdparty/flac
rm -vrf src/framework/audio/thirdparty/stb
%if %{with fluidsynth}
rm -vrf src/framework/audio/thirdparty/fluidsynth
%endif

rm -vrf src/framework/global/thirdparty/{tinyxml,utfcpp*}

rm demos/All_Dudes.mscz demos/Triumph.mscz

%build
# Build the actual program
%global _vpath_builddir build-%{_target}
%cmake \
	-DMUSESCORE_BUILD_CONFIGURATION=app \
	-DMUSE_APP_BUILD_MODE=release \
	-DCMAKE_SKIP_RPATH=ON \
	-DCMAKE_CXX_FLAGS_RELWITHDEBINFO:STRING="-DNDEBUG -DQT_NO_DEBUG" \
	-DCMAKE_POSITION_INDEPENDENT_CODE=ON \
	-DMUE_COMPILE_USE_CCACHE=OFF \
	-DMUE_DOWNLOAD_SOUNDFONT=OFF \
	-DMUE_BUILD_VIDEOEXPORT_MODULE=ON \
	-DMUE_COMPILE_USE_SYSTEM_FLAC=ON \
	-DMUE_COMPILE_USE_SYSTEM_FREETYPE=ON \
	-DMUE_COMPILE_USE_SYSTEM_HARFBUZZ=ON \
	-DMUE_COMPILE_USE_SYSTEM_OPUS=ON \
	-DMUE_COMPILE_USE_SYSTEM_OPUSENC=ON \
	-DMUE_COMPILE_USE_SYSTEM_TINYXML=ON \
	-DMUSE_MODULE_DIAGNOSTICS_CRASHPAD_CLIENT=OFF \
	-DMUSE_COMPILE_USE_PCH=OFF \
	-DMUSESCORE_BUILD_UPDATE_MODULE=OFF \
	-DMUSESCORE_CRASHREPORT_URL="https://bugs.mageia.org" \
	-DMUSE_ENABLE_UNIT_TESTS=OFF

%make_build -C %{_vpath_builddir} PREFIX=%{_prefix} mscore_lrelease
%make_build -C %{_vpath_builddir} PREFIX=%{_prefix} manpages
%make_build -C %{_vpath_builddir} PREFIX=%{_prefix} VERBOSE=1

%install
echo %{shortver}
%make_install -C %{_vpath_builddir} PREFIX=%{_prefix}

# DELETE REMAINING DEVEL FILES OF Gtest Gmock and KDDockWidgets
rm -rf %{buildroot}{%{_includedir},%{_libdir}}

# Install fonts
mkdir -p %{buildroot}%{fontdir}
mkdir -p %{buildroot}%{fontdir}/bravura
mkdir -p %{buildroot}%{fontdir}/campania
mkdir -p %{buildroot}%{fontdir}/gootville
mkdir -p %{buildroot}%{fontdir}/musejazz
install -pm 644 fonts/*.ttf %{buildroot}%{fontdir}
install -pm 644 fonts/bravura/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/bravura/*.json %{buildroot}%{fontdir}/bravura
install -pm 644 fonts/campania/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/gootville/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/gootville/*.json %{buildroot}%{fontdir}/gootville/
install -pm 644 fonts/mscore/*.ttf %{buildroot}%{fontdir}
install -pm 644 fonts/mscore/*.json %{buildroot}%{fontdir}
install -pm 644 fonts/musejazz/*.otf %{buildroot}%{fontdir}
install -pm 644 fonts/musejazz/*.json %{buildroot}%{fontdir}/musejazz/
install -pm 644 fonts/*.xml %{buildroot}%{fontdir}


pushd %{buildroot}%{fontdir}
cd bravura
ln -s ../Bravura.otf .
ln -s ../BravuraText.otf .
cd ../campania
ln -s ../Campania.otf .
cd ../gootville
ln -s ../Gootville.otf .
ln -s ../GootvilleText.otf .
cd ../musejazz
ln -s ../MuseJazz.otf .
ln -s ../MuseJazzText.otf .
cd ..
popd

# Mime type
mkdir -p %{buildroot}%{_datadir}/mime/packages
install -pm 644 %{SOURCE1} %{buildroot}%{_datadir}/mime/packages/

# Desktop file
desktop-file-install \
   --dir=%{buildroot}%{_datadir}/applications \
   --add-category="X-Notation" \
   --remove-category="Sequencer" \
   --remove-category="AudioVideoEditing" \
   --add-mime-type="audio/midi" \
   --add-mime-type="text/x-lilypond" \
   --add-mime-type="application/xml" \
   %{buildroot}%{_datadir}/applications/org.musescore.MuseScore.desktop

# There are many doc files spread around the tarball. Let's collect them
mkdir -p docs
rm -rf docs/*
cp -a thirdparty/rtf2html/ChangeLog        docs/ChangeLog.rtf2html
cp -a thirdparty/rtf2html/COPYING.LESSER   docs/COPYING.LESSER.rtf2html
cp -a thirdparty/rtf2html/README           docs/README.rtf2html
cp -a thirdparty/rtf2html/README.mscore    docs/README.mscore.rtf2html
cp -a thirdparty/rtf2html/README.ru        docs/README.ru.rtf2html
cp -a share/wallpapers/COPYRIGHT            docs/COPYING.wallpaper
cp -a fonts/bravura/OFL.txt                docs/COPYING.OFL
cp -a share/sound/FluidR3Mono_License.md  docs/COPYING.FluidR3Mono

# Add AppStream metadata for fonts
install -Dm 0644 -p %{SOURCE2} \
  %{buildroot}%{_metainfodir}/%{name}.metainfo.xml

# Install soundfont
install -Dm 0644 -p share/sound/FluidR3Mono_GM.sf3 \
  %{buildroot}%{_datadir}/soundfonts/FluidR3Mono_GM.sf3

# remove binary executable
rm -f %{buildroot}%{_bindir}/crashpad_handler

%files
%doc README* docs/ChangeLog* docs/README*
%license docs/COPYING*
%{_bindir}/%{name}
%{_datadir}/%{name}-%{shortver}/
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/applications/org.musescore.MuseScore.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/mime/packages/musescore.xml
%{_mandir}/man1/*.1*
%{_datadir}/soundfonts/FluidR3Mono_GM.sf3
%{_metainfodir}/org.musescore.MuseScore.appdata.xml

%files fonts
%{_datadir}/fonts/mscore/
%{_metainfodir}/%{name}.metainfo.xml
