%define major   0
%define libname %mklibname multipath %{major}
%define libmp_c %mklibname mpathcmd %{major}
%define libmp_p %mklibname mpathpersist %{major}
%define libmp_u %mklibname mpathutil%{major}
%define libmp_v %mklibname mpathvalid %{major}
%define libdmmp %mklibname dmmp %{major}
%define devname %mklibname multipath-tools -d
%define devdmmp %mklibname dmmp -d

%define systemd_ver %(pkg-config --modversion systemd 2> /dev/null)

%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libmpathcmd

%define _libmpathdir %{_libdir}/multipath
%define _pkgconfdir %{_libdir}/pkgconfig

Name:           multipath-tools
# This URL is no longer available
URL:            http://christophe.varoqui.free.fr/
License:        GPLv2
Group:          System/Kernel and hardware
Version:        0.10.0
Release:        %mkrel 1
Summary:        Tools to manage multipathed devices with the device-mapper
# The source for this package was pulled from upstream's git repo.  Use the
# following command to generate the tarball
# curl "https://git.opensvc.com/?p=multipath-tools/.git;a=snapshot;h=refs/tags/0.8.4;sf=tgz" -o multipath-tools-0.8.4.tgz
Source0:        https://github.com/opensvc/multipath-tools/archive/%{version}/multipath-tools-%{version}.tar.gz
Patch0021:      0021-RH-Fix-nvme-compilation-warning.patch

BuildRequires:  libaio-devel
BuildRequires:  libsysfs-devel
BuildRequires:  userspace-rcu-devel
BuildRequires:  pkgconfig(devmapper)
BuildRequires:  pkgconfig(mount)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(udev)

Requires:       dmsetup
Requires:       kpartx = %{version}
Conflicts:      kpartx < 0.4.8-16
Provides:       device-mapper-multipath = %{version}-%{release}

%{?systemd_requires}

%description
This package provides the tools to manage multipathed devices by
instructing the device-mapper multipath module what to do. The tools
are:

- multipath: scan the system for multipathed devices, assembles them
  and update the device-mapper's maps

- multipathd: wait for maps events, then execs multipath

- devmap-name: provides a meaningful device name to udev for devmaps

- kpartx: maps linear devmaps upon device partitions, which makes
  multipath maps partitionable

%package -n %{libname}
Summary:        Shared multipath library for %{name}
Group:          System/Libraries

%description -n %{libname}
Shared multipath library for %{name}.

%package -n %{libmp_c}
Summary:        Shared mpathcmd library for %{name}
Group:          System/Libraries

%description -n %{libmp_c}
Shared mpathcmd library for %{name}.

%package -n %{libmp_p}
Summary:        Shared mpathpersist library for %{name}
Group:          System/Libraries

%description -n %{libmp_p}
Shared mpathpersist library for %{name}.

%package -n %{libmp_u}
Summary:        Shared mpathutil library for %{name}
Group:          System/Libraries

%description -n %{libmp_u}
Shared mpathutil library for %{name}.

%package -n %{libmp_v}
Summary:        Shared mpathvalid library for %{name}
Group:          System/Libraries

%description -n %{libmp_v}
Shared mpathvalid library for %{name}.

%package -n %{devname}
Summary:        Development libraries and headers for %{name}
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libmp_c} = %{version}-%{release}
Requires:       %{libmp_p} = %{version}-%{release}
Requires:       %{libmp_u} = %{version}-%{release}
Requires:	%{libmp_v} = %{version}-%{release}
Provides:       device-mapper-multipath-devel = %{version}-%{release}
Provides:       multipath-devel = %{version}-%{release}

%description -n %{devname}
This package contains the files need to develop applications that use
device-mapper-multipath's lbmpathpersist and libmpathcmd libraries.

%package -n kpartx
Summary:        Partition device manager for device-mapper devices
Group:          System/Kernel and hardware
Requires:       dmsetup
Conflicts:      multipath-tools < 0.4.8-16

%description -n kpartx
kpartx manages partition creation and removal for device-mapper devices.

%package -n %{libdmmp}
Summary:        device-mapper-multipath C API library
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description -n %{libdmmp}
This package contains the shared library for the device-mapper-multipath
C API library.

%package -n %{devdmmp}
Summary:        device-mapper-multipath C API library headers
Group:          Development/C
Requires:       %{libdmmp} = %{version}-%{release}
Provides:       libdmmp-devel = %{version}-%{release}

%description -n %{devdmmp}
This package contains the files needed to develop applications that use
device-mapper-multipath's libdmmp C API library.

%prep
%autosetup -p1

%build
%set_build_flags
%make_build OPTFLAGS="%{optflags}" SYSTEMD=%{systemd_ver}

%install
%make_install \
	syslibdir=%{_libdir} \
	usrlibdir=%{_libdir} \
	plugindir=%{_libmpathdir} \
	unitdir=%{_unitdir} \
	includedir=%{_includedir} \
	pkgconfdir=%{_pkgconfdir} \
	tmpfilesdir=%{_tmpfilesdir}

rm -rf %{buildroot}%{_sysconfig}/hotplug.d

%post
%_post_service multipathd

%preun
%_preun_service multipathd

%postun
%_postun_service multipathd

%files
%license LICENSES/*
%doc README.md
/sbin/multipath
/sbin/multipathc
/sbin/multipathd
/sbin/mpathpersist
%{_mandir}/man?/*dmmp*
%{_mandir}/man?/multipath*
%{_mandir}/man?/mpath*
%dir %{_libmpathdir}
%{_libmpathdir}/*
%{_tmpfilesdir}/multipath.conf
%{_unitdir}/multipathd.service
%{_unitdir}/multipathd.socket
%{_udevrulesdir}/*path*.rules
%{_udevrulesdir}/*part*.rules

%files -n %{libname}
%doc README.md
%license LICENSES/*
%{_libdir}/libmultipath.so.%{major}{,.*}

%files -n %{libmp_c}
%license LICENSES/*
%{_libdir}/libmpathcmd.so.%{major}{,.*}

%files -n %{libmp_p}
%license LICENSES/*
%{_libdir}/libmpathpersist.so.%{major}{,.*}

%files -n %{libmp_u}
%license LICENSES/*
%{_libdir}/libmpathutil.so.%{major}{,.*}

%files -n %{libmp_v}
%license LICENSES/*
%{_libdir}/libmpathvalid.so.%{major}{,.*}

%files -n %{devname}
%license LICENSES/*
%{_libdir}/libmultipath.so
%{_libdir}/libmpathpersist.so
%{_libdir}/libmpathcmd.so
%{_libdir}/libmpathutil.so
%{_libdir}/libmpathvalid.so
%{_includedir}/mpath_cmd.h
%{_includedir}/mpath_persist.h
%{_includedir}/mpath_valid.h
%{_mandir}/man3/mpath_persistent_reserve_in.3.*
%{_mandir}/man3/mpath_persistent_reserve_out.3.*

%files -n kpartx
%license LICENSES/*
/sbin/kpartx
%{_udevrulesdir}/*kpartx.rules
%{_prefix}/lib/udev/kpartx_id
%{_mandir}/man8/kpartx.8*

%files -n %{libdmmp}
%license LICENSES/*
%{_libdir}/libdmmp.so.%{major}{,.*}

%files -n %devdmmp
%license LICENSES/*
%{_libdir}/libdmmp.so
%dir %{_includedir}/libdmmp
%{_includedir}/libdmmp/*
%{_mandir}/man3/dmmp_*
%{_mandir}/man3/libdmmp.h.3.*
%{_pkgconfdir}/libdmmp.pc
