# configuration options for the server (mumble-server)
%define build_server	1
%define build_web	0
%define build_ice	1
# configuration options for the client
%define build_client	1
%define build_speechd	1
%define build_g15	1

%{?_without_server:	%{expand: %%global build_server 0}}
%{?_without_server:	%{expand: %%global build_ice 0}}
%{?_with_server:	%{expand: %%global build_server 1}}

%{?_without_ice:	%{expand: %%global build_ice 0}}
%{?_with_ice:		%{expand: %%global build_ice 1}}

%{?_without_client:	%{expand: %%global build_client 0}}
%{?_without_client:	%{expand: %%global build_speechd 0}}
%{?_without_client:	%{expand: %%global build_g15 0}}
%{?_with_client:	%{expand: %%global build_client 1}}

%{?_without_speechd:	%{expand: %%global build_speechd 0}}
%{?_with_speechd:	%{expand: %%global build_speechd 1}}

%{?_without_g15:	%{expand: %%global build_g15 0}}
%{?_with_g15:		%{expand: %%global build_g15 1}}

# comment out if not a pre-release
#define prel	rc1
# bump the rel
%define rel	5

%define build_number	735

Summary:	Low-latency, high-quality voice communication for gamers
Name:		mumble
Version:	1.5.%{build_number}
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	BSD
Group:		Communications/Telephony
Url:		https://mumble.sourceforge.net/
Source0:	https://github.com/mumble-voip/mumble/releases/download/v%{version}%{?prel:-%prel}/%{name}-%{version}%{?prel:-%prel}.tar.gz
# conf files courtesy of debian package
Source2:	%{name}-server-web.conf
Source3:	MurmurPHP.ini
Source4:	README.install.urpmi.mumble-server-web
Source6:	%{name}-server.logrotate
Patch1:		mumble-mageiaize-systemd-unit.patch
Patch2:		mumble-add-pid-location-hint.patch
Patch3:		mumble-unbundle-audio-backends.patch

BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	desktop-file-utils
BuildRequires:	boost-devel
BuildRequires:	cmake(Qt5Concurrent)
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5DBus)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5Help)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5Sql)
BuildRequires:	cmake(Qt5Svg)
BuildRequires:	cmake(Qt5TextToSpeech)
BuildRequires:	cmake(Qt5Widgets)
BuildRequires:	cmake(Qt5Xml)
BuildRequires:	cmake(Microsoft.GSL)
BuildRequires:	cmake(PocoXML)
BuildRequires:	cmake(PocoZip)
BuildRequires:	cmake(SndFile)
BuildRequires:	protobuf-compiler
BuildRequires:	pkgconfig(avahi-compat-libdns_sd)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(nlohmann_json)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(speex) >= 1.2
BuildRequires:	pkgconfig(speexdsp)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libpipewire-0.3)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(opus)
BuildRequires:	pkgconfig(portaudio-2.0)
BuildRequires:	pkgconfig(silk)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(xi) >= 1.6.0

%if %build_speechd
BuildRequires:	pkgconfig(speech-dispatcher)
%endif

%if %build_g15
BuildRequires:	g15daemon_client-devel
%endif

Requires:	qt5-database-plugin-sqlite
Requires:	%{name}-plugins = %{version}-%{release}

%if %build_speechd
Recommends:	speech-dispatcher
%endif

%if %build_g15
Recommends:	g15daemon
%endif

Provides:	bundled(renamenoise)

Obsoletes:	mumble-protocol-plasma5 < 1.4.287-9

%description
Low-latency, high-quality voice communication for gamers.

Includes game linking, so voice from other players comes
from the direction of their characters, and has echo
cancellation so the sound from your loudspeakers won't be
audible to other players.

%package	plugins
Summary:	Mumble plugins
Group:		Communications/Telephony
Requires:	%{name} = %{version}-%{release}

%description	plugins
This packages provides the Mumble plugins.

%if %build_server
%package	server
Summary:	The VOIP server for Mumble
Group:		Communications/Telephony
Requires(post):	systemd >= %{systemd_required_version}
Requires(pre):	rpm-helper
Requires(post):	rpm-helper
Requires(preun):	rpm-helper
%if %build_ice
# keep ice-devel, pkgconfig(ice) is not the same ice devel pkg
BuildRequires:	ice-devel
# (cg) ice-devel should require this itself, but it doesn't...
BuildRequires:	ice
%endif
Requires:	qt5-database-plugin-sqlite
Requires:	dbus
%if !%build_web
Conflicts:	%{name}-server-web
%endif

%description	server
This package provides the VOIP server for Mumble.

%if %build_web
%package	server-web
Summary:	Web scripts for mumble-server
Group:		Communications/Telephony
Requires:	apache
Requires:	perl-CGI
Requires:	mail-server
%if %build_ice
Requires:	ice
%endif
Requires:	%{name}-server = %{version}-%{release}

%description	server-web
This package contains the web scripts for mumble-server.

%endif
%endif

%prep
%autosetup -p1

cp -p %{SOURCE4} README.install.urpmi

# ensure the default server directory is created
printf "d /var/lib/mumble-server 0750 _mumble-server _mumble-server -\n" >> auxiliary_files/config_files/mumble-server.tmpfiles.in
printf "d /run/mumble-server 0710 mumble-server mumble-server -\n" >> auxiliary_files/config_files/mumble-server.tmpfiles.in

%build
%cmake_qt5 \
	-GNinja \
	-DCMAKE_CXX_STANDARD=17 \
	-DCMAKE_SHARED_LINKER_FLAGS="-L%{_libdir}/libGL.so" \
%if ! %build_server
	-Dserver:BOOL=OFF \
%endif
%if ! %build_client
	-Dclient:BOOL=OFF \
%endif
%if ! %build_ice
	-Dice:BOOL=OFF \
%endif
%if %build_g15
	-Dg15:BOOL=ON \
%endif
%ifarch %{ix86} %{arm32}
	-Dwarnings-as-errors:BOOL=OFF \
%endif
	-Duse-pkgconf-install-paths:BOOL=ON \
	-Ddisplay-install-paths:BOOL=ON \
	-Dsymbols:BOOL=ON \
	-Dupdate:BOOL=OFF \
	-Dbundled-gsl:BOOL=OFF \
	-Dbundled-speex:BOOL=OFF \
	-Dbundled-json:BOOL=OFF \
	-Dbundled-renamenoise:BOOL=ON \
	-Dbundle-qt-translations:BOOL=OFF \
	-Dqtspeech:BOOL=ON
%cmake_build

%install
%cmake_install

%if %build_server
# --- Mumble-server/Murmur install ---

mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-server

# create database directory
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/%{name}-server

# create log directory
install -d -m 0755 %{buildroot}%{_localstatedir}/log/%{name}-server

# install examplefreeipa
mkdir -p %{buildroot}%{_localstatedir}/%{name}-server/examples

# create pidfile directory
install -d -m 0755 %{buildroot}%{_rundir}/%{name}-server

%if %build_web
# --- Mumble-server-web files ---
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}-server-web.conf
%if %build_ice
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/php.d/MurmurPHP.ini
install -D -m 0644 scripts/server/ice/weblist.php %{buildroot}%{_datadir}/%{name}-server-web/www/weblist.php
%endif
install -D -m 0755 scripts/server/dbus/weblist.pl %{buildroot}%{_datadir}/%{name}-server-web/www/weblist.cgi
install -D -m 0755 scripts/server/dbus/murmur.pl %{buildroot}%{_datadir}/%{name}-server-web/www/register.cgi
pushd %{buildroot}%{_datadir}/%{name}-server-web/www
ln -s weblist.php index.php
popd
%endif
%endif

%if %build_server
%pre server
%_pre_useradd %{name}-server %{_var}/lib/%{name}-server /bin/sh

%post server
%_tmpfilescreate %{name}-server
%_post_service %{name}-server

%preun server
%_preun_service %{name}-server
%endif

%if %build_client
%files
%doc README.md SECURITY.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}-overlay
%{_datadir}/applications/info.mumble.Mumble.desktop
%{_metainfodir}/info.mumble.Mumble.appdata.xml
%{_iconsdir}/hicolor/*/apps/%{name}.{png,svg}
%{_mandir}/man1/%{name}.*
%{_mandir}/man1/%{name}-overlay.*

%files plugins
%{_libdir}/%{name}/
%endif

%if %build_server
%files server
%if ! %build_client
%doc README.md SECURITY.md
%license LICENSE
%endif
%{_bindir}/%{name}-server-user-wrapper
%{_bindir}/%{name}-server
%{_unitdir}/%{name}-server.service
%{_sysusersdir}/%{name}-server.conf
%{_tmpfilesdir}/%{name}-server.conf
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}-server.ini
%{_sysconfdir}/logrotate.d/%{name}-server
%attr(-,mumble-server,mumble-server) %dir %{_localstatedir}/lib/%{name}-server
%attr(-,mumble-server,root) %dir %{_localstatedir}/log/%{name}-server
%attr(0710,mumble-server,mumble-server) %ghost %dir %{_rundir}/%{name}-server
%ghost %attr(0660, -, -) %{_rundir}/mumble-server/mumble-server.pid
%if %build_ice
%dir %{_datadir}/%{name}-server
%{_datadir}/%{name}-server/MumbleServer.ice
%endif
%{_mandir}/man1/mumble-server-user-wrapper.1*
%{_mandir}/man1/mumble-server.1*

%if %build_web
%files server-web
%doc README.install.urpmi
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}-server-web.conf
%if %build_ice
%config(noreplace) %{_sysconfdir}/php.d/MurmurPHP.ini
%endif
%{_datadir}/%{name}-server-web/
%endif
%endif
