# Most cores don't require a BIOS/copyrighted material, so it can go in core.

%define major   2
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           mupen64plus
Version:        2.6.0
Release:        %mkrel 5
Summary:        Nintendo 64 Emulator (console frontend)
License:        GPLv2+ and LGPLv2+
Group:          Emulators
URL:            https://www.mupen64plus.org
Source0:        https://github.com/mupen64plus/mupen64plus-core/releases/download/%{version}/%{name}-bundle-src-%{version}.tar.gz
Patch0:         mupen64plus-use-system-font.patch
Patch1:         mupen64plus-arm32.patch

BuildRequires:  boost-devel
BuildRequires:  lirc-devel
BuildRequires:  nasm
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(vulkan)
Requires:       fonts-ttf-dejavu
Requires:       %{libname} = %{version}-%{release}

%description
Mupen64Plus is a cross-platform plugin-based Nintendo 64 emulator which is
capable of accurately playing many games. Included are four MIPS R4300 CPU
emulators, with dynamic recompilers for 32-bit x86 and 64-bit amd64 systems,
and necessary plugins for audio, graphical rendering (RDP), signal
co-processor (RSP), and input.

%files
%license source/mupen64plus-core/LICENSES
%doc source/mupen64plus-core/{README,RELEASE}
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------------

%package -n     %{libname}
Summary:        Main library for Mupen64Plus Nintendo 64 Emulator
Group:          System/Libraries
Recommends:     m64py

%description -n %{libname}
Mupen64Plus is a cross-platform plugin-based Nintendo 64 emulator which is
capable of accurately playing many games. Included are four MIPS R4300 CPU
emulators, with dynamic recompilers for 32-bit x86 and 64-bit amd64 systems,
and necessary plugins for audio, graphical rendering (RDP), signal
co-processor (RSP), and input.

This package contains the shared library interface for Mupen64Plus frontends
and all plugins from the upstream project.

%files -n       %{libname}
%license source/mupen64plus-core/LICENSES
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/%{name}/

#----------------------------------------------------------------------------

%package -n     %{devname}
Summary:        Development headers for Mupen64Plus Nintendo 64 Emulator
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Mupen64Plus is a cross-platform plugin-based Nintendo 64 emulator which is
capable of accurately playing many games. Included are four MIPS R4300 CPU
emulators, with dynamic recompilers for 32-bit x86 and 64-bit amd64 systems,
and necessary plugins for audio, graphical rendering (RDP), signal
co-processor (RSP), and input.

This package contains all necessary include files to develop frontends
against the Mupen64Plus shared library interface.

%files -n       %{devname}
%{_includedir}/%{name}/

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-bundle-src-%{version}

# We use the system's font instead of the shipped one
rm source/mupen64plus-core/data/font.ttf

%build
OPTFLAGS="%{optflags}" \
LDFLAGS="%{ldflags}" \
./m64p_build.sh LIBDIR=%{_libdir} PLUGINDIR=%{_libdir}/%{name} \
                PIC=1 \
                LIRC=1 \
%ifnarch %{ix86} x86_64
                NO_SSE=1 \
%endif
                V=1 \
                %{_smp_mflags}

%install
./m64p_install.sh DESTDIR=%{buildroot} \
                  PREFIX=%{_prefix} \
                  LIBDIR=%{_libdir} \
                  MANDIR=%{_mandir} \
                  INSTALL_STRIP_FLAG=''

# ensure libraries/modules are executable (mga#24160#c4)
chmod a+rx %{buildroot}%{_libdir}/lib%{name}.so.%{major}*
chmod a+rx %{buildroot}%{_libdir}/%{name}/*.so
