%define _default_patch_fuzz 2

# nntp patch version
%global nversion 1.12.1

%bcond_with nntp

# compile against kerberos
%bcond_with krb5

# enable sasl2
# note that sasl2 includes kerberos support via sasl
%bcond_without sasl2

%global __requires_exclude perl\\(timelocal.pl\\)

Name:		mutt
Epoch:		1
Version:	2.2.14
Release:	%mkrel 1
Summary:	Text mode mail user agent
License:	GPL
Group:		Networking/Mail
Url:		http://www.mutt.org/
Source0:	https://bitbucket.org/mutt/mutt/downloads/%{name}-%{version}.tar.gz
Source1:	https://bitbucket.org/mutt/mutt/downloads/%{name}-%{version}.tar.gz.asc

#
# NOTE: For any patch that modifies Muttrc, please modify Muttrc.head.in
# instead, because Muttrc is automatically generated, so any change will
# be lost
#

#
# Patch 1-99: Mandriva patches
#

# Set tmpdir to ~/tmp in sample config
Patch1:		mutt-1.3.15-tmpdef.patch

# Tell user to install urlview instead of just barf at user
Patch2:         mutt-1.5.18-urlview.patch

# Allow non root users to install mutt
Patch3:		mutt-1.5.24-no-sgid.patch

# Replace ispell with aspell
Patch6:		mutt-1.13.4-aspell.patch

# Fallback charsets
Patch7:		mutt-1.13.4-send_charset.patch

# Fix build with autoconf > 2.69
Patch8:		mutt-autoconf.patch

#
# Patch 100- : external patches
#

# NNTP support
Patch101:       https://www.mutt.org.ua/download/mutt-%{nversion}/patch-%{nversion}.vvv.nntp.xz


#
# Patch200+ : Security patches
#

BuildRequires:	aspell
BuildRequires:	bzip2-devel
BuildRequires:	linuxdoc-tools
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	sendmail-command
BuildRequires:	db-devel >= 5.3
BuildRequires:	gpgme-devel

# manual generation
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
# html manual -> txt manual conversion (lynx messes up the encoding)
BuildRequires:	w3m

%if %{with krb5}
BuildRequires:	krb5-devel
%endif

%if %{with sasl2}
BuildRequires:	pkgconfig(libsasl2) >= 2.1
Requires:	sasl-plug-login
%endif

BuildRequires:	pkgconfig(libidn2)

# without it we have problems with attachments (e.g. .pdfs)
Recommends: mailcap
Recommends: mutt-doc

%description
Mutt is a text mode mail user agent. Mutt supports color, threading,
arbitrary key remapping, and a lot of customization.

You should install mutt if you've used mutt in the past and you prefer
it, or if you're new to mail programs and you haven't decided which
one you're going to use.

%package	doc
Summary:	Manual for Mutt, a text mode mail user agent
Group:		Networking/Mail

%description	doc
This is the complete manual for Mutt, in text and HTML formats.

Mutt is a text mode mail user agent. Mutt supports color, threading,
arbitrary key remapping, and a lot of customization.

You should install mutt if you've used mutt in the past and you prefer
it, or if you're new to mail programs and you haven't decided which
one you're going to use.


%prep
%setup -q
%patch -P1 -p1 -b .tmpdef
%patch -P2 -p1 -b .urlview
%patch -P3 -p0 -b .no-sgid
%patch -P6 -p1 -b .aspell
%patch -P7 -p1 -b .charset
%patch -P8 -p1 -b .autoconf
%if %{with nntp}
%patch -P101 -p1 -b .nntp
%endif

# Fix some bad references in the man pages
# Reference to imapd is not fixed, since uw-imap/courier/cyrus all have
# different paths
perl -pi -e 's|/usr/local/bin|%{_bindir}|g; s|/usr/local/doc/mutt|%{_docdir}/%{name}-doc|g;' doc/*.man init.h

# Fix lib search patch for bdb
perl -pi -e 'bdblibdir|s|d/lib|d/%{_lib}|g' configure.ac

%build
# needed by nntp patch
autoreconf -fi

%configure \
	--with-docdir=%{_docdir}/%{name}-doc \
	--enable-smtp		\
	--enable-pop		\
	--enable-imap		\
	--enable-nfs-fix	\
	--with-ssl		\
	--enable-compressed	\
	--enable-hcache		\
	--without-gdbm		\
	--with-bdb		\
	--enable-pgp		\
	--enable-smime		\
	--enable-gpgme		\
	--with-idn2		\
%if %{with krb5}
	--with-gss 		\
%else
	--without-gss 		\
%endif
%if %{with sasl2}
	--with-sasl 		\
%else
	--without-sasl	 	\
%endif
%if %{with nntp}
	--enable-nntp		\
%endif
	--enable-sidebar

%make_build

# "make install" installs $builddir/Muttrc into $buildroot
%__make update-doc

%install
%make_install

# get rid of unpackaged files
rm -f %{buildroot}%{_sysconfdir}/mime.types
mv -f %{buildroot}%{_sysconfdir}/mime.types.dist .
mv -f %{buildroot}%{_sysconfdir}/Muttrc.dist .

%find_lang %{name}

%files -f %{name}.lang
%license COPYRIGHT
%doc NEWS OPS* PATCHES*
%doc README* TODO UPDATING VERSION
%doc mime.types.dist Muttrc.dist
%doc contrib/sample.muttrc*
%config(noreplace) %{_sysconfdir}/Muttrc
%{_mandir}/man?/*
%{_bindir}/flea
%{_bindir}/mutt
%{_bindir}/muttbug
%{_bindir}/pgpewrap
%{_bindir}/mutt_pgpring
%{_bindir}/smime_keys
%attr(2755, root, mail) %{_bindir}/mutt_dotlock
%{_infodir}/mutt.info*

%files doc
%doc %{_docdir}/%{name}-doc/
