
Summary:       Official JDBC driver for MySQL
Name:          mysql-connector-java
Epoch:         1
Version:       9.2.0
Release:       %mkrel 1
Group:         Development/Java
License:       GPLv2 with exceptions
URL:           https://dev.mysql.com/downloads/connector/j/
Source0:       %{name}-%{version}-nojars.tar.xz

# Mysql has a mirror redirector for its downloads
# You can get this tarball by following a link from:
# https://dev.mysql.com/get/Downloads/Connector-J/mysql-connector-j-%%{version}.tar.gz
#
# OR
# https://github.com/mysql/mysql-connector-j/archive/%%{version}.tar.gz
# Following prebuilt jars and sources have been removed from the tarball:
#
# %%{name}-%%{version}-bin.jar
# lib/c3p0-0.9.1-pre6.jar
# lib/c3p0-0.9.1-pre6.src.zip
# lib/jboss-common-jdbc-wrapper.jar
# lib/jboss-common-jdbc-wrapper-src.jar
# lib/protobuf-java-3.6.1.jar
# lib/slf4j-api-1.6.1.jar
#
# See https://bugs.mysql.com/bug.php?id=28512 for details.

# To make it easier a script generate-tarball.sh has been created:
# ./generate-tarball.sh version
# will create a new tarball compressed with xz and without those jar files.
Source1:       generate-tarball.sh

Patch1:        remove-coverage-test.patch
Patch2:        java-11-migration.patch
Patch3:        remove-authentication-plugin.patch
Patch4:        remove-StatementsTest.patch
Patch5:        %{name}-remove-opentelemetry-support.patch

BuildArch:     noarch

BuildRequires: ant >= 1.6.0
BuildRequires: ant-junit
BuildRequires: apache-commons-logging
BuildRequires: git
BuildRequires: javassist
BuildRequires: java-devel >= 1:1.6.0
BuildRequires: javapackages-local
BuildRequires: junit5
BuildRequires: protobuf-java
BuildRequires: slf4j
BuildRequires: java-21-openjdk-devel

Requires:      slf4j
Requires:      java

%description
MySQL Connector/J is a native Java driver that converts JDBC (Java Database
Connectivity) calls into the network protocol used by the MySQL database.
It lets developers working with the Java programming language easily build
programs and applets that interact with MySQL and connect all corporate
data, even in a heterogeneous environment. MySQL Connector/J is a Type
IV JDBC driver and has a complete JDBC feature set that supports the
capabilities of MySQL.

%prep
%setup -q -n mysql-connector-j-%{version}

# fix line endings
for file in README README.md; do
 sed -i.orig 's|\r||g' $file
 touch -r $file.orig $file
 rm $file.orig
done

%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

# remove OpenTelemetry support
rm -rf src/main/core-impl/java/com/mysql/cj/otel/OpenTelemetryHandler.java
rm -rf src/main/core-impl/java/com/mysql/cj/otel/OpenTelemetrySpan.java
rm -rf src/main/core-impl/java/com/mysql/cj/otel/OpenTelemetryScope.java

%build

# We need both JDK1.5 (for JDBC3.0; appointed by $JAVA_HOME) and JDK1.6 (for JDBC4.0; appointed in the build.xml)
export CLASSPATH=$(build-classpath jdbc-stdext junit slf4j commons-logging.jar)

# We currently need to disable jboss integration because of missing jboss-common-jdbc-wrapper.jar (built from sources).
# See BZ#480154 and BZ#471915 for details.
rm -rf src/main/user-impl/java/com/mysql/cj/jdbc/integration/jboss
rm src/test/java/testsuite/regression/ConnectionRegressionTest.java
rm src/test/java/testsuite/regression/DataSourceRegressionTest.java
rm src/test/java/testsuite/simple/StatementsTest.java

ant -Dcom.mysql.cj.build.jdk=/usr/lib/jvm/java-21-openjdk \
    -Dcom.mysql.cj.extra.libs=%{_javadir} \
    -Dcom.mysql.cj.build.driver.extendedName=mysql-connector-j \
    -Dcom.mysql.cj.build.driver.version.full=%{version} \
    test build

# Provide alias for old name
%mvn_alias com.mysql:mysql-connector-j mysql:mysql-connector-java

%install
# Install the Maven build information
%mvn_file com.mysql:mysql-connector-j mysql-connector-j
%mvn_artifact build/mysql-connector-j-%{version}/pom.xml build/mysql-connector-j-%{version}/mysql-connector-j-%{version}.jar
%mvn_install

%files -f .mfiles
%doc CHANGES README README.md
%license LICENSE


