%define nsusr nagios
%define nsgrp nagios
%define cmdusr apache
%define cmdgrp apache
%define _disable_ld_no_undefined 1

Summary:    Host/service/network monitoring program
Name:       nagios
Epoch:      1
Version:    4.4.14
Release:    %mkrel 1
License:    GPLv2
Group:      Monitoring
URL:        https://www.nagios.org/
Source0:    https://github.com/NagiosEnterprises/nagioscore/releases/download/nagios-%{version}/nagios-%{version}.tar.gz
Source1:    %{name}.service
Source2:    %{name}.tmpfiles
Source5:    favicon.ico
Patch1:     nagios-4.0.0-conf.d.patch
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper
Requires:   nagios-plugins
Recommends:   nagios-check_http
Recommends:   nagios-check_ssh
Recommends:   nagios-check_ping
Recommends:   nagios-check_disk
Recommends:   nagios-check_load
Recommends:   nagios-check_procs
Recommends:   nagios-check_users
Recommends:   nagios-check_swap
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  libtool-devel
BuildRequires:  multiarch-utils >= 1.0.3
BuildRequires:  perl-devel
Provides:	nagios-agent

%description
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem
arises and when a problem is resolved. Nagios is written in C and
is designed to run under Linux (and some other *NIX variants) as a
background process, intermittently running checks on various
services that you specify.

The actual service checks are performed by separate "plugin"
programs which return the status of the checks to Nagios.

This package provide core programs for nagios. The web interface,
documentation, and development files are built as separate
packages

%package    www
Summary:    Provides the HTML and CGI files for the Nagios web interface
Group:      Networking/WWW
Requires:   %{name} = %{epoch}:%{version}-%{release}
Requires:   nail
Requires:   traceroute
Requires:   php-webinterface
Epoch:      %{epoch}

%description    www
Nagios is a program that will monitor hosts and services on your network. It
has the ability to email or page you when a problem arises and when a problem
is resolved. Nagios is written in C and is designed to run under Linux (and
some other *NIX variants) as a background process, intermittently running
checks on various services that you specify.

Several CGI programs are included with Nagios in order to allow you to view the
current service status, problem history, notification history, and log file via
the web. This package provides the HTML and CGI files for the Nagios web
interface. In addition, HTML documentation is included in this package

%package    devel
Group:      Development/C
Summary:    Provides include files that Nagios-related applications may compile against
Epoch:      %{epoch}

%description    devel
Nagios is a program that will monitor hosts and services on your network. It
has the ability to email or page you when a problem arises and when a problem
is resolved. Nagios is written in C and is designed to run under Linux (and
some other *NIX variants) as a background process, intermittently running
checks on various services that you specify.

This package provides include files that Nagios-related applications may
compile against.

%prep
%setup -q
%autopatch -p1

%build
%serverbuild

export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
export FFLAGS="%{optflags} -fPIC"
%configure \
    --with-httpd-conf=%{_webappconfdir} \
    --with-checkresult-dir=/var/spool/nagios/checkresults \
    --with-temp-dir=/tmp \
    --exec-prefix=%{_sbindir} \
    --bindir=%{_sbindir} \
    --sbindir=%{_libdir}/nagios/cgi \
    --libexecdir=%{_libdir}/nagios/plugins \
    --datadir=%{_datadir}/nagios \
    --sysconfdir=%{_sysconfdir}/nagios \
    --localstatedir=/var/log/nagios \
    --with-lockfile=/run/nagios/nagios.pid \
    --with-mail=/bin/mail \
    --with-nagios-user=%{nsusr} \
    --with-nagios-group=%{nsgrp} \
    --with-command-user=%{cmdusr} \
    --with-command-grp=%{cmdgrp} \
    --with-cgiurl=/nagios/cgi-bin \
    --with-htmurl=/nagios \
    --with-gd-lib=%{_libdir} \
    --with-gd-inc=%{_includedir}

# bug
perl -pi -e "s|/var/log/nagios/spool/checkresults|/var/spool/nagios/checkresults|g" include/locations.h

%make_build all

# contrib/Makefile contains code to build a rpm, which we do not use.
# It checks for supported archs, breaking builds on 32-bit machines -
# not VMs on 64-bit hardware. Remove the check by setting ARCH to one
# of the supported values for all calls to make in contrib/ .
pushd contrib
    make convertcfg ARCH=i686
    make daemonchk.cgi ARCH=i686
popd

%install
make \
    DESTDIR=%{buildroot} \
    BINDIR=%{_sbindir} \
    CFGDIR=%{_sysconfdir}/nagios \
    CGIDIR=%{_libdir}/nagios/cgi \
    COMMAND_OPTS="" \
    HTMLDIR=%{_datadir}/nagios/www \
    INIT_OPTS="" \
    INSTALL=install \
    INSTALL_OPTS="" \
    LOGDIR=/var/log/nagios \
    STRIP=/bin/true \
    install \
    install-devel \
    install-config

pushd contrib
make \
    DESTDIR=%{buildroot} \
    BINDIR=%{_sbindir} \
    CFGDIR=%{_sysconfdir}/nagios \
    CGIDIR=%{_libdir}/nagios/cgi \
    COMMAND_OPTS="" \
    HTMLDIR=%{_datadir}/nagios/www \
    INIT_OPTS="" \
    INSTALL=install \
    INSTALL_OPTS="" \
    LOGDIR=/var/log/nagios \
    ARCH=i686 \
    install
popd

# fix strange perms
find %{buildroot}%{_datadir}/nagios -type d | xargs chmod 755
find %{buildroot}%{_datadir}/nagios -type f | xargs chmod 644
find %{buildroot}%{_sysconfdir}/nagios -type d | xargs chmod 755
find %{buildroot}%{_sysconfdir}/nagios -type f | xargs chmod 644
chmod 755 \
    %{buildroot}%{_libdir}/nagios/cgi/* \
    %{buildroot}%{_sbindir}/*

# fix docs
cp sample-config/README README.sample-config
cp sample-config/template-object/README README.template-object

# install headers
install -d -m 755 %{buildroot}%{_includedir}/nagios
install -m 644 include/locations.h %{buildroot}%{_includedir}/nagios/
%multiarch_includes %{buildroot}%{_includedir}/nagios/locations.h

install -d -m 755 %{buildroot}/var/spool/nagios/checkresults

# add a placeholder directory for all object configuration files
install -d -m 755 %{buildroot}%{_sysconfdir}/nagios/conf.d

# transfert relevant files from sample configuration there
for file in commands contacts timeperiods templates localhost; do
    mv %{buildroot}%{_sysconfdir}/nagios/objects/$file.cfg \
        %{buildroot}%{_sysconfdir}/nagios/conf.d
done

# drop others
rm -rf %{buildroot}%{_sysconfdir}/nagios/objects

# adapt default configuration
perl -pi \
    -e 's|^check_for_updates=1|check_for_updates=0|;' \
    -e 's|^#query_socket=|query_socket=|;' \
    -e 's|=/var/log/nagios/rw|=/var/spool/nagios|;' \
    %{buildroot}%{_sysconfdir}/nagios/nagios.cfg

perl -pi \
    -e 's|^physical_html_path=.*|physical_html_path=%{_datadir}/nagios/www|;' \
    %{buildroot}%{_sysconfdir}/nagios/cgi.cfg

# systemd
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/nagios.service
install -D -m 644 %{SOURCE2} %{buildroot}%{_prefix}/lib/tmpfiles.d/nagios.conf

# apache configuration
install -d -m 755 %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/%{name}.conf <<EOF
# Nagios Apache configuration

ScriptAlias /%{name}/cgi-bin %{_libdir}/%{name}/cgi

<Directory %{_libdir}/%{name}/cgi>
    Options ExecCGI
    Require all granted
</Directory>

Alias /%{name} %{_datadir}/%{name}/www

<Directory %{_datadir}/%{name}>
    Require all granted
</Directory>
EOF

# install and fix event handlers
install -d -m 755 %{buildroot}%{_libdir}/nagios/plugins/eventhandlers
pushd contrib/eventhandlers/
install -m 755 \
    disable_active_service_checks \
    disable_notifications \
    enable_active_service_checks \
    enable_notifications \
    submit_check_result \
    distributed-monitoring/obsessive_svc_handler \
    distributed-monitoring/submit_check_result_via_nsca \
    redundancy-scenario1/handle-master-host-event \
    redundancy-scenario1/handle-master-proc-event \
    %{buildroot}%{_libdir}/nagios/plugins/eventhandlers
popd

find %{buildroot}%{_libdir}/nagios/plugins/eventhandlers -type f | \
    xargs perl -pi \
    -e 's|/usr/local/nagios/var/rw/|/var/spool/nagios/|;' \
    -e 's|/usr/local/nagios/libexec/eventhandlers|%{_libdir}/nagios/plugins/eventhandlers|g;' \
    -e 's|/usr/local/nagios/libexec/send_nsca|%{_libdir}/nagios/plugins/send_nsca|g;' \
    -e 's|/usr/local/nagios/test/var|/var/log/nagios|g;' \
    -e 's|/usr/local/nagios/etc/send_nsca.cfg|%{_sysconfdir}/nagios/send_nsca.cfg|g;' \
    -e 's|printfcmd="/bin/printf"|printfcmd="/usr/bin/printf"|;'

# install the favicon.ico
install -m 644 %{SOURCE5} %{buildroot}%{_datadir}/nagios/www

# rpm filetriggers
%transfiletriggerin -- %{_sysconfdir}/nagios/conf.d
/usr/bin/systemctl reload-or-try-restart nagios.service

%pre
%_pre_useradd %{nsusr} /var/log/nagios /bin/sh
%{_bindir}/gpasswd -a %{cmdusr} %{nsgrp} >/dev/null 2>&1 || :

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{nsusr}

%files
%doc Changelog INSTALLING LEGAL README.md UPGRADING
%doc sample-config/mrtg.cfg
%{_unitdir}/nagios.service
%{_prefix}/lib/tmpfiles.d/nagios.conf
%{_sbindir}/*
%dir %{_sysconfdir}/nagios
%dir %{_sysconfdir}/nagios/conf.d
%config(noreplace) %{_sysconfdir}/nagios/*.cfg
%config(noreplace) %{_sysconfdir}/nagios/conf.d/*.cfg
%attr(-,%{nsusr},%{nsgrp}) %dir /var/log/nagios
%attr(-,%{nsusr},%{nsgrp}) %dir /var/log/nagios/archives
%attr(2775,%{nsusr},%{cmdgrp}) %dir /var/spool/nagios
%attr(-,%{nsusr},%{nsgrp}) %dir /var/spool/nagios/checkresults
%{_libdir}/nagios/plugins/eventhandlers

%files www
%config(noreplace) %{_webappconfdir}/nagios.conf
%{_libdir}/nagios/cgi
%{_datadir}/nagios/www

%files devel
%multiarch %{multiarch_includedir}/nagios/locations.h
%{_includedir}/nagios
%{_libdir}/libnagios.a
