#define git		664e5bd
#define dte		250217
%define rel		2

Name:			nanovna-saver
Version:		0.7.3
Release:		%mkrel %{?git:0.%{dte}.%{git}.}%{rel}
Summary:		Connects to a NanoVNA to display, manipulate and save data
Group:			Communications/Radio
License:		GPLv3
Url:			https://github.com/NanoVNA-Saver/nanovna-saver
Source0:		https://github.com/NanoVNA-Saver/%{name}/archive/v%{version}%{?git:-%{dte}.%{git}}/%{name}-%{version}%{?git:-%{dte}.%{git}}.tar.gz
# Use ./mk-tar <tag> in SOURCES dir to get full sources (github generated tarball will NOT build)
Source1:		mk-tar

BuildRequires:	git
BuildRequires:	libxml2-python3
#BuildRequires:	python3-setuptools-scm
BuildRequires:	pyproject-rpm-macros
BuildRequires:	qtbase6-common-devel

Requires(pre):	shadow-utils

BuildArch:		noarch

%description
A multi-platform tool to save Touchstone files from the NanoVNA. 
Sweep frequency spans in segments to gain more than 101 data points,
and display and analyze the resulting data.

Current features:
*   Reading data from a NanoVNA
*   Splitting a frequency range into multiple segments to increase resolution
    (tried up to >10k points)
*   Zoom into frequency displays to examine details
*   Averaging data for better results particularly at higher frequencies
*   Displaying data on multiple chart types, such as Smith, LogMag, Phase and
    VSWR-charts, for both S11 and S21
*   Displaying markers, and the impedance, VSWR, Q, equivalent
    capacitance/inductance etc. at these locations
*   Displaying customizable frequency bands as reference, for example amateur
    radio bands
*   Exporting and importing 1-port and 2-port Touchstone files
    TDR function (measurement of cable length)
*   Display of both an active and a reference trace
*   Live updates of data from the NanoVNA, including for multi-segment sweeps
*   In-application calibration, including compensation for non-ideal 
    calibration standards
*   Customizable display options, including "dark mode"
*   Exporting images of plotted values

%pre
usermod -G dialout -a $(users|cut -d' ' -f1) ||:

%prep
%autosetup -p1 -n %{name}-%{version}%{?git:-%{dte}.%{git}}

# Fix build with uic and rcc (Mga#34022)
sed -i -e 's/pyside6-uic/uic-qt6", "-g", "python/g' -e 's/pyside6-rcc/rcc-qt6", "-g", "python/g' src/tools/ui_compile.py

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files NanoVNASaver

# Remove unneeded files
rm -rf %{buildroot}%{python3_sitelib}/tools/

# Make binary lower case and use name
mv %{buildroot}%{_bindir}/NanoVNASaver-gui %{buildroot}%{_bindir}/%{name}
rm -f %{buildroot}%{_bindir}/NanoVNASaver

# Remove upstream desktop file with camel names
rm -f %{buildroot}%{_datadir}/applications/NanoVNASaver.desktop

# Fix icon name
mkdir -p %{buildroot}%{_iconsdir}/hicolor/48x48/apps/
install -m 644 NanoVNASaver_48x48.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

# Desktop file
cat>%{name}.desktop<<EOF
[Desktop Entry]
Name=NanoVNA-Saver
GenericName=NanoVNA-Saver
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Science;Engineering;Electronics;
Version=1.0
Comment=Connect to NanoVNA
EOF

desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{name}.desktop

cat > README.urpmi <<EOF
You will need to log out and log back in to your system
after installing NanoVNA-Saver before using it for the
first time.

Then connect your NanoVNA to a USB port and switch it on
before running NanoVNA-Saver from the menu.

Note that you will need to use the 'Connect' button near
the foot of the GUI to connect to your VNA.

NanoVNA-Saver is located under the 'Sciences' section of
the main menu.
EOF

%files -f %{pyproject_files}
%doc README.urpmi
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/48x48/apps/%{name}.png
