%define	lib_name_orig		lib%{name}

%define	lib_major		2
%define	lib_name		%mklibname %{name} %{lib_major}
%define	lib_name_devel		%mklibname %{name} -d
%define	lib_name_static_devel	%mklibname %{name} -s -d

%global __requires_exclude ^perl\\(getopts.pl\\)

Summary:	Network Audio System
Name:		nas
Version:	1.9.5
Release:	%mkrel 6
License:	Public Domain
Group:		System/Servers
URL:		https://radscan.com/nas.html
Source0:	https://sourceforge.net/projects/nas/files/nas/nas-%{version}/%{name}-%{version}.tar.gz
Source1:	nasd.service
Source2:	nasd.sysconfig
Patch0:		nas-1.9.2-asneeded.patch
# Adapt to GCC 14, in upstream after 1.9.5,
# bug #2149230, <https://sourceforge.net/p/nas/bugs/10/>
Patch1:		nas-1.9.5-No-implicit-ints-and-function-declarations.patch
# Respect linker flags when linking shared libraries, in upstream after 1.9.5,
# <https://sourceforge.net/p/nas/bugs/11/>
Patch2:		nas-1.9.5-Pass-extra-linker-flags-to-shared-libraries.patch
# Adapt pointer types to GCC 14, bug #2261396, in upstream after 1.9.5,
# <https://sourceforge.net/p/nas/bugs/12/>
Patch3:		nas-1.9.5-Correct-pointer-types-for-GCC-14.patch
# Adapt to API changes in libXaw-1.0.16, bug #2276343, proposed to an
# upstream, <https://sourceforge.net/p/nas/bugs/14/>
Patch4:		nas-1.9.5-Adapt-to-libXaw-1.0.16.patch
BuildRequires:	autoconf-archive
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	x11-util-cf-files
BuildRequires:	imake
BuildRequires:	systemd
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xau)
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(xt)
BuildRequires:	rman
BuildRequires:	gccmakedep
Requires(post):	systemd
Requires(preun):	systemd
Provides:	nasd

%description
This package contains a network-transparent, client/server audio
system, with a library Key features of the Network Audio System
include:
 - Device-independent audio over the network
 - Lots of audio file and data formats
 - Can store sounds in server for rapid replay
 - Extensive mixing, separating, and manipulation of audio data
 - Simultaneous use of audio devices by multiple applications
 - Use by a growing number of ISVs
 - Small size
 - Free! No obnoxious licensing terms

%description -l	no
Denne pakken inneholder ett netttverkstransparent, klient/server audio
system, med et bibliotek. Nøkkelfinessene til Network Audio Systemm
inkluderer:
 - Enhetsuavhengig lyd over nettverket
 - Masser av audiofiler og dataformater
 - Kan lagre lyder i tjener for kjapp gjenavspilling
 - Utvidet mixing, separering og manipulering av lyddata
 - Samtidig bruk av lydenheter fra flere applikasjoner på en gang
 - Brukt av ett voksende nummer av uavhengige programvareutviklere
 - Liten i størrelse
 - Gratis! Ingen irriterende lisensbetingelser

%package -n	%{lib_name}
Summary:	Libraries needed for nasd
Group:		System/Libraries

%description -n	%{lib_name}
Libraries needed for nasd and other programs linked against nasd.

%package -n	%{lib_name_devel}
Summary:	Development headers and libraries for writing programs using NAS
Group:		Development/C
Requires:	%{lib_name} = %{version}
Provides:	%{lib_name_orig}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{lib_name_devel}
This package allows you to develop your own network audio programs.

%package -n	%{lib_name_static_devel}
Summary:	NAS static library
Group:		Development/C
Requires:	%{lib_name_devel} = %{version}
Provides:	%{lib_name_orig}-static-devel = %{version}-%{release}
Provides:	%{name}-static-devel = %{version}-%{release}
Provides:	%{name}-static

%description -n %{lib_name_static_devel}
NAS static library.

%prep
%autosetup -p1

# fix build on aarch64
cp -af %{_rpmconfigdir}/%{_real_vendor}/config.{guess,sub} config/

%build
autoreconf -i -f config

for cfgdir in %{_libdir} %{_prefix}/lib %{_datadir}; do
  if [[ -f "$cfgdir/X11/config/Imake.tmpl" ]]; then
    CONFIGDIR="$cfgdir/X11/config"
    break
  fi
done
if [[ -z "$CONFIGDIR" ]]; then
  echo "Error: Imake.tmpl not found, the package won't build."
  exit 1
fi
xmkmf
%make_build World CONFIGDIR=$CONFIGDIR \
    WORLDOPTS="-k CDEBUGFLAGS='%{optflags} -D__USE_BSD_SIGNAL' " \
    CXXDEBUGFLAGS="%{optflags} -w" EXTRA_LDOPTIONS="%ldflags" CC="gcc %ldflags -fPIE"

%install
%make_install \
   BINDIR="%{_bindir}" \
   LIBDIR="%{_libdir}/X11" \
   INCROOT="%{_includedir}" \
   USRLIBDIR="%{_libdir}" \
   SHLIBDIR="%{_libdir}" \
   MANPATH="%{_mandir}" \
   DOCDIR="%{_datadir}/X11/doc" \
   install.man

mv %{buildroot}%{_sysconfdir}/nas/nasd.conf{.eg,}
install -d %{buildroot}%{_localstatedir}/lib/nasd
install -m644 %{SOURCE1} -D %{buildroot}%{_unitdir}/nasd.service
install -m644 %{SOURCE2} -D %{buildroot}%{_sysconfdir}/sysconfig/nasd

%pre
%_pre_useradd nasd %{_localstatedir}/lib/nasd /bin/true
usermod -G audio nasd

%post
%_post_service nasd

%triggerpostun -- nas <= 1.9-1
#(peroyvind): be sure to remove old socket belonging to root and restart nasd
#             now that it runs under own user
rm -f /tmp/.sockets/audio*
service nasd condrestart

%preun
%_preun_service nasd

%postun
%_postun_userdel nasd

%files
%doc FAQ HISTORY README RELEASE TODO
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/nasd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/nasd
%{_mandir}/man[15]/*
%dir %attr(-,nasd,nasd) %{_localstatedir}/lib/nasd
%{_bindir}/*
%{_unitdir}/nasd.service

%files -n %{lib_name}
%{_libdir}/lib*.so.%{lib_major}{,.*}
%{_libdir}/X11/AuErrorDB

%files -n %{lib_name_devel}
%{_libdir}/lib*.so
#{_datadir}/X11/doc/*
%{_includedir}/audio/
%{_mandir}/man3/*

%files -n %{lib_name_static_devel}
%{_libdir}/lib*.a
