Name:		navit
Summary:	Car navigation system with routing engine
Version:	0.5.6
Release:	%mkrel 4
Group:		Sciences/Other
License:	GPLv2+
URL:		https://www.navit-project.org/
Source0:	https://github.com/navit-gps/navit/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	https://www.navit-project.org/maps/osm_bbox_11.3,47.9,11.7,48.2.osm.bz2
Patch1:		navit-0.5.3-speech-dispatcher.patch
Patch2:		navit-0.5.4-Findespeak.cmake.patch
Patch3:		navit-0.5.4-static.patch
Patch4:		navit-0.5.4-sample_map.patch
Patch5:		navit-0.5.6-fix-format-not-a-string-literal.patch
Patch6:		navit-gcc14.patch
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(fribidi)
BuildRequires:	pkgconfig(libgarmin)
BuildRequires:	pkgconfig(libgeoclue-2.0)
BuildRequires:	pkgconfig(SDL_image)
BuildRequires:	pkgconfig(SDL_ttf)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(SDL2_image)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(imlib2)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(dbus-glib-1)
BuildRequires:	pkgconfig(gdlib)
BuildRequires:	pkgconfig(speech-dispatcher)
BuildRequires:	pkgconfig(libgps) >= 3.23-1
BuildRequires:	pkgconfig(libprotobuf-c)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Multimedia)
BuildRequires:	pkgconfig(Qt5Positioning)
BuildRequires:	pkgconfig(Qt5Quick)
BuildRequires:	pkgconfig(Qt5Sensors)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	freeimage-devel
BuildRequires:	gettext-devel
BuildRequires:	libespeak-devel
BuildRequires:	nas-devel
BuildRequires:	postgresql-devel
BuildRequires:	cmake
# for P5
BuildRequires:	git-core
BuildRequires:	inkscape
BuildRequires:	rsvg
BuildRequires:	xsltproc
Requires:	fonts-ttf-dejavu
Recommends:	gpsd

%description
Navit is a car navigation system with routing engine. Its modular
design is capable of using vector maps of various formats for routing
and rendering of the displayed map. It's even possible to use multiple
maps at a time.

The GTK+ or SDL user interfaces are designed to work well with touch
screen displays. Points of Interest of various formats are displayed
on the map.

The current vehicle position is either read from gpsd or directly from
NMEA GPS sensors.

The routing engine not only calculates an optimal route to your
destination, but also generates directions and even speaks to you.

%package gtk-gui
Summary:	GTK GUI for Navit navigation system
Group:		Sciences/Other
Requires:	%{name} = %{version}-%{release}

%description gtk-gui
Navit is a car navigation system with routing engine. This package
contains the GTK GUI for Navit. You need to enable this GUI in
/etc/navit/navit.xml or ~/.navit/navit.xml to use it.

%package graphics-sdl
Summary:	SDL graphics renderer for Navit navigation system
Group:		Sciences/Other
Requires:	%{name} = %{version}-%{release}

%description graphics-sdl
Navit is a car navigation system with routing engine. This package
contains the SDL graphics renderer for Navit. You need to enable
this renderer in /etc/navit/navit.xml or ~/.navit/navit.xml to use it.

%prep
%autosetup -p1

install -m 0644 %{SOURCE1} navit/maps

# make sure that include "debug.h" from navit source is used and not
# a system one like <debug.h>
find . -name '*.c' -o -name "*.cpp" | xargs sed -i 's|#include "debug.h"|#include "../debug.h"|'

%build
%define _disable_ld_no_undefined 1

%cmake \
       %ifarch %{ix86} %{arm}
       -DSAMPLE_MAP=FALSE \
       %endif
       -Dgraphics/gd=FALSE \
       -Dbinding/python=FALSE

install -m 0644 %{SOURCE1} %{_vpath_builddir}/navit/maps

%cmake_build

%install
%cmake_install

# Put the config file in /etc: upstream likes it in /usr to be
# relocatable, but that doesn't concern us. The code does check
# in /etc, so we don't need a patch - AdamW 2009/01
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mv %{buildroot}%{_datadir}/%{name}/%{name}.xml %{buildroot}%{_sysconfdir}/%{name}/%{name}.xml

# Create a README.urpmi - AdamW 2009/01
cat > README.urpmi << EOF
Navit comes with a sample map of Munich, but if you live (or drive!)
anywhere else, you'll need to add another map set. These are not
available as packages because they're rather large and the data changes
on a daily basis, so the packages would have to be refreshed very
often. For instructions on downloading or generating, and installing,
different types of map sets, see these Navit Wiki pages:

http://wiki.navit-project.org/index.php/OpenStreetMaps

http://wiki.navit-project.org/index.php/European_maps

http://wiki.navit-project.org/index.php/Garmin_maps

You should either add the appropriate configuration elements to
/etc/navit/navit.xml, or copy /etc/navit/navit.xml to
~/.navit/navit.xml and edit it there. You may have to remove or comment
out the section for the sample map set, also. Also note that the
default configuration assumes you have a GPS device active, and gpsd
running.
EOF

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS CHANGELOG.md README.md README.urpmi
%{_bindir}/*
%{_libdir}/%{name}/
%{_datadir}/dbus-1/services/org.navit_project.navit.service
%exclude %{_libdir}/%{name}/graphics/libgraphics_sdl*
%exclude %{_libdir}/%{name}/gui/libgui_gtk*
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/%{name}/
%{_mandir}/man1/*
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.xml

%files gtk-gui
%{_libdir}/%{name}/gui/libgui_gtk*

%files graphics-sdl
%{_libdir}/%{name}/graphics/libgraphics_sdl*
