%global major      6
%define libname    %mklibname ndctl %major
%define devname    %mklibname ndctl -d

%global daxmajor   1
%define libdaxname %mklibname daxctl %daxmajor
%define devdaxname %mklibname daxctl -d

%global cxlmajor   1
%define libcxlname %mklibname cxl %cxlmajor
%define devcxlname %mklibname cxl -d

Name:		ndctl
Version:	80
Release:	%mkrel 1
Summary:	Manage "libnvdimm" subsystem devices (Non-volatile Memory)
License:	GPLv2
Group:		System/Libraries
Url:		https://github.com/pmem/ndctl
Source0:	https://github.com/pmem/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:		cxl-json-Fix-tracefs-include.patch

BuildRequires:	autoconf
BuildRequires:	ruby-asciidoctor
BuildRequires:	xmlto
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	pkgconfig(iniparser)
BuildRequires:	pkgconfig(libkmod)
BuildRequires:	pkgconfig(libudev)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(json-c)
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(libtraceevent)
BuildRequires:	pkgconfig(libtracefs)
BuildRequires:	keyutils-devel
BuildRequires:	meson

%description
Utility library for managing the "libnvdimm" subsystem.  The "libnvdimm"
subsystem defines a kernel device model and control message interface for
platform NVDIMM resources like those defined by the ACPI 6+ NFIT (NVDIMM
Firmware Interface Table).


%package -n %devname
Summary:	Development files for libndctl
License:	LGPLv2
Group:		Development/C
Requires:	%libname%{?_isa} = %{version}-%{release}
Provides:	ndctl-devel = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n daxctl
Summary:	Manage Device-DAX instances
License:	GPLv2
Group:		System/Libraries
Requires:	%libdaxname%{?_isa} = %{version}-%{release}

%description -n daxctl
The daxctl utility provides enumeration and provisioning commands for
the Linux kernel Device-DAX facility. This facility enables DAX mappings
of performance / feature differentiated memory without need of a
filesystem.

%package -n cxl-cli
Summary:	Manage CXL devices
License:	GPL-2.0-only

%description -n cxl-cli
The cxl utility provides enumeration and provisioning commands for
the Linux kernel CXL devices.

%package -n %devdaxname
Summary:	Development files for libdaxctl
License:	LGPLv2
Group:		Development/C
Requires:	%libdaxname%{?_isa} = %{version}-%{release}
Provides:	daxctl-devel = %{version}-%{release}

%description -n %devdaxname
The %devdaxname package contains libraries and header files for
developing applications that use libdaxctl, a library for enumerating
"Device DAX" devices.  Device DAX is a facility for establishing DAX
mappings of performance / feature-differentiated memory.

%package -n %devcxlname
Summary:	Development files for libcxl
License:	LGPLv2
Group:		Development/C
Requires:	%libcxlname%{?_isa} = %{version}-%{release}
Provides:	cxl-devel = %{version}-%{release}

%description -n %devcxlname
The %devcxlname package contains libraries and header files for
developing applications that use libcxl, a library for enumerating
and communicating with CXL devices


%package -n %libname
Summary:	Management library for "libnvdimm" subsystem devices (Non-volatile Memory)
License:	LGPLv2
Group:		System/Libraries
Requires:	%libdaxname%{?_isa} = %{version}-%{release}


%description -n %libname
Libraries for %{name}.

%package -n %libdaxname
Summary:	Management library for "Device DAX" devices
License:	LGPLv2
Group:		System/Libraries

%description -n %libdaxname
Device DAX is a facility for establishing DAX mappings of performance /
feature-differentiated memory. %libdaxname provides an enumeration /
control API for these devices.

%package -n %libcxlname
Summary:	Management library for "Compute Express Link" devices
License:	LGPL-2.1-only AND CC0-1.0 AND MIT
Group:		System/Libraries

%description -n %libcxlname
libcxl is a library for enumerating and communicating with CXL devices.


%prep
%autosetup -p1

%build
%meson -Dversion-tag=%{version}
%meson_build

%install
%meson_install

%check
%meson_test



%define bashcompdir %(pkg-config --variable=completionsdir bash-completion)

%files
%license LICENSES/preferred/GPL-2.0 LICENSES/other/MIT LICENSES/other/CC0-1.0
%doc README.md CONTRIBUTING.md
%config(noreplace) %{_sysconfdir}/ndctl.conf.d/monitor.conf
%config(noreplace) %{_sysconfdir}/ndctl.conf.d/ndctl.conf
%{_bindir}/ndctl
%{_mandir}/man1/ndctl*
%{bashcompdir}/ndctl
%{_unitdir}/ndctl-monitor.service
%{_sysconfdir}/ndctl/keys/keys.readme
%{_sysconfdir}/modprobe.d/nvdimm-security.conf

%files -n daxctl
%license LICENSES/preferred/GPL-2.0 LICENSES/other/MIT LICENSES/other/CC0-1.0
%doc README.md CONTRIBUTING.md
%config(noreplace) %{_sysconfdir}/daxctl.conf.d/daxctl.example.conf
%{_bindir}/daxctl
%{_mandir}/man1/daxctl*
%{_datadir}/daxctl/daxctl.conf
%{bashcompdir}/daxctl
%{_unitdir}/daxdev-reconfigure@.service
%{_udevrulesdir}/90-daxctl-device.rules

%files -n cxl-cli
%license LICENSES/preferred/GPL-2.0 LICENSES/other/MIT LICENSES/other/CC0-1.0
%doc README.md CONTRIBUTING.md
%{_bindir}/cxl
%{_mandir}/man1/cxl*
%{_unitdir}/cxl-monitor.service
%{bashcompdir}/cxl

%files -n %libname
%license LICENSES/preferred/LGPL-2.1 LICENSES/other/MIT LICENSES/other/CC0-1.0
%doc README.md CONTRIBUTING.md
%{_libdir}/libndctl.so.%{major}{,.*}

%files -n %libdaxname
%license LICENSES/preferred/LGPL-2.1 LICENSES/other/MIT LICENSES/other/CC0-1.0
%doc README.md CONTRIBUTING.md
%{_libdir}/libdaxctl.so.%{daxmajor}{,.*}

%files -n %libcxlname
%license LICENSES/preferred/LGPL-2.1 LICENSES/other/MIT LICENSES/other/CC0-1.0
%doc README.md CONTRIBUTING.md
%{_libdir}/libcxl.so.%{cxlmajor}{,.*}

%files -n %devname
%license LICENSES/preferred/LGPL-2.1
%{_includedir}/ndctl/
%{_libdir}/libndctl.so
%{_libdir}/pkgconfig/libndctl.pc

%files -n %devdaxname
%license LICENSES/preferred/LGPL-2.1
%{_includedir}/daxctl/
%{_libdir}/libdaxctl.so
%{_libdir}/pkgconfig/libdaxctl.pc

%files -n %devcxlname
%license LICENSES/preferred/LGPL-2.1
%{_includedir}/cxl/
%{_libdir}/libcxl.so
%{_libdir}/pkgconfig/libcxl.pc
%{_mandir}/man3/cxl*.3*
%{_mandir}/man3/libcxl*.3*
