%define srcname    %{name}-c
%define major_c    19
%define libname    %mklibname %{name} %{major_c}
%define pluginname %mklibname %{name}-plugins
%define develname  %mklibname %{name} -d

Summary:	Libraries to use the Unidata network Common Data Form (netCDF)
Name:		netcdf
Version:	4.9.2
Release:	%mkrel 3
Group:		Development/C
License:	BSD
URL:		https://www.unidata.ucar.edu/software/netcdf/
Source0:	https://github.com/Unidata/netcdf-c/archive/v%{version}/%{srcname}-%{version}.tar.gz
# Fix plugins - https://github.com/Unidata/netcdf-c/pull/2431
#Patch0:         netcdf-plugin.patch
Patch1:         netcdf-4.9.2-soname.patch
#https://github.com/Unidata/netcdf-c/issues/2849
Patch2:         netcdf-4.9.2-types.patch

Requires(post): info-install
Requires(postun): info-install
BuildRequires:	hdf5-devel
BuildRequires:	pkgconfig(blosc)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libzip)
BuildRequires:	pkgconfig(zlib)
BuildRequires:  pkgconfig(libbsd)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:	valgrind
BuildRequires:	texinfo
BuildRequires:	tetex-latex
BuildRequires:	groff

%description
NetCDF (network Common Data Form) is an interface for array-oriented data
access and a freely-distributed collection of software libraries for C,
Fortran, C++, and perl that provides an implementation of the interface.
The netCDF library also defines a machine-independent format for representing
scientific data. Together, the interface, library, and format support the
creation, access, and sharing of scientific data. The netCDF software was
developed at the Unidata Program Center in Boulder, Colorado.

NetCDF data is:

   o Self-Describing. A netCDF file includes information about the data it
     contains.

   o Network-transparent. A netCDF file is represented in a form that can be
     accessed by computers with different ways of storing integers, characters,
     and floating-point numbers.

   o Direct-access. A small subset of a large dataset may be accessed
     efficiently, without first reading through all the preceding data.

   o Appendable. Data can be appended to a netCDF dataset along one dimension
     without copying the dataset or redefining its structure. The structure of
     a netCDF dataset can be changed, though this sometimes causes the dataset
     to be copied.

   o Shareable. One writer and multiple readers may simultaneously access the
     same netCDF file.

%package -n	%{libname}
Summary:	C libraries for netcdf-4
Group:		System/Libraries
Provides:	lib%{name} = %{version}-%{release}
Requires:	%{pluginname} = %{version}-%{release}
Requires:	hdf5 = %{_hdf5_version}

%description -n	%{libname}
This package contains the netCDF-4 C libraries.

%package -n     %{pluginname}
Summary:        netcdf-4 HDF5 plugins
Group:          System/Libraries
Provides:       lib%{name}-plugins = %{version}

%description -n %{pluginname}
This package contains the netCDF-4 HDF5 plugins.

%package -n	%{develname}
Summary:	Development files for netcdf-4
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 4.0
Conflicts:	%{name} < 4.1
Conflicts:	%{mklibname %{name} 7}

%description -n %{develname}
This package contains the netCDF-4 header files, shared devel libs, and
man pages.

%prep
%autosetup -p1 -n %{srcname}-%{version}

%build
autoreconf -fi
%configure --enable-shared --disable-static \
		--enable-dap \
		--with-plugin-dir=%{_libdir}/hdf5/plugin \
		--disable-dap-remote-tests


#parallel make was buggy
#{__make} #{_make_output_sync}

%make_build

%install
%make_install

%check
#(eatdirt) one test fails on i586, let's skip it (TOFIX)
#(4.9.2), that test fails on x86_64 now. Let's disable the tests from now.
#ifnarch %{ix86}
#make check || ( cat */test-suite.log && exit 1 )
#endif

%files
%doc COPYRIGHT README.md RELEASE_NOTES.md
%{_bindir}/ncgen
%{_bindir}/ncgen3
%{_bindir}/ncdump
%{_bindir}/nccopy
%{_bindir}/nc4print
%{_bindir}/ocprint
%{_mandir}/man1/*.1*


%files -n %{libname}
%{_libdir}/libnetcdf.so.%{major_c}{,.*}

%files -n %{pluginname}
%{_libdir}/hdf5/plugin/lib__nc*.so

%files -n %{develname}
%{_bindir}/nc-config
%{_includedir}/*.h
%{_libdir}/*.so
%{_mandir}/man3/*.3*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libnetcdf.settings
