%global nhgamedir /usr/games/nethack
%global nhdatadir /var/games/nethack

%global fontfamily nethack-bitmap
%global fonts *.pcf
%global _myfontname nethack-bitmap
%global _fontdir %{_datadir}/fonts/nethack-bitmap-fonts

Name:           nethack
Version:        3.6.7
Release:        %mkrel 1
Summary:        A rogue-like single player dungeon exploration game

Group:          Games/Adventure
License:        NGPL
URL:            https://nethack.org
Source0:        https://nethack.org/download/%{version}/%{name}-367-src.tgz
Source1:        %{name}.desktop
Patch0:         %{name}-3.6.2-makefile.patch
Patch1:         %{name}-3.6.2-config.patch
Patch2:         Makefile.top.patch
Patch3:         %{name}-3.6.6-guidebook.patch
Requires:       %{_myfontname}-fonts-core

BuildRequires:  bdftopcf
BuildRequires:  bison
BuildRequires:  desktop-file-utils
BuildRequires:  flex
BuildRequires:  fontpackages-devel
BuildRequires:  gcc
BuildRequires:  mkfontdir
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)


%description
NetHack is a single player dungeon exploration game that runs on a
wide variety of computer systems, with a variety of graphical and text
interfaces all using the same game engine.

Unlike many other Dungeons & Dragons-inspired games, the emphasis in
NetHack is on discovering the detail of the dungeon and not simply
killing everything in sight - in fact, killing everything in sight is
a good way to die quickly.

Each game presents a different landscape - the random number generator
provides an essentially unlimited number of variations of the dungeon
and its denizens to be discovered by the player in one of a number of
characters: you can pick your race, your role, and your gender.


%package -n %{_myfontname}-fonts
Summary:        Bitmap fonts for Nethack
Group:          System/Fonts/X11 bitmap
BuildArch:      noarch
Requires:       fontpackages-filesystem

%description -n %{_myfontname}-fonts
Bitmap fonts for Nethack.

%package -n %{_myfontname}-fonts-core
Summary:         X11 core fonts configuration for %{name}
Group:          System/Fonts/X11 bitmap
BuildArch:      noarch
Requires:        %{_myfontname}-fonts
Requires(post):  %{_myfontname}-fonts
Requires(post):  coreutils
Requires(post):  mkfontdir
Requires(preun): coreutils


%description -n %{_myfontname}-fonts-core
X11 core fonts configuration for %{_myfontname}.


%prep
%autosetup -p0 -n NetHack-%{version}

sed -i -e "s:PREFIX=\$(wildcard ~)/nh/install:PREFIX=/usr:" sys/unix/hints/linux
sed -i -e "s:^\(HACKDIR=\).*:\1%{nhgamedir}:" sys/unix/hints/linux
sh sys/unix/setup.sh sys/unix/hints/linux

# Set our paths
sed -i -e "s:^\(HACKDIR=\).*:\1%{nhgamedir}:" sys/unix/nethack.sh
sed -i -e "s:FEDORA_CONFDIR:%{nhgamedir}:" sys/unix/nethack.sh
sed -i -e "s:FEDORA_STATEDIR:%{nhdatadir}:" include/unixconf.h
sed -i -e "s:FEDORA_HACKDIR:%{nhgamedir}:" include/config.h
sed -i -e "s:/usr/games/lib/nethackdir:%{nhgamedir}:" \
        doc/nethack.6 doc/nethack.txt doc/recover.6 doc/recover.txt

# Point the linker in the right direction
sed -i -e "s:-L/usr/X11R6/lib:-L/usr/X11R6/%{_lib}:" \
        src/Makefile util/Makefile

%build
make all

%install
%make_install \
        PREFIX=%{buildroot} \
        HACKDIR=%{buildroot}%{nhgamedir} \
        GAMEDIR=%{buildroot}%{nhgamedir} \
        VARDIR=%{buildroot}%{nhdatadir} \
        SHELLDIR=%{buildroot}%{_bindir} \
        CHOWN=/bin/true \
        CHGRP=/bin/true

install -d -m 0755 %{buildroot}%{_mandir}/man6
make -C doc MANDIR=%{buildroot}%{_mandir}/man6 manpages

install -D -p -m 0644 win/X11/nh_icon.xpm \
        %{buildroot}%{_datadir}/pixmaps/nethack.xpm

desktop-file-install \
        --dir %{buildroot}%{_datadir}/applications \
        %{SOURCE1}

# Install the fonts for the X11 interface
cd win/X11
bdftopcf -o nh10.pcf nh10.bdf
bdftopcf -o ibm.pcf ibm.bdf
%fontinstall

# install -m 0755 -d $RPM_BUILD_ROOT%%{_fontdir}
# install -m 0644 -p *.pcf $RPM_BUILD_ROOT%%{_fontdir}

sed -i -e 's:^!\(NetHack.tile_file.*\):\1:' \
        %{buildroot}%{nhgamedir}/NetHack.ad

%post -n %{_myfontname}-fonts-core
if [ -L /etc/X11/fontpath.d/nethack ] ; then
    rm /etc/X11/fontpath.d/nethack
fi
mkfontdir %{_fontdir}
if [ ! -L /etc/X11/fontpath.d/nethack ] ; then
    ln -s %{_fontdir} /etc/X11/fontpath.d/nethack
fi

%preun -n %{_myfontname}-fonts-core
if [ $1 -eq 0 ] ; then
    rm /etc/X11/fontpath.d/nethack
    rm %{_fontdir}/fonts.dir
fi;


%files
%doc doc/*.txt README dat/license dat/history
%doc dat/opthelp dat/wizhelp
%{_mandir}/man6/*.6*
%{_datadir}/pixmaps/nethack.xpm
%{_datadir}/applications/nethack.desktop
%{_bindir}/nethack
# %%{nhgamedir}
%defattr(0664,root,games)
%config(noreplace) %{nhdatadir}/record
%config(noreplace) %{nhdatadir}/perm
%config(noreplace) %{nhdatadir}/logfile
%config(noreplace) %{nhdatadir}/xlogfile
%attr(0775,root,games) %dir %{nhdatadir}
%attr(0775,root,games) %dir %{nhdatadir}/save
%attr(2755,root,games) %{nhgamedir}/nethack
%config(noreplace) %{nhgamedir}/nhdat
%config(noreplace) %{nhgamedir}/sysconf
%config(noreplace) %{nhgamedir}/NetHack.ad
%config(noreplace) %{nhgamedir}/license
%config(noreplace) %{nhgamedir}/pet_mark.xbm
%config(noreplace) %attr(0555,root,games) %{nhgamedir}/recover
%config(noreplace) %{nhgamedir}/rip.xpm
%config(noreplace) %{nhgamedir}/pilemark.xbm
%config(noreplace) %{nhgamedir}/symbols
%config(noreplace) %{nhgamedir}/x11tiles

# %%_font_pkg -n bitmap *.pcf
%fontfiles

%files -n %{_myfontname}-fonts-core

