# (ovitters) disable --no-undefined as per upstream advice
#   https://bugzilla.gnome.org/show_bug.cgi?id=732177#c4
#
#   The problem isn't -Wl,--as-needed, it's -Wl,--no-undefined. You aren't going to
#   be able to build libnm-wwan.la with that flag, because it depends on symbols in
#   the NM binary. (libnm-wwan is a library which is shared between the wwan and bt
#   modules. So it's not actually a module itself, but it's expected that it has
#   unresolved symbols.)
%define _disable_ld_no_undefined 1

# enable/disable vala
%bcond_without vala

# enable/disable docs
%bcond_without docs

# disable ovs for now as we don't have openvswitch
%bcond_with ovs

# Install and use firewalld zone for shared mode
%bcond_with firewalld_zone

# _without = gnutls, _with = nss
%bcond_without crypto_gnutls

%global ppp_ver	%(rpm -q --queryformat "%{VERSION}" ppp)

%define major_nm		0
%define libnm			%mklibname nm %{major_nm}
%define libnm_devel		%mklibname -d nm

%define gimajor_nmclient	1.0
%define nmclient_gi		%mklibname nmclient-gir %{gimajor_nmclient}

%define gimajor_nm              1.0
%define nm_gi			%mklibname nm-gir %{gimajor_nm}

%define	rname		NetworkManager

# meson option -Ddist_version defines where plugins are installed:
# -Ddist_version=%%{version}-%{release} --> %%{_libdir}/%%{rname}/%%{version}-%%{release}
# -Ddist_version=%%{version} --> %%{_libdir}/%%{rname}/%%{version}
%define nmplugindir	%{_libdir}/%{rname}/%{version}

Name:		networkmanager
Summary:	Network management daemon
Version:	1.52.0
Release:	%mkrel 1
Group:		System/Base
License:	GPLv2+
URL:		https://wiki.gnome.org/Projects/NetworkManager
Source0:	https://gitlab.freedesktop.org/NetworkManager/NetworkManager/-/releases/%{version}/downloads/NetworkManager-%{version}.tar.xz
Source1:	README.urpmi
Source3:	nm-poke-nscd
# Upstream patches
#
# Mageia patches
# (blino) read WIRELESS_ESSID, but kept ESSID as fallback
Patch201:	NetworkManager-1.30.2-mga-wireless_essid.patch

BuildRequires:	meson
BuildRequires:	pkgconfig(audit)
BuildRequires:	pkgconfig(libpsl)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libnl-3.0)
BuildRequires:	wpa_supplicant
BuildRequires:	libiw-devel
BuildRequires:	pkgconfig(dbus-glib-1)

# looks like both crypto backends are always built
# https://gitlab.freedesktop.org/NetworkManager/NetworkManager/-/commit/243051a8a62a01dc34a89cf9b3ea4d3ad961805b
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(nss)

BuildRequires:	intltool
BuildRequires:	gtk-doc
BuildRequires:	pkgconfig(ext2fs)
BuildRequires:	ppp-devel
BuildRequires:	polkit-1-devel
BuildRequires:	pkgconfig(libndp)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(gudev-1.0)
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(readline)
#BuildRequires:	dhcp-client
BuildRequires:	iptables
BuildRequires:	pkgconfig(gobject-introspection-1.0) >= 0.10.3
BuildRequires:	python3-gobject3
# (bor) for systemd support, pkg-config; move to systemd?
BuildRequires:	systemd-units
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(mm-glib)
BuildRequires:	pkgconfig(mobile-broadband-provider-info)
%if %{with vala}
BuildRequires:	pkgconfig(vapigen)
%endif
# connection check:
BuildRequires:	pkgconfig(libcurl) >= 7.24.0
# Bluez5 DUN support:
BuildRequires:	pkgconfig(bluez) >= 5
# For nmtui
BuildRequires:	pkgconfig(libnewt) >= 0.52.15
# libteam
BuildRequires:	pkgconfig(libteamdctl) >= 1.9
# dnsmasq
BuildRequires:	dnsmasq
Requires:	networkmanager-wifi
Recommends:	networkmanager-wwan
Recommends:	networkmanager-team
Recommends:	networkmanager-adsl
Recommends:	networkmanager-bluetooth
Recommends:	networkmanager-ppp
Recommends:	networkmanager-l2tp
Recommends:	networkmanager-openconnect
Recommends:	networkmanager-libreswan
Recommends:	networkmanager-openvpn
Recommends:	networkmanager-pptp
Recommends:	networkmanager-vpnc
Recommends:	networkmanager-tui
Provides:	NetworkManager = %{version}-%{release}
Requires(post):		rpm-helper >= 0.24.8-1
Requires(preun):	rpm-helper >= 0.24.8-1
# drop old cnetworkmanager (nmcli does the same and perhaps even more)
Obsoletes:	cnetworkmanager < 0.21.1-10

%description
NetworkManager is a system service that manages network interfaces and
connections based on user or automatic configuration. It supports Ethernet,
Bridge, Bond, VLAN, Team, InfiniBand, Wi-Fi, mobile broadband (WWAN), PPPoE and
other devices, and supports a variety of different VPN services.

%package adsl
Summary:	ADSL device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}

%description adsl
This package contains NetworkManager support for ADSL devices.

%package bluetooth
Summary:	Bluetooth device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-wwan = %{version}-%{release}
Requires:	bluez >= 5

%description bluetooth
This package contains NetworkManager support for Bluetooth devices.

%package team
Summary:	Team device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}

%description team
This package contains NetworkManager support for team devices.

%package wifi
Summary:	Wifi plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	wpa_supplicant
Requires:	wireless-tools

%description wifi
This package contains NetworkManager support for Wifi and OLPC devices.

%package wwan
Summary:	Mobile broadband device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	modemmanager
Requires:	mobile-broadband-provider-info

%description wwan
This package contains NetworkManager support for mobile broadband (WWAN)
devices.

%if %{with ovs}
%package	ovs
Summary:	OpenVSwitch device plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	openvswitch

%description ovs
This package contains NetworkManager support for OpenVSwitch bridges.
%endif

%package ppp
Summary:	PPP plugin for NetworkManager
Group:		System/Base
Requires:	%{name} = %{version}-%{release}
Requires:	ppp = %{ppp_ver}

%description ppp
This package contains NetworkManager support for PPP.

%package	tui
Summary:	Text User Interface for NetworkManager based on curses
Group:		System/Base

%description	tui
This adds a curses-based "TUI" (Text User Interface) to NetworkManager, to
allow performing some of the operations supported by nm-connection-editor and
nm-applet in a non-graphical environment.

%package -n	%{libnm}
Summary:	Shared library for nm
Group:		System/Libraries

%description -n %{libnm}
Shared library for nm.

%package -n	%{libnm_devel}
Summary:	Development files for nm
Group:		Development/C
Provides:	libnm-devel = %{version}-%{release}
Requires:	%{nm_gi} = %{version}-%{release}

%description -n %{libnm_devel}
Development files for nm.

%package -n	%{nm_gi}
Summary:	GObject Introspection interface library for NM
Group:		System/Libraries
Requires:	%{libnm} = %{version}-%{release}

%description -n %{nm_gi}
GObject Introspection interface library for NM.

%prep
%setup -q -n %{rname}-%{version}
%autopatch -p1

%build
%meson \
	-Dsystemdsystemunitdir=%{_unitdir} \
	-Dsystem_ca_path=/etc/pki/tls/certs \
	-Dudev_dir=%{_prefix}/lib/udev/ \
	-Ddbus_conf_dir=%{_datadir}/dbus-1/system.d/ \
	-Dkernel_firmware_dir=/lib/firmware \
	-Druntime_dir=%{_rundir} \
	-Diptables=%{_sbindir}/iptables \
	-Dnft=%{_sbindir}/nft \
	-Ddnsmasq=%{_sbindir}/dnsmasq \
	-Dmodprobe=%{_sbindir}/modprobe \
	\
	\
	-Ddist_version=%{version} \
	-Dsession_tracking_consolekit=false \
	-Dsession_tracking=systemd \
	-Dsuspend_resume=systemd \
	-Dpolkit=true \
	-Dconfig_auth_polkit_default=default \
	-Dmodify_system=true \
	-Dpolkit_agent_helper_1=%{_prefix}/lib/polkit-1/polkit-agent-helper-1 \
	-Dselinux=false \
	-Dsystemd_journal=true \
	-Dconfig_logging_backend_default=journal \
	-Dconfig_wifi_backend_default=wpa_supplicant \
	-Dhostname_persist=default \
	-Dlibaudit=yes-disabled-by-default \
	\
	\
	-Dwext=true \
	-Dwifi=true \
	-Diwd=true \
	-Dppp=true \
	-Dpppd=%{_sbindir}/pppd \
	-Dpppd_plugin_dir=%{_libdir}/pppd/%{ppp_ver} \
	-Dmodem_manager=true \
	\
	-Dofono=false \
	-Dconcheck=true \
	-Dteamdctl=true \
	-Dovs=%{?with_ovs:true}%{!?with_ovs:false} \
	-Dnmcli=true \
	-Dnmtui=true \
	-Dnm_cloud_setup=false \
	-Dbluez5_dun=false \
	-Debpf=false \
	\
	\
	-Dconfig_plugins_default=ifcfg-rh \
	-Difcfg_rh=true \
	-Difupdown=false \
	-Dconfig_migrate_ifcfg_rh_default=false \
	\
	\
	-Dresolvconf=false \
	-Dnetconfig=false \
	-Dconfig_dns_rc_manager_default=auto \
	\
	\
	-Ddhclient=true \
	-Ddhcpcd=true \
	-Dconfig_dhcp_default=internal \
	\
	\
	-Dintrospection=true \
	-Dvapi=%{?with_vala:true}%{!?with_vala:false} \
	-Ddocs=%{?with_docs:true}%{!?with_docs:false} \
	-Dtests=yes \
	-Dfirewalld_zone=%{?with_firewalld_zone:true}%{!?with_firewalld_zone:false} \
	-Dmore_asserts=0 \
	-Dmore_logging=false \
	-Dvalgrind=false \
	-Dvalgrind_suppressions='' \
	-Dld_gc=true \
	-Dlibpsl=true \
	-Dcrypto=%{?with_crypto_gnutls:gnutls}%{!?with_crypto_gnutls:nss} \
	-Dqt=false \
	-Dreadline=libreadline
%meson_build

%install
%meson_install

install -d %{buildroot}%{_libexecdir}
install -m755 %{SOURCE3} %{buildroot}%{_libexecdir}/

install -d %{buildroot}%{_sysconfdir}/%{rname}/conf.d/
cat > %{buildroot}%{_sysconfdir}/%{rname}/%{rname}.conf << EOF
[main]
plugins=ifcfg-rh,keyfile
dhcp=internal
EOF

# Create netprofile module
install -d %{buildroot}%{_sysconfdir}/netprofile/modules/
cat > %{buildroot}%{_sysconfdir}/netprofile/modules/01_networkmanager << EOF
# netprofile module
#
# this module contains settings for saving/restore the NetworkManager configuration
# in different network profiles

NAME="networkmanager"
DESCRIPTION="Networkmanager connection settings"

# list of files to be saved by netprofile
FILES="/etc/NetworkManager/"

# list of services to be restarted by netprofile
SERVICES="networkmanager"
EOF

chmod  755 %{buildroot}%{_sysconfdir}/netprofile/modules/01_networkmanager

# create a VPN directory
install -d %{buildroot}%{_sysconfdir}/%{rname}/VPN

# create keyfile plugin system-settings directory
install -d %{buildroot}%{_sysconfdir}/%{rname}/system-connections

install -d %{buildroot}%{_prefix}/lib/%{rname}/conf.d/
install -d %{buildroot}%{_prefix}/lib/%{rname}/VPN/
install -d %{buildroot}%{_localstatedir}/lib/%{rname}/
touch %{buildroot}%{_localstatedir}/lib/%{rname}/%{rname}-intern.conf

# create dir for dnsmasq configs
install -d %{buildroot}%{_sysconfdir}/%{rname}/dnsmasq.d/
install -d %{buildroot}%{_sysconfdir}/%{rname}/dnsmasq-shared.d/

# Disable touching MAC addresses on devices not supporting it
install -Dpm644 examples/nm-conf.d/31-mac-addr-change.conf \
  %{buildroot}%{_prefix}/lib/%{rname}/conf.d/

# Add readme displayed by urpmi
install -pm644 %{SOURCE1} .

# provide networkmanager daemon via systemd as well
pushd %{buildroot}/%{_unitdir}
ln -s NetworkManager.service %{name}.service
ln -s NetworkManager.service nm.service
popd

%find_lang %{rname}

#post
# (cg) Do not enable NM by default. Doing so means that all configuration done
# via draknetcenter suddenly no longer applies if this package is installed
# on a running system. Likewise, configuration made during install might not
# apply either when booting which is again bad.
# Users can now enable NM in drakxservices and on reboot all interfaces will
# automatically flip over to NM. This behaviour is now deterministic and can
# be documented cleanly rather than the previous mess.
#%_post_service %{name}

%preun
%_preun_service %{name}

%files -f %{rname}.lang
%doc AUTHORS CONTRIBUTING.md ChangeLog NEWS TODO
%doc README.urpmi
%doc %{_docdir}/%{rname}/examples/server.conf
%if %{with docs}
%doc %{_datadir}/gtk-doc/html/%{rname}/
%endif
%{_datadir}/dbus-1/system.d/org.freedesktop.NetworkManager.conf
%{_datadir}/dbus-1/system.d/nm-dispatcher.conf
%{_datadir}/dbus-1/system.d/nm-ifcfg-rh.conf
%{_datadir}/dbus-1/system.d/nm-priv-helper.conf
%dir %{_sysconfdir}/%{rname}/
%config(noreplace) %{_sysconfdir}/%{rname}/NetworkManager.conf
%dir %{_sysconfdir}/%{rname}/conf.d/
%dir %{_sysconfdir}/%{rname}/dispatcher.d/
%dir %{_sysconfdir}/%{rname}/dnsmasq.d/
%dir %{_sysconfdir}/%{rname}/dnsmasq-shared.d/
%dir %{_sysconfdir}/%{rname}/system-connections/
%dir %{_sysconfdir}/%{rname}/VPN/
%{_sysconfdir}/netprofile/modules/01_networkmanager
%{_sbindir}/%{rname}
%{_bindir}/nmcli
%{_bindir}/nm-online
%{_libexecdir}/nm-daemon-helper
%{_libexecdir}/nm-dispatcher
%{_libexecdir}/nm-dhcp-helper
%{_libexecdir}/nm-initrd-generator
%{_libexecdir}/nm-poke-nscd
%{_libexecdir}/nm-priv-helper
%{_libexecdir}/nm-ifdown
%{_libexecdir}/nm-ifup
%if %{with docs}
%{_mandir}/man1/*.1*
%exclude %{_mandir}/man1/nmtui*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man7/*.7*
%{_mandir}/man8/*.8*
%endif
%dir %{nmplugindir}/
%{nmplugindir}/libnm-settings-plugin-ifcfg-rh.so
%dir %{_prefix}/lib/%{rname}/
%dir %{_prefix}/lib/%{rname}/conf.d/
%{_prefix}/lib/%{rname}/conf.d/31-mac-addr-change.conf
%dir %{_prefix}/lib/%{rname}/VPN/
%dir %{_localstatedir}/lib/%{rname}/
%ghost %{_localstatedir}/lib/%{rname}/%{rname}-intern.conf
%{_udevrulesdir}/*.rules
%if %{with firewalld_zone}
%{_prefix}/lib/firewalld/zones/nm-shared.xml
%endif
%{_unitdir}/NetworkManager.service
%{_unitdir}/networkmanager.service
%{_unitdir}/nm.service
%{_unitdir}/nm-priv-helper.service
%{_unitdir}/NetworkManager-wait-online.service
%{_unitdir}/NetworkManager-dispatcher.service
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_dispatcher.service
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_priv_helper.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.NetworkManager.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.NetworkManager.*.xml
%{_datadir}/polkit-1/actions/org.freedesktop.NetworkManager.policy
%{_datadir}/bash-completion/completions/nmcli

%files adsl
%{nmplugindir}/libnm-device-plugin-adsl.so

%files bluetooth
%{nmplugindir}/libnm-device-plugin-bluetooth.so

%files team
%{nmplugindir}/libnm-device-plugin-team.so

%files wifi
%{nmplugindir}/libnm-device-plugin-wifi.so

%files wwan
%{nmplugindir}/libnm-device-plugin-wwan.so
%{nmplugindir}/libnm-wwan.so

%if %{with ovs}
%files ovs
%{nmplugindir}/libnm-device-plugin-ovs.so
%{_prefix}/lib/systemd/system/NetworkManager.service.d/NetworkManager-ovs.conf
%endif

%files ppp
%{_libdir}/pppd/%{ppp_ver}/nm-pppd-plugin.so
%{nmplugindir}/libnm-ppp-plugin.so

%files tui
%{_bindir}/nmtui
%{_bindir}/nmtui-connect
%{_bindir}/nmtui-edit
%{_bindir}/nmtui-hostname
%if %{with docs}
%{_mandir}/man1/nmtui*.1*
%endif

%files -n %{libnm}
%{_libdir}/libnm.so.%{major_nm}{,.*}

%files -n %{nm_gi}
%{_libdir}/girepository-1.0/NM-%{gimajor_nm}.typelib

%files -n %{libnm_devel}
%doc %{_datadir}/gtk-doc/html/libnm/
%dir %{_includedir}/libnm
%{_includedir}/libnm/*.h
%{_libdir}/pkgconfig/libnm.pc
%{_libdir}/libnm.so
%{_datadir}/gir-1.0/NM-1.0.gir
%if %{with vala}
%{_datadir}/vala/vapi/libnm.deps
%{_datadir}/vala/vapi/libnm.vapi
%endif
