%define major_version 24
%define version %{major_version}.0.5
%define rel 3

%define prerel %{nil}
%define name_root nextcloud
%define oname server

%if "%{prerel}" != "%{nil}"
%define lc_prerel %(echo %{prerel} | tr "A-Z" "a-z")
%define release %mkrel 1.%{lc_prerel}.%{rel}
%else
%define release %mkrel %{rel}
%endif

# exclude PHP dependencies as long as their usage is not proven
%define __requires_exclude_from ^%{_datadir}/.*$
%define __jar_repack %{nil}

Summary:      Open personal cloud
Name:         %{name_root}
Version:      %{version}
Release:      %{release}
License:      AGPLv3
Group:        Networking/WWW 
Url:          https://nextcloud.com/
Source0:      https://download.nextcloud.com/server/releases/%name-%{version}%{?prerel}.tar.bz2
Source1:      %{name_root}-httpd.conf
Source2:      %{name_root}-httpd.inc
Source4:      %{name_root}-mysql.txt
Source5:      %{name_root}-postgresql.txt
Source7:      %{name_root}-config.php
Source8:      %{name_root}-fpm.conf
# Systemd timer for background jobs
Source9:       %{name}-systemd-timer.service
Source10:       %{name}-systemd-timer.timer
Requires:     php-webinterface >= 3:8.0.0

# Mageia Patch
Patch0:	      nextcloud-24.0.5-allow-php-8_2.patch

Requires:     php-curl >= 3:8.0.0
Requires:     php-dom  >= 3:8.0.0
Requires:     php-exif >= 3:8.0.0
Requires:     php-fileinfo >= 3:8.0.0
Requires:     php-gd >= 3:8.0.0
Requires:     php-iconv >= 3:8.0.0
Requires:     php-imagick 
Recommends:   php-intl >= 3:8.0.0
Requires:     php-json >= 3:8.0.0
Requires:     php-ldap >= 3:8.0.0
Requires:     php-mbstring >= 3:8.0.0
Requires:     php-openssl >= 3:8.0.0
Requires:     php-pcre >= 3:8.0.0
Recommends:   php-pcntl >= 3:8.0.0
Requires:     php-pdo >= 3:8.0.0
Requires:     php-session >= 3:8.0.0
Requires:     php-simplexml >= 3:8.0.0
Requires:     php-xmlwriter >= 3:8.0.0
Requires:     php-xmlreader
Requires:     php-zip >= 3:8.0.0
Requires:     php-filter >= 3:8.0.0
Requires:     %{name}-database = %{version}-%{release}
Requires:     openssl >= 1.0.2f
Obsoletes:    nextcloud17 <= 18.0.0.0
Obsoletes:    nextcloud18 < %{version}
BuildArch:    noarch

%description
A personal cloud server which runs on you personal server 
and enables accessing your data from everywhere and sharing 
with other people.

%package mysql
Summary:    MySQL database support for NextCloud
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
# From getSupportedDatabases, mysql => pdo, mysql
Requires:   php-pdo_mysql >= 3:8.0.0

%description mysql
This package ensures the necessary dependencies are in place for NextCloud to
work with MySQL / MariaDB databases. It does not require a MySQL / MariaDB
server to be installed, as you may well wish to use a remote database
server.
If you want the database to be on the same system as NextCloud itself, you must
also install and enable a MySQL / MariaDB server package. See README.mysql for
more details.

%package postgresql
Summary:    PostgreSQL database support for NextCloud
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
# From getSupportedDatabases, pgsql => function, pg_connect
Requires:   php-pdo_pgsql >= 3:8.0.0

%description postgresql
This package ensures the necessary dependencies are in place for NextCloud to
work with a PostgreSQL database. It does not require the PostgreSQL server
package to be installed, as you may well wish to use a remote database
server.
If you want the database to be on the same system as NextCloud itself, you must
also install and enable the PostgreSQL server package. See README.postgresql
for more details.

%package sqlite
Summary:    SQLite 3 database support for NextCloud
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
# From getSupportedDatabases, pgsql => class, SQLite3
Requires:   php-pdo_sqlite >= 3:8.0.0
Requires:   php-pcre  >= 3:8.0.0

%description sqlite
This package ensures the necessary dependencies are in place for NextCloud to
work with an SQLite 3 database stored on the local system.

%prep
%setup -q -n %name
%autopatch -p1

cp %{SOURCE4} README.mysql
cp %{SOURCE5} README.postgresql
# drop upstream update notification app
rm -rf apps/updatenotification
# also remove the actual updater
rm -rf updater

%install
install -d -m 755 %{buildroot}%{_datadir}/%{name_root}
# create nextcloud datadir
install -d -m 755 %{buildroot}%{_localstatedir}/lib/%{name_root}/data
# create writable app dir for appstore
install -d -m 755 %{buildroot}%{_localstatedir}/lib/%{name_root}/apps
# create nextcloud sysconfdir
install -d -m 755 %{buildroot}%{_sysconfdir}/%{name_root}

# install content
for d in $(find . -mindepth 1 -maxdepth 1 -type d | grep -v config); do
    cp -a "$d" %{buildroot}%{_datadir}/%{name_root}
done

for f in {*.php,*.html,occ,robots.txt}; do
    install -p -m 644 "$f" %{buildroot}%{_datadir}/%{name_root}
done

# occ should be executable
install -pm 755 occ %{buildroot}%{_datadir}/%{name}

# symlink config dir
ln -sf %{_sysconfdir}/%{name_root} %{buildroot}%{_datadir}/%{name_root}/config

# nextcloud looks for ca-bundle.crt in config dir
ln -sf %{_sysconfdir}/pki/tls/certs/ca-bundle.crt %{buildroot}%{_sysconfdir}/%{name_root}/ca-bundle.crt

# set default config
install -p -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name_root}/config.php

install -D -m 644 %{SOURCE1} %{buildroot}%{webappconfdir}/%{name_root}.conf
install -D -m 644 %{SOURCE2} %{buildroot}%{webappconfdir}/%{name_root}.inc
install -D -m 644 %{SOURCE8} %{buildroot}%{_sysconfdir}/php-fpm.d/%{name_root}.conf

cat > %{buildroot}%{_datadir}/%{name_root}/.htaccess <<EOF
# Version: %{version}
EOF

install -d -m 755 %{buildroot}%{_sysconfdir}/cron.d
cat > %{buildroot}%{_sysconfdir}/cron.d/%{name_root} <<EOF
# Run cron from to execute task even when no user connected
*/15 * * * * apache /usr/bin/php -f /usr/share/nextcloud/cron.php
EOF

# Install the systemd timer
install -Dpm 644 %{SOURCE9} %{buildroot}%{_unitdir}/nextcloud-cron.service
install -Dpm 644 %{SOURCE10} %{buildroot}%{_unitdir}/nextcloud-cron.timer

%pre
# on update from previous release, move data directory from
# %{_localstatedir}/lib/%{name} to %{_localstatedir}/lib/%{name}/data
if [ $1 -gt 1 ] ; then
    if [ -d %{_localstatedir}/lib/%{name_root}/ -a ! -d %{_localstatedir}/lib/%{name_root}/data ]; then
        mv %{_localstatedir}/lib/%{name_root} %{_localstatedir}/lib/%{name_root}.tmp
        mkdir %{_localstatedir}/lib/%{name_root}
        mv %{_localstatedir}/lib/%{name_root}.tmp %{_localstatedir}/lib/%{name_root}/data
    fi
fi

%post
touch '%{_sysconfdir}/%{name}/CAN_INSTALL'
/usr/bin/chown apache:apache '%{_sysconfdir}/%{name}/CAN_INSTALL'

%files
%doc AUTHORS config/config.sample.php

%dir %attr(-,apache,apache) %{_sysconfdir}/%{name_root}
%config(noreplace) %attr(0600,apache,apache) %{_sysconfdir}/%{name_root}/config.php
%{_sysconfdir}/%{name_root}/ca-bundle.crt

%{_datadir}/%{name_root}
%{_unitdir}/nextcloud-cron.service
%{_unitdir}/nextcloud-cron.timer

%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name_root}
%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name_root}/apps
%dir %attr(0750,apache,apache) %{_localstatedir}/lib/%{name_root}/data

%config(noreplace) %{webappconfdir}/nextcloud.conf
%config(noreplace) %{webappconfdir}/nextcloud.inc
%config(noreplace) %{_sysconfdir}/cron.d/%{name_root}
%config(noreplace) %{_sysconfdir}/php-fpm.d/%{name_root}.conf

%files mysql
%doc README.mysql

%files postgresql
%doc README.postgresql

%files sqlite
