%bcond_without	ndiff
%bcond_without	zenmap
%bcond_without	pcre

Summary:	Network exploration tool and security scanner
Name:		nmap
Epoch:		1
Version:	7.95
Release:	%mkrel 5
License:	GPLv2
Group:		Networking/Other
URL:		https://nmap.org/
Source0:	http://download.insecure.org/nmap/dist/%{name}-%{version}.tar.bz2
Source1:	%{name}_icons.tar.bz2
#
Patch1:		0001-Don-t-recompile-Python-bytecode-unnecessarily.patch
Patch9:		0009-Python-use-gpep517.patch
#
BuildRequires:	pkgconfig(libpcap)
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre2-8)
%endif
BuildRequires:	pkgconfig(libssh2)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	lua-devel
%if %{with ndiff}
BuildRequires:	pkgconfig(python3)
%endif
%if ! %{with zenmap}
Obsoletes:	%{name}-frontend < %{epoch}:%{version}-%{release}
%endif
Requires:	%{name}-ncat = %{epoch}:%{version}-%{release}

%description
Nmap is a utility for network exploration or security auditing. It supports
ping scanning (determine which hosts are up), many port scanning techniques
(determine what services the hosts are offering), and TCP/IP fingerprinting
(remote host operating system identification). Nmap also offers flexible target
and port specification, decoy scanning, determination of TCP sequence
predictability characteristics, sunRPC scanning, reverse-identd scanning, and
more.

%package	ncat
Summary:	Nmap's Netcat replacement
Group:		Networking/Other
Obsoletes:	nc < 1.0
Obsoletes:	nc6 < 1.0-29
Provides:	nc = %{epoch}:%{version}-%{release}
Provides:	nc6 = %{epoch}:%{version}-%{release}
Provides:	ncat = %{epoch}:%{version}-%{release}
Requires(post):	 alternatives
Requires(preun): alternatives

# ease upgrade mga9 -> mga10
Conflicts:	nmap < 1:7.95-2

%description	ncat
Ncat is a feature packed networking utility which will read and
write data across a network from the command line.  It uses both
TCP and UDP for communication and is designed to be a reliable
back-end tool to instantly provide network connectivity to other
applications and users. Ncat will not only work with IPv4 and IPv6
but provides the user with a virtually limitless number of potential
uses.

%if %{with zenmap}
%package	frontend
Summary:	Multi-platform graphical Nmap frontend and results viewer
Group:		Networking/Other
Requires:	%{name} = %{epoch}:%{version}-%{release}
Provides:	zenmap = %{epoch}:%{version}-%{release}
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(build)
BuildRequires:	python3dist(setuptools)
Requires:	python3-gi
Requires(post):	desktop-file-utils
Requires(postun): desktop-file-utils

%description	frontend
Zenmap is an Nmap frontend. It is meant to be useful for advanced users and to
make Nmap easy to use by beginners. It was originally derived from Umit, an
Nmap GUI created as part of the Google Summer of Code.
%endif

%prep
%autosetup -p1 -n %{name}-%{version} -a1

rm -rf libpcap libpcre macosx mswin32 libssh2 libz

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure \
    --with-libpcap=yes \
    --with-liblua=included \
    --with-libssh2=yes \
    --enable-dbus \
    %{?!with_zenmap:--without-zenmap} \
    %{?!with_ndiff:--without-ndiff} \
    %{?with_pcre:--with-pcre2}%{?!with_pcre:--without-pcre2} \
    --without-libpcre \
    --without-nmap-update
%make_build

%if %{with zenmap}
pushd zenmap
%pyproject_wheel
popd
%endif

%install
%if %{with zenmap}
pushd zenmap
%pyproject_install
popd
%endif

%make_install nmapdatadir=%{_datadir}/nmap STRIP=/bin/true

# drop bundled certs
rm -rf %{buildroot}%{_datadir}/ncat/ca-bundle.crt
rmdir %{buildroot}%{_datadir}/ncat

rm -f %{buildroot}%{_datadir}/applications/*.desktop

%if %{with zenmap}
# XDG menu
install -d %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}.desktop << EOF
[Desktop Entry]
Name=Nmap
GenericName=GUI Port Scanner
Comment=A frontend for the Nmap Security Scanner
Exec=zenmap %%F
Icon=zenmap
Terminal=false
Type=Application
Categories=System;Monitor;
Keywords=network;scan;scanner;IP;security;
EOF

mkdir -p %{buildroot}%{_iconsdir}/hicolor/256x256/apps
install -m0644 zenmap/zenmapCore/data/pixmaps/zenmap.png %{buildroot}%{_iconsdir}/hicolor/256x256/apps/
%endif

# we provide 'nc' replacement (#1653119)
touch %{buildroot}%{_bindir}/nc
touch %{buildroot}%{_bindir}/netcat
touch %{buildroot}%{_mandir}/man1/nc.1
touch %{buildroot}%{_mandir}/man1/netcat.1

%find_lang %{name} --with-man

# cleanup
rm -f %{buildroot}%{_bindir}/uninstall_*

%triggerprein ncat -- netcat-openbsd < 1.89-14, netcat-traditional < 1.10-45
if [ -f %{_bindir}/nc ]; then
  rm -rf %{_bindir}/nc
fi
if [ -f %{_mandir}/man1/nc.1%{?_extension} ]; then
  rm -rf %{_mandir}/man1/nc.1%{?_extension}
fi

%post ncat
%{_sbindir}/alternatives --install %{_bindir}/nc nc %{_bindir}/ncat 10 \
  --slave %{_bindir}/netcat netcat %{_bindir}/ncat \
  --slave %{_mandir}/man1/nc.1.xz nc-man %{_mandir}/man1/ncat.1.xz \
  --slave %{_mandir}/man1/netcat.1.xz netcat-man %{_mandir}/man1/ncat.1.xz

%preun ncat
if [ $1 -eq 0 ]; then
  %{_sbindir}/alternatives --remove nc %{_bindir}/ncat
fi

%files -f %{name}.lang
%doc HACKING docs/README docs/nmap.usage.txt
%license LICENSE
%{_bindir}/%{name}
%if %{with ndiff}
%{_bindir}/ndiff
%{_mandir}/man1/ndiff.*
%endif
%{_bindir}/nping
%{_datadir}/%{name}/
%{_mandir}/man1/nmap.*
%{_mandir}/man1/nping.*

%files ncat
%license LICENSE
%doc ncat/docs/AUTHORS ncat/docs/README ncat/docs/THANKS ncat/docs/examples
%{_bindir}/ncat
%{_mandir}/man1/ncat.1.*
%ghost %{_bindir}/nc
%ghost %{_bindir}/netcat
%ghost %{_mandir}/man1/nc.1*
%ghost %{_mandir}/man1/netcat.1*

%if %{with zenmap}
%files frontend
%{_bindir}/nmapfe
%{_bindir}/xnmap
%{_bindir}/zenmap
%{python3_sitelib}/*
%{_datadir}/applications/*.desktop
%{_iconsdir}/hicolor/*/apps/zenmap.png
%{_mandir}/man1/zenmap.1*
%endif
