%define		srcdir	ImageLounge
#define		date	20220907

# rel for bumping
%define rel	3

Name:		nomacs
Version:	3.19.0
Release:	%mkrel %{?date:0.git%date.}%{rel}
Summary:	A fast and small image viewer
License:	GPLv3
Group:		Graphics/Viewers
Url:		https://www.nomacs.org/
# From https://github.com/nomacs/nomacs/ - only ImageLounge directory repacked
# Memo: tar Jcvf nomacs-%%{version}.tar.xz nomacs-%%{version}/
Source0:	%{name}-%{version}.tar.xz
Source1:	https://github.com/novomesk/nomacs-plugins/archive/%{version}/%{name}-plugins-%{version}.tar.gz
Patch0:		nomacs-not-update-version.patch
Patch1:		nomacs-quazip-qt6.patch

BuildRequires:	cmake
BuildRequires:	lcov
BuildRequires:	qttools6
BuildRequires:	cmake(QuaZip-Qt6)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6PrintSupport)
BuildRequires:	cmake(Qt6Svg)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(exiv2)
BuildRequires:	pkgconfig(libavif)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(libjxl)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(zlib)

Requires:	qt6-avif-image-plugin
Requires:	qt6-jpegxl-image-plugin
Requires:	qt6-heic-image-plugin

%description
nomacs is an image viewer based on the Qt5 library. It is free, small, fast and
is able to handle the most common image formats including RAW images.

Additionally, synchronization of viewers running on the same computer or via
LAN is possible, which allows one to compare images and spot the differences.

This package also contains some usefull plugins for nomacs image viewer:
 * Affine transformations
 * RGB image from greyscales
 * Fake miniature filter
 * Page extractions
 * Painting

%prep
%autosetup -p1 -a 1

# plug them in
mv nomacs-plugins-%{version}/* plugins/ && rm -rf nomacs-plugins-%{version}
# plugins install path (https://github.com/nomacs/nomacs-plugins/issues/34)
sed -i 's|lib/nomacs-plugins|lib\${LIB_SUFFIX}/nomacs-plugins|' plugins/cmake/Utils.cmake

# fix SVG icon install path
sed -i cmake/UnixBuildTarget.cmake -e 's@share/pixmaps@share/icons/hicolor/scalable/apps@'

%build
%cmake_qt6 \
	-DQT_VERSION_MAJOR=6 \
	-DCMAKE_BUILD_TYPE=Release \
	-DENABLE_QUAZIP=ON \
	-DUSE_SYSTEM_QUAZIP=ON \
	-DENABLE_TRANSLATIONS=ON \
	-DENABLE_PLUGINS=ON

%cmake_build

%install
%cmake_install

# we don't want unneeded devel files
find %{buildroot} -name '*.so' -delete

%files
%doc README.md
%license license/LICENSE.GPLv3
%{_bindir}/%{name}
%{_libdir}/lib%{name}*.so*
%{_datadir}/%{name}/
%{_libdir}/nomacs-plugins/
%{_datadir}/applications/org.%{name}.ImageLounge.desktop
%{_datadir}/metainfo/org.%{name}.ImageLounge.appdata.xml
%{_iconsdir}/hicolor/scalable/*/org.%{name}.ImageLounge.svg
%{_mandir}/man1/%{name}.1.*
