%define real_name nss-mdns

%define major	2
%define libname	%mklibname %{real_name} %{major}

Summary:	Multicast dns support for glibc domain resolver
Name:		nss_mdns
Version:	0.15.1
Release:	%mkrel 2
License:	LGPLv2+
Url:		https://github.com/lathiat/nss-mdns
Source:		https://github.com/lathiat/nss-mdns/releases/download/v%{version}/%{real_name}-%{version}.tar.gz
Group:		System/Libraries
BuildRequires:	pkgconfig(avahi-core)

%description
nss-mdns is a plugin for the Name Service Switch (NSS) functionality of the
glibc providing host name resolution via Multicast DNS (aka Zeroconf, aka
Apple Rendezvous), effectively allowing name resolution by common
Unix/Linux programs in the ad-hoc mDNS domain .local.

nss-mdns provides client functionality only, which means that you have to run
a mDNS responder daemon separately from nss-mdns if you want to register
the local host name via mDNS.

%package data
Summary:	Configuration files for %{name}
Group:		Networking/Other
BuildArch:	noarch
Conflicts:	%{name} < 0.10-11

%description data
This package contains the configuration files for %{name}.

%package -n %{libname}
Summary:	Multicast dns support for glibc domain resolver
Group:		System/Libraries
Obsoletes:	%{name} < 0.10-11
Provides:	%{name} = %{version}-%{release}
Provides:	%{name}-modules = %{version}-%{release}
Requires:	%{name}-data >= %{version}
# for /etc/sysconfig/network
Requires(post):	initscripts

%description -n %{libname}
nss-mdns is a plugin for the Name Service Switch (NSS) functionality of the
glibc providing host name resolution via Multicast DNS (aka Zeroconf, aka
Apple Rendezvous), effectively allowing name resolution by common
Unix/Linux programs in the ad-hoc mDNS domain .local.

nss-mdns provides client functionality only, which means that you have to run
a mDNS responder daemon separately from nss-mdns if you want to register
the local host name via mDNS.

%prep
%setup -q -n %{real_name}-%{version}

%build
# to recognize aarch64
autoreconf -vfi

%configure \
	--enable-avahi
%make_build

%install
%make_install

mkdir -p %{buildroot}/%{_sysconfdir}/
cat > %{buildroot}/%{_sysconfdir}/mdns.allow  <<EOF
# place here the domain that should be resolved by multicast dns
# use * to include all ( not recommended )
.local.
.local
EOF

%post -n %{libname}
if [ $1 = 1 ]; then
   # ipv4 by default, as explained on the webpage
    [ -f /etc/sysconfig/network ] && source /etc/sysconfig/network
    unset hosts
    eval $(grep ^hosts: /etc/nsswitch.conf|sed -e 's/hosts:\(.*\)$/hosts=\"\1\"/')
    if [ "${NETWORKING_IPV6}" = "yes" ]; then
        # for both ipv6 and ipv4
	minimal_nss=mdns_minimal
	dns_nss=mdns
    else
        minimal_nss=mdns4_minimal
	dns_nss=mdns4
    fi
    new_hosts=$minimal_nss

    for i in $hosts; do
        if [ $i != mdns4_minimal ] && [ $i != mdns_minimal ] && [ $i != mdns4 ] && [ $i != mdns ]; then
            if [ -n "$new_hosts" ]; then
                new_hosts="$new_hosts $i"
            else
                new_hosts="$i"
            fi
            if [ $i = dns ] && [ -n "$dns_nss" ]; then
                new_hosts="$new_hosts $dns_nss"
            fi
        fi
    done
    sed -i -e "s/^hosts:.*$/hosts:\t\t$new_hosts/" /etc/nsswitch.conf
fi

%postun -n %{libname}
if [ $1 = 0 ]; then
    unset hosts
    eval $(grep ^hosts: /etc/nsswitch.conf|sed -e 's/hosts:\(.*\)$/hosts=\"\1\"/')

    for i in $hosts; do
        if [ $i != mdns4_minimal ] && [ $i != mdns_minimal ] && [ $i != mdns4 ] && [ $i != mdns ]; then
            if [ -n "$new_hosts" ]; then
                new_hosts="$new_hosts $i"
            else
                new_hosts="$i"
            fi
            if [ $i = dns ] && [ -n "$dns_nss" ]; then
                new_hosts="$new_hosts $dns_nss"
            fi
        fi
    done
    sed -i -e "s/^hosts:.*$/hosts:\t\t$new_hosts/" /etc/nsswitch.conf
fi

%files data
%config(noreplace) %{_sysconfdir}/mdns.allow

%files -n %{libname}
%doc README.md NEWS.md
%{_libdir}/lib%{name}*.so.%{major}
