%define build_external_fuse 0
%define build_external_fuse 1

# flag to allow local users to mount partitions. This is *really* not a good
# idea, because all users who have access to the device can do whatever they
# want with the data, and it also adds a root setuid binary to your system, so
# use it on your own risk. Refer to
# http://www.tuxera.com/community/ntfs-3g-faq/#useroption for details.
%define allow_unsafe_mount 0
%if %allow_unsafe_mount
# user mount only works if ntfs-3g is using internal fuse library
%define build_external_fuse 0
%endif

%define major	89
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:		ntfs-3g
Version:	2022.10.3
Release:	%mkrel 2
Summary:	Read-write ntfs driver
License:	GPLv2+
Group:		System/Base
URL:		https://www.tuxera.com/company/open-source/
Source0:	https://tuxera.com/opensource/%{name}_ntfsprogs-%{version}.tgz

BuildRequires:	pkgconfig(libattr)
BuildRequires:	libgcrypt-devel
BuildRequires:	pkgconfig(gnutls)
BuildRequires:  libuuid-devel
%if %build_external_fuse
BuildRequires:	pkgconfig(fuse) >= 2.8
Requires:	fuse >= 2.8
Requires(pre):	fuse >= 2.8
%else
Requires:	kmod(fuse)
%endif
Obsoletes:	ntfsprogs < 2.0.0-11
Provides:	ntfsprogs = %{version}-%{release}
Recommends:	ntfs-3g-system-compression

Patch0:		ntfs-3g_ntfsprogs-2011.10.9-RC-ntfsck-unsupported-return-0.patch
Patch1:		75dcdc2cf37478fad6c0e3427403d198b554951d.patch

%description
NTFS-3G is a stable, open source, GPL licensed, POSIX, read/write NTFS 
driver for Linux and many other operating systems. It provides safe 
handling of the Windows XP, Windows Server 2003, Windows 2000, Windows 
Vista, Windows Server 2008 and Windows 7 NTFS file systems. NTFS-3G can 
create, remove, rename, move files, directories, hard links, and streams; 
it can read and write normal and transparently compressed files, including 
streams and sparse files; it can handle special files like symbolic links, 
devices, and FIFOs, ACL, extended attributes; moreover it provides full 
file access right and ownership support.

%package	-n %{libname}
Summary:	Library for ntfs-3g
Group:		System/Libraries
Conflicts:	%{name} < 2017.3.23-2

%description	-n %{libname}
This package contains the library needed to run programs dynamically
linked with libntfs-3g.

%package	-n %{develname}
Summary:	Development files and libraries for ntfs-3g
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}ntfs-devel < 2.0.0-11
Obsoletes:	ntfs-3g-devel < 2017.3.23-2

%description	-n %{develname}
Headers and libraries for developing applications that use ntfs-3g
functionality.

%prep
%autosetup -n %{name}_ntfsprogs-%{version} -p1

%build
export CFLAGS="%{optflags} -fPIC"
%configure \
	--disable-static \
	--disable-ldconfig \
%if %build_external_fuse
	--with-fuse=external \
%else
	--with-fuse=internal \
%endif
	--exec-prefix=/ \
	--enable-posix-acls \
	--enable-xattr-mappings \
	--enable-crypto \
	--enable-extras \
	--enable-quarantined

%make_build

%install
sed -i -e 's|/sbin/ldconfig|true|' src/Makefile
%make_install

rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_libdir}/*.a

# make the symlink an actual copy to avoid confusion
rm -rf %{buildroot}/%{_sbindir}/mount.ntfs-3g
cp -a %{buildroot}/%{_bindir}/ntfs-3g %{buildroot}/%{_sbindir}/mount.ntfs-3g

# Actually make some symlinks for simplicity...
# ... since we're obsoleting ntfsprogs-fuse
pushd %{buildroot}/%{_bindir}
ln -s ntfs-3g ntfsmount
popd
pushd %{buildroot}/%{_sbindir}
ln -s mount.ntfs-3g mount.ntfs-fuse
# And since there is no other package in Fedora that provides an ntfs 
# mount...
ln -s mount.ntfs-3g mount.ntfs
# Need this for fsck to find it
ln -s ../bin/ntfsck fsck.ntfs
popd

mv %{buildroot}/sbin/* %{buildroot}/%{_sbindir}
rmdir %{buildroot}/sbin

# We get this on our own, thanks.
rm -rf %{buildroot}%{_defaultdocdir}/%{name}/README


%files
%doc README AUTHORS CREDITS NEWS
%{_bindir}/lowntfs-3g
%{_bindir}/ntfsmount
%{_bindir}/ntfs-3g
%{_bindir}/ntfs-3g.probe
%{_bindir}/ntfscat
%{_bindir}/ntfscluster
%{_bindir}/ntfscmp
%{_bindir}/ntfsfix
%{_bindir}/ntfsinfo
%{_bindir}/ntfsls
%{_bindir}/ntfssecaudit
%{_bindir}/ntfsusermap
# Extras
%{_bindir}/ntfsck
%{_bindir}/ntfsdecrypt
%{_bindir}/ntfsdump_logfile
%{_bindir}/ntfsfallocate
%{_bindir}/ntfsmftalloc
%{_bindir}/ntfsmove
%{_bindir}/ntfsrecover
%{_bindir}/ntfstruncate
%{_bindir}/ntfswipe
%{_sbindir}/fsck.ntfs
%{_sbindir}/mkfs.ntfs
%{_sbindir}/mkntfs
%{_sbindir}/ntfsclone
%{_sbindir}/ntfscp
%{_sbindir}/ntfslabel
%{_sbindir}/ntfsresize
%{_sbindir}/ntfsundelete
%{_mandir}/man8/*
%{_sbindir}/mount.ntfs
%if %allow_unsafe_mount
%attr(4755,root,root) %{_sbindir}/mount.ntfs-3g
%else
%attr(754,root,root) %{_sbindir}/mount.ntfs-3g
%endif
%{_sbindir}/mount.lowntfs-3g
%{_sbindir}/mount.ntfs-fuse

%files -n %{libname}
/%{_libdir}/libntfs-3g.so.%{major}{,.*}

%files -n %{develname}
%doc ChangeLog
/%{_libdir}/libntfs-3g.so
%{_includedir}/ntfs-3g
%{_libdir}/pkgconfig/libntfs-3g.pc
