%define pver p15

# pool.ntp.org vendor zone which will be used in ntp.conf
# use fedora, as long as we don't have a mageia specific one
%define vendorzone fedora

Summary:        Synchronizes system time using the Network Time Protocol (NTP)
Name:           ntp
Version:        4.2.8%{pver}
Release:        %mkrel 4
License:        BSD with attribution
Group:          System/Servers
URL:            https://www.ntp.org/
Source0:        https://www.eecis.udel.edu/~ntp/ntp_spool/ntp4/ntp-4.2/%{name}-%{version}.tar.gz
Source99:       https://www.eecis.udel.edu/~ntp/ntp_spool/ntp4/ntp-4.2/%{name}-%{version}.tar.gz.md5
Source1:        ntp.conf.v2
Source2:        ntp.keys
Source4:        ntpd.sysconfig
Source5:        https://github.com/mlichvar/ntpstat/archive/0.5/ntpstat-0.5.tar.gz
Source6:        ntp.step-tickers
Source7:        ntpdate.wrapper
Source8:        ntp.cryptopw
Source9:        ntpdate.sysconfig
Source10:       ntp.dhclient
Source12:       ntpd.service
Source13:       ntpdate.service
Source14:       ntp-wait.service
Source15:       sntp.service
Source16:       sntp.sysconfig
# https://bugs.ntp.org/show_bug.cgi?id=3741
Patch0:         ntp-4.2.8p15.patch
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  elfutils-devel
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  net-snmp-devel
BuildRequires:  bison
BuildRequires:  pps-tools-devel
# for html2man
BuildRequires:  perl(HTML::Parser)

%description
The Network Time Protocol (NTP) is used to synchronize a computer's time
with another reference time source. This package includes ntpd
(a daemon which continuously adjusts system time) and utilities used
to query and configure the ntpd daemon.

Perl scripts are in the ntp-perl package, ntpdate is in the ntpdate
package and sntp is in the sntp package. The documentation in HTML
format is in the ntp-doc package.


%package perl
Summary:    NTP utilities written in Perl
Group:      System/Servers
Requires:   %{name} = %{version}-%{release}
Obsoletes:  %{name} < 4.2.8p10
BuildArch:  noarch

%description perl
This package contains Perl scripts calc_tickadj, ntp-wait and ntptrace.

%package -n ntpdate
Summary:    Utility to set the date and time via NTP
Group:      System/Servers
Obsoletes:  ntp-client

%description -n ntpdate
ntpdate is a program for retrieving the date and time from
NTP servers.

%package -n sntp
Summary:    Standard Simple Network Time Protocol program
Group:      System/Servers

%description -n sntp
sntp can be used as a SNTP client to query a NTP or SNTP server and either
display the time or set the local system's time (given suitable privilege).
It can be run as an interactive command or in a cron job.

%package doc
Summary:    Complete HTML documentation for ntp
Group:      System/Servers
BuildArch:	noarch

%description doc
This is the original, complete, documentation for NTP, in HTML format.
Manpages documentation comes with the binary package(s).

The Network Time Protocol (NTP) is used to synchronize a computer's time
with another reference time source.  The ntp package contains utilities
and daemons which will synchronize your computer's time to Coordinated
Universal Time (UTC) via the NTP protocol and NTP servers.  Ntp includes
ntpdate (a program for retrieving the date and time from remote machines
via a network) and ntpd (a daemon which continuously adjusts system time).

%prep
%autosetup -a5 -p1

# fix format and encoding of packaged documentation
sed -i 's|\r||g' html/scripts/{footer.txt,style.css}
for f in COPYRIGHT; do
	iconv -f iso8859-1 -t utf8 -o ${f}{_,} && touch -r ${f}{,_} && mv -f ${f}{_,}
done

%build
%serverbuild

sed -i 's|$CFLAGS -Wstrict-overflow|$CFLAGS|' configure sntp/configure
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fno-strict-overflow"
%configure \
    --sysconfdir=%{_sysconfdir}/ntp/crypto \
	--with-locfile=redhat \
	--without-ntpsnmpd \
	--enable-all-clocks \
	--enable-parse-clocks \
	--enable-ntp-signd=%{_localstatedir}/run/ntp_signd \
	--disable-local-libopts

# fix default paths that are not configurable

sed -i 's|/var/db/ntp-kod|%{_localstatedir}/lib/sntp/kod|' \
    sntp/sntp{-opts.c,.1*}
sed -i 's|/etc/ntp/drift|%{_localstatedir}/lib/ntp/drift|' \
	scripts/calc_tickadj/calc_tickadj{,.m*.in}
echo '#define KEYFILE "%{_sysconfdir}/ntp/keys"' >> ntpdate/ntpdate.h
echo '#define NTP_VAR "%{_localstatedir}/log/ntpstats/"' >> config.h

%make_build
%make_build -C ntpstat-0.5

# generate manpages from HTML docs
sed -e 's|@PATH_PERL@|%{_bindir}/perl|' -e 's|@[^@]*_MS@|8|g' \
	< scripts/deprecated/html2man.in \
	> scripts/deprecated/html2man
pushd html
perl ../scripts/deprecated/html2man
# remove adjacent blank lines
sed -i 's/^[\t\ ]*$//;/./,/^$/!d' man/man*/*.[58]
popd 

%install
%make_install bindir=%{_sbindir}
%makeinstall -C ntpstat-0.5

# install missing man pages (generated from HTML)
cp -r html/man/man8/{ntpdate,ntptime,tickadj}* %{buildroot}%{_mandir}/man8

# package only selected documentation
rm -rf %{buildroot}%{_docdir}
install -d -m 755 -p %{buildroot}%{_docdir}/ntp
cp -p COPYRIGHT ChangeLog NEWS %{buildroot}%{_docdir}/ntp

# prepare html documentation
find html | grep -E '\.(html|css|txt|jpg|gif)$' | grep -v '/build/\|sntp' | \
	cpio -pmd %{buildroot}%{_docdir}/ntp
find %{buildroot}%{_docdir}/ntp -type f | xargs chmod 644
find %{buildroot}%{_docdir}/ntp -type d | xargs chmod 755

install -d -m 755 %{buildroot}%{_sysconfdir}
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/ntp.conf
install -d -m 755 %{buildroot}%{_sysconfdir}/ntp
install -p -m 600 %{SOURCE2} %{buildroot}%{_sysconfdir}/ntp/keys
install -p -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/ntp/step-tickers
install -d -m 750 %{buildroot}%{_sysconfdir}/ntp/crypto
install -p -m 600 %{SOURCE8} %{buildroot}%{_sysconfdir}/ntp/crypto/pw

install -d -m 755 %{buildroot}%{_libexecdir}
install -p -m 755 %{SOURCE7} %{buildroot}%{_libexecdir}/ntpdate-wrapper

install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE4}  %{buildroot}%{_sysconfdir}/sysconfig/ntpd
install -m 644 %{SOURCE9}  %{buildroot}%{_sysconfdir}/sysconfig/ntpdate
install -m 644 %{SOURCE16} %{buildroot}%{_sysconfdir}/sysconfig/sntp

sed -i \
    -e 's|VENDORZONE|%{vendorzone}|' \
	-e 's|ETCNTP|%{_sysconfdir}/ntp|' \
	-e 's|VARNTP|%{_localstatedir}/lib/ntp|' \
	%{buildroot}%{_sysconfdir}/ntp.conf
sed -i \
    -e 's|VENDORZONE|%{vendorzone}|'\
    %{buildroot}%{_sysconfdir}/ntp/step-tickers
sed -i \
    -e 's|VENDORZONE|%{vendorzone}|' \
	%{buildroot}%{_sysconfdir}/sysconfig/sntp

install -d -m 755 %{buildroot}%{_sysconfdir}/dhcp/dhclient.d
install -p -m 755 %{SOURCE10} %{buildroot}%{_sysconfdir}/dhcp/dhclient.d/ntp.sh

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE12} %{buildroot}%{_unitdir}/ntpd.service
install -m 644 %{SOURCE13} %{buildroot}%{_unitdir}/ntpdate.service
install -m 644 %{SOURCE14} %{buildroot}%{_unitdir}/ntp-wait.service
install -m 644 %{SOURCE15} %{buildroot}%{_unitdir}/sntp.service

install -d -m 755 %{buildroot}%{_prefix}/lib/systemd/ntp-units.d
echo 'ntpd.service' > %{buildroot}%{_prefix}/lib/systemd/ntp-units.d/60-ntpd.list

install -d -m 755 %{buildroot}%{_localstatedir}/lib/ntp
install -d -m 755 %{buildroot}%{_localstatedir}/lib/sntp
install -d -m 755 %{buildroot}%{_localstatedir}/log/ntpstats
touch %{buildroot}%{_localstatedir}/lib/ntp/drift
touch %{buildroot}%{_localstatedir}/lib/sntp/kod

%pre
%_pre_useradd ntp %{_sysconfdir}/ntp /bin/false

%post
%_post_service ntpd
/bin/touch %{_sysconfdir}/ntp/step-tickers

%preun
%_preun_service ntpd

%postun
%_postun_userdel ntp

%files
%doc COPYRIGHT ChangeLog NEWS
%config(noreplace) %{_sysconfdir}/sysconfig/ntpd
%config(noreplace) %{_sysconfdir}/ntp.conf
%dir %{_sysconfdir}/ntp
%config(noreplace) %{_sysconfdir}/ntp/keys
%dir %attr(-,root,ntp) %{_sysconfdir}/ntp/crypto
%config(noreplace) %{_sysconfdir}/ntp/crypto/pw
%dir %{_sysconfdir}/dhcp/dhclient.d
%{_sysconfdir}/dhcp/dhclient.d/ntp.sh
%dir %attr(-,ntp,ntp) %{_localstatedir}/lib/ntp
%ghost %attr(-,ntp,ntp) %{_localstatedir}/lib/ntp/drift
%dir %attr(-,ntp,ntp) %{_localstatedir}/log/ntpstats
%{_sbindir}/ntp-keygen
%{_sbindir}/ntpd
%{_sbindir}/ntpdc
%{_sbindir}/ntpq
%{_sbindir}/ntptime
%{_sbindir}/tickadj
%{_bindir}/ntpstat
%{_mandir}/man1/ntpstat.1*
%{_mandir}/man5/ntp.conf.5*
%{_mandir}/man5/ntp.keys.5*
%{_mandir}/man8/ntp-keygen.8*
%{_mandir}/man8/ntpd.8*
%{_mandir}/man8/ntpdc.8*
%{_mandir}/man8/ntpq.8*
%{_mandir}/man8/ntptime.8*
%{_mandir}/man8/tickadj.8*
%{_prefix}/lib/systemd/ntp-units.d/*.list
%{_unitdir}/ntpd.service

%files perl
%{_sbindir}/calc_tickadj
%{_sbindir}/ntp-wait
%{_sbindir}/ntptrace
%{_mandir}/man8/calc_tickadj.8*
%{_mandir}/man8/ntp-wait.8*
%{_mandir}/man8/ntptrace.8*
%{_unitdir}/ntp-wait.service
%{_datadir}/ntp

%files -n ntpdate
%doc COPYRIGHT README
%{_sbindir}/ntpdate
%{_libexecdir}/ntpdate-wrapper
%{_mandir}/man8/ntpdate.8*
%{_unitdir}/ntpdate.service
%config(noreplace) %{_sysconfdir}/sysconfig/ntpdate
%config(noreplace) %{_sysconfdir}/ntp/step-tickers

%files -n sntp
%doc sntp/COPYRIGHT
%{_sbindir}/sntp
%{_mandir}/man8/sntp.8*
%dir %{_localstatedir}/lib/sntp
%ghost %{_localstatedir}/lib/sntp/kod
%{_unitdir}/sntp.service
%config(noreplace) %{_sysconfdir}/sysconfig/sntp

%files doc
%{_docdir}/ntp/html
