# Needs waf 2.0 until an upstream fix: https://gitlab.com/NTPsec/ntpsec/-/issues/830
%bcond_with system_waf

%if ! %{with system_waf}
%global __waf %{python3} waf
%define _disable_ld_no_undefined 1
%endif

Name:           ntpsec
Version:        1.2.3
Release:        %mkrel 4
Summary:        NTP daemon and utilities
Group:          System/Servers
License:        MIT and BSD and BSD with advertising and ISC and ASL 2.0
URL:            https://www.ntpsec.org/
Source0:        https://ftp.ntpsec.org/pub/releases/%{name}-%{version}.tar.gz
Source1:        https://ftp.ntpsec.org/pub/releases/%{name}-%{version}.tar.gz.asc
Source2:        https://ftp.ntpsec.org/pub/releases/%{name}.gpg.pub.asc
Source3:        ntp.conf
BuildRequires:  bison
BuildRequires:  gcc
BuildRequires:  gnupg2
BuildRequires:  libbsd-devel
BuildRequires:  libcap-devel
BuildRequires:  m4
BuildRequires:  openssl-devel
BuildRequires:  pps-tools-devel
BuildRequires:  python3-devel
BuildRequires:  python3-gpsd
BuildRequires:  ruby-asciidoctor
BuildRequires:  systemd
BuildRequires:  waf
Requires(pre):  shadow-utils
%{?systemd_requires}
Conflicts:      ntp ntp-perl ntpdate
Obsoletes:      ntp < 4.2.10 ntp-perl < 4.2.10 ntp-doc < 4.2.10 ntpdate < 4.2.10 sntp < 4.2.10

# Set pool.ntp.org vendor zone for default configuration
%if 0%{!?vendorzone:1}
%global vendorzone %(source /etc/os-release && echo ${ID}.)
%endif

# Private library
%global __provides_exclude ^libntpc\\.so.*$
%global __requires_exclude ^libntpc\\.so.*$

%description
NTPsec is a more secure and improved implementation of the Network Time
Protocol derived from the original NTP project.

%prep
%{gpgverify} --keyring=%{SOURCE2} --signature=%{SOURCE1} --data=%{SOURCE0}
%autosetup -p1

# Fix egg info to use a shorter version which will work as an rpm provide
sed -i 's|NTPSEC_VERSION_EXTENDED|NTPSEC_VERSION|' pylib/ntp-in.egg-info

# Modify compiled-in statsdir
sed -i 's|/var/NTP|%{_localstatedir}/log/ntpstats|' \
        docs/includes/ntpd-body.adoc ntpd/ntp_util.c

%build
%waf \
        --enable-debug \
        --disable-doc \
        --refclock=all \
        --pythondir=%{python3_sitelib} \
        --pythonarchdir=%{python3_sitearch} \
        --pyshebang='%{python3} -s'

%waf_build -v

%install
%waf_install

install -p -m755 attic/ntpdate %{buildroot}%{_sbindir}/ntpdate

# Install a log rotate script
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -p -m644 etc/logrotate-config.ntpd \
        %{buildroot}%{_sysconfdir}/logrotate.d/ntpd

# Install the configuration file and sample configuration
for configfile in etc/ntp.d/*; do
     install -Dm 644 $configfile %{buildroot}/$configfile
done

rm -rf %{buildroot}%{_docdir}
# remove .so symlink so no devel() deps are generated
rm -f %{buildroot}%{_libdir}/libntpc.so

sed -e 's|VENDORZONE\.|%{vendorzone}|' \
        -e 's|VARNTP|%{_localstatedir}/lib/ntp|' \
        < %{SOURCE3} > %{buildroot}%{_sysconfdir}/ntp.conf
touch -r %{SOURCE3} %{buildroot}%{_sysconfdir}/ntp.conf

# Move ntpq to sbin for better compatibility with ntp package
mv %{buildroot}%{_bindir}/ntpq %{buildroot}%{_sbindir}/ntpq

mkdir -p %{buildroot}%{_localstatedir}/{lib/ntp,log/ntpstats}
touch %{buildroot}%{_localstatedir}/lib/ntp/ntp.drift

mkdir -p %{buildroot}%{_prefix}/lib/systemd/ntp-units.d
echo 'ntpd.service' > %{buildroot}%{_prefix}/lib/systemd/ntp-units.d/60-ntpd.list

%check
./waf check

%pre
# UID/GID inherited from the ntp package
/usr/sbin/groupadd -g 38 ntp 2> /dev/null || :
/usr/sbin/useradd -u 38 -g 38 -s /sbin/nologin -M -r \
        -d %{_localstatedir}/lib/ntp ntp 2>/dev/null || :

%post
%_post_service ntpd
%_post_service ntp-wait
systemctl daemon-reload 2> /dev/null || :

%preun
%_preun_service ntpd
%_preun_service ntp-wait

%global service_save_file /run/ntp-ntpsec.upgrade.services

%triggerprein -- ntp < 4.2.10
[ $1 = 0 ] || exit 0
# Save enabled ntp services and configuration (before our post)
for s in ntpd ntp-wait; do
        systemctl is-enabled -q "$s".service 2> /dev/null &&
                echo "$s" 2> /dev/null >> %{service_save_file}
done
rm -rf %{_sysconfdir}/ntp.ntpsec
cp -r --preserve=all %{_sysconfdir}/ntp %{_sysconfdir}/ntp.ntpsec 2> /dev/null
:

%triggerpostun -- ntp < 4.2.10
[ $2 = 0 ] || exit 0
# Restore the services and configuration from ntp (after its preun)
for s in ntpd ntp-wait; do
        grep -q "^$s$" %{service_save_file} 2> /dev/null &&
                systemctl enable -q "$s".service 2> /dev/null
done
rm -f %{service_save_file}
mv -f -T --backup=numbered %{_sysconfdir}/ntp.ntpsec %{_sysconfdir}/ntp
# Remove unsupported restrictions
sed -i.bak -E '/^restrict/s/no(e?peer|trap)//g' %{_sysconfdir}/ntp.conf
:

%files
%license LICENSES/*
%doc NEWS.adoc README.adoc
%config(noreplace) %{_sysconfdir}/ntp.conf
%dir %{_sysconfdir}/logrotate.d
%config(noreplace) %{_sysconfdir}/logrotate.d/ntpd
%dir %{_sysconfdir}/ntp.d
%config(noreplace) %{_sysconfdir}/ntp.d/*
%{_bindir}/ntp*
%{_sbindir}/ntp*
%{_libdir}/libntpc.so.*
%{_mandir}/man1/ntp*.1*
%{_mandir}/man5/ntp*.5*
%{_mandir}/man8/ntp*.8*
%{_unitdir}/ntp*.service
%{_unitdir}/ntp*.timer
%{_prefix}/lib/systemd/ntp-units.d/*ntpd.list
%dir %attr(-,ntp,ntp) %{_localstatedir}/lib/ntp
%ghost %attr(644,ntp,ntp) %{_localstatedir}/lib/ntp/ntp.drift
%dir %attr(-,ntp,ntp) %{_localstatedir}/log/ntpstats
%{python3_sitearch}/ntp-*.egg-info
%{python3_sitearch}/ntp
