%define		__jar_repack %nil
%define		minimum_driver_ver 525.60.13
%define		driver_ver 550.54.15
%define		cuda_major 12.4
%define		nsight_compute_ver	2024.1.1
%define		nsight_sys_ver		2023.4.4
%define		samples_ver 12.4
%define		_enable_debug_packages %{nil}
%define		debug_package %{nil}

%define		cuda_toolkit_root_dir	cuda-toolkit-root-dir

# See https://docs.nvidia.com/cuda/cuda-toolkit-release-notes/index.html#cuda-major-component-versions for driver compatibility
# and https://docs.nvidia.com/cuda/archive/12.4.1/cuda-toolkit-release-notes/index.html#cuda-toolkit-major-component-versions for the 12.4.1 driver compatibility
# See https://docs.nvidia.com/cuda/archive/12.4.1/ for online documentation
# See https://docs.nvidia.com/cuda/archive/12.4.1/CUDA_12.4.1_docs.zip for archived documentation

# bcond_with -> don't use jdk8 (enable this, if/when openjdk 1.8.0 will be dropped from distro or when nvvp works with plain system java [jdk11])
# bcond_without -> use jdk8 for nvvp compatibility
%bcond_without	use_jdk8

Summary:	NVIDIA CUDA runtime libraries
Name:		nvidia-cuda-toolkit
Version:	12.4.1
Release:	%mkrel 1
Source0:	https://developer.download.nvidia.com/compute/cuda/%{version}/local_installers/cuda_%{version}_%{driver_ver}_linux.run
Source2:	nvidia
Source10:	nvvp.desktop
Source20:	findegl-fix-mageia.patch
Source21:	findgllib-fix-mageia.patch
Source22:	findgleslib-fix-mageia.patch
Source23:	findvulkan-fix-mageia.patch
Source25:	nvidia-cuda-toolkit-12.4.1-fix-ncu-nsys-path.patch
# these .pc files are derived from the installed version (just extracting the .run file doesn't seem to produce them)
# remember to update when changing the major version.
Source26:	nvidia-cuda-toolkit-pkgconfig-12.4.tar.gz
# cuda samples (https://github.com/NVIDIA/cuda-samples).
# Remember to upgrade the package nvidia-cuda-toolkit-samples-bins when upgrading cuda-samples here or the main package.
Source27:	https://github.com/NVIDIA/cuda-samples/archive/v%{samples_ver}/cuda-samples-%{samples_ver}.tar.gz
License:	Freeware
Group:		Development/Other
Url:		https://www.nvidia.com/cuda/
Recommends:	nvidia >= %{minimum_driver_ver}
BuildRequires:	chrpath
BuildRequires:	imagemagick
BuildRequires:	jpackage-utils
BuildRequires:	lndir
ExclusiveArch:	x86_64

# We don't require installation of the NVIDIA graphics drivers so that 
# folks can do CUDA development on systems without NVIDIA hardware.

# A library, libcudainj.so, was introduced in CUDA 4.1, which depends
# on libcuda.so. It is not needed to compile CUDA programs, though.
# python(abi) auto-require is triggered by runant.py script somewhere
# inside Eclipse plugins used by NVVP.
%global __requires_exclude libcuda.so.1|devel\\(libcuda\\)|devel\\(libcuda\\(64bit\\)\\)|python\\(abi\\)
%global __provides_exclude libcairo.so.2

# Avoid exposing dependecies of bundled libQt libraries and other stuff coming from nvvp and nsight
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^libQt5|^libboost_.*\\.so|^libcrypto|^libicudata|^libicuuc|^libicui18n|^libssl\\.so|^libprotobuf|^libqgif|^libqico|^libqjpeg|libqsvg|libqtga|libqtiff|libqwbmp|libqxcb|^libspawner|^libstdc++|^libudev|^libunixfile|osgi\\(org.apache.*\\)|osgi\\(org.antlr.*\\)|osgi\\(org.mozilla.*\\)|osgi\\(org.w3c.*\\)|osgi\\(org.eclipse.*\\)|osgi\\(com.ibm.*\\)|osgi\\(javaewah\\)|osgi\\(javax.*\\)|osgi\\(com.sat4.*\\)|osgi\\(com.lowagie.*\\)|osgi\\(com.sun.el\\)|osgi\\(com.jcraft.*\\)
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^libQt5|^libboost_.*\\.so|^libcrypto|^libicudata|^libicuuc|^libicui18n|^libssl\\.so|^libprotobuf|^libqgif|^libqico|^libqjpeg|libqsvg|libqtga|libqtiff|libqwbmp|libqxcb|^libspawner|^libstdc++|^libudev|^libunixfile|osgi\\(org.apache.*\\)|osgi\\(org.antlr.*\\)|osgi\\(org.mozilla.*\\)|osgi\\(org.w3c.*\\)|osgi\\(org.eclipse.*\\)|osgi\\(com.ibm.*\\)|osgi\\(javaewah\\)|osgi\\(javax.*\\)|osgi\\(com.sat4.*\\)|osgi\\(com.lowagie.*\\)|osgi\\(com.sun.el\\)|osgi\\(com.jcraft.*\\)

# filter out more system libs (mga#25358)
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^libhyphen|^libjpeg|^libpng12|^libCore\\.so
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^libhyphen|^libjpeg|^libpng12|^libCore\\.so

# filter out libmlx5.so.1, devel(libmlx5(64bit))
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^libmlx5.so.1|devel\\(libmlx5\\(64bit\\)\\)
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^libmlx5.so.1|devel\\(libmlx5\\(64bit\\)\\)

# filter out nsight libs
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^libAppLib\\.so|^libAppLibInterfaces\\.so|^libGL\\.so|^libInterceptorInjectionTarget\\.so|^libNvQtGui\\.so|^libQtPropertyBrowser\\.so|^libnvlog\\.so|^libssh\\.so
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^libAppLib\\.so|^libAppLibInterfaces\\.so|^libGL\\.so|^libInterceptorInjectionTarget\\.so|^libNvQtGui\\.so|^libQtPropertyBrowser\\.so|^libnvlog\\.so|^libssh\\.so
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}^%{_libdir}/nsight-compute-%{nsight_compute_ver}
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}^%{_libdir}/nsight-compute-%{nsight_compute_ver}
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}^%{_libdir}/nsight-systems-%{nsight_sys_ver}
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}^%{_libdir}/nsight-systems-%{nsight_sys_ver}
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}^%{_libdir}/compute-sanitizer|^%{_libdir}/nvrtc-prev|^%{_libdir}/nvvm|^%{_libdir}/nvvm-prev
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}^%{_libdir}/compute-sanitizer|^%{_libdir}/nvrtc-prev|^%{_libdir}/nvvm|^%{_libdir}/nvvm-prev

%description
NVIDIA® CUDA™ is a general purpose parallel computing architecture
that leverages the parallel compute engine in NVIDIA graphics
processing units (GPUs) to solve many complex computational problems
in a fraction of the time required on a CPU. It includes the CUDA
Instruction Set Architecture (ISA) and the parallel compute engine in
the GPU. To program to the CUDA™ architecture, developers can, today,
use C++, one of the most widely used high-level programming languages,
which can then be run at great performance on a CUDA™ enabled
processor. Support for other languages, like FORTRAN, Python or Java,
is available from third parties.

This package contains the libraries and attendant files needed to run
programs that make use of CUDA.

%package devel
Summary:	NVIDIA CUDA Toolkit development files
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
Recommends:	nvidia-devel >= %{minimum_driver_ver}
Recommends:	gcc-c++

%description devel
NVIDIA® CUDA™ is a general purpose parallel computing architecture
that leverages the parallel compute engine in NVIDIA graphics
processing units (GPUs) to solve many complex computational problems
in a fraction of the time required on a CPU. It includes the CUDA
Instruction Set Architecture (ISA) and the parallel compute engine in
the GPU. To program to the CUDA™ architecture, developers can, today,
use C++, one of the most widely used high-level programming languages,
which can then be run at great performance on a CUDA™ enabled
processor. Support for other languages, like FORTRAN, Python or Java,
is available from third parties.

This package contains the development files needed to build programs
that make use of CUDA.

%package samples
Summary:	NVIDIA CUDA Toolkit samples
Recommends:	%{name}-devel = %{version}-%{release}
Requires:	glslang
Requires:	glfw-devel
Requires:	glut-devel
Requires:	mesaglesv2-devel
Requires:	vulkan-devel
Requires:	vulkan-headers
Requires:	x11-server-devel

%description samples
NVIDIA® CUDA™ is a general purpose parallel computing architecture
that leverages the parallel compute engine in NVIDIA graphics
processing units (GPUs) to solve many complex computational problems
in a fraction of the time required on a CPU. It includes the CUDA
Instruction Set Architecture (ISA) and the parallel compute engine in
the GPU. To program to the CUDA™ architecture, developers can, today,
use C++, one of the most widely used high-level programming languages,
which can then be run at great performance on a CUDA™ enabled
processor. Support for other languages, like FORTRAN, Python or Java,
is available from third parties.

This package contains numerous CUDA code samples (formerly CUDA SDK).

%package -n nvidia-visual-profiler
Summary:	NVIDIA Visual Profiler
Group:		Development/Other
%if %{with use_jdk8}
Requires:	java-1.8.0
%else
Requires:	java
%endif
Obsoletes:	nvidia-cuda-profiler < 4.0, nvidia-opencl-profiler < 4.0, nvidia-compute-profiler < 5.0
Recommends:	nvidia-devel >= %{minimum_driver_ver}
Recommends:	%{name} = %{version}-%{release}

# We don't strictly require NVIDIA CUDA Toolkit, because the profiler
# could be used to analyze CSV profile logs obtained elsewhere.

%description -n nvidia-visual-profiler
NVIDIA® CUDA™ is a general purpose parallel computing architecture
that leverages the parallel compute engine in NVIDIA graphics
processing units (GPUs) to solve many complex computational problems
in a fraction of the time required on a CPU. It includes the CUDA
Instruction Set Architecture (ISA) and the parallel compute engine in
the GPU. To program to the CUDA™ architecture, developers can, today,
use C++, one of the most widely used high-level programming languages,
which can then be run at great performance on a CUDA™ enabled
processor. Support for other languages, like FORTRAN, Python or Java,
is available from third parties.

This package contains NVIDIA Visual Profiler for CUDA and OpenCL.

%package -n nvidia-nsight
Summary:	NVIDIA Nsight IDE
Group:		Development/Other
Requires:	java
Recommends:	nvidia-devel >= %{minimum_driver_ver}

# We don't strictly require NVIDIA CUDA Toolkit, because Nsight IDE
# could be used to develop CUDA programs on a remote node.

%description -n nvidia-nsight
NVIDIA® CUDA™ is a general purpose parallel computing architecture
that leverages the parallel compute engine in NVIDIA graphics
processing units (GPUs) to solve many complex computational problems
in a fraction of the time required on a CPU. It includes the CUDA
Instruction Set Architecture (ISA) and the parallel compute engine in
the GPU. To program to the CUDA™ architecture, developers can, today,
use C++, one of the most widely used high-level programming languages,
which can then be run at great performance on a CUDA™ enabled
processor. Support for other languages, like FORTRAN, Python or Java,
is available from third parties.

This package contains Nsight Eclipse Edition, a full-featured CUDA IDE.

%prep
%setup -q -T -c %{name}-%{version}

%build
# Nothing to do

%install
%__install -d -m 755 %{buildroot}%{_usr}
%__install -d -m 755 %{buildroot}%{_includedir}
%__install -d -m 755 %{buildroot}%{_bindir}
%__install -d -m 755 %{buildroot}%{_libdir}
%__install -d -m 755 %{buildroot}%{_datadir}/%{name}
%__install -d -m 755 %{buildroot}%{_datadir}/%{name}/samples
%__install -d -m 755 %{buildroot}%{_datadir}/applications
%__install -d -m 755 %{buildroot}%{_docdir}/%{name}-devel

bash %{SOURCE0} --tar xf -C .

# fix permissions
find ./builds -type f -name '*.so*' -exec chmod 755 '{}' \;
find ./builds -type f \( -name '*.h' -o -name '*.hpp' -o -name '*.zip' \) -exec chmod 644 '{}' \;
find ./builds -type f -exec chmod u+w '{}' \;

# install files. The toolkit installation is scattered across /usr,
# so virtually CUDA_PATH corresponds to %%{_usr}. Alternatively a
# non-scattered configuration can be used by setting (typically)
# CUDA_PATH or CUDA_TOOLKIT_ROOT_DIR or CUDAToolkit_Root to
# %%{_libdir}/cuda-toolkit-root-dir.
#

pushd builds/cuda_cccl
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/cuda_cudart
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/cuda_cuobjdump
cp -pr bin/*  %{buildroot}%{_bindir}/
popd

pushd builds/cuda_nvdisasm
cp -pr bin/* %{buildroot}%{_bindir}/
popd

pushd builds/cuda_nvprof
cp -pr bin/* %{buildroot}%{_bindir}
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/cuda_nvprune
cp -pr bin/* %{buildroot}%{_bindir}/
popd

pushd builds/cuda_nvrtc
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/cuda_nvtx
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/libcublas
mkdir -p %{buildroot}%{_datadir}/%{name}/src
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
cp -pr src/* %{buildroot}%{_datadir}/%{name}/src/
popd

pushd builds/libcufile
# fix error in soft link
rm -f lib64/lib64
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
mkdir -p \
	%{buildroot}%{_libdir}/gds \
	%{buildroot}%{_libdir}/gds-%{cuda_major} \
	%{buildroot}%{_libdir}/gds-tools
cp -pr gds/* %{buildroot}%{_libdir}/gds/
cp -pr gds-%{cuda_major}/* %{buildroot}%{_libdir}/gds-%{cuda_major}/
cp -pr gds-tools/* %{buildroot}%{_libdir}/gds-tools/
popd

pushd builds/libcufft
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/libcurand
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/libcusolver
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/libcusparse
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
cp -pr src/* %{buildroot}%{_datadir}/%{name}/src/
popd

pushd builds/libnpp
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/libnvfatbin
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/libnvjitlink
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
cp -p LICENSE ../../LICENSE.libnvjitlink
popd

pushd builds/libnvjpeg
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/cuda_cupti
mkdir -p %{buildroot}%{_datadir}/%{name}/extras/CUPTI
cp -pr ./extras/* %{buildroot}%{_datadir}/%{name}/extras/
mv %{buildroot}%{_datadir}/%{name}/extras/CUPTI/lib64/* %{buildroot}%{_libdir}/
rm -rf %{buildroot}%{_datadir}/%{name}/extras/CUPTI/lib64
popd

pushd builds/cuda_cuxxfilt
cp -p bin/* %{buildroot}/%{_bindir}
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
popd

pushd builds/cuda_nvcc
cp -pr bin/* %{buildroot}%{_bindir}
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
cp -pr nvvm %{buildroot}%{_libdir}/
# add compatibility nvvm link, as sometimes seems required (despite nvcc.profile path already fixed)
ln -s %{_libdir}/nvvm %{buildroot}%{_prefix}/nvvm

# Fix nvcc.profile for current lib path
sed -i 's/lib:/lib64:/g' %{buildroot}%{_bindir}/nvcc.profile
sed -i 's/lib\//lib64\//g' %{buildroot}%{_bindir}/nvcc.profile

# (tmb) restore libdevice
sed -i 's/lib64device/libdevice/g' %{buildroot}%{_bindir}/nvcc.profile
# Fix nvcc.profile to reflect the /usr/nvvm move
sed -i 's/\$(_NVVM_BRANCH_)/%{_lib}\/\$(_NVVM_BRANCH_)/g' %{buildroot}%{_bindir}/nvcc.profile
popd

pushd builds/cuda_nvml_dev
cp -pr include/* %{buildroot}%{_includedir}/
cp -pr lib64/* %{buildroot}%{_libdir}/
cp -pr nvml %{buildroot}%{_libdir}/
popd

pushd builds/cuda_nvvp
cp -pr bin/* %{buildroot}%{_bindir}/
cp -pr libnvvp %{buildroot}%{_libdir}/
mv -f %{buildroot}%{_libdir}/libnvvp %{buildroot}%{_libdir}/nvvp
popd

pushd builds/cuda_gdb
cp -pr bin/* %{buildroot}%{_bindir}
cp -pr ./extras/* %{buildroot}%{_datadir}/%{name}/extras/
popd

pushd builds/cuda_nsight
cp -pr bin/* %{buildroot}%{_bindir}
cp -pr nsightee_plugins %{buildroot}%{_libdir}/
popd

pushd builds/cuda_demo_suite
cp -pr ./extras/* %{buildroot}%{_datadir}/%{name}/extras/
popd

pushd builds/cuda_profiler_api/
cp -pr ./include/* %{buildroot}%{_includedir}/
popd

pushd builds/cuda_sanitizer_api/
cp -pr ./compute-sanitizer %{buildroot}%{_libdir}/
popd

pushd builds/nsight_compute
mkdir -p %{buildroot}%{_libdir}/nsight-compute-%{nsight_compute_ver}
cp -pr ./ %{buildroot}%{_libdir}/nsight-compute-%{nsight_compute_ver}/
popd

pushd builds/nsight_systems
mkdir -p -p %{buildroot}%{_libdir}/nsight-systems-%{nsight_sys_ver}
cp -pr ./ %{buildroot}%{_libdir}/nsight-systems-%{nsight_sys_ver}
# fix permission
chmod u+w %{buildroot}%{_libdir}/nsight-systems-%{nsight_sys_ver}/host-linux-x64/libexec/QtWebEngineProcess
popd

pushd builds/integration
cp -pr ./Sanitizer/* %{buildroot}%{_bindir}/
cp -pr ./nsight-compute/* %{buildroot}%{_bindir}/
cp -pr ./nsight-systems/* %{buildroot}%{_bindir}/
sed -i 's|\$DIR/../compute-sanitizer/compute-sanitizer|%{_libdir}/compute-sanitizer/compute-sanitizer|g' %{buildroot}%{_bindir}/compute-sanitizer

cd %{buildroot}%{_bindir}
# Fix path for ncu and nsys
patch -p1 < %{SOURCE25}
cd ..
popd

# install pkgconfig .pc files
mkdir -p %{buildroot}%{_libdir}/pkgconfig
tar xf %{SOURCE26} -C %{buildroot}%{_libdir}/pkgconfig

# Copy samples (SDK)
tar xf %{SOURCE27}
mv -f cuda-samples-%{samples_ver} builds/cuda_samples
# remove dlls
rm -rf builds/cuda_samples/Common/lib/x64
#
pushd builds/cuda_samples
# fix path for mageia
cp -p %{SOURCE20} .
cp -p %{SOURCE21} .
cp -p %{SOURCE22} .
cp -p %{SOURCE23} .
for i in findegl findgleslib findgllib findvulkan; do
	find . -type f -name "$i.mk" -exec patch -p1 {} $i-fix-mageia.patch \;
done
rm -f	findegl-fix-mageia.patch \
	findgleslib-fix-mageia.patch \
	findgllib-fix-mageia.patch \
	findvulkan-fix-mageia.patch
cp -pr . %{buildroot}%{_datadir}/%{name}/samples
popd

pushd builds/cuda_documentation
mkdir -p %{buildroot}%{_docdir}/%{name}-devel/
cp -p CUDA_Toolkit_Release_Notes.txt DOCS EULA.txt README %{buildroot}%{_docdir}/%{name}-devel/
cp -pr tools %{buildroot}%{_docdir}/%{name}-devel
popd

# Fix wrong permissions
find %{buildroot} -type f \( -name "*.hpp" -o -name "*.xpm" -o -name "*.h" -o -name '*.jar' -o -name '*.src' -o -name -o -name '*.bfc' -o -name '*.properties' \)  -exec chmod 644 {} \;
# Fix samples path
find %{buildroot}%{_datadir}/%{name}/samples -type f -name Makefile -exec sed -i 's@/usr/local/cuda@%_usr@g' {} \; -exec echo "Fix path in " {} \;
# Explicit python shebang
find %{buildroot}%{_libdir} -name "*.py" -exec sed -i "s|#!/usr/bin/env python|#!%{__python3}|" {} \;

# Don't ship non-x86_64 binaries
rm -rf %{buildroot}%{_libdir}/nsight-compute-%{nsight_compute_ver}/target/linux-desktop-glibc_2_19_0-ppc64le
rm -rf %{buildroot}%{_libdir}/nsight-compute-%{nsight_compute_ver}/target/linux-desktop-t210-a64
rm -rf %{buildroot}%{_libdir}/nsight-systems-%{nsight_sys_ver}/target-linux-armv8/
rm -rf %{buildroot}%{_datadir}/%{name}/samples/common/lib/linux/armv7l
rm -rf %{buildroot}%{_datadir}/%{name}/samples/common/lib/linux/aarch64

# Don't ship .cmake files inside %{_includedir}
rm -rf %{buildroot}%{_includedir}/thrust/cmake/
rm -rf  %{buildroot}%{_includedir}/cub/cmake

# Fix paths for Java
sed -i 's|\.\./jre/bin/java|%{_jvmdir}/jre/bin/java|g' %{buildroot}%{_libdir}/nvvp/nvvp.ini
# Use Java 1.8.0 as Java 11 doesn't work (to review for future releases)
%if %{with use_jdk8}
cat >> %{buildroot}%{_libdir}/nvvp/nvvp.ini <<EOF
-vm
%{_jvmdir}/jre-1.8.0/bin/java
EOF
%endif

# Don't ship OpenCL files, we already ship them as separate packages
rm -rf %{buildroot}/%{_includedir}/CL
rm -rf %{buildroot}/%{_libdir}/libOpenCL.so*

# Fix path
sed -i 's|$CUDA_BIN/../libnvvp/nvvp|%{_libdir}/nvvp/nvvp|g' %{buildroot}%{_bindir}/nvvp

# Build icons for nvpp and nsight
for S in 16 24 32 48 64 128 192 256; do
 %__install -d -m755 %{buildroot}%{_iconsdir}/hicolor/$S\x$S/apps
 convert -scale $S\x$S %{buildroot}/%{_libdir}/nvvp/icon.xpm %{buildroot}%{_iconsdir}/hicolor/$S\x$S/apps/nvvp.png
done

%__install -m644 %{SOURCE10} %{buildroot}%{_datadir}/applications/
%__install -D -m 755 %{SOURCE2} %{buildroot}%{_sysconfdir}/init.d/nvidia

# Don't prevent the use of gcc 13.x
sed -i 's|__GNUC__ > 13|__GNUC__ > 15|g' %{buildroot}%{_includedir}/crt/host_config.h
#
# Don't prevent the use of clang 16.x
sed -i 's|__clang_major__ >= 18|__clang_major__ >= 20|g' %{buildroot}%{_includedir}/crt/host_config.h

# fix rpath
pushd %{buildroot}%{_libdir}/nsight-systems-%{nsight_sys_ver}/host-linux-x64
  for i in \
  	libarrow.so.500.0.0 \
	libicudata.so.71 \
  	libicui18n.so.71 \
	libicuuc.so.71 \
	libpapi.so.5 \
	libparquet.so.500.0.0 \
	libQt6Core.so.6 \
	libQt6WebEngineCore.so.6 \
  ; do
  	chrpath -d ${i}
  done
popd
#
pushd %{buildroot}%{_libdir}/nsight-compute-%{nsight_compute_ver}/host/linux-desktop-glibc_2_11_3-x64/
  for i in \
  	libarrow.so.500.0.0 \
	libicudata.so.71 \
	libicui18n.so.71 \
	libicuuc.so.71 \
	libpapi.so.5 \
	libparquet.so.500.0.0 \
	libQt6Core.so.6 \
  ; do
  	chrpath -d ${i}
  done
popd


# Remove bundled ant-apache-log4j.jar
# See https://nvidia.custhelp.com/app/answers/detail/a_id/5294/~/security-notice%3A-nvidia-response-to-log4j-vulnerabilities---december-2021
rm -f %{buildroot}%{_libdir}/nvvp/plugins/org.apache.ant_*/lib/ant-apache-log4j.jar

# Add non-scattered compatibility tree "cuda-toolkit-root-dir" as tree of soft links.
# This is useful for compatibility purposes, for providing -DCUDA_TOOLKIT_ROOT_DIR or
# -DCUDA_PATH=%%{_libdir}/cuda-toolkit-root-dir when some cmake configuration
# fails to work or returns weird error with plain vars (scattered) configuration.
mkdir -p %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}
mkdir -p %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/bin
mkdir -p %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/include
mkdir -p %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/pkgconfig
mkdir -p %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/lib64/stubs
ln -s ./lib64 %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/lib
ln -s %{_libdir}/nvvm %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/nvvm
ln -s %{_libdir}/nvml  %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/nvml
ln -s %{_libdir}/nvvp %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/libnvvp
ln -s %{_libdir}/compute-sanitizer %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/compute-sanitizer
ln -s %{_libdir}/nsightee_plugins %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/nsightee_plugins
ln -s %{_datadir}/%{name}/extras %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/extras
ln -s %{_datadir}/%{name}/samples %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/samples
ln -s %{_datadir}/doc/%{name}-devel/tools %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/tools
ln -s %{_libdir}/nsight-compute-%{nsight_compute_ver} %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/nsight-compute-%{nsight_compute_ver}
ln -s %{_libdir}/nsight-systems-%{nsight_sys_ver}  %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/nsight-systems-%{nsight_sys_ver}
install -m 644 builds/version.json %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}
cd %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/bin
  for i in %{buildroot}%{_bindir}/*; do \
	ln -sf %{_bindir}/$(basename $i) $(basename $i)
  done
cd ..
cd %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/pkgconfig
  for i in %{buildroot}%{_libdir}/pkgconfig/*; do \
        ln -sf %{_libdir}/pkgconfig/$(basename $i) $(basename $i)
  done
cd ..
cd %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/lib64
  for i in %{buildroot}%{_libdir}/lib*.*; do \
  	ln -sf %{_libdir}/$(basename $i) $(basename $i)
  done
  cd stubs
    for i in %{buildroot}%{_libdir}/stubs/lib*.*; do \
    	ln -sf %{_libdir}/stubs/$(basename $i) $(basename $i)
    done
  cd ..
cd ..
lndir -ignorelinks ../../../include %{buildroot}%{_libdir}/%{cuda_toolkit_root_dir}/include/

%files
%_libdir/*.so.*
%_sysconfdir/init.d/*

%files devel
%doc %{_docdir}/%{name}-devel/*
%_bindir/*
%exclude %_bindir/nvvp
%exclude %_bindir/ncu
%exclude %_bindir/ncu-ui
%exclude %_bindir/nsight-sys
%exclude %_bindir/nsys
%exclude %_bindir/nsys-ui
%_libdir/*.so
%_libdir/*.a
%_includedir/*
%_libdir/compute-sanitizer
%_libdir/nvml
%_libdir/nvvm
%_prefix/nvvm
%_libdir/stubs/*
%_libdir/pkgconfig/*.pc
%_libdir/%{cuda_toolkit_root_dir}
%_libdir/cmake/*
%_libdir/gds-%{cuda_major}
%_libdir/gds
%_libdir/gds-tools
%_datadir/%{name}/*
%exclude %_datadir/%{name}/samples

%files samples
%_datadir/%{name}/samples

%files -n nvidia-visual-profiler
%_bindir/nvvp
%_libdir/nvvp/.eclipseproduct
%_libdir/nvvp/*
%_datadir/applications/nvvp.desktop
%_iconsdir/hicolor/*/apps/nvvp.png

%files -n nvidia-nsight
%_bindir/ncu
%_bindir/ncu-ui
%_bindir/nsight-sys
%_bindir/nsys
%_bindir/nsys-ui
%_libdir/nsightee_plugins
%_libdir/nsight-compute-%{nsight_compute_ver}
%_libdir/nsight-systems-%{nsight_sys_ver}
