# Important note!
# There are at least two quite separate OCaml cairo projects.
#
# This is (packaged in Mageia >= 7):
#   https://forge.ocamlcore.org/projects/cairo/
#   https://github.com/Chris00/ocaml-cairo
#
# The other one (which used to be packaged in Mageia <= 6) is:
#   https://cairographics.org/cairo-ocaml/

%define rel 1
# "fix" underlinking:
%define _disable_ld_no_undefined 1


Name:           ocaml-cairo
Epoch:          2
Version:        0.6.4
Release:        %mkrel %{rel}

Summary:        OCaml library for accessing cairo graphics
Group:          Development/OCaml

License:        LGPLv3+
URL:            https://github.com/Chris00/%{name}

Source0:        %{url}/releases/download/%{version}/cairo2-%{version}.tbz

BuildRequires:  ocaml >= 4.02
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-dune-configurator-devel
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-lablgtk2-devel
BuildRequires:  pkgconfig(cairo) >= 1.2.0
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gtk+-2.0)

%global _description %{expand:
Cairo is a multi-platform library providing anti-aliased vector-based
rendering for multiple target backends. Paths consist of line segments
and cubic splines and can be rendered at any width with various join
and cap styles. All colors may be specified with optional translucence
(opacity/alpha) and combined using the extended Porter/Duff
compositing algebra as found in the X Render Extension.

Cairo exports a stateful rendering API similar in spirit to the path
construction, text, and painting operators of PostScript, (with the
significant addition of translucence in the imaging model). When
complete, the API is intended to support the complete imaging model of
PDF 1.4.}

%description
%_description

This package contains OCaml bindings for Cairo.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       ocaml-lablgtk2-devel%{?_isa}
Requires:       cairo-devel

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%package        gtk
Summary:        OCaml library to render cairo on a gtk2 canvas
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description    gtk
%_description

This package contains OCaml bindings for rendering cairo on a gtk2 canvas.


%package        gtk-devel
Summary:        Development files for %{name}-gtk
Requires:       %{name}-gtk%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}


%description    gtk-devel
The %{name}-gtk-devel package contains libraries and signature files for
developing applications that use %{name}-gtk.


%package        pango
Summary:        OCaml library to use pango with cairo
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description    pango
%_description

This package contains OCaml bindings to use pango with cairo.


%package        pango-devel
Summary:        Development files for %{name}-pango
Requires:       %{name}-pango%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}


%description    pango-devel
The %{name}-pango-devel package contains libraries and signature files
for developing applications that use %{name}-pango.


%prep
%autosetup -n cairo2-%{version} -p1


%build
cairo_cflags="$(pkgconf --cflags cairo)"
cairo_libs="$(pkgconf --libs cairo)"
gtk_cflags="$(pkgconf --cflags gtk+-2.0)"
gtk_libs="$(pkgconf --libs gtk+-2.0)"
export CAIRO_CFLAGS="%{optflags} $cairo_cflags"
export CAIRO_LIBS="$RPM_LD_FLAGS $cairo_libs"
export GTK_CFLAGS="%{optflags} $gtk_cflags"
export GTK_LIBS="$RPM_LD_FLAGS $gtk_libs"
dune build

# Dune passes RPM_LD_FLAGS to ocamlmklib without -ldopt, resulting in "Unknown
# option" warnings from ocamlmklib and a library that has not been linked with
# the correct flags.  We can't add -ldopt ourselves, since that breaks
# compilation of the cmxs files.  This seems to be a weakness of dune; linker
# flags and libraries to be linked with have to be specified together, and
# nothing takes care of separating them and adding ldopt as necessary.  We
# relink manually to address the problem.
pushd _build/default/src
ocamlmklib -g -ldopt "$RPM_LD_FLAGS" $cairo_libs -o cairo_stubs cairo_stubs.o
cd ../gtk
ocamlmklib -g -ldopt "$RPM_LD_FLAGS" $gtk_libs -o cairo_gtk_stubs cairo_gtk_stubs.o
cd ../pango
ocamlmklib -g -ldopt "$RPM_LD_FLAGS" $gtk_libs -o cairo_pango_stubs cairo_pango_stubs.o
popd


%install
dune install --destdir=%{buildroot}

# This just contains the README, LICENSE, and CHANGES files, 3 times, in
# directories with names other than the ones we want.
rm -rf %{buildroot}%{_prefix}/doc

%ifarch %{ocaml_native_compiler}
# Add missing executable bits
chmod a+x %{buildroot}%{_libdir}/ocaml/*/*.cmxs
%endif

# Remove files we do not need to package
rm %{buildroot}%{_libdir}/ocaml/*/*.ml


%check
#dune runtest

%files
%doc CHANGES.md README.md
%license GPL3.md LICENSE.md
%dir %{_libdir}/ocaml/cairo2
%{_libdir}/ocaml/cairo2/META
%{_libdir}/ocaml/cairo2/cairo.cma
%{_libdir}/ocaml/cairo2/cairo.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2/cairo.cmxs
%endif
%{_libdir}/ocaml/stublibs/dllcairo_stubs.so

%files devel
# XXX The tutorial doesn't build.
%doc examples
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2/cairo.a
%{_libdir}/ocaml/cairo2/cairo.cmx
%{_libdir}/ocaml/cairo2/cairo.cmxa
%endif
%{_libdir}/ocaml/cairo2/cairo.cmt
%{_libdir}/ocaml/cairo2/cairo.cmti
%{_libdir}/ocaml/cairo2/cairo.mli
%{_libdir}/ocaml/cairo2/cairo_ocaml.h
%{_libdir}/ocaml/cairo2/dune-package
%{_libdir}/ocaml/cairo2/libcairo_stubs.a
%{_libdir}/ocaml/cairo2/opam


%files gtk
%dir %{_libdir}/ocaml/cairo2-gtk
%{_libdir}/ocaml/cairo2-gtk/META
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cma
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmxs
%endif
%{_libdir}/ocaml/stublibs/dllcairo_gtk_stubs.so


%files gtk-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.a
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmx
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmxa
%endif
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmt
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmti
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.mli
%{_libdir}/ocaml/cairo2-gtk/dune-package
%{_libdir}/ocaml/cairo2-gtk/libcairo_gtk_stubs.a
%{_libdir}/ocaml/cairo2-gtk/opam


%files pango
%dir %{_libdir}/ocaml/cairo2-pango
%{_libdir}/ocaml/cairo2-pango/META
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cma
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmxs
%endif
%{_libdir}/ocaml/stublibs/dllcairo_pango_stubs.so


%files pango-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-pango/cairo_pango.a
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmx
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmxa
%endif
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmt
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmti
%{_libdir}/ocaml/cairo2-pango/cairo_pango.mli
%{_libdir}/ocaml/cairo2-pango/dune-package
%{_libdir}/ocaml/cairo2-pango/libcairo_pango_stubs.a
%{_libdir}/ocaml/cairo2-pango/opam

