
%global shortversion 109

Name:           ocaml-camlidl
Version:        1.09
Release:        %mkrel 4
Summary:        Stub code generator and COM binding for Objective Caml
Group:          Development/OCaml
License:        QPL and LGPLv2 with exceptions
URL:            https://caml.inria.fr/pub/old_caml_site/camlidl/
Source0:        https://github.com/xavierleroy/camlidl/archive/camlidl%{shortversion}.tar.gz
# This is the latest prebuilt documentation available.
# Actually building the documentation requires many TeX tools.
Source1:        https://caml.inria.fr/pub/old_caml_site/distrib/bazar-ocaml/camlidl-1.05.doc.pdf
# META file from Debian (RHBZ#1026991).
Source2:        META.camlidl.in

# Both patches sent upstream on 2020-05-20.
# Allow destdir installs.
Patch1:         0001-Allow-destdir-installs.patch
# Pass -g option to ocamlmklib.
Patch2:         0002-Pass-g-option-to-ocamlmklib.patch

BuildRequires: make
BuildRequires:  ocaml
BuildRequires:  ocaml-compiler
BuildRequires:  perl

%description
CamlIDL is a stub code generator and COM binding for Objective Caml.

CamlIDL comprises two parts:

* A stub code generator that generates the C stub code required for
  the Caml/C interface, based on an MIDL specification. (MIDL stands
  for Microsoft's Interface Description Language; it looks like C
  header files with some extra annotations, plus a notion of object
  interfaces that look like C++ classes without inheritance.)

* A (currently small) library of functions and tools to import COM
  components in Caml applications, and export Caml code as COM
  components.


%package    devel
Summary:    Development files for %{name}
Group:      Development/OCaml
Requires:   %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%prep
%autosetup -n camlidl-camlidl%{shortversion} -p1

sed -e 's|^OCAMLLIB=.*|OCAMLLIB=%{_libdir}/ocaml|' \
    -e 's|^BINDIR=.*|BINDIR=%{_bindir}|' \
    -e 's|^CFLAGS=.*|CFLAGS=%{optflags}|' \
    -e 's|^OCAMLC=.*|OCAMLC=ocamlc.opt -g|' \
    -e 's|^OCAMLOPT=.*|OCAMLOPT=ocamlopt.opt -g|' \
    < config/Makefile.unix \
    > config/Makefile

cp %{SOURCE1} .


%build
# Parallel builds will fail.
make


%install
mkdir -p %{buildroot}%{_libdir}/ocaml
mkdir -p %{buildroot}%{_libdir}/ocaml/caml
mkdir -p %{buildroot}%{_libdir}/ocaml/stublibs
mkdir -p %{buildroot}%{_bindir}

# Install META file (RHBZ#1026991).
sed 's/@VERSION@/%{version}/' < %{SOURCE2} > $RPM_BUILD_ROOT/%{_libdir}/ocaml/META.camlidl

make DESTDIR=$RPM_BUILD_ROOT install


%files
%doc LICENSE
%{_libdir}/ocaml/*.*
%exclude %{_libdir}/ocaml/*.a
%exclude %{_libdir}/ocaml/*.cmxa
%{_libdir}/ocaml/stublibs/*.so
%{_bindir}/camlidl


%files devel
%doc LICENSE README Changes camlidl-1.05.doc.pdf tests
%{_libdir}/ocaml/*.a
%{_libdir}/ocaml/*.cmxa
%{_libdir}/ocaml/caml/*.h
