# "fix" underlinking:
%define _disable_ld_no_undefined 1

%global srcname cryptokit

Name:           ocaml-cryptokit
Version:        1.16.1
Release:        %mkrel 4
Summary:        OCaml library of cryptographic and hash functions
License:        LGPLv2 with linking exception
Group:          Development/OCaml

%global upver %(tr -d . <<< %{version})

URL:            https://github.com/xavierleroy/cryptokit/
Source0:        %{url}/archive/release%{upver}/%{srcname}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.03.0
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-dune-devel >= 2.0
BuildRequires:  ocaml-result-devel
BuildRequires:  ocaml-zarith-devel >= 1.4
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(ncurses)

%description
The Cryptokit library for Objective Caml provides a variety of
cryptographic primitives that can be used to implement cryptographic
protocols in security-sensitive applications. The primitives provided
include:

* Symmetric-key cryptography: AES, DES, Triple-DES, ARCfour, in ECB,
  CBC, CFB and OFB modes.
* Public-key cryptography: RSA encryption and signature; Diffie-Hellman
  key agreement.
* Hash functions and MACs: SHA-1, SHA-256, RIPEMD-160, MD5, and MACs
  based on AES and DES.
* Random number generation.
* Encodings and compression: base 64, hexadecimal, Zlib compression. 

Additional ciphers and hashes can easily be used in conjunction with
the library. In particular, basic mechanisms such as chaining modes,
output buffering, and padding are provided by generic classes that can
easily be composed with user-provided ciphers. More generally, the
library promotes a "Lego"-like style of constructing and composing
transformations over character streams.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-zarith-devel
Requires:       pkgconfig(zlib)

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n cryptokit-release%{upver}

%build
# On x86 and x86_64, the configure script finds support for the -maes flag in
# the compiler, and uses it to compile src/aesni.{c,h}.  This is okay because
# use of the compiled code is conditional.  The function aesni_check_available()
# is called first, which checks the CPUID to verify that the instructions exist
# on the CPU.  Therefore, older CPUs can still run the compiled code.
dune build %{?_smp_mflags} @install
%if %{with doc}
dune build %{?_smp_mflags} @doc
%endif

# Relink the stublibs with Fedora flags
cd _build/default/src
ocamlmklib -g -ldopt "%build_ldflags" -o cryptokit_stubs \
  $(ar t libcryptokit_stubs.a)
cd -
 
%check
# This opens /dev/random but never reads from it.
dune runtest

%install
dune install --destdir=%{buildroot}

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

# We do not want the ml files
find %{buildroot}%{_libdir}/ocaml -name \*.ml -delete

%files
%doc README.md Changes
%dir %{_libdir}/ocaml/cryptokit
%{_libdir}/ocaml/%{srcname}/dune-package
%{_libdir}/ocaml/cryptokit/META
%{_libdir}/ocaml/%{srcname}/opam
%{_libdir}/ocaml/cryptokit/*.cma
%{_libdir}/ocaml/cryptokit/*.cmi
%{_libdir}/ocaml/cryptokit/*.cmxs
%{_libdir}/ocaml/stublibs/*.so*

%files devel
%{_libdir}/ocaml/cryptokit/*.a
%{_libdir}/ocaml/cryptokit/*.cmt
%{_libdir}/ocaml/cryptokit/*.cmti
%{_libdir}/ocaml/cryptokit/*.cmxa
%{_libdir}/ocaml/cryptokit/*.cmx
%{_libdir}/ocaml/cryptokit/*.mli
