%define up_name findlib
%bcond_without bootstrap

%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

Summary:        A module packaging tool for OCaml
Name:           ocaml-%{up_name}
Version:        1.9.8
Release:        %mkrel 5
Group:          Development/OCaml
License:        BSD
Url:            https://projects.camlcity.org/projects/findlib.html
Source0:        https://download.camlcity.org/download/%{up_name}-%{version}.tar.gz

BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-compiler-libs
%if ! %with bootstrap
BuildRequires:  ocaml-camlp4-devel
BuildRequires:  ocaml-labltk-devel
%endif
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(libzstd)
%ifarch %arm %ix86 
BuildRequires:  devel(libatomic)
%endif
Requires:       ocaml-compiler
Obsoletes:      %{up_name} < %{version}


%description
The findlib library provides a scheme to manage reusable software
components (packages), and includes tools that support this scheme.
Packages are collections of OCaml modules for which meta-information can
be stored. The packages are kept in the file-system hierarchy, but with
strict directory structure. The library contains functions to look the
directory up that stores a package, to query meta-information about a
package, and to retrieve dependency information about multiple packages.
There is also a tool that allows the user to enter queries on the
command-line. In order to simplify compilation and linkage, there are
new front-ends of the various OCaml compilers that can directly deal with
packages.

%package devel
Summary:    Development files for %{name}
Group:      Development/OCaml
Requires:   %{name} = %{version}-%{release}


%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q -n %{up_name}-%{version}

# Build an executable that is not damaged by stripping
sed -i 's/\(custom=\)-custom/\1-output-complete-exe/' configure

%build
ocamlc -version
ocamlc -where
(cd tools/extract_args && make)
tools/extract_args/extract_args -o src/findlib/ocaml_args.ml ocamlc ocamlcp ocamlmktop ocamlopt ocamldep ocamldoc ||:
cat src/findlib/ocaml_args.ml
./configure -config %{_sysconfdir}/findlib.conf \
    -bindir %{_bindir} \
    -sitelib `ocamlc -where` \
    -mandir %{_mandir} \
    -with-toolbox
make all
%ifarch %{ocaml_native_compiler}
make opt
%endif

%install
make prefix=%{buildroot} PREFIX=%{buildroot} install 

# don't ship META files for standard library in this package,
# they are included in ocaml package,
# [IMPORTANT] so when this package is updated, update too
# the tarball that contain these files (Source5) in the ocaml package!
rm -f %{buildroot}%{_libdir}/ocaml/bigarray/META
rm -f %{buildroot}%{_libdir}/ocaml/dbm/META
rm -f %{buildroot}%{_libdir}/ocaml/dynlink/META
rm -f %{buildroot}%{_libdir}/ocaml/graphics/META
rm -f %{buildroot}%{_libdir}/ocaml/num/META
rm -f %{buildroot}%{_libdir}/ocaml/num-top/META
rm -f %{buildroot}%{_libdir}/ocaml/stdlib/META
rm -f %{buildroot}%{_libdir}/ocaml/str/META
rm -f %{buildroot}%{_libdir}/ocaml/threads/META
rm -f %{buildroot}%{_libdir}/ocaml/unix/META
rm -f %{buildroot}%{_libdir}/ocaml/ocamlbuild/META
rm -f %{buildroot}%{_libdir}/ocaml/compiler-libs/META
rm -f %{buildroot}%{_libdir}/ocaml/bytes/META
rm -f %{buildroot}%{_libdir}/ocaml/ocamldoc/META
rm -f %{buildroot}%{_libdir}/ocaml/raw_spacetime/META

# In order to update the [Source5] field of ocaml.spec,
# in the findlib source directory run the ./configure script
# with camlp4 and ocaml-labltk properly installed, then:
# tar cfj  findlib-1.4-ocaml-4.00.1-meta-files.tar.bz2  site-lib-src/*/META
# This goes into ocaml-camlp4
rm -f %{buildroot}%{_libdir}/ocaml/camlp4/META
# This goes into ocaml-labltk
rm -f %{buildroot}%{_libdir}/ocaml/labltk/META

%files
%doc LICENSE
%config(noreplace) %{_sysconfdir}/findlib.conf
%{_bindir}/*
%{_mandir}/man*/*
%{_libdir}/ocaml/findlib
%{_libdir}/ocaml/topfind
#{_libdir}/ocaml/num-top
%exclude %{_libdir}/ocaml/findlib/*.a
%exclude %{_libdir}/ocaml/findlib/*.cmxa
%exclude %{_libdir}/ocaml/findlib/*.mli
%exclude %{_libdir}/ocaml/findlib/Makefile.config


%files devel
%doc LICENSE doc doc/README doc/guide-html
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/findlib/*.a
%{_libdir}/ocaml/findlib/*.cmxa
%endif
%{_libdir}/ocaml/findlib/*.mli
%{_libdir}/ocaml/findlib/Makefile.config
