Name:           ocaml-ocamlnet
Version:        4.1.9
Release:        %mkrel 4
Summary:        Network protocols for OCaml
License:        BSD
Group:          Development/OCaml
URL:            https://projects.camlcity.org/projects/ocamlnet.html
Source:         https://download.camlcity.org/download/ocamlnet-%{version}.tar.gz
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-compiler-libs
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-pcre-devel
BuildRequires:  ocaml-camlzip-devel
BuildRequires:  gnutls-devel
BuildRequires:  krb5-devel

BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(tcl)

%description
Ocamlnet is an ongoing effort to collect modules, classes and
functions that are useful to implement network protocols. Since
version 2.2, Ocamlnet incorporates the Equeue, RPC, and Netclient
libraries, so it now really a big player.

In detail, the following features are available:

 * netstring is about processing strings that occur in network
   context. Features: MIME encoding/decoding, Date/time parsing,
   Character encoding conversion, HTML parsing and printing, URL
   parsing and printing, OO-representation of channels, and a lot
   more.

 * netcgi1 and netcgi2 focus on portable web applications. netcgi1 is
   the older, backward-compatible version, whereas netcgi2 bases on a
   revised design, and is only partly backward-compatible. Supported
   are CGI, FastCGI, AJP (mod_jk), and SCGI.

 * rpc implements ONCRPC (alias SunRPC), the remote procedure call
   technology behind NFS and other Unix services.

 * netplex is a generic server framework. It can be used to build
   stand-alone server programs from individual components like those
   from netcgi2, nethttpd, and rpc.

 * netclient implements clients for HTTP (version 1.1, of course), FTP
   (currently partially), and Telnet.

 * equeue is an event queue used for many protocol implementations. It
   makes it possible to run several clients and/or servers in parallel
   without having to use multi-threading or multi-processing.

 * shell is about calling external commands like a Unix shell does.

 * netshm provides shared memory for IPC purposes.

 * netsys contains bindings for system functions missing in core O'Caml.

 * netsmtp and netpop are client implementations of the SMTP and POP3
   protocols.

 * Bindings for GnuTLS and GSSAPI (TLS/HTTPS support).

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-pcre-devel
Requires:       pkgconfig(tcl)

%description    devel
This package contains the development files needed to build applications
using %{name}.

%package        gtk2
Summary:        GTK2 development libraries for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
BuildRequires:  ocaml-lablgtk2-devel
Requires:       ocaml-lablgtk2

%description    gtk2
GTK2 development libraries for %{name}.


%package        gtk2-devel
Summary:        GTK2 development libraries for %{name}
Group:          Development/OCaml
Requires:       %{name}-gtk2 = %{version}-%{release}
Requires:       ocaml-lablgtk2-devel

%description    gtk2-devel
This package contains the development files needed to build applications
using %{name}-gtk2.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
This package contains the HTML API documentation for %{name}.


%package        nethttpd
Summary:        Ocamlnet HTTP daemon
License:        GPLv2+
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    nethttpd
Nethttpd is a web server component (HTTP server implementation). It
can be used for web applications without using an extra web server, or
for serving web services.


%package        nethttpd-devel
Summary:        Development files for %{name}-nethttpd
License:        GPLv2+
Group:          Development/OCaml
Requires:       %{name}-nethttpd = %{version}-%{release}

%description    nethttpd-devel
The %{name}-nethttpd-devel package contains libraries and signature
files for developing applications that use %{name}-nethttpd.


%prep
%setup -q -n ocamlnet-%{version}

%build
%define ocamlnet_datadir %{_datadir}/%{name}
# not an autoconf one
./configure \
  -enable-tcl \
  -equeue-tcl-libs -ltcl \
  -bindir %{_bindir} \
  -datadir %{ocamlnet_datadir} \
  -disable-apache \
  -enable-pcre \
  -enable-gtk2 \
  -enable-gnutls \
  -enable-gssapi \
  -enable-nethttpd \
  -enable-tcl \
  -enable-zip

make all
make opt


%install
install -d -m 755 %{buildroot}/%{_libdir}/ocaml
install -d -m 755 %{buildroot}/%{_libdir}/ocaml/stublibs
make install \
  OCAMLFIND_INSTFLAGS="-destdir %{buildroot}/%{_libdir}/ocaml" \
  OCAMLFIND_DESTDIR=%{buildroot}%{_libdir}/ocaml \
  DESTDIR="%{buildroot}"

# rpc-generator/dummy.mli is empty and according to Gerd Stolpmann can
# be deleted safely.  This avoids an rpmlint warning.
rm -f %{buildroot}%{_libdir}/ocaml/rpc-generator/dummy.mli

# Strip libraries.
strip %{buildroot}%{_libdir}/ocaml/stublibs/*.so

mv ChangeLog ChangeLog.old
iconv -f iso-8859-1 -t utf-8 < ChangeLog.old > ChangeLog

%files
%doc ChangeLog LICENSE LICENSE.GPL LICENSE.LGPL RELNOTES
%{_bindir}/*
%{_libdir}/ocaml/equeue
%exclude %{_libdir}/ocaml/equeue-gtk2
%{_libdir}/ocaml/equeue-tcl
%{_libdir}/ocaml/netcamlbox
%{_libdir}/ocaml/netcgi2
%{_libdir}/ocaml/netcgi2-plex
%{_libdir}/ocaml/netclient
%{_libdir}/ocaml/netgss-system
%exclude %{_libdir}/ocaml/nethttpd
%{_libdir}/ocaml/netmulticore
%{_libdir}/ocaml/netplex
%{_libdir}/ocaml/netshm
%{_libdir}/ocaml/netstring
%{_libdir}/ocaml/netstring-pcre
%{_libdir}/ocaml/netsys
%{_libdir}/ocaml/nettls-gnutls
%{_libdir}/ocaml/netunidata
%{_libdir}/ocaml/netzip
%{_libdir}/ocaml/rpc
%{_libdir}/ocaml/rpc-auth-local
%{_libdir}/ocaml/rpc-generator
%{_libdir}/ocaml/shell
%{_libdir}/ocaml/stublibs/*.so*
# Adjustment for -custom compilation
%exclude %{_libdir}/ocaml/*/*.a
%exclude %{_libdir}/ocaml/*/*.cmxa
%exclude %{_libdir}/ocaml/*/*.cmx
%exclude %{_libdir}/ocaml/*/*.o
%exclude %{_libdir}/ocaml/*/*.mli
%{ocamlnet_datadir}

%files devel
%{_libdir}/ocaml/*/*.cmxa
%{_libdir}/ocaml/*/*.cmx
%{_libdir}/ocaml/*/*.mli
%{_libdir}/ocaml/*/*.a
%{_libdir}/ocaml/netsys/netsys_oothr_mt_init.o
%exclude %{_libdir}/ocaml/nethttpd
%exclude %{_libdir}/ocaml/equeue-gtk2


%files gtk2
%{_libdir}/ocaml/equeue-gtk2/META
%{_libdir}/ocaml/equeue-gtk2/*.cmi
%{_libdir}/ocaml/equeue-gtk2/*.cma


%files gtk2-devel
%{_libdir}/ocaml/equeue-gtk2/*.cmxa
%{_libdir}/ocaml/equeue-gtk2/*.mli
%{_libdir}/ocaml/equeue-gtk2/*.a

%files doc
%doc doc/html-main/
%doc examples/

%files nethttpd
%{_libdir}/ocaml/nethttpd
%exclude %{_libdir}/ocaml/*/*.a
%exclude %{_libdir}/ocaml/*/*.cmxa
%exclude %{_libdir}/ocaml/*/*.mli

%files nethttpd-devel
%{_libdir}/ocaml/nethttpd/nethttpd*.a
%{_libdir}/ocaml/nethttpd/nethttpd*.cmxa
%{_libdir}/ocaml/nethttpd/nethttpd*.mli
