Name:       ocaml-pareto
Version:    0.2
Release:    %mkrel 7
Summary:    OCaml statistics library
Group:      Development/OCaml
License:    MIT
URL:        https://github.com/superbobry/pareto
Source0:    https://github.com/superbobry/pareto/archive/pareto-%{version}.tar.gz
# ocaml-gsl does not support arm
ExcludeArch:	%arm

BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-gsl-devel

%description
pareto is an OCaml statistics library, based on GSL [1], which provides:

- Common statistical tests for significant differences between samples.
- Uniform interface for common discrete and continuous probability
  distributions.
- Sample statistics, quantile estimation, kernel density estimation.
- Resampling methods: jackknife, BCa bootstrap.

*Note*: before using `pareto` make sure you understand some of the
subtleties in OCaml GSL bindings. See section *ERROR HANDLING* in GSL
README [2].

[1]: https://www.gnu.org/software/gsl
[2]: https://bitbucket.org/mmottl/gsl-ocaml

%package    devel
Summary:    Development files for %{name}
Group:      Development/OCaml
Requires:   %{name} = %{version}-%{release}
BuildRequires:  ocaml-gsl-devel

%description devel
This package contains the development modules you need to use %{name} in
your programs.

%prep
%setup -q -n pareto-%{version}

%build
ocaml setup.ml -configure \
    --prefix %{_prefix} \
    --libdir %{_libdir} \
    --libexecdir %{_libexecdir} \
    --exec-prefix %{_exec_prefix} \
    --bindir %{_bindir} \
    --sbindir %{_sbindir} \
    --mandir %{_mandir} \
    --datadir %{_datadir} \
    --localstatedir %{_localstatedir} \
    --destdir %{buildroot}

#   --docdir %{_docdir}/%{name}-devel/ \

ocaml setup.ml -build
#ocaml setup.ml -doc

%check
ocaml setup.ml -test

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
export OCAMLFIND_LDCONF=ignore
export DLLDIR=$OCAMLFIND_DESTDIR/stublibs
mkdir -p $OCAMLFIND_DESTDIR/stublibs
mkdir -p $OCAMLFIND_DESTDIR/pareto
ocaml setup.ml -install

%files
%doc README.md LICENSE CHANGES
%dir %{_libdir}/ocaml/pareto
%{_libdir}/ocaml/pareto/META
%{_libdir}/ocaml/pareto/*.cmi
%{_libdir}/ocaml/pareto/*.cma
%{_libdir}/ocaml/pareto/*.cmxs
%{_libdir}/ocaml/stublibs/*.so*

%files devel
%doc examples/
%doc lib_test/
#%doc doc/
#%{_docdir}/%{name}-devel
%{_libdir}/ocaml/pareto/*.a
%{_libdir}/ocaml/pareto/*.cmxa
%{_libdir}/ocaml/pareto/*.mli
%{_libdir}/ocaml/pareto/*.ml
