Name:       ocaml-safepass
Version:    1.2
Release:    %mkrel 6
Summary:    Library enabling the safe storage of user passwords
License:    LGPL 2.1 with linking exception
Group:      Development/OCaml
URL:        https://forge.ocamlcore.org/projects/ocaml-safepass/
#ProjectPage: https://forge.ocamlcore.org/projects/ocaml-safepass/
Source0:    https://download.ocamlcore.org/ocaml-safepass/ocaml-safepass/%{version}/ocaml-safepass-%{version}.tgz
BuildRequires:  ocaml-findlib

%description
OCaml-safepass is a library enabling the safe storage of user passwords,
for use in web applications. Passwords are salted and hashed using the
bcrypt algorithm.

OCaml-safepass is a library offering facilities for the safe storage of
user passwords. By "safe" we mean that passwords are salted and hashed using
the Bcrypt algorithm (https://en.wikipedia.org/wiki/Bcrypt).
Salting prevents rainbow-table (https://en.wikipedia.org/wiki/Rainbow_table)
based attacks, whereas hashing by a very time-consuming algorithm such as
Bcrypt renders brute-force password cracking impractical.

OCaml-safepass's obvious usage domain are web applications, though it does
not depend on any particular framework.
Internally, OCaml-safepass binds to the C routines from Openwall's
Crypt_blowfish (https://www.openwall.com/crypt/). However, it would be
incorrect to describe OCaml-safepass as an OCaml binding to Crypt_blowfish,
because the API it exposes is higher-level and more compact than that
offered by Crypt_blowfish. Moreover, OCaml-safepass's API takes advantage of
OCaml's type-system to make usage mistakes nearly impossible.

OCaml-safepass is developed by Dario Teixeira and is licensed under the
terms of the GNU LGPL 2.1 with the usual OCaml linking exception.

%package    devel
Summary:    Development files for %{name}
Group:      Development/OCaml
Requires:   %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries for developing applications
that use %{name}.

%prep
%setup -q

%build
./configure \
    --prefix %{_prefix} \
    --libdir %{_libdir} \
    --libexecdir %{_libexecdir} \
    --exec-prefix %{_exec_prefix} \
    --bindir %{_bindir} \
    --sbindir %{_sbindir} \
    --mandir %{_mandir} \
    --datadir %{_datadir} \
    --localstatedir %{_localstatedir} \
    --docdir %{_docdir}/%{name}-devel/ \
    --destdir %{buildroot}

make
make doc

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
export DLLDIR=$OCAMLFIND_DESTDIR/stublibs
mkdir -p $OCAMLFIND_DESTDIR/stublibs
mkdir -p $OCAMLFIND_DESTDIR/safepass
make install

%files
%doc README LICENSE CHANGELOG
%dir %{_libdir}/ocaml/safepass
%{_libdir}/ocaml/safepass/META
%{_libdir}/ocaml/safepass/*.cmi
%{_libdir}/ocaml/safepass/*.cma
%{_libdir}/ocaml/safepass/*.cmxs
%{_libdir}/ocaml/stublibs/*.so*

%files devel
%{_docdir}/%{name}-devel
%{_libdir}/ocaml/safepass/*.a
%{_libdir}/ocaml/safepass/*.cmxa
%{_libdir}/ocaml/safepass/*.cmx
%{_libdir}/ocaml/safepass/*.mli
