%define major	4.14

# "fix" underlinking:
%define _disable_ld_no_undefined 1


%bcond_with bootstrap

%ifarch %{ocaml_native_compiler}
%global native_compiler 1
%else
%global native_compiler 0
%endif

%global giturl https://github.com/ocaml/ocaml
#global rcver +git
%global rcver %{nil}

Name:		ocaml
Version:	5.3.0
Release:	%mkrel 5
Summary:	The OCaml compiler and programming environment
URL:		https://www.ocaml.org
VCS:		git:%{giturl}.git
License:	QPL with exceptions and LGPLv2 with exceptions
Group:		Development/OCaml
Source0:        https://github.com/ocaml/ocaml/archive/%{version}.tar.gz
Source1:	https://caml.inria.fr/pub/distrib/ocaml-%{major}/%{name}-%{major}-refman-html.tar.gz
Source2:        macros.ocaml-rpm
Source3:        ocaml_files.py

# IMPORTANT: 
# The contents (META's files) of this tarball comes from findlib
# This tarball have to be updated when findlib or ocaml are updated to a
# new version these META's files are only generated by the ./configure in
# the findlib source directory (ocaml-x11
# and ocaml-compiler-libs have to be installed for this operation) then
# just: 
# tar cfj findlib-1.4-ocaml-4.00.1-meta-files.tar.bz2 site-lib-src/*/META
Source5:	findlib-1.9.1-ocaml-%{version}-meta-files.tar.bz2

Patch0001:      0001-Don-t-add-rpaths-to-libraries.patch
Patch0002:      0002-configure-Allow-user-defined-C-compiler-flags.patch
Patch0003:      0003-configure-Remove-incorrect-assumption-about-cross-co.patch

# Workaround for upstream https://caml.inria.fr/mantis/view.php?id=5753
# Remove ocamltoplevel.cmxa from META file
Source19:	ocaml-4.00.1-fix-META-ocamltoplevel.cmxa.patch

BuildRequires: make
BuildRequires:  git
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:	tk
BuildRequires:	pkgconfig(tk)
# So that ocamlobjinfo has bfd support
BuildRequires:  binutils-devel
# On 32 bits architectures it uses libatomic
%ifarch %arm %ix86 
BuildRequires:  devel(libatomic)
%endif
BuildRequires:  pkgconfig(libzstd)

# This BR is to enable automatic provides generation for this package.
# It can be removed safely if we need to bootstrap.
%if ! %with bootstrap
BuildRequires:  ocaml-compiler
%endif

Requires:	ncurses-devel
%if ! %with bootstrap
Requires:	ocaml-compiler = %{version}
%endif

Obsoletes:	ocaml-emacs < %{version}
Provides:	ocaml-emacs = %{version}

%if %{native_compiler}
%global __ocaml_requires_opts -c -f '%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte' -i Dynlink_cmo_format -i Dynlink_cmxs_format
%else
%global __ocaml_requires_opts -c -f '%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte' -i Backend_intf -i Inlining_decision_intf -i Simplify_boxed_integer_ops_intf -i Dynlink_cmo_format -i Dynlink_cmxs_format
%endif
%global __ocaml_provides_opts -f '%{buildroot}%{_bindir}/ocamlrun %{buildroot}%{_bindir}/ocamlobjinfo.byte'

%package	compiler
Summary:	Compiler and Runtime for OCaml
Group:		Development/OCaml
Conflicts:	ocaml < 3.12.1-7
Provides:       ocaml(compiler) = %{version}
Provides:       ocaml(runtime) = %{version}
Provides:       ocaml-uchar = %{version}
Obsoletes:      ocaml-uchar < %{version}
Provides:       ocaml-ocamldoc = %{version}-%{release}
Requires:       pkgconfig(libzstd)
%ifarch %arm %ix86 
Requires:       devel(libatomic)
%endif

%package	doc
Summary:	Documentation for OCaml
Group:		Documentation
BuildArch:	noarch
Requires:	%{name}-compiler = %{version}

%package sources
Summary:	OCaml sources
Group:		Development/OCaml
BuildArch:	noarch

%package compiler-libs
Summary:	OCaml compiler library
Group:		Development/OCaml
Requires:	%{name}-compiler = %{version}

%description
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

%description compiler
This package comprises two batch OCaml compilers (a fast byte-code compiler and an
optimizing native-code compiler), an interactive top-level system, Lex&Yacc
tools, a replay debugger, and a comprehensive library.

%description	doc
Documentation for OCaml

%description sources
OCaml sources

%description compiler-libs
This package contains several modules used internally by the OCaml
compilers.  They are not needed for normal OCaml development, but may
be helpful in the development of certain applications.

%package rpm-macros
# LGPL-2.1-or-later WITH OCaml-LGPL-linking-exception: the project as a whole
# BSD-3-Clause: ocaml_files.py
License:        LGPL-2.1-or-later WITH OCaml-LGPL-linking-exception AND BSD-3-Clause
Summary:        RPM macros for building OCaml packages
BuildArch:      noarch
Requires:       ocaml = %{version}-%{release}
Requires:       python3
# ocaml_files.py used to be in ocaml-srpm-macros
Conflicts:      ocaml-srpm-macros < 10


%description rpm-macros
This package contains macros that are useful for building OCaml RPMs.

%prep
%autosetup -S git -n %{name}-%{version}%{rcver}
%setup -q -T -D -a 1 -n %{name}-%{version}%{rcver}
%setup -q -T -D -a 5 -n %{name}-%{version}%{rcver}
# Patches touch configure.ac, so rebuild it:
autoconf --force

%build
%ifnarch %{no_parallel_build_arches}
make="%make_build"
%else
unset MAKEFLAGS
make=make
%endif

sed -i '/ld_opts/s|\[\]|["%{build_ldflags}"]|' tools/ocamlmklib.ml

# We set --libdir to the unusual directory because we want OCaml to
# install its libraries and other files into a subdirectory.
#
# Force --host because of:
# https://lists.fedoraproject.org/archives/list/devel@lists.fedoraproject.org/thread/2O4HBOK6PTQZAFAVIRDVMZGG2PYB2QHM/
# (see also https://github.com/ocaml/ocaml/issues/8647)
#
# OC_CFLAGS/OC_LDFLAGS control what flags OCaml passes to the linker
# when doing final linking of OCaml binaries.  Setting these is
# necessary to ensure that generated binaries have Fedora hardening
# features.
%configure \
    OC_CFLAGS="$CFLAGS" \
    OC_LDFLAGS="$LDFLAGS" \
%if %{native_compiler}
    --enable-native-compiler \
    --enable-native-toplevel \
%else
    --disable-native-compiler \
    --disable-native-toplevel \
%endif
    --libdir=%{_libdir}/ocaml \
    --host=`./build-aux/config.guess`

$make world
%if %{native_compiler}
$make opt
$make opt.opt
%endif

%install
%make_install

# fix
perl -pi -e "s|%{buildroot}||" %{buildroot}%{_libdir}/ocaml/ld.conf

%ifarch %{ocaml_native_compiler}
# only keep the binary versions, which are much faster
for i in %{buildroot}%{_bindir}/*.opt ; do
  ln -sf `basename $i` ${i%.opt}
done
%endif

# install findlib META files
cp -pr site-lib-src/* %{buildroot}%{_libdir}/ocaml/

# fix me: this one should not be in the input
if [ -f %{buildroot}%{_libdir}/ocaml/dbm/META ]
then rm -f %{buildroot}%{_libdir}/ocaml/dbm/META; fi
# likewise, conflicts with ocaml-num:
rm -fr %{buildroot}%{_libdir}/ocaml/num{,-top}/


rm -f %{name}.list
n="graphics|X11"
(cd %{buildroot} ; find usr/bin ! -type d -printf "/%%p\n" | grep -v -E $n) >> %{name}.list
(cd %{buildroot} ; find usr/%{_lib}/ocaml ! -type d -printf "/%%p\n" | grep -v -E $n) >> %{name}.list
(cd %{buildroot} ; find usr/%{_lib}/ocaml   -type d -printf "%%%%dir /%%p\n" | grep -v -E $n) >> %{name}.list
fgrep \.cmt %{name}.list > cmt+cmti.list
sed -i '/\.cmt/d' %{name}.list

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=OCaml
Comment=ML language implementation with a class-based object system
Comment[fr]=mise en oeuvre de Meta Language (ML) avec un système orienté
Comment[ru]=Реализация языка ML с объектно-ориентированным подходом
GenericName=OCaml compiler and programming environment
GenericName[fr]=Environnement de programmation et compilateur OCaml
GenericName[ru]=Компилятор OCaml и среда программирования
Exec=%{name}
Icon=development_tools_section
Terminal=true
Type=Application
Categories=Development;
EOF


# install sources
install -d -m 755 %{buildroot}%{_prefix}/src
zcat %{SOURCE0} | tar xvf - -C %{buildroot}%{_prefix}/src
mv %{buildroot}%{_prefix}/src/%{name}-%{version}%{?rcver:%rcver} %{buildroot}%{_prefix}/src/%{name}

rm -f %{buildroot}%{_libdir}/ocaml/graphics/META
rm -rf %{buildroot}%{_datadir}/doc/ocaml

mkdir -p %{buildroot}%{_rpmmacrodir}
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_rpmmacrodir}/macros.ocaml-rpm

mkdir -p %{buildroot}%{_rpmconfigdir}/redhat
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_rpmconfigdir}/redhat

%files

%files compiler -f %{name}.list
%doc Changes LICENSE README.adoc 
%{_mandir}/man1/*
%{_datadir}/applications/*
%exclude %{_libdir}/ocaml/compiler-libs

%files doc
%doc htmlman/* 
%{_mandir}/man3/*

%files sources -f cmt+cmti.list
%{_prefix}/src/%{name}

%files compiler-libs
%dir %{_libdir}/ocaml/compiler-libs
%{_libdir}/ocaml/compiler-libs/META
%{_libdir}/ocaml/compiler-libs/*.cmi
%{_libdir}/ocaml/compiler-libs/*.cmo
%{_libdir}/ocaml/compiler-libs/*.cma
%if %{native_compiler}
%{_libdir}/ocaml/compiler-libs/*.a
%{_libdir}/ocaml/compiler-libs/*.cmxa
%{_libdir}/ocaml/compiler-libs/*.cmx
%{_libdir}/ocaml/compiler-libs/*.o
%endif

%files rpm-macros
%{_rpmmacrodir}/macros.ocaml-rpm
%{_rpmconfigdir}/redhat/ocaml_files.py
