Summary: Full featured Web server written in Ocaml
Name:    ocsigenserver
Version: 2.2.0
Release: %mkrel 7
Source0: https://ocsigen.org/download/%{name}-%{version}.tar.gz
Source1: %{name}.init
Source2: %{name}.sysconfig
Source3: %{name}.service
Patch0:  ocsigenserver-2.2.0-opam-use_netstring-pcre.patch
Patch1:  ocsigenserver-2.2.0-mageia-fix-META.patch
Patch2:  use-html5.diff
License: LGPLv2+
Group:   System/Servers
Url:     https://ocsigen.org/ocsigenserver/

BuildRequires: ocaml
BuildRequires: camlp4
BuildRequires: ocaml-findlib
BuildRequires: ocaml-pcre-devel
BuildRequires: ocaml-ssl-devel
BuildRequires: ocaml-ocamlnet-devel
BuildRequires: ocaml-cryptokit-devel
BuildRequires: ocaml-calendar-devel
BuildRequires: ocaml-sqlite3-devel
BuildRequires: ocaml-text-devel
BuildRequires: ocaml-react-devel
BuildRequires: ocaml-camlzip-devel
BuildRequires: ocaml-lwt-devel
BuildRequires: ocaml-tyxml-devel
BuildRequires: ocaml-camldbm-devel
BuildRequires: pkgconfig(libev)
BuildRequires: gdbm-devel
Requires: ocaml-ocsigenserver = %{version}-%{release}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

# Not sure if it should provide that ...
# Provides: webserver


%description
Ocsigen Server is a full featured Web server. It implements most features
of the HTTP protocol, and has a very powerful extension mechanism that make
very easy to plug your own OCaml modules for generating pages. Many
extensions are already written, like a reverse proxy, content compression,
access control, authentication, etc.

%package -n ocaml-%{name}
Summary: Runtime and development files for the Ocsigen server
Group:   Development/OCaml
Requires: ocaml-lwt
Requires: ocaml-ocamlnet
Requires: ocaml-cryptokit
Requires: ocaml-tyxml
Requires: ocaml-sqlite3
Requires: ocaml-camlzip
Requires: ocaml-react
Requires: ocaml-pcre

%description -n ocaml-%{name} 
The ocaml-%{name} package contains the bytecode libraries and signature
files for running applications that use %{name}.


%package -n ocaml-%{name}-devel
Summary: Development files for the Ocsigen server
Group:   Development/OCaml
Requires: ocaml-%{name} = %{version}-%{release}
Requires: ocaml-lwt-devel
Requires: ocaml-ocamlnet-devel
Requires: ocaml-cryptokit-devel
Requires: ocaml-tyxml-devel
Requires: ocaml-sqlite3-devel
Requires: ocaml-camlzip-devel
Requires: ocaml-react-devel
Requires: ocaml-pcre-devel

%description -n ocaml-%{name}-devel
The ocaml-%{name}-devel package contains the headers and native code
libraries to develop applications that use %{name}.


%package doc
Summary: Documentation for the Ocsigen web server
Group: Documentation
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description doc
Documentation for the Ocsigen web server.


%define unixuser $(USER)
%define unixgroup $(USER)
%define webroot %{_var}/www/ocsigenserver


%prep 
%setup -q
%autopatch -p1

%build
export C_INCLUDE_PATH=/usr/include/libev
sh configure \
   --enable-natdynlink \
   --with-sqlite \
   --with-dbm \
   --with-camlzip \
   --prefix %{_prefix} \
   --bindir %{_bindir} \
   --mandir %{_mandir}/man1 \
   --docdir %{_docdir} \
   --staticpagesdir %{webroot} \
   --datadir %{_localstatedir}/lib/%{name} \
   --sysconfdir %{_sysconfdir}/%{name} \
   --ocsigen-user ocsigen \
   --ocsigen-group ocsigen

make
make doc

%install
%make_install TEMPROOT=%{buildroot}

mkdir -p %{buildroot}%{_logdir}/ocsigenserver

install -D -m 755 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service

mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/%{name} <<EOF
%{_logdir}/%{name}/*.log {
    size=20M
    rotate 5
    weekly
    missingok
    notifempty
    postrotate
        service %{name} reload
    endscript
}
EOF

mkdir -p %{buildroot}%{webroot}/html

mkdir -p %{buildroot}%{_sysconfdir}/init.d/
cp %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/
cp %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

mkdir -p %{buildroot}%{_sysconfdir}/%{name}/conf.d/

# Opening port 8080 by default
#sed -i 's|80|8080|g' %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

# Removing fifo
%{__rm} -f %{buildroot}%{_localstatedir}/run/ocsigen_command

%pre
%_pre_useradd ocsigen %{_localstatedir}/lib/%{name} /bin/bash

%post 
%_post_service %{name}

%preun 
%_preun_service %{name}

%postun 
%_postun_userdel ocsigen

%files
%{_bindir}/ocsigenserver
%{_bindir}/ocsigenserver.opt
%attr(0755,root,root) %{_sysconfdir}/init.d/ocsigenserver.init
%attr(0600,root,root) %{_sysconfdir}/sysconfig/ocsigenserver
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%dir %{_sysconfdir}/%{name}/conf.d/
%{_sysconfdir}/%{name}/%{name}.conf.sample
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/mime.types
%{_unitdir}/%{name}.service
%{_mandir}/man1/*
%dir %{_sysconfdir}/%{name}/
%attr(0750,ocsigen,ocsigen) %dir %{_localstatedir}/lib/ocsigenserver
%attr(0750,ocsigen,ocsigen) %dir %{_localstatedir}/log/ocsigenserver
%attr(0750,ocsigen,ocsigen) %dir %{webroot}
%config(noreplace) %{webroot}/index.html
%attr(0750,ocsigen,ocsigen) %dir %{webroot}/ocsigenstuff
%{webroot}/ocsigenstuff/*.png
%{webroot}/ocsigenstuff/*.css

%files -n ocaml-%{name}
%dir %{_libdir}/ocaml/%{name}
%dir %{_libdir}/ocaml/%{name}/extensions
%{_libdir}/ocaml/%{name}/META
%{_libdir}/ocaml/%{name}/*.cma
%{_libdir}/ocaml/%{name}/*.cmi
%{_libdir}/ocaml/%{name}/*.cmo
%{_libdir}/ocaml/%{name}/*.cmxs
%{_libdir}/ocaml/%{name}/extensions/*.cma
%{_libdir}/ocaml/%{name}/extensions/*.cmi
%{_libdir}/ocaml/%{name}/extensions/*.cmo
%{_libdir}/ocaml/%{name}/extensions/*.cmxs
%{_libdir}/ocaml/%{name}/extensions/ocsidbm
%{_libdir}/ocaml/%{name}/extensions/ocsidbm.opt

%files -n ocaml-%{name}-devel
%{_libdir}/ocaml/%{name}/*.a
%{_libdir}/ocaml/%{name}/*.o
%{_libdir}/ocaml/%{name}/*.mli
%{_libdir}/ocaml/%{name}/*.cmx
%{_libdir}/ocaml/%{name}/*.cmxa
%{_libdir}/ocaml/%{name}/extensions/*.a
%{_libdir}/ocaml/%{name}/extensions/*.o
%{_libdir}/ocaml/%{name}/extensions/*.mli
%{_libdir}/ocaml/%{name}/extensions/*.cmx
%{_libdir}/ocaml/%{name}/extensions/*.cmxa

%files doc
%doc LICENSE README CHANGES doc/api-html doc/manual-wiki
