%define	oname OGRE-Next

%define	soname %(echo %{version} | cut -d. -f1,2)
%define	libname %mklibname ogre%{?with_newname:next} %{soname}
%define	develname %mklibname ogre%{?with_newname:next} -d

%global toolchain clang

%bcond_without newname

Summary:	OGRE-Next aka ogre v2 - scene-oriented, flexible 3D C++ engine
Name:		ogre-next
Version:	3.0.0
Release:	%mkrel 1
License:	MIT
Group:		System/Libraries
URL:		https://www.ogre3d.org/
Source0:	https://github.com/OGRECave/ogre-next/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:		ogre-next-linker-flags.patch
BuildRequires:	boost-devel
%if "%{toolchain}" == "clang"
BuildRequires:  clang
BuildRequires:  lld
%endif
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	freeimage-devel
BuildRequires:	libatomic-devel
BuildRequires:	ninja
BuildRequires:	rapidjson
BuildRequires:	swig
BuildRequires:	pkgconfig(assimp)
BuildRequires:	pkgconfig(cppunit)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(OIS)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(tinyxml)
BuildRequires:	pkgconfig(vulkan)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xt)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(zziplib)

%description
Ogre-Next is a 3D graphics rendering engine. Not to be confused with a game
engine which provides Networking, Sound, Physics, etc.

Ogre-Next 3.0 has had a substantial overhaul to focus on high performance
graphics using Data Oriented Design with:
- Cache friendly Entity and Node layout
- Threaded batch processing of Nodes, Frustum Culling and other techniques
  such as Forward Clustered
- SIMD processing using AoSoA (Array of Structures of Arrays) memory layout
- Texture loaded via background streaming

This makes Ogre-Next suitable for projects aiming to have a large number of
objects on screen, or have tight rendering budgets such as VR.


%package -n %{libname}
Summary:	Libraries needed for programs using %{oname}
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n %{libname}
Ogre-Next is a 3D graphics rendering engine. Not to be confused with a game
engine which provides Networking, Sound, Physics, etc.

Ogre-Next 3.0 has had a substantial overhaul to focus on high performance
graphics using Data Oriented Design with:
- Cache friendly Entity and Node layout
- Threaded batch processing of Nodes, Frustum Culling and other techniques
  such as Forward Clustered
- SIMD processing using AoSoA (Array of Structures of Arrays) memory layout
- Texture loaded via background streaming

This makes Ogre-Next suitable for projects aiming to have a large number of
objects on screen, or have tight rendering budgets such as VR.

%package -n %{develname}
Summary:	Development headers and libraries for writing programs using %{oname}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel%{?_isa} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development headers and libraries for writing programs using %{oname}.

%prep
%autosetup -p1

%build
%cmake -GNinja \
    -DCMAKE_SKIP_RPATH=ON \
    -DOGRE_USE_NEW_PROJECT_NAME=%{?with_newname:ON}%{!?with_newname:OFF} \
%ifarch %{arm32} %{arm64}
    -DOGRE_SIMD_SSE2=OFF \
    -DOGRE_SIMD_NEON=OFF \
%endif
    -DOGRE_BUILD_COMPONENT_PLANAR_REFLECTIONS=ON \
    -DOGRE_BUILD_DOCS=OFF \
    -DOGRE_BUILD_RENDERSYSTEM_GL=ON \
    -DOGRE_BUILD_RENDERSYSTEM_GL3PLUS=ON \
    -DOGRE_BUILD_RENDERSYSTEM_GLES2=ON \
    -DOGRE_BUILD_SAMPLES=OFF \
    -DOGRE_BUILD_TESTS=OFF \
    -DOGRE_BUILD_TOOLS=ON \
    -DOGRE_INSTALL_DOCS=OFF \
    -DOGRE_INSTALL_SAMPLES=OFF \
    -DOGRE_INSTALL_TOOLS=ON \
    -DOGRE_STATIC=OFF \
    -DOGRE_NODELESS_POSITIONING=ON
%cmake_build

%install
%cmake_install

%files
%{_bindir}/OgreCmgenToCubemap
%{_bindir}/OgreMeshTool

%files -n %{libname}
%{_libdir}/libOgre%{?with_newname:Next}*.so.%{soname}
%dir %{_libdir}/OGRE%{?with_newname:-Next}/
%{_libdir}/OGRE%{?with_newname:-Next}/*.so.%{soname}

%files -n %{develname}
%{_libdir}/libOgre%{?with_newname:Next}*.so
%{_libdir}/pkgconfig/OGRE%{?with_newname:-Next}*.pc
%{_libdir}/OGRE%{?with_newname:-Next}/*.so
%{_libdir}/OGRE%{?with_newname:-Next}/cmake/
%{_includedir}/OGRE%{?with_newname:-Next}/
