%define	oname OGRE
%define	imguiver 1.91.5

%define	soname %(echo %{version} | cut -d. -f1,2)
%define	libname %mklibname %{name} %{soname}
%define	develname %mklibname %{name} -d

Summary:	Object-Oriented Graphics Rendering Engine
Name:		ogre
Version:	14.3.1
Release:	%mkrel 3
License:	MIT
Group:		System/Libraries
URL:		https://www.ogre3d.org/
Source0:	https://github.com/OGRECave/ogre/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/ocornut/imgui/archive/v%{imguiver}.tar.gz
Patch0:		ogre-14.3.1-mga-swig.patch
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	freeimage-devel
BuildRequires:	libatomic-devel
BuildRequires:	ninja
BuildRequires:	swig
BuildRequires:	pkgconfig(assimp)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(OIS)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(tinyxml)
BuildRequires:	pkgconfig(vulkan)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xt)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(zziplib)

Provides:	bundled(imgui) = %{imguiver}

%description
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented,
flexible 3D engine written in C++ designed to make it easier  and  more
intuitive for developers to produce games and demos utilising 3D hardware.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

%package -n %{libname}
Summary:	Libraries needed for programs using %{oname}
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n %{libname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented,
flexible 3D engine written in C++ designed to make it easier  and  more
intuitive for developers to produce games and demos utilising 3D hardware.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

%package -n %{develname}
Summary:	Development headers and libraries for writing programs using %{oname}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Conflicts:	%{_lib}ogre1.10-devel < 1.11

%description -n %{develname}
Development headers and libraries for writing programs using %{oname}.

%prep
%autosetup -p1 -a1

# Fix location
sed -i -e 's,/dist-packages/,/site-packages/,g' Components/Python/CMakeLists.txt

%build
%cmake -GNinja \
    -DCMAKE_SKIP_RPATH=ON \
    -DIMGUI_DIR="$(pwd)/imgui-%{imguiver}" \
    -DOGRE_CMAKE_DIR="%{_libdir}/cmake/OGRE" \
    -DOGRE_BUILD_DOCS=OFF \
    -DOGRE_BUILD_RENDERSYSTEM_GL=ON \
    -DOGRE_BUILD_RENDERSYSTEM_GL3PLUS=ON \
    -DOGRE_BUILD_RENDERSYSTEM_GLES2=ON \
    -DOGRE_BUILD_SAMPLES=OFF \
    -DOGRE_BUILD_TESTS=OFF \
    -DOGRE_BUILD_TOOLS=ON \
    -DOGRE_INSTALL_DOCS=OFF \
    -DOGRE_INSTALL_SAMPLES=OFF \
    -DOGRE_INSTALL_TOOLS=ON \
    -DOGRE_STATIC=OFF \
    -DOGRE_NODELESS_POSITIONING=ON
%cmake_build

%install
%cmake_install
# Move these to a better location if we need them
test -e "%{buildroot}%{_prefix}/lib/cli/ogre-sharp-%{version}/" && rm -r "%{buildroot}%{_prefix}/lib/cli/ogre-sharp-%{version}/"

%files
%{_bindir}/OgreAssimpConverter
%{_bindir}/OgreMeshUpgrader
%{_bindir}/OgreXMLConverter
%{_bindir}/VRMLConverter
%{_datadir}/%{oname}-%{soname}/
%{python3_sitelib}/Ogre/

%files -n %{libname}
%{_libdir}/libOgre*.so.%{soname}
%dir %{_libdir}/%{oname}/
%{_libdir}/%{oname}/*.so.%{soname}

%files -n %{develname}
%{_libdir}/libOgre*.so
%{_libdir}/pkgconfig/%{oname}*.pc
%{_libdir}/%{oname}/*.so
%{_libdir}/cmake/%{oname}/
%{_includedir}/%{oname}/
