%define module_name dkms-open-iscsi

%define with_dkms 0

%define libiscsi_major     0
%define libiscsi_libname   %mklibname openiscsiusr %{libiscsi_major}
# We have two libiscsi libs with different APIs and versions, so keep
# the somajor in the devel package name
%define libiscsi_develname %mklibname iscsi %{libiscsi_major} -d

Name:           open-iscsi
Version:        2.1.10
Release:        %mkrel 1
Summary:        An implementation of RFC3720 iSCSI
License:        GPL-2.0
Group:          Networking/Other
URL:            https://github.com/open-iscsi/open-iscsi
Source0:        https://github.com/open-iscsi/open-iscsi/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        open-iscsi.service

#
# Mageia patches
#

BuildRequires:  meson
BuildRequires:  bison
BuildRequires:  db-devel
BuildRequires:  doxygen
BuildRequires:  flex
BuildRequires:  glibc-static-devel
BuildRequires:  pkgconfig(libisns)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libkmod)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(mount)

Provides:       iscsi-initiator-utils

%description
Open-iSCSI project is a high-performance, transport independent, multi-platform
implementation of RFC3720 iSCSI. iSCSI is a protocol for distributed disk
access using SCSI commands sent over Internet Protocol networks.

%if %{with_dkms}
%package -n %{module_name}
Summary:        open-iscsi initiator kernel module
Group:          Networking/Other
Requires:       kernel-source
Requires(preun): dkms
Requires(post):  dkms

%description -n %{module_name}
This package contains the open-iscsi initiator kernel module.
%endif

%package -n %{libiscsi_libname}
Summary:        Libraries for libiscsi
Group:          System/Libraries

%description -n %{libiscsi_libname}
This package contains the shared libiscsi library.

%package -n %{libiscsi_develname}
Summary:        Development libraries, header files for libiscsi
Group:          Development/C
Requires:       %{libiscsi_libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       iscsi-initiator-utils-devel = %{version}-%{release}
Provides:       iscsi-devel = %{version}-%{release}

%description -n %{libiscsi_develname}
This package contains libraries and header files for developing applications
that use libiscsi.

%prep
%autosetup -p1

%build
%meson -Drulesdir=%{_udevrulesdir}
%meson_build

%install
%meson_install

mkdir -p -m 0700 %{buildroot}%{_localstatedir}/lib/open-iscsi
mkdir -p -m 0755 %{buildroot}%{_sysconfdir}/iscsi/nodes
mkdir -p -m 0755 %{buildroot}%{_sysconfdir}/iscsi/send_targets

install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/open-iscsi.service


# DKMS
%if %{with_dkms}
mkdir -p %{buildroot}/usr/src/%{module_name}-%{version}
cp -a kernel %{buildroot}/usr/src/%{module_name}-%{version}/
cp -a include %{buildroot}/usr/src/%{module_name}-%{version}/

cat > %{buildroot}/usr/src/%{module_name}-%{version}/dkms.conf <<EOF
PACKAGE_VERSION="%{version}"
PACKAGE_NAME="%{module_name}"
MAKE[0]="cd \${dkms_tree}/\${PACKAGE_NAME}/\${PACKAGE_VERSION}/build/kernel ; make"
CLEAN="cd \${dkms_tree}/\${PACKAGE_NAME}/\${PACKAGE_VERSION}/build/kernel ; make clean"

BUILT_MODULE_NAME[0]="iscsi_tcp"
BUILT_MODULE_LOCATION[0]="kernel"
DEST_MODULE_NAME[0]="iscsi_tcp"
DEST_MODULE_LOCATION[0]="/kernel/drivers/scsi"

BUILT_MODULE_NAME[1]="scsi_transport_iscsi"
BUILT_MODULE_LOCATION[1]="kernel"
DEST_MODULE_NAME[1]="scsi_transport_iscsi"
DEST_MODULE_LOCATION[1]="/kernel/drivers/scsi"

REMAKE_INITRD="no"
AUTOINSTALL=yes
POST_INSTALL="post-install"
POST_REMOVE="post-remove"
EOF
%endif

%post
echo "InitiatorName=`/usr/sbin/iscsi-iname`" > %{_sysconfdir}/iscsi/initiatorname.iscsi
%_post_service open-iscsi

%if %{with_dkms}
%post -n %{module_name}
dkms add -m %{module_name} -v %{version} --rpm_safe_upgrade
dkms build -m %{module_name} -v %{version} --rpm_safe_upgrade
dkms install -m %{module_name} -v %{version} --rpm_safe_upgrade
%endif

%preun
%_preun_service open-iscsi

%if %{with_dkms}
%preun -n %{module_name}
dkms remove -m %{module_name} -v %{version} --rpm_safe_upgrade --all || :
%endif

%files
%doc README
%license COPYING
%dir %{_sysconfdir}/iscsi
%dir %{_sysconfdir}/iscsi/nodes
%dir %{_sysconfdir}/iscsi/send_targets
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/iscsi/iscsid.conf
%config(noreplace) %{_sysconfdir}/iscsi/initiatorname.iscsi
%{_sysconfdir}/logrotate.d/iscsiuiolog
%{_udevrulesdir}/50-iscsi-firmware-login.rules
%{_unitdir}/open-iscsi.service
%{_unitdir}/iscsi-init.service
%{_unitdir}/iscsi.service
%{_unitdir}/iscsid.service
%{_unitdir}/iscsid.socket
%{_unitdir}/iscsiuio.service
%{_unitdir}/iscsiuio.socket
%{_systemdgeneratordir}/ibft-rule-generator
%_sbindir/iscsiadm
%_sbindir/iscsid
%_sbindir/iscsi-iname
%_sbindir/iscsistart
%_sbindir/iscsiuio
%_sbindir/brcm_iscsiuio
%_sbindir/iscsi-gen-initiatorname
%_sbindir/iscsi_discovery
%_sbindir/iscsi_fw_login
%_sbindir/iscsi_offload
%{_mandir}/man8/iscsiadm.8*
%{_mandir}/man8/iscsid.8*
%{_mandir}/man8/iscsi_discovery.8*
%{_mandir}/man8/iscsi-iname.8*
%{_mandir}/man8/iscsi_fw_login.8*
%{_mandir}/man8/iscsistart.8*
%{_mandir}/man8/iscsiuio.8*
%{_mandir}/man8/iscsi-gen-initiatorname.8*
%{_localstatedir}/lib/iscsi/ifaces/iface.example
%dir %{_localstatedir}/lib/iscsi
%dir %{_localstatedir}/lib/iscsi/ifaces
%dir %{_localstatedir}/lib/open-iscsi

%if %{with_dkms}
%files -n %{module_name}
%_usrsrc/%{module_name}-%{version}
%endif

%files -n %{libiscsi_libname}
%license COPYING
%{_libdir}/libopeniscsiusr.so.%{libiscsi_major}{,.*}

%files -n %{libiscsi_develname}
%_includedir/libopeniscsiusr.h
%_includedir/libopeniscsiusr_common.h
%_includedir/libopeniscsiusr_iface.h
%_includedir/libopeniscsiusr_node.h
%_includedir/libopeniscsiusr_session.h
%_libdir/pkgconfig/libopeniscsiusr.pc
%{_libdir}/libopeniscsiusr.so
%{_mandir}/man3/*.3*
