%define title     Openbox

%define rendermajor 32
%define libobrender %mklibname obrender %rendermajor
%define obtmajor    2
%define libobt      %mklibname obt %obtmajor
%define develname   %mklibname %name -d

Summary:          Windowmanager based on the original blackbox-code
Name:             openbox
Version:          3.6.1
Release:          %mkrel 17
Group:            Graphical desktop/Other
License:          BSD
URL:              https://openbox.org/
Source0:          https://openbox.org/dist/openbox/%name-%version.tar.gz
# oxygen-theme here:
# https://box-look.org/content/show.php?content=145240
Source1:          https://box-look.org/CONTENT/content-files/145240-Oxynew.obt
# generate xdg menus
Source2:          xdg-menu-openbox
# mga default menu
Source3:          menu.xml
# run gnome-screenshot when hitting printscreen
Patch0:           01_rc.xml.dpatch
Patch1:           openbox-3.5.2-unused-libs.patch
Patch2:           openbox-default-theme.patch
Patch3:           openbox-3.6.1-upstream-patches.patch
Patch4:           openbox-3.6.1-xscreensaver-kbdbinding.patch
Patch5:           openbox-python3.patch
# The patch is proposed on https://bugzilla.icculus.org/show_bug.cgi?id=6669
# and commited to a work branch in the upstream repo
Patch6:           openbox-3.6.1-glib-2.76.patch

BuildRequires:  pkgconfig(glib-2.0) >= 2.14.0
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libstartup-notification-1.0) >= 0.8
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.0
BuildRequires:  pkgconfig(pango) >= 1.8.0
BuildRequires:  pkgconfig(pangoxft) >= 1.8.0
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xft)
BuildRequires:  gettext-devel
Requires:       xsetroot
Requires:       python3-pyxdg
Recommends:     xscreensaver
Recommends:     xrandr
# use a virtual require to allow choose between obconf and obconf-qt (see mga#32460)
Recommends:     obox-conf
Recommends:     picom
Recommends:     picom-conf
# for PrintScreen
Recommends:     screengrab
Conflicts:      desktop-common-data < 1:3.10-2

%description
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%package -n %libobt
Summary: Libraries from openbox
Group: System/Libraries

%description -n %libobt
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%package -n %libobrender
Summary: Libraries from openbox
Group: System/Libraries

%description -n %libobrender
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%package -n %develname
Summary: Development files from openbox
Group: Development/Other
Requires: %libobt = %version-%release
Requires: %libobrender = %version-%release
Provides: %name-devel = %version-%release

%description -n %develname
Openbox is a window manager for the X11 windowing system.
It currently runs on a large list of platforms. It was originally
based on blackbox and currently remains very similar, even using
blackbox styles (with available extensions) for its themeing.

%prep
%setup -q -a1
%patch -P 0 -p0
%patch -P 1 -p1
%patch -P 2 -p0
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
sed -i "s|tless -->|tless -->\n<!-- Insert dynamic xdg menu -->\n<file>xdg-menu.xml</file>|g" data/rc.xml 

%build
autoreconf -fi
%configure --disable-static
%make_build DEFAULT_MENU=%{_sysconfdir}/xdg/openbox/menu.xml

%install
%make_install

mkdir -p %{buildroot}%{_datadir}/themes/oxygen/openbox-3/
install -m 0644 Oxynew/openbox-3/*.xbm Oxynew/openbox-3/themerc  %{buildroot}%{_datadir}/themes/oxygen/openbox-3/
install -Dpm 0755 %{SOURCE2} %{buildroot}%{_sysconfdir}/menu.d/openbox
install -Dpm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/xdg/openbox/menu.xml

mkdir -p %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/start%{name} <<EOF
#!/bin/sh
%{_bindir}/xsetroot -solid Black
exec %{_bindir}/openbox-session
EOF
chmod 0755 %{buildroot}%{_bindir}/start%{name}

%find_lang %name

find %{buildroot} -name *.la -delete
# drop xsession files per bug#3653
rm -fr %{buildroot}%{_datadir}/xsessions

# session file
mkdir -p %{buildroot}%{_datadir}/xsessions
cat > %{buildroot}%{_datadir}/xsessions/%{name}.desktop << EOF
[Desktop Entry]
Encoding=UTF-8
Name=Openbox
Comment=Openbox
Exec=%{_bindir}/startopenbox
Icon=openbox
Type=Application
EOF

%posttrans
# (ovitters) In posttrans, $1 is always equal to 1, even in the upgrade case.
# So just run this always:
if [ -e %{_datadir}/xsessions/26Openbox.desktop ]; then
  rm -rf %{_datadir}/xsessions/26Openbox.desktop
fi
if [ -e %{_sysconfdir}/X11/dm/Sessions/26Openbox.desktop ]; then
  rm -rf %{_sysconfdir}/X11/dm/Sessions/26Openbox.desktop
fi

%files -f %name.lang
%doc AUTHORS CHANGELOG COMPLIANCE COPYING README
%doc data/*.xsd doc/*.xml
%{_docdir}/%{name}/xbm/
%{_bindir}/*
%dir %{_sysconfdir}/xdg/%{name}
%{_sysconfdir}/menu.d/%{name}
%config(noreplace) %{_sysconfdir}/xdg/%{name}/*
%ghost %config(noreplace) %{_sysconfdir}/xdg/%{name}/xdg-menu.xml
%{_libexecdir}/openbox-autostart
%{_libexecdir}/openbox-xdg-autostart
%{_datadir}/man/man1/*
%{_datadir}/gnome-session/sessions/openbox-*.session
%{_datadir}/gnome/wm-properties/openbox.desktop
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*
%{_datadir}/themes/*
%{_datadir}/xsessions/%{name}.desktop

%files -n %libobt
%{_libdir}/libobt.so.%{obtmajor}{,.*}

%files -n %libobrender
%{_libdir}/libobrender.so.%{rendermajor}{,.*}

%files -n %develname
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_includedir}/%{name}/
