%define name openca-ocspd
%define version 2.1.0
%define release %mkrel 1

%define __libtoolize /bin/true

%define confdir %{_sysconfdir}/pki/ocspd

Summary:	OpenCA OCSP Daemon
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	ASL 1.0-like
Group:		System/Servers
URL:		https://www.openca.org/projects/ocspd/
Source0:	%{name}-%{version}.tar.gz
Source1:	ocspd.init
Source2:	sample_ca.sh
Source3:	sample_ca.cnf
Source4:	ocspproxy.fcgi
Patch0:		%{name}-2.1.0-format_strings.patch
Patch1:		%{name}-2.1.0-error_reporting.patch
BuildRequires:	libpki-devel
BuildRequires:	perl
Requires(post):	openssl
Recommends:	%{name}-samples
Recommends:	%{name}-web

%description
ocspd is an RFC2560-compliant OCSP responder.  The purpose of such a
server is to provide an on-line tool to verify the status of a
certificate.

This product includes software developed by Massimiliano Pala and the
OpenCA Labs for use in the OpenCA project (https://www.openca.org/).

%package -n %{name}-samples
Summary:	Sample configuration for the OpenCA OCSP Daemon
Group:		System/Servers
Requires:	openssl
Requires(post):	openssl
Requires:	%{name} = %{version}

%description -n %{name}-samples
This package contains a sample CA complete with a set of certificates
(one of which is revoked), a CRL, an OCSP responder certificate and
private key, and the necessary configuration files for ocspd.

The sample certificates can be queried using the OpenSSL tools:

  openssl ocsp -issuer %{confdir}/sample_ca/sample_ca.crt \
               -cert %{confdir}/sample_ca/www.crt \
               -url http://localhost:2560

%package -n %{name}-web
Summary:	Web gateway for the OpenCA OCSP Daemon
Group:		System/Servers
Requires:	apache >= 2.2.18
Requires:	apache-mod_fcgid
Requires:	perl(CGI::Fast)
Requires:	perl(URI::Escape)
Requires:	perl(MIME::Base64)
Requires:	perl(LWP::UserAgent)
Requires:	%{name} = %{version}

%description -n %{name}-web
This package provides a small FastCGI proxy that allows the OpenCA
OCSP responder to be accessed via the standard web server port (80),
rather than the custom OCSP port (2560).  This is useful since many
clients may only be able to connect to the standard port.

The proxy also adds support for HTTP GET requests, as required by
RFC2560.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
cp %{SOURCE1} .
cp %{SOURCE2} .
cp %{SOURCE3} .
cp %{SOURCE4} .

%build
%serverbuild
%configure --disable-semaphores --enable-flock \
	   --with-libpki-prefix=%{_prefix} \
	   --with-ocspd-user=ocspd --with-ocspd-group=ocspd \
	   --with-openca-prefix=%{_datadir}/openca
%make

%install
rm -rf %{buildroot}
%makeinstall pkgconfigdir=%{buildroot}%{_libdir}/pkgconfig
# Remove unwanted files
rm %{buildroot}%{_bindir}/{ocspd-genreq.sh,test.sh}
rm %{buildroot}%{_exec_prefix}/etc/ocspd/ca.d/*.xml
# Fix directory locations
mkdir -p %{buildroot}%{confdir}
rm %{buildroot}%{_exec_prefix}/etc/init.d/ocspd
rmdir %{buildroot}%{_exec_prefix}/etc/init.d
mv %{buildroot}%{_exec_prefix}/etc/ocspd/pki/* %{buildroot}%{confdir}/
rmdir %{buildroot}%{_exec_prefix}/etc/ocspd/pki
mv %{buildroot}%{_exec_prefix}/etc/ocspd/* %{buildroot}%{confdir}/
rmdir %{buildroot}%{_exec_prefix}/etc/ocspd
rmdir %{buildroot}%{_exec_prefix}/etc

# Create pidfile directory
install -d %{buildroot}%{_localstatedir}/run/ocspd

# Create certificate directories
mkdir -p %{buildroot}%{confdir}/{certs,crls,private}

# Install sample CA files
mkdir -p %{buildroot}%{confdir}/sample_ca
install -m0644 sample_ca.cnf %{buildroot}%{confdir}/sample_ca.cnf
install -m0755 sample_ca.sh %{buildroot}%{confdir}/sample_ca.sh

# Install init script
mkdir -p %{buildroot}%{_initrddir}
install -m0755 ocspd.init %{buildroot}%{_initrddir}/ocspd
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
cat > ocspd.sysconfig << EOF
# Put options here
OCSPD_OPTIONS=""
EOF
install -m0644 ocspd.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/ocspd
export DONT_GPRINTIFY=1

# Patch configuration file
perl -pi -e 's{/usr/etc/ocspd/pki}{%{confdir}};' \
	 -e 's{/usr/etc/ocspd/ca.d}{%{confdir}/ca.d};' \
	 -e 's{/usr/var/run/ocspd.pid}{%{_localstatedir}/run/ocspd/ocspd.pid};'\
	 -e 's{nobody}{ocspd};' \
	 -e 's{ocspServerToken}{defaultToken};' \
	 %{buildroot}%{confdir}/ocspd.xml

# Create default token XML file
cat > default_token.xml << EOF
<?xml version="1.0" ?>
<pki:tokenConfig xmlns:pki="http://www.openca.org/openca/pki/1/0/0">
  <pki:name>defaultToken</pki:name>
  <pki:type>software</pki:type>
  <pki:keypair>file://%{confdir}/private/default.key</pki:keypair>
  <pki:cert>file://%{confdir}/certs/default.crt</pki:cert>
  <pki:cacert>file://%{confdir}/certs/default.crt</pki:cacert>
  <pki:passin>none</pki:passin>
</pki:tokenConfig>
EOF
install -m0644 default_token.xml %{buildroot}%{confdir}/token.d/default.xml

# Create sample CA XML file
cat > sample_ca.xml << EOF
<?xml version="1.0" ?>
<pki:caConfig xmlns:pki="http://www.openca.org/openca/pki/1/0/0">
   <pki:name>Sample CA</pki:name>
   <pki:caCertUrl>file://%{confdir}/certs/sample_ca.crt</pki:caCertUrl>
   <pki:crlUrl>file://%{confdir}/crls/sample_ca.crl</pki:crlUrl>
   <pki:serverToken>sampleCaToken</pki:serverToken>
   <pki:caCompromised>no</pki:caCompromised>
</pki:caConfig>
EOF
install -m0644 sample_ca.xml %{buildroot}%{confdir}/ca.d/sample_ca.xml

# Create sample CA token XML file
cat > sample_ca_token.xml << EOF
<?xml version="1.0" ?>
<pki:tokenConfig xmlns:pki="http://www.openca.org/openca/pki/1/0/0">
  <pki:name>sampleCaToken</pki:name>
  <pki:type>software</pki:type>
  <pki:keypair>file://%{confdir}/private/sample_ocsp.key</pki:keypair>
  <pki:cert>file://%{confdir}/certs/sample_ocsp.crt</pki:cert>
  <pki:cacert>file://%{confdir}/certs/sample_ca.crt</pki:cacert>
  <pki:passin>none</pki:passin>
</pki:tokenConfig>
EOF
install -m0644 sample_ca_token.xml %{buildroot}%{confdir}/token.d/sample_ca.xml

# Install ocspproxy.fcgi
mkdir -p %{buildroot}%{_libdir}/%{name}/proxy
install -m0755 ocspproxy.fcgi %{buildroot}%{_libdir}/%{name}/proxy/

# Create Apache configuration file
mkdir -p %{buildroot}%{_webappconfdir}
cat > webapp-ocsp.conf << EOF
ScriptAlias /ocsp %{_libdir}/%{name}/proxy/ocspproxy.fcgi/
AllowEncodedSlashes NoDecode

<Directory %{_libdir}/%{name}/proxy>
    AllowOverride all
    Order allow,deny
    Allow from all
</Directory>
EOF
install -m0644 webapp-ocsp.conf %{buildroot}%{_webappconfdir}/ocsp.conf

# Create ghost files
touch %{buildroot}%{confdir}/private/default.key
touch %{buildroot}%{confdir}/certs/default.crt
touch %{buildroot}%{confdir}/sample_ca/sample_ca.{key,crt,crl,idx,srl,srl.old}
touch %{buildroot}%{confdir}/sample_ca/sample_ca.{idx.old,idx.attr,idx.attr.old}
mkdir -p %{buildroot}%{confdir}/sample_ca/signed
touch %{buildroot}%{confdir}/sample_ca/signed/{01,02,03,04,05}.pem
touch %{buildroot}%{confdir}/sample_ca/{www,ftp,mail,bad}.{key,req,crt}
touch %{buildroot}%{confdir}/sample_ca/sample_ocsp.{key,req,crt}
touch %{buildroot}%{confdir}/certs/sample_ca.crt
touch %{buildroot}%{confdir}/crls/sample_ca.crl
touch %{buildroot}%{confdir}/certs/sample_ocsp.crt
touch %{buildroot}%{confdir}/private/sample_ocsp.key

%pre
%_pre_useradd ocspd /dev/null /bin/false

%post
# Create default token
if [ ! -e %{confdir}/certs/default.crt ] ; then
    openssl req -x509 -newkey rsa:2048 -nodes -batch -days 10000 \
	-out %{confdir}/certs/default.crt \
	-keyout %{confdir}/private/default.key \
	-subj "/L=localhost/CN=ocsp-default.localhost.localdomain"
    chmod 640 %{confdir}/private/default.key
    chown root.ocspd %{confdir}/private/default.key
fi
%_post_service ocspd

%post -n %{name}-samples
# Create sample CA files
if [ ! -e %{confdir}/certs/sample_ocsp.crt ] ; then
    pushd %{confdir}
    ./sample_ca.sh
    chown root.ocspd sample_ca/*.key
    ln -s ../sample_ca/sample_ca.crt certs/sample_ca.crt
    ln -s ../sample_ca/sample_ca.crl crls/sample_ca.crl
    ln -s ../sample_ca/sample_ocsp.crt certs/sample_ocsp.crt
    ln -s ../sample_ca/sample_ocsp.key private/sample_ocsp.key
    popd
fi

%preun
%_preun_service ocspd

%postun
%_postun_userdel ocspd

%files
%doc AUTHORS COPYING ChangeLog README etc/ca.d/collegeca.xml
%{_sbindir}/ocspd
%{_initrddir}/ocspd
%config(noreplace) %{_sysconfdir}/sysconfig/ocspd
%dir %{confdir}
%dir %{confdir}/ca.d
%dir %{confdir}/token.d
%config(noreplace) %{confdir}/ocspd.xml
%config(noreplace) %{confdir}/token.d/default.xml
%config(noreplace) %{confdir}/token.d/software.xml
%config(noreplace) %{confdir}/token.d/eracom.xml
%config(noreplace) %{confdir}/token.d/etoken.xml
%dir %{confdir}/certs
%dir %{confdir}/crls
%dir %attr(0750,root,ocspd) %{confdir}/private
%ghost %attr(0640,root,ocspd) %{confdir}/private/default.key
%ghost %attr(0644,root,root) %{confdir}/certs/default.crt
%dir %attr(0755,ocspd,ocspd) %{_localstatedir}/run/ocspd
%{_mandir}/man*/ocspd*
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{name}-samples
%config(noreplace) %{confdir}/ca.d/sample_ca.xml
%config(noreplace) %{confdir}/token.d/sample_ca.xml
%config(noreplace) %{confdir}/sample_ca.cnf
%{confdir}/sample_ca.sh
%dir %{confdir}/sample_ca
%ghost %attr(0640,root,root)  %{confdir}/sample_ca/sample_ca.key
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.crt
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.crl
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.idx
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.idx.old
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.idx.attr
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.idx.attr.old
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.srl
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ca.srl.old
%ghost %attr(0755,root,root)  %dir %{confdir}/sample_ca/signed
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/signed/01.pem
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/signed/02.pem
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/signed/03.pem
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/signed/04.pem
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/signed/05.pem
%ghost %attr(0640,root,root)  %{confdir}/sample_ca/www.key
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/www.req
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/www.crt
%ghost %attr(0640,root,root)  %{confdir}/sample_ca/ftp.key
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/ftp.req
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/ftp.crt
%ghost %attr(0640,root,root)  %{confdir}/sample_ca/mail.key
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/mail.req
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/mail.crt
%ghost %attr(0640,root,root)  %{confdir}/sample_ca/bad.key
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/bad.req
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/bad.crt
%ghost %attr(0640,root,root)  %{confdir}/sample_ca/sample_ocsp.key
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ocsp.req
%ghost %attr(0644,root,root)  %{confdir}/sample_ca/sample_ocsp.crt
%ghost %attr(0644,root,root)  %{confdir}/certs/sample_ca.crt
%ghost %attr(0644,root,root)  %{confdir}/crls/sample_ca.crl
%ghost %attr(0644,root,root)  %{confdir}/certs/sample_ocsp.crt
%ghost %attr(0640,root,ocspd) %{confdir}/private/sample_ocsp.key

%files -n %{name}-web
%config(noreplace) %{_webappconfdir}/ocsp.conf
%{_libdir}/%{name}/proxy/ocspproxy.fcgi
