%define major	7
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

# based on opencascade 6.9.1
%define occtag	7_8_1
%define version	7.8.1

# tpaviot-oce version 0.18.3
%define ocegit	0.18.3

%define vtkver	9.3

# No openmpi on 32bits with openmpi 5 in Mageia 10+
%ifarch %{ix86} %{arm32}
%bcond_with openmpi
%else
%bcond_without openmpi
%endif

Name:		opencascade
Group:		Sciences/Physics
Version:	%{version}
Release:	%mkrel 5
Summary:	3D modeling & numerical simulation
License:	LGPLv2 with exceptions
URL:		https://github.com/tpaviot/oce
Source0:	https://github.com/Open-Cascade-SAS/OCCT/archive/V%{occtag}/%{name}-%{version}.tar.gz
Patch0:		0001-opencascade-cmake-2.8.1.patch
Patch1:		opencascade-externlib.patch
Patch2:		FixnamingconflictbetweenX11headersandVTK9.2.2.patch
# from gentoo
Patch10:	opencascade-7.7.0-tbb-detection.patch
# Upstream patches
Patch20:	0001-FreeType-Use-unsigned-point-and-contour-indexing.patch
BuildRequires:	pkgconfig(draco)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(ftgl)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(xi)
%if %{with openmpi}
BuildRequires:	python3dist(mpi4py)
%endif
BuildRequires:	vtk-devel
BuildRequires:	cmake(rapidjson)
BuildRequires:	cmake(Qt6)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Quick)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	cmake(Qt6Sql)
Requires:	ksh
Requires:	tcl
Requires:	tix
Requires:	tk

%description
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files
%doc LICENSE_LGPL_21.txt OCCT_LGPL_EXCEPTION.txt
%{_datadir}/%{name}
%{_bindir}/*.sh
%{_bindir}/DRAW*
%{_bindir}/ExpToCasExe*

#-----------------------------------------------------------------------

%package	-n %{libname}
Summary:	3D modeling & numerical simulation
Group:		System/Libraries

%description	-n %{libname}
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files		-n %{libname}
%{_libdir}/lib*.so.%{major}{,.*}

#-----------------------------------------------------------------------

%package	-n %{devname}
Summary:	3D modeling & numerical simulation
Group:		Development/Other
Requires:	%{libname} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}
Provides:	oce-devel = %{EVRD}

%description	-n %{devname}
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files		-n %{devname}
%{_libdir}/lib*.so
%{_includedir}/%{name}/
%{_libdir}/cmake/opencascade/

#-----------------------------------------------------------------------

%prep
%setup -qn OCCT-%{occtag}

%patch 0 -p1
%if %{with openmpi}
%patch 1 -p1
%endif
#patch 2 -p1
%patch 10 -p1

%patch 20 -p1

# Sources are marked executable for no good reason...
find ./src -type f -exec chmod -x {} \;

# Fix executable set on text files.
chmod 0644 *.txt

#-----------------------------------------------------------------------

%build
# opencascade does some manual install trickery that does not respect DESTDIR.
# Make DESTDIR and environment variable that can be passed into the CMake config.
# export DESTDIR="%%{buildroot}"

%cmake \
       -DCAN_USE_TBB=True -DUSE_TBB=True \
       -D3RDPARTY_TBB_DIR=%{_prefix} \
       -DINSTALL_DIR_LIB=%{_lib} \
       -DINSTALL_DIR_CMAKE=%{_lib}/cmake/%{name} \
       -DUSE_RAPIDJSON=ON \
       -DCAN_USE_DRACO=False -DUSE_DRACO=False \
       -D3RDPARTY_DRACO_LIBRARY=libdraco.so \
       -D3RDPARTY_DRACO_INCLUDE_DIR=%{_includedir}/draco \
       -DCAN_USE_VTK=True -DUSE_VTK=True \
       -D3RDPARTY_VTK_INCLUDE_DIR=%{_includedir}/vtk-%{vtkver}
%cmake_build


#-----------------------------------------------------------------------

%install
%cmake_install

# adjust environment/directories to avoid (too much) script patching
ln -sf %{_libdir} %{buildroot}%{_datadir}/%{name}/lib
ln -sf %{_includedir}/%{name} %{buildroot}%{_datadir}/%{name}/inc
ln -sf %{_datadir}/%{name} %{buildroot}%{_datadir}/%{name}/lin
ln -sf %{_datadir}/%{name} %{buildroot}%{_datadir}/%{name}/Linux
