%define		major		2.4
%define		libname		%mklibname opencolorio %{major}
%define		develname	%mklibname opencolorio -d

# WARNING: OpenColorIO and OpenImageIO are cross dependent.
# If an ABI incompatible update is done in one, the other also needs to be rebuilt.
%bcond_without	openimageio

%ifarch x86_64
%bcond_with check
%else
%bcond_with check
%endif

Name:		opencolorio
Version:	2.4.2
Release:	%mkrel 1
Summary:	A complete color management solution
Group:		System/Libraries
License:	BSD
URL:		https://opencolorio.org/
Source0:	https://github.com/AcademySoftwareFoundation/OpenColorIO/archive/v%{version}/OpenColorIO-%{version}.tar.gz
## Upstream patches:
#
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	boost-devel
BuildRequires:	pybind11-devel
BuildRequires:	cmake(pystring)
BuildRequires:	pkgconfig(Imath)
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(tinyxml)
BuildRequires:	pkgconfig(yaml-cpp)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(minizip-ng)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(markupsafe)
%if %{with openimageio}
BuildRequires:	pkgconfig(OpenImageIO)
BuildRequires:	openimageio
%endif

%description
OpenColorIO (OCIO) is a complete color management solution geared towards
motion picture production with an emphasis on visual effects and computer
animation. OCIO provides a straightforward and consistent user experience
across all supporting applications while allowing for sophisticated
back-end configuration options suitable for high-end production usage.
OCIO is compatible with the Academy Color Encoding Specification (ACES)
and is LUT-format agnostic, supporting many popular formats.

%package -n %{libname}
Summary:	A complete color management solution
Group:		System/Libraries

%description -n %{libname}
A complete color management solution.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for %{name} library.

%package -n python3-pyopencolorio
Summary:	Python 3 Bindings for %{name}
Group:		Development/Python

%description -n python3-pyopencolorio
This package contains python 3 bindings for %{name}.

%prep
%autosetup -n OpenColorIO-%{version} -p1

%build
%cmake  -GNinja \
	-DCMAKE_INSTALL_LIBDIR=%{_lib} \
	-DCMAKE_SKIP_INSTALL_RPATH=ON \
	-DOCIO_BUILD_APPS=%{?with_openimageio:ON}%{?!with_openimageio:OFF} \
	-DOCIO_BUILD_NUKE=OFF \
	-DOCIO_BUILD_PYTHON=ON \
	-DOCIO_BUILD_TESTS=%{?with_check:ON}%{?!with_check:OFF} \
	-DOCIO_BUILD_GPU_TESTS=OFF \
%ifnarch x86_64
	-DOCIO_USE_SIMD=OFF \
%endif
	-DOCIO_USE_GLVND=ON \
	-DOpenGL_GL_PREFERENCE=GLVND
%cmake_build

%install
%cmake_install

%if %{with check}
%check
%ctest
%endif

%files
%doc CHANGELOG.md README.md
%license LICENSE
%if %{with openimageio}
%{_bindir}/*
%endif
%{_datadir}/ocio/

%files -n %{libname}
%{_libdir}/libOpenColorIO.so.%{major}
%{_libdir}/libOpenColorIO.so.%{version}

%files -n %{develname}
%{_libdir}/libOpenColorIO.so
%{_libdir}/pkgconfig/OpenColorIO.pc
%{_libdir}/cmake/OpenColorIO/
%{_includedir}/OpenColorIO/
#
%if %{with openimageio}
%{_libdir}/libOpenColorIOimageioapphelpers.a
%{_libdir}/libOpenColorIOoglapphelpers.a
%endif

%files -n python3-pyopencolorio
%{python3_sitearch}/PyOpenColorIO/
