# p11-kit needs pkcsslotd daemon starting by default
# upstream does not recommend to enable the pkcsslotd service by default.
# we disable it
%define p11_kit_support	0

%define major		0
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Implementation of the PKCS#11 (Cryptoki) specification v3.0
Name:		opencryptoki
Version:	3.24.0
Release:	%mkrel 2
License:	CPL
Group:		System/Libraries
URL:		https://github.com/opencryptoki/
Source0:	https://github.com/opencryptoki/opencryptoki/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	opencryptoki.module
Source2:	%{name}-tmpfiles.conf
# https://bugzilla.redhat.com/show_bug.cgi?id=732756
Patch0:		opencryptoki-3.11.0-group.patch
Patch1:		opencryptoki-3.24.0-p11sak.patch
Patch2:		opencryptoki-3.24.0-compile-error-due-to-incompatible-pointer-types.patch
# upstream patches
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	systemd-units
BuildRequires:	trousers-devel
BuildRequires:	libitm-devel
BuildRequires:	pkgconfig(libcap)
Requires:	p11-kit
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper

%description
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package contains the Slot Daemon (pkcsslotd) and general utilities.

%package -n	%{libname}
Summary:	The run-time libraries for opencryptoki package
Group:		System/Libraries

%description -n	%{libname}
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package contains the PKCS#11 library implementation, and requires
at least one token implementation (packaged separately) to be fully
functional.

%package -n	%{develname}
Summary:	Development files for openCryptoki
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the development header files for building
opencryptoki and PKCS#11 based applications

%package	swtok
Summary:	The software token implementation for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	swtok
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package brings the software token implementation to use opencryptoki
without any specific cryptographic hardware.

%package	tpmtok
Summary:	Trusted Platform Module (TPM) device support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	tpmtok
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package brings the necessary libraries and files to support
Trusted Platform Module (TPM) devices in the opencryptoki stack.

%package	icsftok
Summary:	ICSF token support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	icsftok
Opencryptoki implements the PKCS#11 specification v2.20 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package brings the necessary libraries and files to support
ICSF token in the opencryptoki stack.

%prep
%autosetup -p1

%build
./bootstrap.sh

%configure \
    --sharedstatedir=/var/lib \
    --with-systemd=%{_unitdir} \
    --with-pkcsslotd-user=pkcs11 --with-pkcs-group=pkcs11 \
    --disable-icatok \
    --disable-ccatok \
    --disable-ep11tok \
    --disable-pkcsep11_migrate \
    --enable-pkcscca_migrate

%make_build CHGRP=/bin/true

%install

%make_install CHGRP=/bin/true

%if 0%{?p11_kit_support}
install -Dpm 644 %{SOURCE1} %{buildroot}%{_datadir}/p11-kit/modules/opencryptoki.module
%endif

# Remove unwanted cruft
find %{buildroot} -name '*.la' -delete

%pre
%_pre_useradd pkcs11 /dev/null /sbin/nologin

%post
%_tmpfilescreate %{name}
%_post_service pkcsslotd

%preun
%_preun_service pkcsslotd

%postun
%_postun_userdel pkcs11

%files
%doc ChangeLog FAQ README.md
%doc doc/opencryptoki-howto.md
%doc doc/README.token_data
%doc %{_docdir}/%{name}/*.conf
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%attr(0640, root, pkcs11) %config(noreplace) %{_sysconfdir}/%{name}/p11sak_defined_attrs.conf
%attr(0640, root, pkcs11) %config(noreplace) %{_sysconfdir}/%{name}/strength.conf
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/pkcsslotd.service
%{_sbindir}/pkcsconf
%{_sbindir}/pkcsslotd
%{_sbindir}/pkcsstats
%{_sbindir}/p11sak
%{_sbindir}/pkcstok_migrate
%{_sbindir}/pkcshsm_mk_change
%{_sbindir}/pkcstok_admin
%{_mandir}/man1/pkcsconf.1*
%{_mandir}/man1/p11sak.1*
%{_mandir}/man1/pkcsstats.1*
%{_mandir}/man1/pkcstok_migrate.1*
%{_mandir}/man1/pkcshsm_mk_change.1*
%{_mandir}/man1/pkcstok_admin.1*
%{_mandir}/man5/%{name}.conf.5*
%{_mandir}/man5/p11sak_defined_attrs.conf.5*
%{_mandir}/man5/policy.conf.5*
%{_mandir}/man5/strength.conf.5*
%{_mandir}/man7/%{name}.7*
%{_mandir}/man8/pkcsslotd.8*
%{_libdir}/opencryptoki/methods
%{_libdir}/pkcs11/methods
%dir %attr(770,root,pkcs11) %{_sharedstatedir}/%{name}
%dir %attr(770,root,pkcs11) %ghost %{_rundir}/lock/%{name}
%dir %attr(770,root,pkcs11) %ghost %{_rundir}/lock/%{name}/*
%if 0%{?p11_kit_support}
%{_datadir}/p11-kit/modules/opencryptoki.module
%endif

%files -n %{libname}
%doc LICENSE
%{_sysconfdir}/ld.so.conf.d/*
# Unversioned .so symlinks usually belong to -devel packages, but opencryptoki
# needs them in the main package, because:
#   pkcs11_startup looks for opencryptoki/stdll/*.so, and
#   documentation suggests that programs should dlopen "PKCS11_API.so".
%dir %{_libdir}/opencryptoki
%{_libdir}/opencryptoki/libopencryptoki.*
%{_libdir}/opencryptoki/PKCS11_API.so
%dir %{_libdir}/opencryptoki/stdll
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/libopencryptoki.so
%{_libdir}/pkcs11/PKCS11_API.so
%{_libdir}/pkcs11/stdll

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files swtok
%{_libdir}/opencryptoki/stdll/libpkcs11_sw.*
%{_libdir}/opencryptoki/stdll/PKCS11_SW.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/swtok/
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/swtok/TOK_OBJ/

%files tpmtok
%doc doc/README.tpm_stdll
%{_libdir}/opencryptoki/stdll/libpkcs11_tpm.*
%{_libdir}/opencryptoki/stdll/PKCS11_TPM.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/tpm/

%files icsftok
%doc doc/README.icsf_stdll
%{_sbindir}/pkcsicsf
%{_mandir}/man1/pkcsicsf.1*
%{_libdir}/opencryptoki/stdll/libpkcs11_icsf.*
%{_libdir}/opencryptoki/stdll/PKCS11_ICSF.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/icsf/
