%global major 410

%bcond_without contrib
%bcond_without internet
%bcond_with doc

# needs also 'bcond_without internet' to dl some stuff
%bcond_with nonfree
%bcond_with wechat_qrcode

%define build_cuda 0
%if "%distro_section" == "nonfree"
%define build_cuda 1
%endif

Name:           opencv
Version:        4.10.0
Release:        %mkrel 6
Group:          Sciences/Computer science
License:        BSD
Summary:        Open Source Computer Vision library
URL:            https://opencv.org/
Source0:        https://github.com/opencv/opencv/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/opencv/opencv_contrib/archive/%{version}/%{name}_contrib-%{version}.tar.gz
# Deprecated headers from 3.x adapted for 4.x
Source4:        opencv-4.x-deprecated-headers.tar.xz
Source5:        https://raw.githubusercontent.com/opencv/opencv_3rdparty/8afa57abc8229d611c4937165d20e2a2d9fc5a12/face_landmark_model.dat
# from https://github.com/opencv/ade
Source6:        https://github.com/opencv/ade/archive/refs/tags/v0.1.2d/dbb095a8bf3008e91edbbf45d8d34885-v0.1.2d.zip

# LAPACK_LIBRARIES doesn't include cblas ATM
Patch0:         opencv-linking.patch

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(flatbuffers)
BuildRequires:  pkgconfig(gflags)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libdc1394-2)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libucil)
BuildRequires:  pkgconfig(libunicap)
BuildRequires:  pkgconfig(jasper)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libv4l1)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  opencl-devel
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(tesseract)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  eigen3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(tbb)
# for doc
%if %{with doc}
BuildRequires:  python3dist(sphinx)
BuildRequires:  doxygen
%endif
%if %{build_cuda}
BuildRequires:  nvidia-cuda-toolkit-devel
%endif

%description
OpenCV (Open Source Computer Vision) is a library of programming
functions for real time computer vision.

#--------------------------------------------------------------------------------

%define libopencv_core_soname %{major}
%define libopencv_core %mklibname opencv_core %{libopencv_core_soname}

%package -n %{libopencv_core}
Summary: OpenCV core library
Group: System/Libraries

%description -n %{libopencv_core}
OpenCV core library (basic structures, arithmetics and linear algebra,
DFT, XML and YAML I/O, etc.).

%files -n %{libopencv_core}
%{_libdir}/libopencv_core.so.%{libopencv_core_soname}
%{_libdir}/libopencv_core.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_hdf_soname %{major}
%define libopencv_hdf %mklibname opencv_hdf %{libopencv_core_soname}

%package -n %{libopencv_hdf}
Summary: OpenCV HDF5 library
Group: System/Libraries

%description -n %{libopencv_hdf}
OpenCV HDF5 library.

%files -n %{libopencv_hdf}
%{_libdir}/libopencv_hdf.so.%{libopencv_hdf_soname}
%{_libdir}/libopencv_hdf.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_imgcodecs_soname %{major}
%define libopencv_imgcodecs %mklibname opencv_imgcodecs %{libopencv_imgcodecs_soname}

%package -n %{libopencv_imgcodecs}
Summary: OpenCV image codecs
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}

%description -n %{libopencv_imgcodecs}
OpenCV image codecs library.

%files -n %{libopencv_imgcodecs}
%{_libdir}/libopencv_imgcodecs.so.%{libopencv_imgcodecs_soname}
%{_libdir}/libopencv_imgcodecs.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_alphamat_soname %{major}
%define libopencv_alphamat %mklibname opencv_alphamat %{libopencv_alphamat_soname}

%package -n %{libopencv_alphamat}
Summary: OpenCV alpha matting
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}

%description -n %{libopencv_alphamat}
OpenCV alpha matting library.

%files -n %{libopencv_alphamat}
%{_libdir}/libopencv_alphamat.so.%{libopencv_alphamat_soname}
%{_libdir}/libopencv_alphamat.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_imgproc_soname %{major}
%define libopencv_imgproc %mklibname opencv_imgproc %{libopencv_imgproc_soname}

%package -n %{libopencv_imgproc}
Summary: OpenCV image processing library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}

%description -n %{libopencv_imgproc}
OpenCV image processing library (filter, Gaussian blur, erode, dilate,
resize, remap, etc.).

%files -n %{libopencv_imgproc}
%{_libdir}/libopencv_imgproc.so.%{libopencv_imgproc_soname}
%{_libdir}/libopencv_imgproc.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_intensity_transform_soname %{major}
%define libopencv_intensity_transform %mklibname opencv_intensity_transform %{libopencv_intensity_transform_soname}

%package -n %{libopencv_intensity_transform}
Summary: OpenCV intensity transform library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}

%description -n %{libopencv_intensity_transform}
OpenCV intensity transform library.

%files -n %{libopencv_intensity_transform}
%{_libdir}/libopencv_intensity_transform.so.%{libopencv_intensity_transform_soname}
%{_libdir}/libopencv_intensity_transform.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_rapid_soname %{major}
%define libopencv_rapid %mklibname opencv_rapid %{libopencv_rapid_soname}

%package -n %{libopencv_rapid}
Summary: OpenCV RAPID-a video rate object tracker
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}

%description -n %{libopencv_rapid}
Implements "RAPID-a video rate object tracker" with dynamic control point
extraction.

%files -n %{libopencv_rapid}
%{_libdir}/libopencv_rapid.so.%{libopencv_rapid_soname}
%{_libdir}/libopencv_rapid.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_highgui_soname %{major}
%define libopencv_highgui %mklibname opencv_highgui %{libopencv_highgui_soname}

%package -n %{libopencv_highgui}
Summary: OpenCV GUI and image/video I/O library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}
Requires: %{libopencv_imgproc} = %{version}-%{release}

%description -n %{libopencv_highgui}
OpenCV GUI and image/video I/O library.

%files -n %{libopencv_highgui}
%{_libdir}/libopencv_highgui.so.%{libopencv_highgui_soname}
%{_libdir}/libopencv_highgui.so.%{version}


#--------------------------------------------------------------------------------

%define libopencv_ml_soname %{major}
%define libopencv_ml %mklibname opencv_ml %{libopencv_ml_soname}

%package -n %{libopencv_ml}
Summary: OpenCV machine learning model library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}

%description -n %{libopencv_ml}
OpenCV statistical machine learning models (SVM,
decision trees, boosting, etc.).

%files -n %{libopencv_ml}
%{_libdir}/libopencv_ml.so.%{libopencv_ml_soname}
%{_libdir}/libopencv_ml.so.%{version}

#--------------------------------------------------------------------------------
%define with_ts %{nil}

%if "%{with_ts}"

%define libopencv_ts_soname %{major}
%define libopencv_ts %mklibname opencv_ts %{libopencv_ts_soname}

%package -n %{libopencv_ts}
Summary: OpenCV Base test library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}

%description -n %{libopencv_ts}
OpenCV Base test library.

%files -n %{libopencv_ts}
%{_libdir}/libopencv_ts.so.%{libopencv_ts_soname}
%{_libdir}/libopencv_ts.so.%{version}

%endif

#--------------------------------------------------------------------------------

%define libopencv_flann_soname %{major}
%define libopencv_flann %mklibname opencv_flann %{libopencv_flann_soname}

%package -n %{libopencv_flann}
Summary: OpenCV FLANN library
Group: System/Libraries

%description -n %{libopencv_flann}
OpenCV wrappers for the Fast Library for Approximate Neurest Neighbors
(FLANN).

%files -n %{libopencv_flann}
%{_libdir}/libopencv_flann.so.%{libopencv_flann_soname}
%{_libdir}/libopencv_flann.so.%{version}


#--------------------------------------------------------------------------------

%define libopencv_calib3d_soname %{major}
%define libopencv_calib3d %mklibname opencv_calib3d %{libopencv_calib3d_soname}

%package -n %{libopencv_calib3d}
Summary: OpenCV camera calibration library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}
Requires: %{libopencv_imgproc} = %{version}-%{release}

%description -n %{libopencv_calib3d}
OpenCV library for camera calibration, stereo correspondence, and
elements of 3D data processing.

%files -n %{libopencv_calib3d}
%{_libdir}/libopencv_calib3d.so.%{libopencv_calib3d_soname}
%{_libdir}/libopencv_calib3d.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_features2d_soname %{major}
%define libopencv_features2d %mklibname opencv_features2d %{libopencv_features2d_soname}

%package -n %{libopencv_features2d}
Summary: OpenCV 2D feature detectors
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}
Requires: %{libopencv_imgproc} = %{version}-%{release}
Requires: %{libopencv_calib3d} = %{version}-%{release}
Requires: %{libopencv_highgui} = %{version}-%{release}
Requires: %{libopencv_flann} = %{version}-%{release}

%description -n %{libopencv_features2d}
OpenCV 2D feature detectors and descriptors (SURF, FAST, etc.).

%files -n %{libopencv_features2d}
%{_libdir}/libopencv_features2d.so.%{libopencv_features2d_soname}
%{_libdir}/libopencv_features2d.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_video_soname %{major}
%define libopencv_video %mklibname opencv_video %{libopencv_video_soname}

%package -n %{libopencv_video}
Summary: OpenCV motion analysis and object tracking library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}
Requires: %{libopencv_imgproc} = %{version}-%{release}

%description -n %{libopencv_video}
OpenCV motion analysis and object tracking library (optical flow,
motion templates, background subtraction, etc.).

%files -n %{libopencv_video}
%{_libdir}/libopencv_video.so.%{libopencv_video_soname}
%{_libdir}/libopencv_video.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_objdetect_soname %{major}
%define libopencv_objdetect %mklibname opencv_objdetect %{libopencv_objdetect_soname}

%package -n %{libopencv_objdetect}
Summary: OpenCV motion analysis and object tracking library
Group: System/Libraries
Requires: %{libopencv_core} = %{version}-%{release}
Requires: %{libopencv_imgproc} = %{version}-%{release}
Requires: %{libopencv_highgui} = %{version}-%{release}

%description -n %{libopencv_objdetect}
OpenCV object detection library (Haar and LBP face detectors, HOG
people detector, etc.).

%files -n %{libopencv_objdetect}
%{_libdir}/libopencv_objdetect.so.%{libopencv_objdetect_soname}
%{_libdir}/libopencv_objdetect.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_dnn_soname %{major}
%define libopencv_dnn %mklibname opencv_dnn %{libopencv_dnn_soname}

%package -n %{libopencv_dnn}
Summary: OpenCV dnn library
Group: System/Libraries

%description -n %{libopencv_dnn}
OpenCV motion analysis and object tracking library (optical flow,
motion templates, background subtraction, etc.).

%files -n %{libopencv_dnn}
%{_libdir}/libopencv_dnn.so.%{libopencv_dnn_soname}
%{_libdir}/libopencv_dnn.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_photo_soname %{major}
%define libopencv_photo %mklibname opencv_photo %{libopencv_photo_soname}

%package -n %{libopencv_photo}
Summary: OpenCV motion analysis and object tracking library
Group: System/Libraries

%description -n %{libopencv_photo}
OpenCV motion analysis and object tracking library (optical flow,
motion templates, background subtraction, etc.).

%files -n %{libopencv_photo}
%{_libdir}/libopencv_photo.so.%{libopencv_photo_soname}
%{_libdir}/libopencv_photo.so.%{version}

#--------------------------------------------------------------------------------

%define with_gpu %{nil}
%if "%{with_gpu}"
%define libopencv_gpu_soname %{major}
%define libopencv_gpu %mklibname opencv_gpu %{libopencv_gpu_soname}

%package -n %{libopencv_gpu}
Summary: OpenCV GPU module
Group: System/Libraries

%description -n %{libopencv_gpu}
The OpenCV GPU module is a set of classes and functions to utilize GPU
computational capabilities. It is implemented using NVIDIA* CUDA* Runtime
API and supports only NVIDIA GPUs. The OpenCV GPU module includes utility
functions, low-level vision primitives, and high-level algorithms. The
utility functions and low-level primitives provide a powerful infrastructure
for developing fast vision algorithms taking advantage of GPU whereas
the high-level functionality includes some state-of-the-art algorithms
(such as stereo correspondence, face and people detectors, and others)
ready to be used by the application developers.

%files -n %{libopencv_gpu}
%{_libdir}/libopencv_gpu.so.%{libopencv_gpu_soname}
%{_libdir}/libopencv_gpu.so.%{version}

%endif

#--------------------------------------------------------------------------------

%define libopencv_shape_soname %{major}
%define libopencv_shape %mklibname opencv_shape %{libopencv_shape_soname}

%package -n %{libopencv_shape}
Summary: OpenCV shape detection
Group: System/Libraries

%description -n %{libopencv_shape}
OpenCV shape detection.

%files -n %{libopencv_shape}
%{_libdir}/libopencv_shape.so.%{libopencv_shape_soname}
%{_libdir}/libopencv_shape.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_stitching_soname %{major}
%define libopencv_stitching %mklibname opencv_stitching %{libopencv_stitching_soname}

%package -n %{libopencv_stitching}
Summary: OpenCV Stitching Pipeline
Group: System/Libraries

%description -n %{libopencv_stitching}
This figure illustrates the stitching module pipeline implemented in the
:ocv:class:`Stitcher` class. Using that class it's possible to configure/remove
some steps, i.e. adjust the stitching pipeline according to the particular
needs. All building blocks from the pipeline are available in the ``detail``
namespace, one can combine and use them separately.


%files -n %{libopencv_stitching}
%{_libdir}/libopencv_stitching.so.%{libopencv_stitching_soname}
%{_libdir}/libopencv_stitching.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_videoio_soname %{major}
%define libopencv_videoio %mklibname opencv_videoio %{libopencv_videoio_soname}

%package -n %{libopencv_videoio}
Summary: OpenCV Video I/O
Group: System/Libraries

%description -n %{libopencv_videoio}
OpenCV Video I/O module.

%files -n %{libopencv_videoio}
%{_libdir}/libopencv_videoio.so.%{libopencv_videoio_soname}
%{_libdir}/libopencv_videoio.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_videostab_soname %{major}
%define libopencv_videostab %mklibname opencv_videostab %{libopencv_videostab_soname}

%package -n %{libopencv_videostab}
Summary: OpenCV Video stabilization
Group: System/Libraries

%description -n %{libopencv_videostab}
OpenCV Video stabilization module.

%files -n %{libopencv_videostab}
%{_libdir}/libopencv_videostab.so.%{libopencv_videostab_soname}
%{_libdir}/libopencv_videostab.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_superres_soname %{major}
%define libopencv_superres %mklibname opencv_superres %{libopencv_superres_soname}

%package -n %{libopencv_superres}
Summary: OpenCV superres library
Group: System/Libraries

%description -n %{libopencv_superres}
OpenCV superres library.

%files -n %{libopencv_superres}
%{_libdir}/libopencv_superres.so.%{libopencv_superres_soname}
%{_libdir}/libopencv_superres.so.%{version}

#--------------------------------------------------------------------------------

%define with_ocl %{nil}
%if "%{with_ocl}"
%define libopencv_ocl_soname %{major}
%define libopencv_ocl %mklibname opencv_ocl %{libopencv_ocl_soname}

%package -n %{libopencv_ocl}
Summary: OpenCV ocl library
Group: System/Libraries

%description -n %{libopencv_ocl}
OpenCV ocl library.

%files -n %{libopencv_ocl}
%{_libdir}/libopencv_ocl.so.%{libopencv_ocl_soname}
%{_libdir}/libopencv_ocl.so.%{version}

%endif
#--------------------------------------------------------------------------------

%if %{with contrib}

%define libopencv_aruco_soname %{major}
%define libopencv_aruco %mklibname opencv_aruco %{libopencv_aruco_soname}

%package -n %{libopencv_aruco}
Summary: OpenCV ArUco and ChArUco Markers module
Group: System/Libraries

%description -n %{libopencv_aruco}
Augmented reality ArUco marker and "ChARUco" markers where ArUco markers
embedded inside the white areas of the checker board.

%files -n %{libopencv_aruco}
%{_libdir}/libopencv_aruco.so.%{libopencv_aruco_soname}
%{_libdir}/libopencv_aruco.so.%{version}

#--------------------------------------------------------------------------------

%if 0
%define libopencv_barcode_soname %{major}
%define libopencv_barcode %mklibname opencv_barcode %{libopencv_barcode_soname}

%package -n %{libopencv_barcode}
Summary: OpenCV bar code recognition module
Group: System/Libraries

%description -n %{libopencv_barcode}
Bar code detection and decoding module supporting the EAN13 encoding method.

%files -n %{libopencv_barcode}
%{_libdir}/libopencv_barcode.so.%{libopencv_barcode_soname}
%{_libdir}/libopencv_barcode.so.%{version}

%endif
#--------------------------------------------------------------------------------

%define libopencv_bgsegm_soname %{major}
%define libopencv_bgsegm %mklibname opencv_bgsegm %{libopencv_bgsegm_soname}

%package -n %{libopencv_bgsegm}
Summary: OpenCV background segmentation algorithm module
Group: System/Libraries

%description -n %{libopencv_bgsegm}
Background segmentation algorithm combining statistical background image
estimation and per-pixel Bayesian segmentation.

%files -n %{libopencv_bgsegm}
%{_libdir}/libopencv_bgsegm.so.%{libopencv_bgsegm_soname}
%{_libdir}/libopencv_bgsegm.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_bioinspired_soname %{major}
%define libopencv_bioinspired %mklibname opencv_bioinspired %{libopencv_bioinspired_soname}

%package -n %{libopencv_bioinspired}
Summary: OpenCV Biological Vision module
Group: System/Libraries

%description -n %{libopencv_bioinspired}
Biologically inspired vision model: minimize noise and luminance variance,
transient event segmentation, high dynamic range tone mapping methods.

%files -n %{libopencv_bioinspired}
%{_libdir}/libopencv_bioinspired.so.%{libopencv_bioinspired_soname}
%{_libdir}/libopencv_bioinspired.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_ccalib_soname %{major}
%define libopencv_ccalib %mklibname opencv_ccalib %{libopencv_ccalib_soname}

%package -n %{libopencv_ccalib}
Summary: OpenCV Custom Calibration module
Group: System/Libraries

%description -n %{libopencv_ccalib}
Patterns for 3D reconstruction, omnidirectional camera calibration,
random pattern calibration and multi-camera calibration.

%files -n %{libopencv_ccalib}
%{_libdir}/libopencv_ccalib.so.%{libopencv_ccalib_soname}
%{_libdir}/libopencv_ccalib.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_datasets_soname %{major}
%define libopencv_datasets %mklibname opencv_datasets %{libopencv_datasets_soname}

%package -n %{libopencv_datasets}
Summary: OpenCV Datasets Reader module
Group: System/Libraries

%description -n %{libopencv_datasets}
Code for reading existing computer vision databases and samples of using
the readers to train, test and run using that dataset's data.

%files -n %{libopencv_datasets}
%{_libdir}/libopencv_datasets.so.%{libopencv_datasets_soname}
%{_libdir}/libopencv_datasets.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_dnn_superres_soname %{major}
%define libopencv_dnn_superres %mklibname opencv_dnn_superres %{libopencv_dnn_superres_soname}

%package -n %{libopencv_dnn_superres}
Summary: OpenCV Super Resolution using CNNs module
Group: System/Libraries

%description -n %{libopencv_dnn_superres}
Implements compact CNN Model for Super Resolution.

%files -n %{libopencv_dnn_superres}
%{_libdir}/libopencv_dnn_superres.so.%{libopencv_dnn_superres_soname}
%{_libdir}/libopencv_dnn_superres.so.%{version}

#--------------------------------------------------------------------------------
%define libopencv_dnn_objdetect_soname %{major}
%define libopencv_dnn_objdetect %mklibname opencv_dnn_objdetect %{libopencv_dnn_objdetect_soname}

%package -n %{libopencv_dnn_objdetect}
Summary: OpenCV Object Detection using CNNs module
Group: System/Libraries

%description -n %{libopencv_dnn_objdetect}
Implements compact CNN Model for object detection. Trained using Caffe
but uses opencv_dnn module.

%files -n %{libopencv_dnn_objdetect}
%{_libdir}/libopencv_dnn_objdetect.so.%{libopencv_dnn_objdetect_soname}
%{_libdir}/libopencv_dnn_objdetect.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_dpm_soname %{major}
%define libopencv_dpm %mklibname opencv_dpm %{libopencv_dpm_soname}

%package -n %{libopencv_dpm}
Summary: OpenCV Deformable Part Model module
Group: System/Libraries

%description -n %{libopencv_dpm}
Felzenszwalb's Cascade with deformable parts object recognition code.

%files -n %{libopencv_dpm}
%{_libdir}/libopencv_dpm.so.%{libopencv_dpm_soname}
%{_libdir}/libopencv_dpm.so.%{version}

#--------------------------------------------------------------------------------

%if %{with internet}
%define libopencv_face_soname %{major}
%define libopencv_face %mklibname opencv_face %{libopencv_face_soname}

%package -n %{libopencv_face}
Summary: OpenCV Face Recognition module
Group: System/Libraries

%description -n %{libopencv_face}
Face recognition techniques: Eigen, Fisher and Local Binary Pattern
Histograms LBPH methods.

%files -n %{libopencv_face}
%{_libdir}/libopencv_face.so.%{libopencv_face_soname}
%{_libdir}/libopencv_face.so.%{version}
%endif

#--------------------------------------------------------------------------------

%define libopencv_freetype_soname %{major}
%define libopencv_freetype %mklibname opencv_freetype %{libopencv_freetype_soname}

%package -n %{libopencv_freetype}
Summary: OpenCV text drawing module
Group: System/Libraries

%description -n %{libopencv_freetype}
Drawing text using freetype and harfbuzz.

%files -n %{libopencv_freetype}
%{_libdir}/libopencv_freetype.so.%{libopencv_freetype_soname}
%{_libdir}/libopencv_freetype.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_fuzzy_soname %{major}
%define libopencv_fuzzy %mklibname opencv_fuzzy %{libopencv_fuzzy_soname}

%package -n %{libopencv_fuzzy}
Summary: OpenCV Fuzzy Logic in Vision module
Group: System/Libraries

%description -n %{libopencv_fuzzy}
Fuzzy logic image transform and inverse; Fuzzy image processing.

%files -n %{libopencv_fuzzy}
%{_libdir}/libopencv_fuzzy.so.%{libopencv_fuzzy_soname}
%{_libdir}/libopencv_fuzzy.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_hfs_soname %{major}
%define libopencv_hfs %mklibname opencv_hfs %{libopencv_hfs_soname}

%package -n %{libopencv_hfs}
Summary: OpenCV Hierarchical Feature Selection for Efficient Image Segmentation module
Group: System/Libraries

%description -n %{libopencv_hfs}
OpenCV Hierarchical Feature Selection for Efficient Image Segmentation module

%files -n %{libopencv_hfs}
%{_libdir}/libopencv_hfs.so.%{libopencv_hfs_soname}
%{_libdir}/libopencv_hfs.so.%{version}


#--------------------------------------------------------------------------------

%define libopencv_img_hash_soname %{major}
%define libopencv_img_hash %mklibname opencv_img_hash %{libopencv_img_hash_soname}

%package -n %{libopencv_img_hash}
Summary: OpenCV Image Hashing algorithms module
Group: System/Libraries

%description -n %{libopencv_img_hash}
This module is intended to port the algorithms from PHash library and
implement other image hash algorithm do not exist in PHash library yet.

%files -n %{libopencv_img_hash}
%{_libdir}/libopencv_img_hash.so.%{libopencv_img_hash_soname}
%{_libdir}/libopencv_img_hash.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_line_descriptor_soname %{major}
%define libopencv_line_descriptor %mklibname opencv_line_descriptor %{libopencv_line_descriptor_soname}

%package -n %{libopencv_line_descriptor}
Summary: OpenCV Line Segment Extract and Match module
Group: System/Libraries

%description -n %{libopencv_line_descriptor}
Methods of extracting, describing and latching line segments using binary descriptors.

%files -n %{libopencv_line_descriptor}
%{_libdir}/libopencv_line_descriptor.so.%{libopencv_line_descriptor_soname}
%{_libdir}/libopencv_line_descriptor.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_mcc_soname %{major}
%define libopencv_mcc %mklibname opencv_mcc %{libopencv_mcc_soname}

%package -n %{libopencv_mcc}
Summary: OpenCV Macbeth Chart module
Group: System/Libraries

%description -n %{libopencv_mcc}
ColorCharts are a tool for calibrating the color profile of camera, which not only depends on the intrinsic and extrinsic parameters of camera but also on the lighting conditions.

%files -n %{libopencv_mcc}
%{_libdir}/libopencv_mcc.so.%{libopencv_mcc_soname}
%{_libdir}/libopencv_mcc.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_optflow_soname %{major}
%define libopencv_optflow %mklibname opencv_optflow %{libopencv_optflow_soname}

%package -n %{libopencv_optflow}
Summary: OpenCV Optical Flow module
Group: System/Libraries

%description -n %{libopencv_optflow}
Algorithms for running and evaluating deepflow, simpleflow, sparsetodenseflow
and motion templates (silhouette flow).

%files -n %{libopencv_optflow}
%{_libdir}/libopencv_optflow.so.%{libopencv_optflow_soname}
%{_libdir}/libopencv_optflow.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_phase_unwrapping_soname %{major}
%define libopencv_phase_unwrapping %mklibname opencv_phase_unwrapping %{libopencv_phase_unwrapping_soname}

%package -n %{libopencv_phase_unwrapping}
Summary: OpenCV Phase Unwrapping module
Group: System/Libraries

%description -n %{libopencv_phase_unwrapping}
OpenCV module that can be used to unwrap two-dimensional phase map.

%files -n %{libopencv_phase_unwrapping}
%{_libdir}/libopencv_phase_unwrapping.so.%{libopencv_phase_unwrapping_soname}
%{_libdir}/libopencv_phase_unwrapping.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_plot_soname %{major}
%define libopencv_plot %mklibname opencv_plot %{libopencv_plot_soname}

%package -n %{libopencv_plot}
Summary: OpenCV Plotting module
Group: System/Libraries

%description -n %{libopencv_plot}
The plot module allows you to easily plot data in 1D or 2D.

%files -n %{libopencv_plot}
%{_libdir}/libopencv_plot.so.%{libopencv_plot_soname}
%{_libdir}/libopencv_plot.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_quality_soname %{major}
%define libopencv_quality %mklibname opencv_quality %{libopencv_quality_soname}

%package -n %{libopencv_quality}
Summary: OpenCV Quality API
Group: System/Libraries

%description -n %{libopencv_quality}
Quality API.

%files -n %{libopencv_quality}
%{_libdir}/libopencv_quality.so.%{libopencv_quality_soname}
%{_libdir}/libopencv_quality.so.%{version}
%{_datadir}/opencv4/quality

#--------------------------------------------------------------------------------

# %%if %%{with internet}
%define libopencv_gapi_soname %{major}
%define libopencv_gapi %mklibname opencv_gapi %{libopencv_gapi_soname}

%package -n %{libopencv_gapi}
Summary: OpenCV Graph API
Group: System/Libraries

%description -n %{libopencv_gapi}
Graph API.

%files -n %{libopencv_gapi}
%{_libdir}/libopencv_gapi.so.%{libopencv_gapi_soname}
%{_libdir}/libopencv_gapi.so.%{version}
# %%endif

#--------------------------------------------------------------------------------

%define libopencv_reg_soname %{major}
%define libopencv_reg %mklibname opencv_reg %{libopencv_reg_soname}

%package -n %{libopencv_reg}
Summary: OpenCV Image Registration module
Group: System/Libraries

%description -n %{libopencv_reg}
Pixels based image registration for precise alignment. Follows the paper
"Image Alignment and Stitching: A Tutorial", by Richard Szeliski.

%files -n %{libopencv_reg}
%{_libdir}/libopencv_reg.so.%{libopencv_reg_soname}
%{_libdir}/libopencv_reg.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_rgbd_soname %{major}
%define libopencv_rgbd %mklibname opencv_rgbd %{libopencv_rgbd_soname}

%package -n %{libopencv_rgbd}
Summary: OpenCV RGB-Depth Processing module
Group: System/Libraries

%description -n %{libopencv_rgbd}
Linemod 3D object recognition; Fast surface normals and 3D plane
finding. 3D visual odometry.

%files -n %{libopencv_rgbd}
%{_libdir}/libopencv_rgbd.so.%{libopencv_rgbd_soname}
%{_libdir}/libopencv_rgbd.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_saliency_soname %{major}
%define libopencv_saliency %mklibname opencv_saliency %{libopencv_saliency_soname}

%package -n %{libopencv_saliency}
Summary: OpenCV Saliency API module
Group: System/Libraries

%description -n %{libopencv_saliency}
Where humans would look in a scene. Has routines for static, motion and "objectness" saliency.

%files -n %{libopencv_saliency}
%{_libdir}/libopencv_saliency.so.%{libopencv_saliency_soname}
%{_libdir}/libopencv_saliency.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_signal_soname %{major}
%define libopencv_signal %mklibname opencv_signal %{libopencv_signal_soname}

%package -n %{libopencv_signal}
Summary: OpenCV signal Processing algorithms module
Group: System/Libraries

%description -n %{libopencv_signal}
Signal resampling done with cubic interpolation and low-pass filtering.

%files -n %{libopencv_signal}
%{_libdir}/libopencv_signal.so.%{libopencv_signal_soname}
%{_libdir}/libopencv_signal.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_stereo_soname %{major}
%define libopencv_stereo %mklibname opencv_stereo %{libopencv_stereo_soname}

%package -n %{libopencv_stereo}
Summary: OpenCV Stereo Correspondence module
Group: System/Libraries

%description -n %{libopencv_stereo}
Stereo matching done with different descriptors:
Census / CS-Census / MCT / BRIEF / MV.

%files -n %{libopencv_stereo}
%{_libdir}/libopencv_stereo.so.%{libopencv_stereo_soname}
%{_libdir}/libopencv_stereo.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_structured_light_soname %{major}
%define libopencv_structured_light %mklibname opencv_structured_light %{libopencv_structured_light_soname}

%package -n %{libopencv_structured_light}
Summary: OpenCV Structured Light Use module
Group: System/Libraries

%description -n %{libopencv_structured_light}
How to generate and project gray code patterns and use them to find dense depth in a scene.

%files -n %{libopencv_structured_light}
%{_libdir}/libopencv_structured_light.so.%{libopencv_structured_light_soname}
%{_libdir}/libopencv_structured_light.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_surface_matching_soname %{major}
%define libopencv_surface_matching %mklibname opencv_surface_matching %{libopencv_surface_matching_soname}

%package -n %{libopencv_surface_matching}
Summary: OpenCV Point Pair Features module
Group: System/Libraries

%description -n %{libopencv_surface_matching}
Implements 3d object detection and localization using multimodal point pair features.

%files -n %{libopencv_surface_matching}
%{_libdir}/libopencv_surface_matching.so.%{libopencv_surface_matching_soname}
%{_libdir}/libopencv_surface_matching.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_text_soname %{major}
%define libopencv_text %mklibname opencv_text %{libopencv_text_soname}

%package -n %{libopencv_text}
Summary: OpenCV Visual Text Matching module
Group: System/Libraries

%description -n %{libopencv_text}
In a visual scene, detect text, segment words and recognise the text.

%files -n %{libopencv_text}
%{_libdir}/libopencv_text.so.%{libopencv_text_soname}
%{_libdir}/libopencv_text.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_tracking_soname %{major}
%define libopencv_tracking %mklibname opencv_tracking %{libopencv_tracking_soname}

%package -n %{libopencv_tracking}
Summary: OpenCV Vision Based Object Tracking module
Group: System/Libraries

%description -n %{libopencv_tracking}
Use and/or evaluate one of 5 different visual object tracking techniques.

%files -n %{libopencv_tracking}
%{_libdir}/libopencv_tracking.so.%{libopencv_tracking_soname}
%{_libdir}/libopencv_tracking.so.%{version}

#--------------------------------------------------------------------------------

%if %{with internet}
%if %{with nonfree}
%define libopencv_xfeatures2d_soname %{major}
%define libopencv_xfeatures2d %mklibname opencv_xfeatures2d %{libopencv_xfeatures2d_soname}

%package -n %{libopencv_xfeatures2d}
Summary: OpenCV Features2D extra module
Group: System/Libraries

%description -n %{libopencv_xfeatures2d}
Extra 2D Features Framework containing experimental and non-free 2D feature
detector/descriptor algorithms. SURF, SIFT, BRIEF, Censure, Freak, LUCID,
Daisy, Self-similar.

%files -n %{libopencv_xfeatures2d}
%{_libdir}/libopencv_xfeatures2d.so.%{libopencv_xfeatures2d_soname}
%{_libdir}/libopencv_xfeatures2d.so.%{version}
%endif
%endif

#--------------------------------------------------------------------------------

%if %{with internet}
%if %{with wechat_qrcode}
%define libopencv_wechat_qrcode_soname %{major}
%define libopencv_wechat_qrcode %mklibname opencv_wechat_qrcode %{libopencv_wechat_qrcode_soname}

%package -n %{libopencv_wechat_qrcode}
Summary: OpenCV WeChat QR code detector module
Group: System/Libraries

%description -n %{libopencv_wechat_qrcode}
WeChat QRCode includes two CNN-based models: A object detection model
and a super resolution model. Object detection model is applied to
detect QRCode with the bounding box. super resolution model is applied
to zoom in QRCode when it is small.

%files -n %{libopencv_wechat_qrcode}
%{_libdir}/libopencv_wechat_qrcode.so.%{libopencv_wechat_qrcode_soname}
%{_libdir}/libopencv_wechat_qrcode.so.%{version}
%endif
%endif

#--------------------------------------------------------------------------------

%define libopencv_ximgproc_soname %{major}
%define libopencv_ximgproc %mklibname opencv_ximgproc %{libopencv_ximgproc_soname}

%package -n %{libopencv_ximgproc}
Summary: OpenCV Extended Image Processing module
Group: System/Libraries

%description -n %{libopencv_ximgproc}
Structured Forests / Domain Transform Filter / Guided Filter / Adaptive Manifold
Filter / Joint Bilateral Filter / Superpixels / Ridge Detection Filter.

%files -n %{libopencv_ximgproc}
%{_libdir}/libopencv_ximgproc.so.%{libopencv_ximgproc_soname}
%{_libdir}/libopencv_ximgproc.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_xobjdetect_soname %{major}
%define libopencv_xobjdetect %mklibname opencv_xobjdetect %{libopencv_xobjdetect_soname}

%package -n %{libopencv_xobjdetect}
Summary: OpenCV Boosted 2D Object Detection module
Group: System/Libraries

%description -n %{libopencv_xobjdetect}
Uses a Waldboost cascade and local binary patterns computed as integral features
for 2D object detection.

%files -n %{libopencv_xobjdetect}
%{_libdir}/libopencv_xobjdetect.so.%{libopencv_xobjdetect_soname}
%{_libdir}/libopencv_xobjdetect.so.%{version}

#--------------------------------------------------------------------------------

%define libopencv_xphoto_soname %{major}
%define libopencv_xphoto %mklibname opencv_xphoto %{libopencv_xphoto_soname}

%package -n %{libopencv_xphoto}
Summary: OpenCV Extra Computational Photography module
Group: System/Libraries

%description -n %{libopencv_xphoto}
Additional photo processing algorithms: Color balance / Denoising / Inpainting.

%files -n %{libopencv_xphoto}
%{_libdir}/libopencv_xphoto.so.%{libopencv_xphoto_soname}
%{_libdir}/libopencv_xphoto.so.%{version}

%endif
#--------------------------------------------------------------------------------

%package devel
Summary: OpenCV development files
Group: Development/C
Provides: libopencv-devel = %{version}-%{release}
Requires: %{libopencv_core} = %{version}-%{release}
Requires: %{libopencv_hdf} = %{version}-%{release}
Requires: %{libopencv_imgcodecs} = %{version}-%{release}
Requires: %{libopencv_imgproc} = %{version}-%{release}
Requires: %{libopencv_highgui} = %{version}-%{release}
Requires: %{libopencv_ml} = %{version}-%{release}
%if "%{with_ts}"
Requires: %{libopencv_ts} = %{version}-%{release}
%endif
Requires: %{libopencv_flann} = %{version}-%{release}
Requires: %{libopencv_calib3d} = %{version}-%{release}
Requires: %{libopencv_features2d} = %{version}-%{release}
Requires: %{libopencv_video} = %{version}-%{release}
Requires: %{libopencv_objdetect} = %{version}-%{release}
Requires: %{libopencv_dnn} = %{version}-%{release}
Requires: %{libopencv_photo} = %{version}-%{release}
%if "%{with_gpu}"
Requires: %{libopencv_gpu} = %{version}-%{release}
%endif
Requires: %{libopencv_shape} = %{version}-%{release}
Requires: %{libopencv_stitching} = %{version}-%{release}
Requires: %{libopencv_videoio} = %{version}-%{release}
Requires: %{libopencv_videostab} = %{version}-%{release}
Requires: %{libopencv_superres} = %{version}-%{release}
%if "%{with_ocl}"
Requires: %{libopencv_ocl} = %{version}-%{release}
%endif
%if %{with contrib}
Requires: %{libopencv_aruco} = %{version}-%{release}
%if 0
Requires: %{libopencv_barcode} = %{version}-%{release}
%endif
Requires: %{libopencv_bgsegm} = %{version}-%{release}
Requires: %{libopencv_bioinspired} = %{version}-%{release}
Requires: %{libopencv_ccalib} = %{version}-%{release}
Requires: %{libopencv_datasets} = %{version}-%{release}
Requires: %{libopencv_dnn_superres} = %{version}-%{release}
Requires: %{libopencv_dnn_objdetect} = %{version}-%{release}
Requires: %{libopencv_dpm} = %{version}-%{release}
%if %{with internet}
Requires: %{libopencv_face} = %{version}-%{release}
Requires: %{libopencv_gapi} = %{version}-%{release}
Requires: %{libopencv_mcc} = %{version}-%{release}
%if %{with nonfree}
Requires: %{libopencv_xfeatures2d} = %{version}-%{release}
%endif
%if %{with wechat_qrcode}
Requires: %{libopencv_wechat_qrcode} = %{version}-%{release}
%endif
%endif
Requires: %{libopencv_freetype} = %{version}-%{release}
Requires: %{libopencv_fuzzy} = %{version}-%{release}
Requires: %{libopencv_hfs} = %{version}-%{release}
Requires: %{libopencv_img_hash} = %{version}-%{release}
Requires: %{libopencv_line_descriptor} = %{version}-%{release}
Requires: %{libopencv_optflow} = %{version}-%{release}
Requires: %{libopencv_phase_unwrapping} = %{version}-%{release}
Requires: %{libopencv_plot} = %{version}-%{release}
Requires: %{libopencv_quality} = %{version}-%{release}
Requires: %{libopencv_reg} = %{version}-%{release}
Requires: %{libopencv_rgbd} = %{version}-%{release}
Requires: %{libopencv_saliency} = %{version}-%{release}
Requires: %{libopencv_signal} = %{version}-%{release}
Requires: %{libopencv_stereo} = %{version}-%{release}
Requires: %{libopencv_structured_light} = %{version}-%{release}
Requires: %{libopencv_surface_matching} = %{version}-%{release}
Requires: %{libopencv_text} = %{version}-%{release}
Requires: %{libopencv_tracking} = %{version}-%{release}
Requires: %{libopencv_ximgproc} = %{version}-%{release}
Requires: %{libopencv_xobjdetect} = %{version}-%{release}
Requires: %{libopencv_xphoto} = %{version}-%{release}
Requires: %{libopencv_alphamat} = %{version}-%{release}
Requires: %{libopencv_intensity_transform} = %{version}-%{release}
Requires: %{libopencv_rapid} = %{version}-%{release}

%endif
Conflicts: %{name}-samples < 3.4.1-9

%description devel
OpenCV development files.

%files devel
%{_libdir}/*.so
# Deprecated headers from 3.x
%{_includedir}/opencv/
%dir %{_includedir}/opencv4
%{_includedir}/opencv4/opencv2/
%{_libdir}/pkgconfig/*
%{_datadir}/licenses/opencv4/*.txt
# %%if %%{with internet}
%{_datadir}/licenses/opencv4/ade-LICENSE
# %%endif
%dir %{_libdir}/cmake/OpenCV
%{_libdir}/cmake/OpenCV/*.cmake
%dir %{_datadir}/opencv4/
%{_datadir}/opencv4/valgrind*.supp
%{_bindir}/opencv_version
%{_bindir}/setup_vars_opencv4.sh

#--------------------------------------------------------------------------------

%package -n python3-opencv
Summary: OpenCV Python 3 bindings
Group: Development/Python
BuildRequires:  python3
%{?python_provide:%python_provide python3-opencv}

%description -n python3-opencv
OpenCV python 3 bindings.

%files -n python3-opencv
%{python3_sitearch}/*

#--------------------------------------------------------------------------------
%if %{with doc}

%package doc
Summary: OpenCV docs
Group: Documentation
BuildArch: noarch

%description doc
OpenCV docs.

%files doc
%{_datadir}/OpenCV/doc/

%endif
#--------------------------------------------------------------------------------

%package samples
Summary: OpenCV sample code
Group: Documentation

%description samples
OpenCV sample code.

%files samples
%{_bindir}/opencv_annotation
%{_bindir}/opencv_interactive-calibration
%{_bindir}/opencv_model_diagnostics
%{_bindir}/opencv_visualisation
%if %{with contrib}
%{_bindir}/opencv_waldboost_detector
%endif
%dir %{_datadir}/opencv4
%{_datadir}/opencv4/samples
%{_datadir}/opencv4/haarcascades
%{_datadir}/opencv4/lbpcascades

#--------------------------------------------------------------------------------

%prep
%setup -q %{?with_contrib:-a1}
%autopatch -p1

# use system libs etc.
rm -rf 3rdparty/*
perl -i -lanE 'print unless /ocv_install_3rdparty_licenses/' cmake/OpenCVDetect*.cmake

%if %{with contrib}

%if %{without internet}
pushd %{name}_contrib-%{version}/modules/
	rm -rf dnn_modern face xfeatures2d
popd
%endif

%if %{without nonfree}
pushd %{name}_contrib-%{version}/modules/
	rm -rf xfeatures2d
popd
%endif

%endif

# Install face_landmark_model
mkdir -p .cache/data
install -pm 0644 %{SOURCE5} .cache/data/7505c44ca4eb54b4ab1e4777cb96ac05-face_landmark_model.dat

# Install ADE, needed for opencv_gapi
mkdir -p .cache/ade
install -pm 0644 %{SOURCE6} .cache/ade/

# Generate/update schema with flatbuffers version we have
rm -rf ./modules/dnn/misc/tflite/schema_generated.h
flatc --cpp -o ./modules/dnn/misc/tflite ./modules/dnn/src/tflite/schema.fbs

%build
# Was for gflags
# export CPATH="$CPATH:/usr/include"
%cmake -GNinja \
        -DCMAKE_SKIP_RPATH:BOOL=ON \
%if %{with contrib}
        -DOPENCV_EXTRA_MODULES_PATH=./opencv_contrib-%{version}/modules \
        -DBUILD_opencv_wechat_qrcode:BOOL=%{?with_wechat_qrcode:ON}%{!?with_wechat_qrcode:OFF} \
%endif
%ifarch %{arm}
        -DOPENCV_EXTRA_CXX_FLAGS='-Wno-psabi' \
%endif
%ifarch %{ix86}
        -DCPU_BASELINE= \
%endif
        -DOPENCL_INCLUDE_DIR:PATH=%{_includedir}/CL \
        -DOPENCV_GENERATE_PKGCONFIG:BOOL=ON \
        -DOPENCV_PC_FILE_NAME=opencv.pc \
        -DOPENCV_LIB_INSTALL_PATH=%{_lib} \
        -DOPENCV_3P_LIB_INSTALL_PATH=%{_lib} \
        -DOPENCV_CONFIG_INSTALL_PATH=%{_lib}/cmake/OpenCV \
        -DBUILD_PROTOBUF:BOOL=OFF \
        -DPROTOBUF_UPDATE_FILES:BOOL=ON \
        -DBUILD_EXAMPLES:BOOL=ON \
        -DBUILD_DOCS:BOOL=%{?with_doc:ON}%{?!with_doc:OFF} \
        -DINSTALL_C_EXAMPLES:BOOL=ON \
        -DINSTALL_PYTHON_EXAMPLES:BOOL=ON \
        -DINSTALL_OCTAVE_EXAMPLES:BOOL=ON \
        -DPYTHON3_EXECUTABLE=%{python3} \
        -DPYTHON3_PACKAGES_PATH=%{python3_sitearch} \
        -DBUILD_opencv_python2:BOOL=OFF \
        -DENABLE_PRECOMPILED_HEADERS:BOOL=OFF \
        -DWITH_CAROTENE:BOOL=OFF \
        -DWITH_IPP:BOOL=OFF \
        -DWITH_QUIRC:BOOL=OFF \
        -DWITH_VTK:BOOL=OFF \
        -DWITH_ITT:BOOL=OFF \
        -DOPENCV_FORCE_3RDPARTY_BUILD:BOOL=OFF
%cmake_build

%install
%cmake_install

%if %{without doc}
rm -rf %{buildroot}%{_datadir}/OpenCV/doc
%endif

# Deprecated headers from 3.x adapted for 4.x
mkdir -p %{buildroot}%{_includedir}/opencv
tar Jxf %{SOURCE4} -C %{buildroot}%{_includedir}/opencv

# For compatibility with existing opencv.pc application
ln -s opencv.pc %{buildroot}%{_libdir}/pkgconfig/opencv4.pc
