# openexr
%define api		3_1
%define major		30
%define libname		%mklibname openexr %{api} %{major}
%define develname	%mklibname openexr -d

# ilmbase
%define ilm_major	30
%define libname_ilm	%mklibname ilmbase %{api} %{ilm_major}

%bcond_without docs

Name:		openexr
Summary:	A high dynamic-range (HDR) image file format
Version:	3.1.13
Release:	%mkrel 1
Group:		Graphics/Utilities
License:	BSD
URL:		https://www.openexr.com
Source0:	https://github.com/AcademySoftwareFoundation/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:		gcc14.patch
BuildRequires:	cmake
BuildRequires:	pkgconfig(Imath)
BuildRequires:	pkgconfig(zlib)
%if %{with docs}
BuildRequires:	python3-sphinx
BuildRequires:	python3-breathe
BuildRequires:	doxygen
%endif

Provides:	OpenEXR = %{version}-%{release}

%description
Industrial Light & Magic developed the OpenEXR format in response to the demand
for higher color fidelity in the visual effects industry.

### openexr

%package -n	%{libname}
Summary:	Dynamic libraries from %{name}
Group:		System/Libraries

%description -n	%{libname}
Dynamic libraries from %{name}.

%package -n	%{develname}
Summary:	Header files and development libraries from %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_ilm} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	libilmbase-devel = %{version}-%{release}
Provides:	ilmbase-devel = %{version}-%{release}
Provides:	OpenEXR-devel = %{version}-%{release}
Obsoletes:	%{_lib}ilmbase-devel < 3.1.3

%description -n	%{develname}
Libraries and includes files for developing programs based on %{name}.

### ilmbase

%package -n	%{libname_ilm}
Summary:	Dynamic libraries from IlmBase
Group:		System/Libraries

%description -n	%{libname_ilm}
Dynamic libraries from IlmBase.

%prep
%autosetup -p1

%build
%cmake \
  -DDOCS:BOOL=%{?with_docs:ON}%{!?with_docs:OFF} \
  -DINSTALL_DOCS:BOOL=ON
%cmake_build

%install
%cmake_install

%if %{with docs}
# Fixup documentation so it can get installed correctly in imath-devel
rm -rf %{buildroot}%{_datadir}/doc/OpenEXR/sphinx/.{doctrees,buildinfo}
%endif

%files
%doc *.md CODEOWNERS
%{_bindir}/exr*

%files -n %{libname}
%{_libdir}/libOpenEXR-%{api}.so.%{major}{,.*}
%{_libdir}/libOpenEXRCore-%{api}.so.%{major}{,.*}
%{_libdir}/libOpenEXRUtil-%{api}.so.%{major}{,.*}

%files -n %{develname}
%docdir %{_datadir}/doc/OpenEXR/
%doc %{_datadir}/doc/OpenEXR/
%{_includedir}/OpenEXR/
%{_libdir}/libOpenEXR.so
%{_libdir}/libOpenEXR-%{api}.so
%{_libdir}/libOpenEXRCore.so
%{_libdir}/libOpenEXRCore-%{api}.so
%{_libdir}/libOpenEXRUtil.so
%{_libdir}/libOpenEXRUtil-%{api}.so
%{_libdir}/libIex.so
%{_libdir}/libIex-%{api}.so
%{_libdir}/libIlmThread.so
%{_libdir}/libIlmThread-%{api}.so
%{_libdir}/pkgconfig/OpenEXR.pc
%{_libdir}/cmake/OpenEXR/

%files -n %{libname_ilm}
%{_libdir}/libIex-%{api}.so.%{ilm_major}{,.*}
%{_libdir}/libIlmThread-%{api}.so.%{ilm_major}{,.*}
