%define oname           OpenFOAM
%define osrcname        %{oname}-%{version}
%define libfoamdir      %{_libdir}/%{name}
%define binfoamdir      %{_libexecdir}/%{name}
%define datafoamdir     %{_datadir}/%{oname}-%{version}
%define pvversion       5.8
%define tag             20240612
%define rel             3

#openfoam devel is doing a very good job lagging ages behind paraview
%define with_paraview   0

# openmpi is no more provided for 32 bits arches
ExcludeArch:    %arm32 %ix86


Name:          openfoam
Version:       11
Release:       %mkrel %{rel}.%{tag}
Summary:       The open source CFD toolbox
License:       GPLv3+
Group:         Sciences/Physics
Url:           https://www.openfoam.org/
# https://github.com/OpenFOAM/OpenFOAM-9/
Source0:       https://github.com/%{name}/%{name}-%{version}/archive/%{tag}.tar.gz
Source1:       openfoam

#find system include and libraries for scotch
Patch0:        openfoam-9-scotch.patch

#find system include and libraries for paraview
Patch1:        openfoam-11-paraview-5.10.1.patch

#Fix basic mistakes in bash preventing to even start compiling...
Patch2:        openfoam-7-aliases.patch

#aarch64 support
Patch4:        openfoam-7-arm8aarch64.patch

#fix deprecated cmake macro
Patch6:        openfoam-7-pvreader-5.8.0.patch

# Fix usage of non fixed root path for etc/bashrc:  can be OpenFOAM-9 or OpenFOAM-9-20211122
Patch7:        openfoam-9-Fix-bashrc-for-not-specific-root-path.patch


BuildRequires: bison
BuildRequires: boost-devel
BuildRequires: cmake
BuildRequires: fdupes
BuildRequires: flex
BuildRequires: mpfr-devel
BuildRequires: pkgconfig(ompi)
BuildRequires: libgomp-devel
BuildRequires: pkgconfig(zlib)
BuildRequires: ptscotch-openmpi-devel
BuildRequires: libptscotch-parmetis-openmpi-devel
BuildRequires: cgal-devel
BuildRequires: paraview-devel
BuildRequires: paraview-static-devel
BuildRequires: python3-mpi4py-devel
BuildRequires: pkgconfig(Qt6Core)
BuildRequires: pkgconfig(Qt6Gui)
BuildRequires: pkgconfig(Qt6Help)
BuildRequires: pkgconfig(Qt6Network)
BuildRequires: pkgconfig(Qt6Widgets)
BuildRequires: pkgconfig(Qt6Svg)
BuildRequires: pkgconfig(jsoncpp)
BuildRequires: pkgconfig(glu)
BuildRequires: netcdf-cxx-devel
BuildRequires: pkgconfig(xt)
BuildRequires: pkgconfig(glew)
BuildRequires: utf8cpp-devel
BuildRequires: pkgconfig(expat)
BuildRequires: pkgconfig(gl)
BuildRequires: pkgconfig(libtiff-4)
BuildRequires: lz4-devel
BuildRequires: pkgconfig(liblzma)
BuildRequires: pkgconfig(eigen3)
BuildRequires: double-conversion-devel
BuildRequires: pkgconfig(ogg)
BuildRequires: pkgconfig(theora)
BuildRequires: pkgconfig(pugixml)
BuildRequires: pkgconfig(libpng)
BuildRequires: utf8cpp-devel
BuildRequires: cgns-devel

Requires:      gcc-c++
Requires:      openmpi-devel

%description
OpenFOAM is a free, open source computational fluid dynamics (CFD)
software package released by the OpenFOAM Foundation. It has a large
user base across most areas of engineering and science, from both
commercial and academic organisations. OpenFOAM has an extensive range
of features to solve anything from complex fluid flows involving
chemical reactions, turbulence and heat transfer, to solid dynamics
and electromagnetics. This package provides the platform specific
binaries and modules located in %{binfoamdir} and %{libfoamdir},
respectively.



%package       tutorials
Summary:       Development files for %{name}
Group:         Sciences/Physics
Requires:      %{name} = %{version}

%description   tutorials
The %{name}-tutorials package contains tutorials and examples
for %{oname}.


%prep
%setup -q -n %{osrcname}-%{tag}
#autopatch -p1
%patch 0 -p1 -b .orig
sed -i "s|libARCH|%{_lib}|g" ./etc/config.sh/scotch
%patch 1 -p1 -b .orig
sed -i "s|libARCH|%{_lib}|g" ./etc/config.sh/paraview
sed -i "s|PVINSTLIBDIR|%{_libdir}|g" ./etc/config.sh/paraview

%patch 2 -p1 -b .orig


# aarch64/armv8l
%patch 4 -p1 -b .arm8aarch64
cp -ar wmake/rules/linux64Gcc wmake/rules/linuxAArch64Gcc
sed -i "/^\(CC\|cc\)/s/-m\(32\|64\)//" wmake/rules/linuxAArch64Gcc/*
sed -i "s|-m32||g" wmake/rules/linuxGcc/*
sed -i "s!^cOPT.*!cOPT = %{optflags}!" wmake/rules/linux*Gcc/cOpt
sed -ie "s!^c++OPT.*!c++OPT = %{optflags}!" wmake/rules/linux*Gcc/c++Opt


%if %{with_paraview}
%patch 6 -p1 -b .pvreader
%else
%__rm -r -f %{_builddir}/%{osrcname}/applications/utilities/postProcessing/graphics/PVReaders
%endif

%patch 7 -p1

%build
#Welcome to the best non-portable build system ever invented...

#Let's set mga compile flags in such a simple way
source %{_builddir}/%{osrcname}-%{tag}/etc/bashrc


#Let's also specify parallel make by hand
./Allwmake %{?_smp_mflags}

%install
#Clean object files, build residuals and other shits
find ./platforms/*/applications \( -name \*.o -o -name \*.dep \) -delete
find ./platforms/*/src \( -name \*.o -o -name \*.dep \) -delete
find ./platforms -name '*.la' -delete
find ./tutorials -name '.keep' -delete

#to be checked for arm?
%ifarch x86_64
PLATFORMDIR=./platforms/linux64GccDPInt32Opt
%endif
%ifarch %{ix86}
PLATFORMDIR=./platforms/linuxGccDPInt32Opt
%endif
%ifarch %{arm}
PLATFORMDIR=./platforms/linuxARM7GccDPInt32Opt
%endif
%ifarch aarch64
PLATFORMDIR=./platforms/linuxArm64GccDPInt32Opt
%endif

pushd $PLATFORMDIR
%__install -D ./bin/* -t %{buildroot}%{binfoamdir}
%__install -D ./lib/*.so -t %{buildroot}%{libfoamdir}
%__install -D ./lib/dummy/*.so -t %{buildroot}%{libfoamdir}/dummy

%if %{with_paraview}
%__install -D ./lib/paraview-%{pvversion}/*.so -t %{buildroot}%{libfoamdir}/paraview-%{pvversion}
%endif
%__install -D ./lib/openmpi-system/*.so -t %{buildroot}%{libfoamdir}/openmpi-system
popd

%__mkdir_p %{buildroot}%{datafoamdir}
cp -r -f tutorials -t %{buildroot}%{datafoamdir}/
cp -r -f bin -t %{buildroot}%{datafoamdir}/
cp -r -f etc -t %{buildroot}%{datafoamdir}/


# ld.conf.d file
%__install -d %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo %{libfoamdir} > %{buildroot}%{_sysconfdir}/ld.so.conf.d/openfoam.conf
echo %{libfoamdir}/dummy >> %{buildroot}%{_sysconfdir}/ld.so.conf.d/openfoam.conf
echo %{libfoamdir}/paraview-%{pvversion} >> %{buildroot}%{_sysconfdir}/ld.so.conf.d/openfoam.conf
echo %{libfoamdir}/openmpi-system >> %{buildroot}%{_sysconfdir}/ld.so.conf.d/openfoam.conf


# replace duplicates by symlinks
%fdupes -s %{buildroot}%{datafoamdir}/doc

%__install -D -m 755 %{SOURCE1} %{buildroot}%{_bindir}/openfoam

%files
%doc doc/Guides/*.pdf
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/openfoam.conf
%{_bindir}/openfoam
%{datafoamdir}/bin
%{datafoamdir}/etc
%{binfoamdir}
%{libfoamdir}


%files tutorials
%{datafoamdir}/tutorials
