%define	major		2.5
%define	libname		%mklibname openimageio %{major}
%define	develname	%mklibname openimageio -d

# The build scripts of openimageio downloads some test images at
# building time using git.
#
# To avoid this set -DOIIO_DOWNLOAD_MISSING_TESTDATA:BOOL in
# cmake configuration. Also there is the possibility to use a
# downloaded test images offline by setting the flag below
# 'with_offline_test_images', as follows:
#
# 1 -> use a previously downloaded offline test image archive.
# 0 -> don't use an offline test image archive
#
# (use the script in Source2 to generate the offline image tarball).
#
%define		with_offline_test_images	0

Name:		openimageio
Version:	2.5.18.0
Release:	%mkrel 5
Summary:	Library for reading and writing images
Group:		System/Libraries
License:	BSD
URL:		https://sites.google.com/site/openimageio/home
Source0:	https://github.com/AcademySoftwareFoundation/OpenImageIO/archive/v%{version}/OpenImageIO-%{version}.tar.gz
# script to build offline
Source1:	gen-test-images-archive.sh
%if %{with_offline_test_images}
Source2:	openimageio-%{version}-test-images.tar.gz
%endif
#
# from upstream
Patch10:	0001-build_Make-C++17-be-the-default.patch
#
#
# Mageia patches
#
Patch101:	0001-Allow-building-without-ARM-NEON-support.patch

BuildRequires:	boost-devel
BuildRequires:	clang-tools-extra
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	cmake(DCMTK)
BuildRequires:	cmake(tsl-robin-map)
BuildRequires:	giflib-devel
BuildRequires:	git-core
BuildRequires:	hdf5-devel
%ifarch aarch64 x86_64
BuildRequires:	openvdb-devel
%endif
BuildRequires:	pkgconfig(fmt)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(jasper)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(libraw_r)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libwebp)
BuildRequires:	pkgconfig(OpenColorIO)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(Ptex)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pybind11-devel
BuildRequires:	squish-devel
BuildRequires:	txt2man

BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6OpenGL)
BuildRequires:	cmake(Qt6OpenGLWidgets)
BuildRequires:	cmake(Qt6Widgets)

%description
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. Main features include:
- Extremely simple but powerful ImageInput and ImageOutput APIs for reading and
  writing 2D images that is format agnostic.
- Format plugins for TIFF, JPEG/JFIF, OpenEXR, PNG, HDR/RGBE, Targa, JPEG-2000,
  DPX, Cineon, FITS, BMP, ICO, RMan Zfile, Softimage PIC, DDS, SGI,
  PNM/PPM/PGM/PBM, Field3d.
- An ImageCache class that transparently manages a cache so that it can access
  truly vast amounts of image data.
- A really nice image viewer, iv, also based on OpenImageIO classes (and so
  will work with any formats for which plugins are available).

%package -n %{libname}
Summary:	A library for reading and writing images
Group:		System/Libraries

%description -n %{libname}
OpenImageIO is a library for reading and writing images.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for %{name} library.

%package -n python3-%{name}
Summary:	Python 3 bindings for %{name}
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python3-OpenImageIO = %{version}-%{release}

%description -n python3-%{name}
Python3 bindings for %{name}.

%prep
%if %{with_offline_test_images}
%autosetup -a 2 -n OpenImageIO-%{version} -Sgit_am
%else
%autosetup -n OpenImageIO-%{version} -Sgit_am
%endif

# Remove bundled pugixml
rm -f src/include/OpenImageIO/pugixml.hpp \
      src/include/OpenImageIO/pugiconfig.hpp \
      src/include/OpenImageIO/pugixml.cpp

# Remove bundled tbb
rm -rf src/include/tbb

# install ttf fonts in /usr/share/fonts/TTF
sed -i 's|/fonts/OpenImageIO|/fonts/TTF/OpenImageIO|' src/fonts/CMakeLists.txt

%build
# this defines the path where openimageio looks up for
# plugins: -DPLUGIN_SEARCH_PATH=%%{_libdir}/OpenImageIO%%{major}
%cmake -GNinja \
       -DPYTHON_VERSION=%{python3_version} \
       -DUSE_PYTHON:BOOL=ON \
       -DSTOP_ON_WARNING:BOOL=OFF \
       -DUSE_EXTERNAL_PUGIXML:BOOL=ON \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DVERBOSE:BOOL=ON \
       -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
       -DCMAKE_SKIP_RPATH:BOOL=ON \
       -DOIIO_DOWNLOAD_MISSING_TESTDATA:BOOL=OFF \
%if %{with_offline_test_images}
       -DOIIO_LOCAL_TESTDATA_ROOT=testsuite \
%endif
%ifarch %{arm32}
       -DOIIO_NO_NEON:BOOL=ON \
%endif
       %nil
%cmake_build

%install
%cmake_install

# Move man pages to the right directory
mkdir -p %{buildroot}%{_mandir}/man1
mv %{buildroot}%{_mandir}/*.1 %{buildroot}%{_mandir}/man1

rm -fr %{buildroot}%{_docdir}

%files
%license LICENSE.md
%{_bindir}/*
%{_xfontdir}/TTF/OpenImageIO
%{_mandir}/man1/*

%files -n %{libname}
%license LICENSE.md
%{_libdir}/libOpenImageIO.so.%{major}{,.*}
%{_libdir}/libOpenImageIO_Util.so.%{major}{,.*}

%files -n %{develname}
%doc CHANGES.md
%doc README.md
%license LICENSE.md
%{_libdir}/libOpenImageIO.so
%{_libdir}/libOpenImageIO_Util.so
%dir %{_includedir}/OpenImageIO
%{_includedir}/OpenImageIO/*
%{_libdir}/pkgconfig/OpenImageIO.pc
%{_libdir}/cmake/OpenImageIO/

%files -n python3-%{name}
%{python3_sitearch}/OpenImageIO/
