%define realname OpenIPMI
%define _disable_ld_no_undefined 1

#The lib naming in OpenIPMI 1.x
%define oldlibname %mklibname %realname 1

Name: 		openipmi
Summary: 	Library interface to OpenIPMI
Version:	2.0.36
Release:	%mkrel 1
License: 	LGPLv2+
Group: 		System/Kernel and hardware
URL: 		https://openipmi.sourceforge.net/
Source: 	https://downloads.sourceforge.net/openipmi/%{realname}-%{version}.tar.gz
Patch1:		0001-man.patch
BuildRequires:	swig >= 1.3
BuildRequires:	gdbm-devel
BuildRequires:	perl-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(netsnmp)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(readline)
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:	tkinter3
BuildRequires:	tk
BuildRequires:	pkgconfig(tk)
Requires(pre):	rpm-helper
Requires(post):	rpm-helper

# Perl is usually installed in /usr/lib, not /usr/lib64 on 64-bit platforms.
#define perl_libdir %%{_exec_prefix}/lib

%description 
This package contains a shared library implementation of IPMI and the
basic tools used with OpenIPMI.

%package devel
Summary:	Development files for OpenIPMI
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-lanserv = %{version}-%{release}
Requires:	%{name}-ui = %{version}-%{release}
Requires:	tcl-%{name} = %{version}-%{release}

%description devel
Contains additional files need for a developer to create applications
and/or middleware that depends on libOpenIPMI

%package -n perl-%{name}
Summary:	Perl interface for OpenIPMI
Group:		Development/Perl
Requires:	%{name} = %{version}-%{release}

%description -n perl-%{name}
A Perl interface for OpenIPMI.

%package -n python3-%{name}
Summary:	Python 3 interface for OpenIPMI
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
A Python 3 interface for OpenIPMI.

%package -n tcl-%{name}
Summary:	TCL interface for OpenIPMI
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
Requires:	tcl

%description -n tcl-%{name}
A TCL interface for OpenIPMI.

%package gui
Summary:	GUI (in python) for OpenIPMI
Group:		System/Kernel and hardware
Requires:	python3-%{name} = %{version}-%{release}
# mga#19117
Requires:	tix
Requires:	tkinter3

%description gui
A GUI interface for OpenIPMI.  Written in python an requiring wxWidgets.

%package ui
Summary:	User Interface (ui)
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description ui
This package contains a user interface

%package lanserv
Summary:	Emulates an IPMI network listener
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description lanserv
This package contains a network IPMI listener.

%prep
%setup -q -n %{realname}-%{version}
%autopatch -p1

sed -i 's|import Tix|import tix|' configure.ac

%build
export PYTHONDONTWRITEBYTECODE=
%configure \
	--disable-static \
	--with-perlinstall=%{perl_vendorarch} \
	--with-pythoninstall=%{python3_sitearch} \
	--with-python=%{__python3} \
	--with-tkinter=yes \
	--with-pythonusepthreads=yes \
	--with-perlusepthreads=yes \
	--with-tcl=yes \
	--with-tclcflags="-I %{_includedir}"

make

%install
%make_install PYTHON_GUI_DIR=openipmigui

find %{buildroot} -name '*.la' -delete

install -m755 ipmi.init -D %{buildroot}%{_sysconfdir}/init.d/ipmi
install -m644 ipmi.sysconf -D %{buildroot}%{_sysconfdir}/sysconfig/ipmi

# python shebangs
%py3_shebang_fix %{buildroot}%{_bindir}/openipmigui

%preun
%_preun_service ipmi

%postun
%_post_service ipmi

%files
%{_libdir}/libOpenIPMIcmdlang.so.*
%{_libdir}/libOpenIPMIglib.so.*
%{_libdir}/libOpenIPMIposix.so.*
%{_libdir}/libOpenIPMIpthread.so.*
%{_libdir}/libOpenIPMI.so.*
%{_libdir}/libOpenIPMIutils.so.*
%{_sysconfdir}/init.d/ipmi
%config(noreplace) %{_sysconfdir}/sysconfig/ipmi
%doc FAQ README README.Force
%doc README.MotorolaMXP

%files -n perl-%{name}
%{perl_vendorarch}/OpenIPMI.pm
%{perl_vendorarch}/auto/OpenIPMI
%doc swig/OpenIPMI.i swig/perl/sample swig/perl/ipmi_powerctl

%files -n python3-%{name}
%{python3_sitearch}/*OpenIPMI.*
%{python3_sitearch}/__pycache__/*
%doc swig/OpenIPMI.i

%files -n tcl-%{name}
%{_libdir}/*OpenIPMItcl.so.*

%files gui
%{python3_sitearch}/openipmigui/
%{_bindir}/openipmigui

%files devel
%{_includedir}/OpenIPMI/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%doc doc/IPMI.pdf

%files ui
%{_bindir}/ipmi_ui
%{_bindir}/ipmicmd
%{_bindir}/openipmicmd
%{_bindir}/ipmish
%{_bindir}/openipmish
%{_bindir}/solterm
%{_bindir}/rmcp_ping
%{_bindir}/openipmi_eventd
%{_libdir}/libOpenIPMIui.so.*
%{_mandir}/man1/ipmi_ui.1*
%{_mandir}/man1/openipmicmd.1*
%{_mandir}/man1/openipmish.1*
%{_mandir}/man1/openipmigui.1*
%{_mandir}/man1/solterm.1*
%{_mandir}/man1/rmcp_ping.1*
%{_mandir}/man1/openipmi_eventd.1*
%{_mandir}/man7/ipmi_cmdlang.7*
%{_mandir}/man7/openipmi_conparms.7*

%files lanserv
%config(noreplace) %{_sysconfdir}/ipmi/ipmisim1.emu
%config(noreplace) %{_sysconfdir}/ipmi/lan.conf
%{_bindir}/ipmilan
%{_bindir}/ipmi_sim
%{_bindir}/sdrcomp
%{_libdir}/libIPMIlanserv.so.*
%{_mandir}/man8/ipmilan.8*
%{_mandir}/man1/ipmi_sim.1*
%{_mandir}/man5/ipmi_lan.5*
%{_mandir}/man5/ipmi_sim_cmd.5*
