%global ppp_ver %(rpm -q --queryformat "%{VERSION}" ppp)

Summary:		An L2TP client/server, designed for VPN use
Name:			openl2tp
Version:		1.8
Release:		%mkrel 29
License:		GPLv2
Group:			System/Base
URL:			https://www.openl2tp.org/
Source0:		https://sourceforge.net/projects/openl2tp/files/openl2tp/%{version}/openl2tp-%{version}.tar.gz
Source1:		openl2tp.service
Source2:		openl2tp-tmpfiles.conf
Patch0:			openl2tp-1.8-make.patch
Patch1:			no-Werror.pach
Patch2:			fix-build-with-glibc-2.32.patch 
# From PLD
Patch3:			openl2tp-tirpc.patch
#
Patch4:			openl2tp-fix-build-with-gcc14.patch
Requires:		ppp = %{ppp_ver}
Requires:		readline >= 4.2
Requires:		rpcbind
Requires(post):		systemd >= %{systemd_required_version}
Requires(post):		rpm-helper
Requires(preun):	rpm-helper

BuildRequires:		pkgconfig(pppd) >= 2.4.8
BuildRequires:		pkgconfig(readline)
BuildRequires:		glibc >= 2.4
BuildRequires:		flex
BuildRequires:		bison
BuildRequires:		rpcgen
BuildRequires:		pkgconfig(libtirpc)
BuildRequires:		kernel-headers >= 2.6.23

%description
OpenL2TP is a complete implementation of RFC2661 - Layer Two Tunneling
Protocol Version 2, able to operate as both a server and a client. It
is ideal for use as an enterprise L2TP VPN server, supporting more
than 100 simultaneous connected users. It may also be used as a client
on a home PC or road warrior laptop.

OpenL2TP has been designed and implemented specifically for Linux. It
consists of

- a daemon, openl2tpd, handling the L2TP control protocol exchanges
  for all tunnels and sessions

- a plugin for pppd to allow its PPP connections to run over L2TP
  sessions

- a Linux kernel driver for efficient datapath (integrated into the
  standard kernel from 2.6.23).

- a command line application, l2tpconfig, for management.

%package devel
Summary: OpenL2TP support files for plugin development
Group: Development/Other

%description devel
This package contains support files for building plugins for OpenL2TP,
or applications that use the OpenL2TP APIs.

%prep
%autosetup -p0
# rpcgen generates only a subset of methods on armv7hl for some reason :(
%ifarch armv7hl
sed -i 's/L2TP_FEATURE_RPC_MANAGEMENT=.*/L2TP_FEATURE_RPC_MANAGEMENT=n/' Makefile
%endif

%build
%__make CFLAGS.optimize="%{optflags} $(pkg-config --cflags libtirpc) -Wno-unused-but-set-variable -Wno-error=format-truncation" SYS_LIBDIR=%{_libdir} PPPD_VERSION=%{ppp_ver} PPPD_SUBDIR=

%install
%make_install SYS_LIBDIR=%{_libdir} PPPD_VERSION=%{ppp_ver} PPPD_SUBDIR=
%{__mkdir} -p %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/openl2tp.service
%{__cp} -f etc/sysconfig/openl2tpd %{buildroot}%{_sysconfdir}/sysconfig/openl2tpd
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc README LICENSE
%{_tmpfilesdir}/%{name}.conf
%dir %{_libdir}/openl2tp
%{_sbindir}/openl2tpd
%{_libdir}/openl2tp/ppp_null.so
%{_libdir}/openl2tp/ppp_unix.so
%{_libdir}/openl2tp/ipsec.so
%{_libdir}/openl2tp/event_sock.so
%{_mandir}/man4/openl2tp_rpc.4.*
%{_mandir}/man5/openl2tpd.conf.5.*
%{_mandir}/man7/openl2tp.7.*
%{_mandir}/man8/openl2tpd.8.*
%{_unitdir}/openl2tp.service
%config %{_sysconfdir}/sysconfig/openl2tpd
%ifnarch armv7hl
%{_bindir}/l2tpconfig
%{_mandir}/man1/l2tpconfig.1.*
%endif

%files devel
%doc plugins/README doc/README.event_sock
%{_libdir}/openl2tp/l2tp_rpc.x
%{_libdir}/openl2tp/l2tp_event.h
%{_libdir}/openl2tp/event_sock.h


