%define         _disable_ld_no_undefined 0

%define         major                    40

%define         cxx_major                %{major}
%define         usempif08_major          %{major}
%define         usempi_ignore_major      %{major}
%define         mpifh_major              %{major}
%define         ompitrace_major          %{major}
%define         openpal_major            80
%define         prrte_major              3

%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d
%define         staticdevelname          %mklibname %{name} -s -d

%define         gccinstalldir   %(LC_ALL=C %__cc --print-search-dirs | grep install | %__awk '{print $2}')
%define         fincludedir     %{gccinstalldir}finclude

Summary:        An implementation of the Message Passing Interface
Name:           openmpi
Version:        5.0.6
Release:        %mkrel 1
License:        BSD
Group:          Development/Other

URL:            https://www.open-mpi.org/
Source0:        https://www.open-mpi.org/software/ompi/v4.1/downloads/openmpi-%{version}.tar.bz2

BuildRequires:  perl
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gawk
BuildRequires:  pkgconfig(pkg-config)
BuildRequires:  gcc-gfortran
%ifarch %ix86 x86_64
BuildRequires:  java-openjdk
BuildRequires:  quadmath-devel
BuildRequires:  librdmacm-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  binutils-devel
BuildRequires:  libibverbs-devel
BuildRequires:  libgomp-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(hwloc)
BuildRequires:  hwloc
BuildRequires:  autoconf
BuildRequires:  openpmix
BuildRequires:  openpmix-devel


#let's not build the devel docs (not for users)
#BuildRequires: python3-sphinx
#BuildRequires: python3-recommonmark

Requires:       %{libname} = %{version}-%{release}
Recommends:     %{develname} = %{version}-%{release}

Conflicts:      mpich
Conflicts:      mpich2
Conflicts:      lam

# 32 bits support dropped since 5.0.0
ExcludeArch: 	%{ix86}
ExcludeArch:    %{arm32}



%description
The Open MPI Project is an open source fully compliant MPI-3
implementation that is developed and maintained by a consortium of
academic, research, and industry partners. OpenMPI is therefore able
to combine the expertise, technologies, and resources from all across
the High Performance Computing community in order to build the best
MPI library available. OpenMPI offers advantages for system and
software vendors, application developers and computer science
researchers. This package contains all of the tools necessary to
compile, link, and run OpenMPI jobs.



%package -n %{libname}
Summary:        Shared libraries for OpenMPI
Group:          Development/Other
Provides:       lib%{name} = %{version}-%{release}
Obsoletes:      %{_lib}openmpi0 <= 1.5
# Build with wrong major:
Obsoletes:      %{_lib}openmpi1 < 1.10.0-2

%description -n %{libname}
%{summary}.



%package -n %{develname}
Summary:        Development files for OpenMPI
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
#was Requires
Recommends:     %{name} = %{version}-%{release}
Requires:       gcc-gfortran
Requires:       gcc-c++
Requires:       openpmix
Provides:       lib%{name}-devel  = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      lam-devel
Conflicts:      mpich1-devel
Conflicts:      mpich2-devel

%description -n %{develname}
%{summary}.



%package -n %{staticdevelname}
Summary:        Static Development files for OpenMPI
Group:          Development/Other
Requires:       %{develname} = %{version}-%{release}
Requires:       gcc-gfortran
Requires:       gcc-c++
Provides:       lib%{name}-static-devel  = %{version}-%{release}
Provides:       %{name}-static-devel = %{version}-%{release}
Conflicts:      lam-devel
Conflicts:      mpich1-devel
Conflicts:      mpich2-devel

%description -n %{staticdevelname}
%{summary}.



%prep
%setup -q
%autopatch -p1

%build


%configure \
	   --disable-silent-rules \
	   --enable-shared \
	   --enable-static \
	   --enable-mpi-fortran=all \
	   --disable-wrapper-rpath \
	   --disable-wrapper-runpath \
	   --with-pmix=external \
	   --with-hwloc=external

%make_build


%install
%make_install

%__rm -rf %{buildroot}%{_sysconfdir}/openmpi-totalview.tcl
%__rm -rf %{buildroot}%{_datadir}/libtool
%__rm -f %{buildroot}%{_datadir}/config.log
%__rm -f %{buildroot}%{_datadir}/omp.h


%__install -D -m 644 %{buildroot}%{_libdir}/mpi.mod %{buildroot}%{fincludedir}/mpi.mod
%__install -D -m 644 %{buildroot}%{_libdir}/mpi_ext.mod %{buildroot}%{fincludedir}/mpi_ext.mod
%__install -D -m 644 %{buildroot}%{_libdir}/mpi_f08.mod %{buildroot}%{fincludedir}/mpi_f08.mod
%__install -D -m 644 %{buildroot}%{_libdir}/mpi_f08_ext.mod %{buildroot}%{fincludedir}/mpi_f08_ext.mod
%__install -D -m 644 %{buildroot}%{_libdir}/mpi_f08_interfaces.mod %{buildroot}%{fincludedir}/mpi_f08_interfaces.mod
%__install -D -m 644 %{buildroot}%{_libdir}/mpi_f08_interfaces_callbacks.mod %{buildroot}%{fincludedir}/mpi_f08_interfaces_callbacks.mod
%__install -D -m 644 %{buildroot}%{_libdir}/mpi_f08_types.mod %{buildroot}%{fincludedir}/mpi_f08_types.mod
%__install -D -m 644 %{buildroot}%{_libdir}/pmpi_f08_interfaces.mod %{buildroot}%{fincludedir}/pmpi_f08_interfaces.mod
%__rm %{buildroot}%{_libdir}/*.mod
pushd %{buildroot}%{_libdir}
ln -s %{fincludedir}/*.mod  .
popd

find %{buildroot}%{_libdir} -name *.la -delete



%files
%doc README.md AUTHORS
%license LICENSE
%config(noreplace) %{_sysconfdir}/*
%{_bindir}/mpirun
%{_bindir}/mpiexec
%{_bindir}/prun
%{_bindir}/prte
%{_bindir}/prterun
%{_bindir}/prted
%{_bindir}/pterm
%{_bindir}/oshrun
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libompi_dbg_msgq.so
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.txt
%{_datadir}/%{name}/amca*
%{_datadir}/%{name}/*.supp
%{_datadir}/prte
%{_mandir}/man1/mpirun*
%{_mandir}/man1/ompi-*
%{_mandir}/man1/mpisync*
%{_mandir}/man1/prte*
%{_mandir}/man1/prun*
%{_mandir}/man1/pterm*
%{_mandir}/man5/prte*
%{_mandir}/man7/*
%{_docdir}/prrte/html



#may be splitted at some point
%files -n %{libname}
%doc README.md
%license LICENSE
%{_libdir}/libmpi.so.%{major}{,.*}
%{_libdir}/libmpi_usempif08.so.%{usempif08_major}{,.*}
%{_libdir}/libmpi_usempi_ignore*.so.%{usempi_ignore_major}{,.*}
%{_libdir}/libmpi_mpifh*.so.%{mpifh_major}{,.*}
%{_libdir}/libopen-pal*.so.%{openpal_major}{,.*}
%{_libdir}/libprrte.so.%{prrte_major}{,.*}

%files -n %{develname}
%doc examples/
%{_bindir}/mpif*
%{_bindir}/mpic*
%{_bindir}/mpiC*
%{_bindir}/opal*
%{_bindir}/ompi_*
%{_bindir}/prte_*
%{_bindir}/pcc
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.mod
%{fincludedir}/*.mod
%{_libdir}/pkgconfig/*.pc
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/mpi*
%{_mandir}/man1/mpif*
%{_mandir}/man1/mpic*
%{_mandir}/man1/ompi_*
%{_mandir}/man1/opal_wrapper*
%{_mandir}/man3/*
%{_docdir}/%{name}/html


%files -n %{staticdevelname}
%{_libdir}/*.a
%{_libdir}/%{name}/*.a
