%define url_ver	%(echo %{version} | tr '.' '_')

Summary:	Open source MSX emulator
Name:		openmsx
Version:	20.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Emulators
URL:		https://openmsx.sourceforge.net/
Source0:	https://github.com/openMSX/openMSX/releases/download/RELEASE_%{url_ver}/openmsx-%{version}.tar.gz
BuildRequires:	docbook-utils
BuildRequires:	python3
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(SDL2_ttf)
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(libxml-2.0)
Requires:	cbios-openmsx

# Catapult is no longer maintained
Obsoletes:	%{name}-catapult <= 19.1

%description
The open source MSX emulator that tries to achieve
near-perfect emulation by using a novel emulation model.

%files
%doc %{_docdir}/%{name}/
%license doc/GPL.txt
%{_bindir}/openmsx
%{_datadir}/openmsx/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_mandir}/man1/openmsx.1*
%dir %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/settings.xml

#--------------------------------------------------------------------

%prep
%autosetup -p1

# Make the custom flavour module, so we can use RPM OPT FLAGS here
cat > build/flavour-rpm.mk << EOF
# Opt flags.
CXXFLAGS+=%{build_cxxflags} -DNDEBUG
LINK_FLAGS+=%{build_ldflags}

# Dont strip exe, let rpm do it and save debug info
OPENMSX_STRIP:=false
EOF

# Build config
cat > build/custom.mk << EOF
PYTHON:=python3
INSTALL_BASE:=%{_prefix}
VERSION_EXEC:=false
SYMLINK_FOR_BINARY:=false
INSTALL_CONTRIB:=false
INSTALL_SHARE_DIR=%{_datadir}/%{name}
INSTALL_DOC_DIR=%{_docdir}/%{name}
EOF

%build
%configure
%make_build OPENMSX_FLAVOUR=rpm V=1

# Build the man page
docbook2man doc/openmsx.sgml -o ./

%install
%make_install OPENMSX_FLAVOUR=rpm V=1

rm -rf $RPM_BUILD_ROOT%{_docdir}/%{name}/GPL.txt

mv $RPM_BUILD_ROOT%{_datadir}/%{name}/machines/*.txt \
   $RPM_BUILD_ROOT%{_docdir}/%{name}

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
mv $RPM_BUILD_ROOT%{_datadir}/%{name}/settings.xml \
   $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
ln -s --target-directory=$RPM_BUILD_ROOT%{_datadir}/%{name} \
   ../../../etc/openmsx/settings.xml

mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
install -pm 0644 OPENMSX.1 $RPM_BUILD_ROOT%{_mandir}/man1/openmsx.1

# Install icon set
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/{16x16,32x32,48x48,64x64,128x128}/apps
for i in 16 32 48 64 128; do
install -pm 0644 share/icons/openMSX-logo-"$i".png \
    $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/"$i"x"$i"/apps/%{name}.png
done

# Install desktop file
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=openMSX
GenericName=MSX Emulator
Comment=Graphical interface for openMSX
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;Emulator;
Keywords=emulator;msx;openmsx;
EOF
