%define major		3
%define libname		%mklibname eac %{major}
%define develname	%mklibname eac -d

Name:		openpace
Version:	1.1.3
Release:	%mkrel 1
Summary:	Cryptographic library for EAC version 2
License:	GPL-3.0
Group:		Security
Url:		https://frankmorgner.github.io/openpace/
Source0:	https://github.com/frankmorgner/openpace/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires:	gengetopt
BuildRequires:	help2man
BuildRequires:	pkgconfig(libssl)
BuildRequires:	pkgconfig(python3)

# For tests
BuildRequires:	openssl

%description
OpenPACE implements Extended Access Control (EAC) version 2 as specified in BSI
TR-03110. OpenPACE comprises support for the following protocols:

* Password Authenticated Connection Establishment (PACE) Establish a secure
channel with a strong key between two parties that only share a weak secret.
Terminal Authentication (TA) Verify/prove the terminal's certificate (or rather
certificate chain) and secret key.

* Chip Authentication (CA) Establish a secure channel based on the chip's
static key pair proving its authenticy.

* Furthermore, OpenPACE also supports Card Verifiable Certificates (CV
Certificates) as well as easy to use wrappers for using the established secure
channels.

The handlers for looking up trust anchors during TA and CA (i.e. the CVCA and
the CSCA certificates) can be customized. By default, the appropriate
certificates will be looked up in the file system.

OpenPACE supports all variants of PACE (DH/ECDH, GM/IM), TA
(RSASSA-PKCS1-v1_5/RSASSA-PSS/ECDSA), CA (DH/ECDH) and all standardized domain
parameters (GFP/ECP).

#------------------------------------------------

%package -n	%{libname}
Summary:	Cryptographic library for EAC version 2
Group:		System/Libraries

%description -n %{libname}
EAC component library for %{name}.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	eac-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development with %{name}.

#------------------------------------------------

%package docs
Summary:	Documentation for %{name}
Group:		Documentation
BuildArch:	noarch

%description docs
Documentation files for %{name}.

#------------------------------------------------

%prep
%autosetup

%build
%configure \
	--disable-static \
	--disable-openssl-install \
	--disable-go \
	--disable-java \
	--disable-python \
	--disable-ruby
%make_build

%install
%make_install

mv %{buildroot}%{_bindir}/{,%{name}-}example

%check
#%%__make check

%files
%license COPYING
%{_sysconfdir}/eac/
%{_bindir}/cvc-create
%{_bindir}/cvc-print
%{_bindir}/eactest
%{_bindir}/%{name}-example
%{_mandir}/man1/*.1*

%files -n %{libname}
%license COPYING
%{_libdir}/libeac.so.%{major}{,.*}

%files -n %{develname}
%license COPYING
%{_includedir}/eac/
%{_libdir}/libeac.so
%{_libdir}/pkgconfig/libeac.pc

%files docs
%{_defaultdocdir}/%{name}/
