# limit parallel builds
%ifarch aarch64 x86_64
%global _smp_ncpus_max 4
%endif

%define uversion 2021.01
%define version %(echo %{uversion} | tr '-' '.')

Name:           openscad
Version:        %{version}
Release:        %mkrel 18
Summary:        The Programmers Solid 3D CAD Modeller
# COPYING contains a linking exception for CGAL
# AppData is CC0
License:        GPLv2 with exceptions and CC0
Group:          Graphics/3D
URL:            https://www.openscad.org/
Source0:        https://files.openscad.org/%{name}-%{name}-%{uversion}.tar.gz
Patch0:         openscad-polyclipping.patch
Patch1:         openscad-lib3mf.patch
# CGAL 5.3 fixes from https://github.com/openscad/openscad/pull/3844
Patch2:         openscad-cgal5.3.patch
# https://github.com/openscad/openscad/commit/9b79576c1ee9d57d0f4a5de5c1365bb87c548f36
Patch3:         openscad-2021.01-fix-overloaded-join.patch
# https://github.com/openscad/openscad/commit/71f2831c0484c3f35cbf44e1d1dc2c857384100b
Patch4:         openscad-2021.01-cgal-build-fix.patch
Patch5:         fix_fs_error.patch
# https://src.fedoraproject.org/rpms/openscad/raw/rawhide/f/openscad-2021.01-cgal6-cpp17.patch
Patch6:         openscad-2021.01-cgal6-cpp17.patch
#
# Security patches:
# P100 -> ...
#
Patch100:	CVE-2022-0496.patch
Patch101:	CVE-2022-0497.patch
BuildRequires:  bison
BuildRequires:  git
BuildRequires:  boost-devel
BuildRequires:  cgal-devel
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  imagemagick
BuildRequires:  gmp-devel
BuildRequires:  opencsg-devel
BuildRequires:  cmake(double-conversion)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(lib3mf)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(polyclipping)
BuildRequires:  pkgconfig(python3)
BuildRequires:  qscintilla-qt5-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gamepad)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  x11-server-xvfb

%description
OpenSCAD is a software for creating solid 3D CAD objects.
Unlike most free software for creating 3D models (such as the famous
application Blender) it does not focus on the artistic aspects of 3D
modeling but instead on the CAD aspects. Thus it might be the application
you are looking for when you are planning to create 3D models of machine
parts but pretty sure is not what you are looking for when you are more
interested in creating computer-animated movies.

%prep
%autosetup -S git -n %{name}-%{name}-%{uversion} -p1

# Unbundle polyclipping
rm -rf src/ext/polyclipping

%build
%qmake_qt5 VERSION=%{uversion} \
           PREFIX=%{_prefix} \
           CONFIG-=debug
%make_build

%if 0
# Build test suite
pushd tests
  cmake -DPYTHON_EXECUTABLE:STRING=%{__python3} .
  %make_build
popd
%endif
%install
%make_install INSTALL_ROOT=%{buildroot}

%check
# Run tests
pushd tests
  ctest %{?_smp_mflags} || : # let the tests fail, as some don't work on the BS
popd

%files
%doc COPYING README.md RELEASE_NOTES.md
%{_bindir}/%{name}
%{_metainfodir}/org.%{name}.OpenSCAD.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_iconsdir}/hicolor/*/apps/openscad.png
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}.1*
