%define major          33
%define libname        %mklibname %name %major
%define libnamedev     %mklibname %name -d
%define libname_sce    %mklibname %name-engine-sce %major
%define libnamedev_sce %mklibname %name-engine-sce -d

Name:           openscap
Version:        1.4.2
Release:        %mkrel 1
Summary:        Set of open source libraries enabling integration of the SCAP line of standards
Group:          System/Libraries
License:        LGPLv2+
URL:            https://www.open-scap.org/
# https://fedorahosted.org/releases/o/p/openscap/%%{name}-%%{version}.tar.gz
Source0:        https://github.com/OpenSCAP/openscap/releases/download/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  asciidoc
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  swig
BuildRequires:  libacl-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  openldap-devel
BuildRequires:  rpm-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(libcap)
# re-enable when an upstream port to procps 4.x
#BuildRequires:  pkgconfig(libproc2)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(opendbx)
BuildRequires:  pkgconfig(xmlsec1)
BuildRequires:  pkgconfig(xmlsec1-openssl)
BuildRequires:  pkgconfig(yaml-0.1)

%description
OpenSCAP is a set of open source libraries providing an easier path
for integration of the SCAP line of standards. SCAP is a line of standards
managed by NIST with the goal of providing a standard language
for the expression of Computer Network Defense related information.

%package -n %{libname}
Summary:        Set of open source libraries enabling integration of the SCAP line of standards
Group:          System/Libraries

%description -n %{libname}
OpenSCAP is a set of open source libraries providing an easier path
for integration of the SCAP line of standards. SCAP is a line of standards
managed by NIST with the goal of providing a standard language
for the expression of Computer Network Defense related information.


%package -n %{libnamedev}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{libnamedev}
The %{libnamedev} package contains libraries and header files for
developing applications that use %{name}.

%package -n     python3-%{name}
Summary:        Python 3 bindings for %{name}
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
BuildRequires:  pkgconfig(python3)

Provides:       openscap-python3 = %{version}-%{release}

%description -n python3-%{name}
The python3-%{name} package contains the bindings so that %{name}
libraries can be used by python3.

%package        perl
Summary:        Perl bindings for %{name}
Group:          Development/Perl
Requires:       %{name} = %{version}-%{release}
BuildRequires:  perl-devel

%description    perl
The %{name}-perl package contains the bindings so that %{name}
libraries can be used by perl.

%package        scanner
Summary:        OpenSCAP Scanner Tool (oscap)
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
BuildRequires:  pkgconfig(libcurl)

%description    scanner
The %{name}-scanner package contains oscap command-line tool. The oscap
is configuration and vulnerability scanner, capable of performing
compliance checking using SCAP content.

%package        utils
Summary:        OpenSCAP Utilities
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-scanner = %{version}-%{release}
Requires:       rpmdevtools
Requires:       rpm-build

%description    utils
The %{name}-utils package contains command-line tools build on top
of OpenSCAP library. Historically, openscap-utils included oscap
tool which is now separated to %{name}-scanner sub-package.

%package -n %{libname_sce}
Summary:        Script Check Engine plug-in for OpenSCAP
Group:          System/Libraries

%description -n %{libname_sce}
The Script Check Engine is non-standard extension to SCAP protocol. This
engine allows content authors to avoid OVAL language and write their assessment
commands using a scripting language (Bash, Perl, Python, Ruby, ...).

%package -n    %{libnamedev_sce}
Summary:        Development files for %{libname_sce}
Group:          Development/C
Requires:       %{libnamedev} = %{version}-%{release}
Requires:       %{libname_sce} = %{version}-%{release}
Provides:       %{name}-engine-sce-devel = %{version}-%{release}

%description -n %{libnamedev_sce}
The %{libnamedev_sce} package contains libraries and header files
for developing applications that use %{libname_sce}.

%package        containers
Summary:        Utils for scanning containers
Group:          System/Base
Requires:       %{name} >= %{version}-%{release}
Requires:       %{name}-scanner
BuildArch:      noarch

%description    containers
Tool for scanning Atomic containers.

%prep
%autosetup -p1

%build
# gconf is a legacy system not used any more, and it blocks testing of oscap-anaconda-addon
# as gconf is no longer part of the installation medium
%cmake \
       -DENABLE_DOCS=ON \
       -DENABLE_PROBES=ON \
       -DWITH_PCRE2=ON \
       -DOPENSCAP_PROBE_UNIX_GCONF=OFF \
       -DCMAKE_SHARED_LINKER_FLAGS=""

%cmake_build

%install
%cmake_install

%files
%doc AUTHORS NEWS README.md
%license COPYING
%doc %{_docdir}/%{name}/manual/
%{_datadir}/%{name}/

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n python3-%{name}
%{python3_sitearch}/*

%files perl
%{perl_vendorarch}/*
%{perl_vendorlib}/openscap_pm.pm

%files -n %{libnamedev}
%doc docs/{html,examples}/
%{_docdir}/%{name}/html/
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*.pc
%exclude %{_includedir}/%{name}/sce_engine_api.h

%files -n %{libnamedev_sce}
%{_libdir}/lib%{name}_sce.so
%{_includedir}/%{name}/sce_engine_api.h

%files scanner
%{_sysconfdir}/bash_completion.d/oscap
%{_bindir}/oscap
%{_mandir}/man8/oscap.8*

%files utils
%doc docs/oscap-scan.cron
%{_bindir}/autotailor
%{_bindir}/oscap-chroot
%{_bindir}/oscap-im
%{_bindir}/oscap-podman
%{_bindir}/oscap-run-sce-script
%{_bindir}/oscap-ssh
%{_bindir}/oscap-vm
%{_bindir}/scap-as-rpm
%{_mandir}/man8/autotailor.8*
%{_mandir}/man8/oscap-chroot.8*
%{_mandir}/man8/oscap-im.8.*
%{_mandir}/man8/oscap-podman.8*
%{_mandir}/man8/oscap-ssh.8*
%{_mandir}/man8/oscap-vm.8*
%{_mandir}/man8/scap-as-rpm.8*

%files -n %{libname_sce}
%{_libdir}/lib%{name}_sce.so.%{major}{,.*}

%files containers
%{_bindir}/oscap-docker
%{_mandir}/man8/oscap-docker.8*
%{python3_sitelib}/oscap_docker_python/
