# please before bumping the version of this package ensure there is a
# match between the openshadinglanguage version used in the blender
# package and in the upstream blender (the easiest way to check is to
# take just the upstream blender binaries at the same version level of
# our blender. run them and do a save system-info.txt from the Edit
# menu, so to get the list of library versions actually used); if a
# newer OSL package is needed, fork this package using something like:
#
# svn cp svn+ssh://svn.mageia.org/svn/packages/cauldron/openshadinglanguage1.11 \
#         svn+ssh://svn.mageia.org/svn/packages/cauldron/openshadinglanguage1.12
#
# (e.g. for forking from release 1.11 to 1.12). Then in the new
# package, fix the %libmajor, %apiversion and the newer name of the
# SPEC file accordingly.

%define fver		%{version}
%define libmajor	1.11
%define apiversion	1.11
%define pkgname		openshadinglanguage

%define libname		%mklibname %{pkgname} %{apiversion} %{libmajor}
%define develname	%mklibname -d %{pkgname} %{apiversion}

Name:		openshadinglanguage%{libmajor}
Version:	1.11.17.0
Release:	%mkrel 16
Summary:	A language for programmable shading in advanced renderers
Group:		Graphics/3D
License:	BSD-3-Clause
Url:		https://github.com/AcademySoftwareFoundation/OpenShadingLanguage
Source0:	https://github.com/AcademySoftwareFoundation/OpenShadingLanguage/archive/refs/tags/v%{version}.tar.gz#//OpenShadingLanguage-%{version}.tar.gz
# from git
Patch0:		0001-Support-for-LLVM-14-1492.patch
# Mageia patches
Patch100:	0001-Allow-building-without-ARM-NEON-support.patch
BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	cmake(pybind11)
BuildRequires:	clang
BuildRequires:	clang-devel
BuildRequires:	flex
BuildRequires:	llvm-devel
BuildRequires:	libboost-devel
BuildRequires:	ninja
BuildRequires:	openimageio
%ifnarch %{ix86} %{arm32}
BuildRequires:	partio-devel
%endif
%if %mgaversion < 9
BuildRequires:	pkgconfig(IlmBase)
%else
BuildRequires:	pkgconfig(Imath)
%endif
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(OpenImageIO) >= 2.0
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(numpy)

%description
Open Shading Language (OSL) is a small but rich language for
programmable shading in advanced renderers and other applications,
ideal for describing materials, lights, displacement, and pattern
generation.

%package -n %{libname}
Summary:	A language for programmable shading in advanced renderers
Group:		System/Libraries
Provides:	openshadinglanguage = %{version}-%{release}
Provides:	%{pkgname} = %{version}-%{release}
Provides:	lib%{pkgname} = %{version}-%{release}
Provides:	lib%{name} = %{version}-%{release}

%description -n %{libname}
Open Shading Language (OSL) is a small but rich language for
programmable shading in advanced renderers and other applications,
ideal for describing materials, lights, displacement, and pattern
generation.

This package contains the shared library of OpenShadingLanguage.

%package -n %{develname}
Summary:	Development files for the OpenShadingLanguage library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the OpenShadingLanguage library.

Install this package if you want to compile applications using the
OpenShadingLanguage library.

%package -n python3-%{name}
Summary:	Python files for the OpenShadingLanguage library
Group:		Development/Python	
Requires:	%{libname} = %{version}-%{release}
	
%description    -n python3-%{name}
Python bindinds for the OpenShadingLanguage.

%package -n openimageio-plugin-osl
Summary:	OSL plugin for OpenImageIO
Group:		Graphics/3D

%description -n openimageio-plugin-osl
OSL plugin for OpenImageIO.

%prep
%setup -q -n OpenShadingLanguage-%{fver}
%autopatch -p1

%build
# TODO: rebuild without -DSTOP_ON_WARNING:BOOL=OFF

# Note for packagers: the OpenImageIO plugin search path is defined with the
# configuration option "-DPLUGIN_SEARCH_PATH" in the openimageio.spec
# file. Please ensure that the file "osl.imageio.so" is placed at the
# right place to match the path defined in the openimageio package
# (which is %{_libdir} for now). Please do not move the plugin file manually in other places,
# unless fixing the path in the openimageio.spec file accordingly.
%cmake	-GNinja \
	-DCMAKE_CXX_STANDARD=17 \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DUSE_fPIC:BOOL=ON \
	-DENABLERTTI:BOOL=ON \
	-DUSE_BOOST_WAVE:BOOL=ON \
	-DOSL_BUILD_MATERIALX:BOOL=ON \
	-DOSL_SHADER_INSTALL_DIR:PATH=%{_datadir}/%{name} \
%ifarch %{arm32}
	-DOSL_OIIO_NO_NEON:BOOL=ON \
%endif
%ifarch %{ix86} %{arm32}
	-DUSE_PARTIO:BOOL=OFF \
%endif
	-DSTOP_ON_WARNING:BOOL=OFF
# avoid build break in simd which includes NEON armv8 instruction

%cmake_build

%install
%cmake_install

%files
%doc CHANGES.md CONTRIBUTING.md README.md
%license LICENSE.md
%{_bindir}/*
%{_datadir}/doc/OSL/*
%{_datadir}/%{name}

%files -n %{libname}
%{_libdir}/*.%{libmajor}{,.*}

%files -n %{develname}
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/cmake/OSL
%{_libdir}/pkgconfig/*.pc

%files -n python3-%{name}
%{python3_sitearch}/oslquery.so

%files -n openimageio-plugin-osl
%{_libdir}/osl.imageio.so
