%define oname    OpenTimelineIO

%define major     0
%define libname2  %mklibname opentime %{major}
%define libname   %mklibname %{name} %{major}
%define devname   %mklibname %{name} -d

# NOTE: upstream has not added any SOVERSION to the C++ libraries.
# In order to avoid any possible ambiguity, this has been patched to
# add VERSION but no SOVERSION, so that **each version bump is treated
# as incompatible** and will require dependents to be rebuilt.
# https://github.com/AcademySoftwareFoundation/OpenTimelineIO/issues/1182

# C++ and Python APIs have different build paths,
# not well designed to be built together
%bcond_with python

%define rjcommit 24b5e7a8b27f42fa16b96fc70aade9106cf7102f

Name:           opentimelineio
Version:        0.17.0
Release:        %mkrel 1
Summary:        Editorial timeline information API
Group:          System/Libraries
# OpenTimelineIO is Apache-2.0, rapidjson is MIT
License:        Apache-2.0 AND MIT
URL:            https://github.com/AcademySoftwareFoundation/OpenTimelineIO
Source0:        %{url}/archive/v%{version}/%{oname}-%{version}.tar.gz
Source1:        https://github.com/Tencent/rapidjson/archive/%{rjcommit}/rapidjson-%{rjcommit}.tar.gz

Source10:       0001-Use-system-rapidjson.patch
Patch1:         0002-CMake-fixes.patch

BuildRequires:  cmake
BuildRequires:  cmake(Imath)
BuildRequires:  cmake(RapidJSON)
%if %{with python}
BuildRequires:  cmake(pybind11)
BuildRequires:  python3-devel
%endif

Provides:       bundled(rapidjson) = %{rjcommit}

%description
OpenTimelineIO is an interchange format and API for editorial cut information.
OTIO contains information about the order and length of cuts and references to
external media. It is not however, a container format for media.

%package -n %{libname}
Summary:        Editorial timeline information API
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
OpenTimelineIO is an interchange format and API for editorial cut information.
OTIO contains information about the order and length of cuts and references to
external media. It is not however, a container format for media.

%package -n %{libname2}
Summary:        Editorial time information API
Group:          System/Libraries

%description -n %{libname2}
OpenTimelineIO is an interchange format and API for editorial cut information.
OTIO contains information about the order and length of cuts and references to
external media. It is not however, a container format for media.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname2} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Requires:       cmake(Imath)

%description -n %{devname}
OpenTimelineIO is an interchange format and API for editorial cut information.
OTIO contains information about the order and length of cuts and references to
external media. It is not however, a container format for media.

%if %{with python}
%package -n python3-%{name}
Summary:        Python interface for %{name}
Group:          Development/Python
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n python3-%{name}
OpenTimelineIO is an interchange format and API for editorial cut information.
OTIO contains information about the order and length of cuts and references to
external media. It is not however, a container format for media.

%package tools
Summary:        Additional tools for %{name}
Requires:       python3-%{name} = %{version}-%{release}

%description tools
Additional tools for %{name}.

%endif

%prep
%autosetup -p1 -n OpenTimelineIO-%{version} -a1
# Imath: system version used via OTIO_FIND_MATH
# rapidjson: snapshot needed for APIs added since last release
find src/deps/{Imath,rapidjson} -delete
mv rapidjson-%{rjcommit} src/deps/rapidjson

%build
%cmake \
  -DOTIO_CXX_INSTALL=ON \
%if %{with python}
  -DOTIO_PYTHON_INSTALL=ON \
  -DOTIO_PYTHON_INSTALL_DIR=%{python3_sitearch} \
%endif
  -DOTIO_FIND_IMATH=ON \
  -DOTIO_SHARED_LIBS=ON \
  -DOTIO_DEPENDENCIES_INSTALL=OFF
%cmake_build


%install
%cmake_install


%files -n %{libname}
%license LICENSE.txt NOTICE.txt
%doc README.md
%{_libdir}/libopentimelineio.so.%{major}{,.*}

%files -n %{libname2}
%license LICENSE.txt NOTICE.txt
%doc README.md
%{_libdir}/libopentime.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/opentime/
%{_includedir}/opentimelineio/
%{_libdir}/libopentime.so
%{_libdir}/libopentimelineio.so
%{_libdir}/cmake/opentime/
%{_libdir}/cmake/opentimelineio/

%if %{with python}
%files -n python3-%{name}
%{python3_sitearch}/opentimelineio-%{version}.*/
%{python3_sitearch}/opentimelineio/
%{python3_sitearch}/opentimelineview/

%files tools
%{_bindir}/otio*
%endif
