# Limit parallel builds
%global _smp_ncpus_max 4

%bcond_with docs

# OpenEXR support is optional:
# The new embedded version of half floating point types can be used instead of
# the Half implementation from IMath
%bcond_without openexr

%define major		11.0
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Name:		openvdb
Version:	11.0.0
Release:	%mkrel 7
Summary:	C++ library for sparse volumetric data discretized on three-dimensional grids
License:        MPLv2.0
Group:		System/Libraries
URL:		https://www.openvdb.org/
Source0:	https://github.com/AcademySoftwareFoundation/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
# OpenVDB no longer builds on 32bits with latest TBB due to OOM.
ExcludeArch:	%{ix86} %{arm}

BuildRequires:	cmake
BuildRequires:	ninja
%if %{with docs}
BuildRequires:	doxygen
BuildRequires:	dot
%endif
BuildRequires:	gcc-c++
BuildRequires:	ghostscript
BuildRequires:	python3dist(numpy)
BuildRequires:	boost-devel >= 1.57.0
BuildRequires:	cmake(pybind11)
BuildRequires:	pkgconfig(blosc)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:	pkgconfig(glfw3)
BuildRequires:	pkgconfig(jemalloc)
%if %{with openexr}
BuildRequires:	pkgconfig(OpenEXR)
%endif
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(zlib)
%if %{without docs}
Obsoletes:	%{name}-doc < %{version}-%{release}
%endif

%description
OpenVDB is an Academy Award-winning open-source C++ library comprising a novel
hierarchical data structure and a suite of tools for the efficient storage and
manipulation of sparse volumetric data discretized on three-dimensional grids.
It is developed and maintained by DreamWorks Animation for use in volumetric
applications typically encountered in feature film production.

This package contains some graphical tools.

%package -n	%{libname}
Summary:	Core OpenVDB libraries
Group:		System/Libraries

%description -n	%{libname}
OpenVDB is an Academy Award-winning open-source C++ library comprising a novel
hierarchical data structure and a suite of tools for the efficient storage and
manipulation of sparse volumetric data discretized on three-dimensional grids.
It is developed and maintained by DreamWorks Animation for use in volumetric
applications typically encountered in feature film production.

%package -n	%{develname}
Summary:        Development files for %{name}
Group:		Development/C++
Requires:       %{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for developing
applications that use %{name}.

%package -n	python3-%{name}
Summary:	OpenVDB Python 3 module
Group:		Development/Python
Requires:	%{libname} >= %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description -n	python3-%{name}
OpenVDB is an Academy Award-winning open-source C++ library comprising a novel
hierarchical data structure and a suite of tools for the efficient storage and
manipulation of sparse volumetric data discretized on three-dimensional grids.
It is developed and maintained by DreamWorks Animation for use in volumetric
applications typically encountered in feature film production.

This package contains the Python 3 module.

%package 	doc
Summary:	Documentation for %{name}
Group:		Documentation
BuildArch:	noarch

%description	doc
The %{name}-doc package contains documentation for developing applications that
use %{name}.

%prep
%autosetup -p1

# Hardcoded paths for installation, as described in the INSTALL file
sed -i \
    -e 's|lib$|%{_lib}|g' \
    %{name}/%{name}/CMakeLists.txt %{name}/%{name}/python/CMakeLists.txt

%build
%cmake -GNinja \
    -DOPENVDB_BUILD_DOCS=%{?with_docs:ON}%{?!with_docs:OFF} \
    -DCMAKE_NO_SYSTEM_FROM_IMPORTED=TRUE \
    -DDISABLE_DEPENDENCY_VERSION_CHECKS=ON \
    -DOPENVDB_ENABLE_RPATH=OFF \
    -DOPENVDB_BUILD_PYTHON_MODULE=ON \
    -DOPENVDB_INSTALL_CMAKE_MODULES=ON \
    -DPYOPENVDB_INSTALL_DIRECTORY=%{python3_sitearch} \
    -DOPENVDB_BUILD_UNITTESTS=OFF \
    -DUSE_IMATH_HALF=%{?with_openexr:ON}%{!?with_openexr:OFF} \
    -DUSE_NANOVDB=ON

%cmake_build %limit_build -m 8192

%install
%cmake_install

%if %{with docs}
# Let RPM pick up HTML documents in the files section
rm -fr %{buildroot}%{_prefix}/docs
%endif

find %{buildroot} -name '*.a' -delete

%files
%license LICENSE
%doc README.md CHANGES
%{_bindir}/vdb_print
%{_bindir}/nanovdb_{print,validate}

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/openvdb/
%{_includedir}/nanovdb/
%{_libdir}/lib%{name}.so
%{_libdir}/cmake/OpenVDB/

%files -n python3-%{name}
%{python3_sitearch}/py%{name}*.so

%if %{with docs}
%files doc
%doc build/openvdb/doc/html
%endif
