%define auth_ldap_version 2.0.4
%define easy_rsa_version 3.1.7
%define develname %mklibname %{name} -d


%define plugindir %{_libdir}/%{name}/plugins
%bcond_without ldap

%bcond_without tests_long

# There is an issue with gcc, so disable for amd64
# waiting reply/fix
%ifarch amd64
%bcond_without ldap
%endif

Summary:	A Secure TCP/UDP Tunneling Daemon
Name:		openvpn
Version:	2.6.14
Release:	%mkrel 1
URL:		https://openvpn.net/
Source0:	https://build.openvpn.net/downloads/releases/%{name}-%{version}.tar.gz
Source2:	https://github.com/threerings/openvpn-auth-ldap/archive/refs/tags/auth-ldap-%{auth_ldap_version}.tar.gz
Source3:	dhcp.sh
Source4:	openvpn-tmpfile.conf
Source5:	openvpn@.service
Source6:	openvpn.target
Source7:	https://github.com/OpenVPN/easy-rsa/releases/download/v%{easy_rsa_version}/EasyRSA-%{easy_rsa_version}.tgz
Patch2:		auth-ldap-tools-CFLAGS.patch
Patch4:		auth-ldap-remoteAddress.patch
Patch5:		auth-ldap-epel-gcc-objc.patch
Patch6:		auth-ldap-load-ldflags.patch

License:	GPLv2
Group:		Networking/Other
BuildRequires:	liblzo-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(libpkcs11-helper-1)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:  libcmocka-devel
BuildRequires:  python3-docutils
BuildRequires:  pkgconfig(libnl-genl-3.0)
%if %with ldap
BuildRequires:	gcc-objc
BuildRequires:	openldap-devel
BuildRequires:	re2c
%endif
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
OpenVPN is a robust and highly flexible tunneling application that  uses
all of the encryption, authentication, and certification features of the
OpenSSL library to securely tunnel IP networks over a single UDP port.


%package -n	%{develname}
Summary: 	Development package for OpenVPN plugins
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}

%description -n	%{develname}
OpenVPN .h files.

%if %with ldap
This package contains the auth-ldap plugin
%endif

%prep
%setup -q -n openvpn-%{version} -a 7
%if %with ldap
%setup -q -n openvpn-%{version} -a 2 -a 7
%{__mv} openvpn-auth-ldap-auth-ldap-%{auth_ldap_version}/README.md openvpn-auth-ldap-auth-ldap-%{auth_ldap_version}/README-openvpn-auth-ldap.md
pushd openvpn-auth-ldap-auth-ldap-%{auth_ldap_version}
./regen.sh
%patch -P 2 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
popd
%endif

%build
%serverbuild
%configure \
	--enable-systemd \
	--enable-pthread \
	--enable-pkcs11 \
        --enable-silent-rules \
	--enable-x509-alt-username \
	--enable-async-push \
	--with-crypto-library=openssl \
	--with-lzo-headers=%{_includedir}/lzo \
	--enable-password-save || cat config.log

%make_build

# plugins
%make_build -C src/plugins/down-root
%make_build -C src/plugins/auth-pam

%if %with ldap
pushd openvpn-auth-ldap-auth-ldap-%{auth_ldap_version}
%configure CFLAGS="%{optflags} -std=gnu99" \
	--with-openvpn=`pwd`/../include \
	--libdir=%{plugindir} \
	--with-objc-runtime=GNU
# workaround parallel build problem with generated header
%make_build -C tools
make -C src TRConfigParser.h
%make_build
popd
%endif

%install
mkdir -p %{buildroot}%{_datadir}/%{name}/easy-rsa

%make_install

pushd EasyRSA-%{easy_rsa_version}
cp -rp easyrsa %{buildroot}%{_datadir}/%{name}/easy-rsa/
cp -rp openssl-easyrsa.cnf %{buildroot}%{_datadir}/%{name}/easy-rsa/
cp -rp x509-types %{buildroot}%{_datadir}/%{name}/easy-rsa/
popd

install -d %{buildroot}%{_sysconfdir}/%{name}
# (cg) NB The sample config file is needed for drakvpn
cp -a sample/sample-{config-file,key,script}s %{buildroot}%{_datadir}/%{name}

install -d %{buildroot}%{_localstatedir}/lib/%{name}

# (cg) Nuke sysvinit script
rm -f %{buildroot}%{_datadir}/%{name}/sample-scripts/openvpn.init

# (cg) Add systemd units
install -D -m 644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/openvpn.conf
install -D -m 644 %{SOURCE5} %{buildroot}%{_unitdir}/openvpn@.service
install -D -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/openvpn.target
# and remove wrongly generated ones
%ifarch x86_64 aarch64
rm -f %{buildroot}/%{_libdir}/systemd/system/%{name}*.service
rm -f %{buildroot}/%{_libdir}/tmpfiles.d/%{name}.conf
%endif

# Additional examples
cp -a ./contrib %{buildroot}%{_datadir}/%{name}

#plugins
mkdir -p %{buildroot}%{plugindir}

%if %with ldap
pushd openvpn-auth-ldap-auth-ldap-%{auth_ldap_version}
%make_install
popd
%endif

install -m755 %{SOURCE3} %{buildroot}%{_datadir}/%{name}

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /bin/true

%post
# (cg) This is a templated unit, so we have to manually convert to systemd
if [ ! -f %{_localstatedir}/lib/rpm-helper/systemd-migration/%{name} ]; then
  if [ -f %{_sysconfdir}/rc3.d/S??%{name} ]; then
    for conf in %{_sysconfdir}/%{name}/*.conf; do
      [ "$conf" = "%{_sysconfdir}/%{name}/*.conf" ] && continue
      conf=$(basename $conf .conf)
      mkdir -p %{_sysconfdir}/systemd/system/%{name}.target.wants
      ln -s %{_unitdir}/%{name}@.service %{_sysconfdir}/systemd/system/%{name}.target.wants/%{name}@$conf.service
    done
    systemctl --quiet enable %{name}.target
  fi
  mkdir -p %{_localstatedir}/lib/rpm-helper/systemd-migration
  touch %{_localstatedir}/lib/rpm-helper/systemd-migration/%{name}
else
  # (cg) Older versions were not controlled by their own target
  UNITS=
  for unit in %{_sysconfdir}/systemd/system/multi-user.target.wants/%{name}@?*.service; do
    [ "$unit" = "%{_sysconfdir}/systemd/system/multi-user.target.wants/%{name}@?*.service" ] && continue
    UNITS="$UNITS $unit"
  done
  if [ -n "$UNITS" ]; then
    mkdir %{_sysconfdir}/systemd/system/%{name}.target.wants
    mv $UNITS %{_sysconfdir}/systemd/system/%{name}.target.wants
    systemctl --quiet enable %{name}.target
  fi
fi
%_tmpfilescreate %{name}
%_post_service %{name} %{name}.target

%preun
%_preun_service %{name} %{name}.target

%postun
%_postun_userdel %{name}

%check
# Test Crypto:
./src/openvpn/openvpn --genkey --secret key
./src/openvpn/openvpn --cipher aes-128-cbc --test-crypto --secret key
./src/openvpn/openvpn --cipher aes-256-cbc --test-crypto --secret key
./src/openvpn/openvpn --cipher aes-128-gcm --test-crypto --secret key
./src/openvpn/openvpn --cipher aes-256-gcm --test-crypto --secret key

%if %{with tests_long}
# Randomize ports for tests to avoid conflicts on the build servers.
cport=$[ 50000 + ($RANDOM % 15534) ]
sport=$[ $cport + 1 ]
sed -e 's/^\(rport\) .*$/\1 '$sport'/' \
    -e 's/^\(lport\) .*$/\1 '$cport'/' \
    < sample/sample-config-files/loopback-client \
    > %{_tmppath}/%{name}-%{version}-%{release}-%(%{__id_u})-loopback-client

sed -e 's/^\(rport\) .*$/\1 '$cport'/' \
    -e 's/^\(lport\) .*$/\1 '$sport'/' \
    < sample/sample-config-files/loopback-server \
    > %{_tmppath}/%{name}-%{version}-%{release}-%(%{__id_u})-loopback-server

pushd sample
# Test SSL/TLS negotiations (runs for 2 minutes):
../src/openvpn/openvpn --config \
    %{_tmppath}/%{name}-%{version}-%{release}-%(%{__id_u})-loopback-client &
../src/openvpn/openvpn --config \
    %{_tmppath}/%{name}-%{version}-%{release}-%(%{__id_u})-loopback-server
wait
popd

rm -f %{_tmppath}/%{name}-%{version}-%{release}-%(%{__id_u})-loopback-client \
    %{_tmppath}/%{name}-%{version}-%{release}-%(%{__id_u})-loopback-server
%endif

%files
%doc AUTHORS INSTALL PORTS
%doc COPYING COPYRIGHT.GPL README* doc/management-notes.txt Changes.rst
%doc doc/openvpn-examples.5.html doc/openvpn.8.html
%doc distro/systemd/README.systemd src/plugins/*/README.* doc/gui-notes.txt
%doc EasyRSA-%{easy_rsa_version}/ChangeLog EasyRSA-%{easy_rsa_version}/vars.example
%doc EasyRSA-%{easy_rsa_version}/README.quickstart.md EasyRSA-%{easy_rsa_version}/doc/EasyRSA-*.md

%if %with ldap
%doc openvpn-auth-ldap-auth-ldap-%{auth_ldap_version}/README-openvpn-auth-ldap.md
%endif
%{_mandir}/man5/%{name}*
%{_mandir}/man8/%{name}*
%{_sbindir}/%{name}
%{_datadir}/%{name}
%dir %{_sysconfdir}/%{name}
#{_datadir}/%%{name}/dhcp.sh
%{_unitdir}/%{name}*.service
%{_unitdir}/%{name}.target
%{_tmpfilesdir}/%{name}.conf
%dir %{_localstatedir}/lib/%{name}
%dir %{plugindir}
%{plugindir}/*

%files -n %{develname}
%{_includedir}/openvpn-plugin.h
%{_includedir}/openvpn-msg.h
