%define major   2
%define libname %mklibname openvr-api %{major}
%define devname %mklibname %{name} -d

# Samples aren't supported on 32bits
%ifarch %{ix86} %{arm}
%bcond_with samples
%else
%bcond_without samples
%endif

Name:           openvr
Version:        2.5.1
Release:        %mkrel 1
Summary:        OpenVR SDK
Group:          System/Libraries
License:        BSD-3-Clause
URL:            https://github.com/ValveSoftware/openvr
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
# Use GNUInstallDirs to determine lib install path
Patch1:         %{url}/pull/1511.patch
# Add ability to build with system installed jsoncpp
Patch2:         %{url}/pull/1716.patch
# Add option to neuter the steamvr check
Patch3:         openvr-skip-steamvr-check.patch
# Add ability to build with system installed SDL2 and Vulkan
Patch4:         openvr-use-system-sdl2-vulkan.patch
# Define soversion for the OpenVR API library
Patch5:         openvr-api-soversion.patch

BuildRequires:  cmake
BuildRequires:  cmake(jsoncpp)

%if %{with samples}
BuildRequires:  chrpath
BuildRequires:  glslang
BuildRequires:  glslc
BuildRequires:  sed

BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Widgets)
%endif

%description
OpenVR is an API and runtime that allows access to VR hardware from multiple
vendors without requiring that applications have specific knowledge of the
hardware they are targeting.

%package -n     %{libname}
Summary:        OpenVR API libraries
Group:          System/Libraries

%description -n %{libname}
OpenVR is an API and runtime that allows access to VR hardware from multiple
vendors without requiring that applications have specific knowledge of the
hardware they are targeting.

This package provides the shared libraries for the OpenVR Application API.

%package -n     %{devname}
Summary:        Development headers for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package provides the development headers for OpenVR.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
This package provides additional documentation for OpenVR.

%if %{with samples}
%package        samples
Summary:        OpenVR Samples
Group:          System/Libraries

%description    samples
This package provides various sample programs and drivers using OpenVR.
%endif

%prep
%autosetup -p1

# Delete prebuilt binaries and libraries
rm -r bin lib samples/bin/{android*,linux*,win*}

# Delete prebuilt shaders
rm samples/bin/shaders/*.spv

# Delete bundled library sources
rm -r thirdparty samples/thirdparty

%if %{with samples}
# Fix paths in samples
sed -i 's:../hellovr_actions.json:%{_datadir}/%{name}/hellovr_actions.json:' \
  samples/hellovr_opengl/hellovr_opengl_main.cpp
sed -i 's:../shaders/:%{_libdir}/%{name}/shaders/:' \
  samples/hellovr_vulkan/hellovr_vulkan_main.cpp
sed -i 's:../cube_texture.png:%{_datadir}/%{name}/cube_texture.png:' \
  samples/hellovr_opengl/hellovr_opengl_main.cpp \
  samples/hellovr_vulkan/hellovr_vulkan_main.cpp

# Disable broken simplehmd driver
# https://bugzilla.redhat.com/show_bug.cgi?id=2275022
sed -i '/simplehmd/d' samples/drivers/drivers/CMakeLists.txt
%endif

%build
# Build library
%cmake \
  -DINSTALL_PKGCONFIG_DIR=%{_libdir}/pkgconfig \
  -DBUILD_SHARED=ON \
  -DUSE_SYSTEM_JSONCPP=ON
%cmake_build

%if %{with samples}
# Build shaders
# see samples/bin/shaders/build_vulkan_shaders.bat
for f in samples/bin/shaders/*.hlsl; do
  base="$(dirname "$f")/$(basename "$f" .hlsl)"

  glslangValidator \
    -S vert \
    -e VSMain \
    -o "${base}_vs.spv" \
    -V \
    --hlsl-iomap \
    --auto-map-bindings \
    --shift-cbuffer-binding 0 \
    --shift-texture-binding 1 \
    --shift-sampler-binding 2 \
    -D "$f"

  glslangValidator \
    -S frag \
    -e PSMain \
    -o "${base}_ps.spv" \
    -V \
    --hlsl-iomap \
    --auto-map-bindings \
    --shift-cbuffer-binding 0 \
    --shift-texture-binding 1 \
    --shift-sampler-binding 2 \
    -D "$f"
done

# Build samples
pushd samples
%cmake \
  -DSKIP_STEAMVR_CHECK=ON \
  -DUSE_SYSTEM_SDL2=ON \
  -DUSE_SYSTEM_VULKAN=ON
%cmake_build
%endif

%install
%cmake_install

%if %{with samples}
# Samples have to be installed manually
install -Dpm0755 -t %{buildroot}%{_bindir} samples/bin/linux%{__isa_bits}/*
install -Dpm0644 -t %{buildroot}%{_datadir}/%{name} \
  samples/bin/*.json \
  samples/bin/cube_texture.png
install -Dpm0644 -t %{buildroot}%{_libdir}/%{name}/shaders \
  samples/bin/shaders/*.spv

# Fix runpath in samples
chrpath -d %{buildroot}%{_bindir}/*
%endif

%files -n %{libname}
%license LICENSE
%doc README.md
%{_libdir}/libopenvr_api.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/libopenvr_api.so

%files doc
%license LICENSE
%doc docs controller_callouts

%if %{with samples}
%files samples
%license LICENSE
%{_bindir}/hellovr_opengl
%{_bindir}/hellovr_vulkan
%{_bindir}/helloworldoverlay
%{_bindir}/tracked_camera_openvr_sample
%{_datadir}/%{name}/
%{_libdir}/%{name}/
%endif
