#
# spec file for package organicmaps
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself 

Name:           organicmaps
Version:        2024.11.27
Release:        %mkrel 2
Summary:        Offline maps app for travelers, tourists, hikers, and cyclists
License:        Apache-2.0
Group:          Geography
URL:            https://organicmaps.app/
# Present source file is obtain with the command:
# git clone --depth 1 --branch 2024.11.27-12-android https://github.com/organicmaps/organicmaps.git --recurse-submodules
# then removing unbundled repositories from 3party, .git and .github
# then renaming the root directory in organicmaps-<version>
# then compressing with xz
Source:         %{name}-%{version}-12.tar.xz
Patch:          organicmaps-fix-boost-change.patch
Patch:          organicmaps-configure_remove_boost.patch
Patch:          organicmaps-unbundle_boost.patch
Patch:          organicmaps-unbundle_glm.patch
Patch:          organicmaps-unbundle_pugixml.patch
Patch:          organicmaps-2024.11.27.remove_android_references.patch
Patch:          organicmaps-remove_shaders_compiler.patch
Patch:          organicmaps-unbundle_utf8.patch
Patch:          organicmaps-jansson_pkgconfig.patch
Patch:          organicmaps-rebundle_protobuf.patch
Patch:          organicmaps-rebundle_fast_double_parser.patch
# FIX-UPSTREAM  https://github.com/organicmaps/organicmaps/pull/9814
Patch:          9814.patch
# the application for desktop is not provided for 32 bits arches. See https://github.com/organicmaps/organicmaps/issues/8921
ExcludeArch:    %ix86 %arm
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  pkgconfig(gflags)
BuildRequires:  cmake(glm)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  cmake(pugixml)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Positioning)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(utf8cpp)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  rsync
BuildRequires:  vulkan-headers
Requires:       %{name}-data = %{version}

Provides:       bundled(agg)
Provides:       bundled(bsdiff-courgette)
Provides:       bundled(fast_obj)
Provides:       bundled(fast_double_parser)
Provides:       bundled(freetype)
Provides:       bundled(googletest)
Provides:       bundled(just_gtfs)
Provides:       bundled(libtess2)
Provides:       bundled(kdtree++)
Provides:       bundled(minizip)
Provides:       bundled(open-location-code)
Provides:       bundled(opening_hours)
Provides:       bundled(osrm)
Provides:       bundled(protobuf)
Provides:       bundled(robust)
Provides:       bundled(stb_image)
Provides:       bundled(vulkan_wrapper)

%description
Organic Maps is a free offline maps app for travelers, tourists, hikers, and 
cyclists. It uses crowd-sourced OpenStreetMap data and is developed with love by
MapsWithMe (MapsMe) founders and our community.

%package data
Summary:        Data for OrganicMaps
BuildArch:      noarch

%description data
Data files for OrganicMaps.

%prep
%autosetup -p1 -n %{name}-%{version}-12
echo "echo %{version} | sed 's/\.//g'" > tools/unix/version.sh

%build
bash ./configure.sh
%cmake \
    -DUNITY_DISABLE=OFF \
    -DSKIP_TESTS=ON \
    -DSKIP_TOOLS=ON \
    -DBUILD_SHARED_LIBS:BOOL=OFF \
    -DBUILD_STATIC_LIBS:BOOL=ON \
    -DWITH_SYSTEM_PROVIDED_3PARTY:BOOL=ON

%cmake_build

%install
%cmake_install

%files
%license LICENSE NOTICE
%doc README.md
%{_iconsdir}/hicolor/*/apps/organicmaps.png
%{_metainfodir}/app.organicmaps.desktop.metainfo.xml
%{_datadir}/applications/app.organicmaps.desktop.desktop
%{_bindir}/OMaps

%files data
%{_datadir}/%{name}/
