# FIXME: macro for unversioned doc dirs, exists since f20 - https://fedoraproject.org/wiki/Changes/UnversionedDocdirs
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

# Fedora uses %%_lib for %%libexecdir, redefine it here so we don't break os-autoinst paths
#global _libexecdir %%_libdir

# Fedora spec initially based on upstream spec file from OBS:
# https://build.opensuse.org/package/view_file/devel:openQA/os-autoinst/os-autoinst.spec
# License: GPLv2+

# Tests require perl-Test-Compile >= 1.1.0
%global with_tests 1

# os-autoinst has a bunch of annoyingly-badly-named private modules,
# we do not want automatic provides or requires for these
# ref https://fedoraproject.org/wiki/Packaging:AutoProvidesAndRequiresFiltering#Perl
# but per https://fedorahosted.org/fpc/ticket/591 , these have been
# improved, and contrary to the wiki it is safe to set them first and
# then call perl_default_filter, the values will be properly merged.
# I tried to sell upstream on naming these properly and installing
# them to the perl vendor dir, but they wouldn't bite.
# https://github.com/os-autoinst/os-autoinst/issues/387

%global __provides_exclude_from %{_libexecdir}/os-autoinst
%global __requires_exclude perl\\((autotest|backend|basetest|bmwqemu|commands|consoles|cv|distribution|lockapi|mmapi|needle|ocr|testapi)
%{?perl_default_filter}

%global github_owner    os-autoinst
%global github_name     os-autoinst
%global github_version  4.3
%global github_commit   8b5f22e8a84cc12b3ab8b24992fbb601048adc1b
# if set, will be a post-release snapshot build, otherwise a 'normal' build
#global github_date     20150423
%global shortcommit     %(c=%{github_commit}; echo ${c:0:7})

Name:           os-autoinst
Version:        %{github_version}
Release:        %mkrel 1%{?github_date:.%{github_date}git%{shortcommit}}
Summary:        OS-level test automation
License:        GPLv2+
Group:          Development/Other
URL:            https://os-autoinst.github.io/openQA/
Source0:        https://github.com/%{github_owner}/%{github_name}/archive/%{github_commit}/%{github_name}-%{github_commit}.tar.gz
# Fix 'format not a literal' warnings in snd2png
# https://github.com/os-autoinst/os-autoinst/pull/386
Patch0:         0001-use-fputs-rather-than-fprintf-to-avoid-format-not-a-.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  opencv-devel
BuildRequires:  perl-devel
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(ExtUtils::Embed)
BuildRequires:  perl(IPC::System::Simple)
BuildRequires:  perl(Module::CPANfile)
BuildRequires:  perl(Perl::Critic)
BuildRequires:  perl(Net::SSH2)
BuildRequires:  perl(Perl::Tidy)
BuildRequires:  perl(Pod::Html)
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(theoraenc)
BuildRequires:  systemd
%if 0%{?with_tests}
# The OO interface to Test::Compile only appeared in 1.1.0
BuildRequires:  perl(Test::Compile) >= 1.1.0
%endif # with_tests
Requires:       qemu-img
Requires:       qemu >= 2.0.0
Requires:       optipng
Requires:       tesseract
# locking wrapper script for cron
Requires:       withlock
# (doktor5000) perl Requires are autodetected, explicit Requires are disregarded
# FIXME: this macro is used for packages that are both BuildRequires and Requires
%define t_requires perl(Carp::Always) perl(Data::Dump) perl(Crypt::DES) perl(JSON)  perl(Class::Accessor::Fast)  perl(File::Which)  perl(IO::Socket::SSL) perl(IPC::Run::Debug) perl(Net::DBus) perl(Net::SNMP) perl(Perl::Tidy) perl(Test::Compile) perl(YAML) perl(Net::IP)
BuildRequires:  %{t_requires}
Requires:       %{t_requires}
BuildRequires:  perl(Mojolicious)
# require minimum version, automatic requires generation detects this only as unversionned perl(Mojolicious::Lite)
Requires:       perl(Mojolicious) >= 5.60
#Recommends:     eatmydata /usr/bin/multimon
Requires(pre):  %{_bindir}/getent
Requires(pre):  %{_sbindir}/useradd

%description
The OS-autoinst project aims at providing a means to run fully
automated tests. Especially to run tests of basic and low-level
operating system components such as boot-loader, kernel, installer and
upgrade, which can not easily and safely be tested with other
automated testing frameworks. However, it can just as well be used to
test applications on top of a newly installed OS.

%package openvswitch
Summary:        Open vSwitch support for os-autoinst
Requires:       openvswitch
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd

%description openvswitch
This package contains Open vSwitch support for os-autoinst.

%prep
%autosetup -p1 -n %{github_name}-%{github_commit}
#setup -q -n %%{github_name}-%%{github_commit}

%build
mkdir -p m4
autoreconf -f -i
%configure --docdir=%{_pkgdocdir}
make INSTALLDIRS=vendor

%install
%make_install INSTALLDIRS=vendor
# only internal stuff
rm %{buildroot}%{_libexecdir}/os-autoinst/tools/tidy
rm -r %{buildroot}%{_libexecdir}/os-autoinst/tools/lib/perlcritic
# we don't really need to ship this in the package, usually the web UI
# is much better for needle editing
rm %{buildroot}%{_libexecdir}/os-autoinst/crop.py*
# This is no use for package users
rm %{buildroot}%{_pkgdocdir}/INSTALL.asciidoc
# Pretty sure we don't need this, rpmlint complains
rm %{buildroot}%{_libexecdir}/os-autoinst/distri/.gitignore
ls -lR %buildroot
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -depth -type d -and -not -name distri -exec rmdir {} \;

# we need the stale symlinks to point to git
export NO_BRP_STALE_LINK_ERROR=yes

%check
%if 0%{?with_tests}
make check VERBOSE=1
%endif # with_tests

%post openvswitch
%_post_service os-autoinst-openvswitch.service

%preun openvswitch
%_preun_service os-autoinst-openvswitch.service

%files
%{_pkgdocdir}
%{perl_vendorarch}/tinycv.pm
%{perl_vendorarch}/auto/tinycv
#%dir %{_localstatedir}/lib/os-autoinst
#%{_localstatedir}/lib/os-autoinst/tests
%dir %{_libexecdir}/os-autoinst
%{_libexecdir}/os-autoinst/videoencoder
%{_libexecdir}/os-autoinst/basetest.pm
#
%{_libexecdir}/os-autoinst/consoles
%{_libexecdir}/os-autoinst/distri
%{_libexecdir}/os-autoinst/dmidata
#
%{_libexecdir}/os-autoinst/bmwqemu.pm
%{_libexecdir}/os-autoinst/commands.pm
%{_libexecdir}/os-autoinst/distribution.pm
%{_libexecdir}/os-autoinst/testapi.pm
%{_libexecdir}/os-autoinst/mmapi.pm
%{_libexecdir}/os-autoinst/lockapi.pm
%{_libexecdir}/os-autoinst/cv.pm
%{_libexecdir}/os-autoinst/ocr.pm
%{_libexecdir}/os-autoinst/needle.pm
%{_libexecdir}/os-autoinst/backend
%dir %{_libexecdir}/os-autoinst/tools
%{_libexecdir}/os-autoinst/tools/absolutize
%{_libexecdir}/os-autoinst/tools/preparepool
#%{_libexecdir}/os-autoinst/tools/lib/perlcritic/Perl/Critic/Policy/HashKeyQuotes.pm
%{_libexecdir}/os-autoinst/autotest.pm
%{_bindir}/debugviewer
%{_bindir}/isotovideo
%{_bindir}/snd2png
%dir %{_sysconfdir}/os-autoinst
%config(noreplace) %{_sysconfdir}/os-autoinst/kvm2usb.yml

%files openvswitch
%{_libexecdir}/os-autoinst/os-autoinst-openvswitch
%{_unitdir}/os-autoinst-openvswitch.service
%config %{_sysconfdir}/dbus-1/system.d/org.opensuse.os_autoinst.switch.conf

