# Warning, this package is synchronized with openSUSE and Fedora!

Name:           os-prober
Version:        1.81
Release:        %mkrel 2
Summary:        Probes disks on the system for installed operating systems
# For more information about licensing, see copyright file.
License:        GPLv2+ and GPL+
Group:          System/Boot and Init
Url:            https://kitenet.net/~joey/code/%{name}/
Source0:        https://ftp.debian.org/debian/pool/main/o/%{name}/%{name}_%{version}.tar.xz
# add bsd detection script Mga#18271 (r1007407 & r1008727)
Source2:        91bsd
Source3:        60ufs-test
# OpenSuSE patch: Fix spelling of SUSE aj@suse.de
Patch1:         os-prober-SUSE.patch
# OpenSuSE patch: Fix parsing of grub.cfg [bnc#796919]
Patch3:         os-prober-1.49-fix-grub2.cfg-parsing.patch
# OpenSuSE patch: Probe also unpartitioned Linux MD devices (bnc#811006)
Patch7:         os-prober-probe-MD-devices.patch
# OpenSuSE patch: Detect linux secure boot entries too (bnc#810912)
Patch8:         os-prober-linux-secure-boot.patch
# OpenSuSE patch: btrfs support from Fedora (rediffed)
Patch9:         os-prober-btrfsfix.patch
# OpenSuSE patch: difference between upstream and our previous scripts
Patch10:        os-prober-EFI-openSUSEfy.patch
# OpenSuSE patch: accept ESP on IMSM MD raid (bnc#818871)
Patch11:        os-prober-accept-ESP-on-IMSM.patch
# OpenSuSE patch: don't modprobe all file system modules and don't test mount on unknown partition (bnc#851722)
Patch12:        os-prober-dont-load-all-fs-module-and-dont-test-mount.patch
# OpenSuSE patch: fix os-prober entries for distro on btrfs root-fs not created (bnc#846003)
Patch13:       os-prober-fix-btrfs-subvol-mounted-tests.patch
# SLE patch: fix os-prober creates many unusuable entries on multipath disk (bnc#875327)
Patch14:       os-prober-skip-part-on-multipath.patch
# SLE patch: fix os-prober fails to detect other SLES12 installation (bsc#892364)
Patch17:       Improve-btrfs-handling-on-os-probing-for-grub2.patch
# SLE patch: fix os-prober mount error, no such file or directory (bsc#931955)
# OpenSuSE modification: the do_unmount has to be skipped for btrfs as it removes tmp mount point of which btrfs is making use (bsc#1024196)
Patch18:       os-prober-btrfs-absolute-subvol.patch
# OpenSuSE patch: also skip legacy grub if /boot/grub2/grub.cfg is present
Patch19:       os-prober-40grub-check-grub2.patch
# OpenSuSE patch: detect os on default subvolume in snapshot (bsc#954225)
Patch21:       os-prober-btrfs-snapshot-detection.patch
# OpenSuSE patch: os-prober update broke Linux detection (bsc#957018)
Source22:       os-prober-btrfs-always-detect-default.patch
# OpenSuSE patch: y2base runs at 100% cpu busy from beginning in installation of files to completion (bsc#953987)
Patch23:       os-prober-linux-distro-avoid-expensive-ld-file-test.patch
# OpenSuSE patch: Leap does not recognize Tumbleweed any more (bsc#997465)
Patch24:       os-prober-linux-distro-parse-os-release.patch

# FEDORA:
# improve slow os-prober (rhbz#875356)
# https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=694668
Patch110:        os-prober-factor-out-logger.patch
Patch111:        os-prober-factored-logger-efi-fix.patch
Patch112:        os-prober-efi-shell.patch
# More Fedora patches
Patch113:        os-prober-umount-fix.patch
Patch114:        os-prober-grepfix.patch
Patch115:        os-prober-mounted-partitions-fix.patch
Patch116:        os-prober-bootpart-name-fix.patch
Patch117:        os-prober-no-dummy-mach-kernel.patch
#Patch118:        os-prober-grub2-mount-workaround.patch
Patch119:        os-prober-arm64-win11.patch

Requires:       grep
Requires:       sed
Requires:       kmod
Requires:       btrfs-progs
Requires:       coreutils
Requires:       udev
Requires:       util-linux
Requires:       dmsetup
Recommends:     dmraid
Recommends:     lvm2

%description
This package detects other OSes available on a system and outputs the results
in a generic machine-readable format. Support for new OSes and Linux
distributions can be added easily.

%prep
%autosetup -p1

# Replace blkid with /sbin/blkid Mga#16803
/bin/sed -i 's:(blkid:(/sbin/blkid:g' common.sh
/bin/sed -i 's:pe blkid:pe /sbin/blkid:g' common.sh

find -type f -exec sed -i -e 's|usr/lib|usr/libexec|g' {} \;

sed -i -e 's|grub-probe|grub2-probe|g' os-probes/common/50mounted-tests \
    linux-boot-probes/common/50mounted-tests
sed -i -e 's|grub-mount|grub2-mount|g' os-probes/common/50mounted-tests \
     linux-boot-probes/common/50mounted-tests common.sh

%build
%set_build_flags
%make_build LDFLAGS="$LDFLAGS -fPIC" CFLAGS="$CFLAGS" CPPFLAGS="$CPPFLAGS"

%install
install -m 0755 -d %{buildroot}%{_bindir}
install -m 0755 -d %{buildroot}%{_localstatedir}/lib/%{name}

install -m 0755 -p os-prober linux-boot-prober %{buildroot}%{_bindir}
install -m 0755 -Dp newns %{buildroot}%{_libexecdir}/os-prober/newns
install -m 0644 -Dp common.sh %{buildroot}%{_datadir}/%{name}/common.sh

# add bsd detection script Mga#18271 (r1007407 & r1008727)
mkdir -p os-probes/common/ufs
cp -a %{SOURCE2} os-probes/common/ufs/91bsd
cp -a %{SOURCE3} os-probes/common/60ufs-test

%ifarch %{ix86} x86_64
ARCH=x86
%endif

for probes in os-probes os-probes/mounted os-probes/init \
              linux-boot-probes linux-boot-probes/mounted; do
        install -m 755 -d %{buildroot}%{_libexecdir}/$probes
        cp -a $probes/common/* %{buildroot}%{_libexecdir}/$probes
        if [ -e "$probes/$ARCH" ]; then
                cp -a $probes/$ARCH/* %{buildroot}%{_libexecdir}/$probes
        fi
done

ln -sf ../ufs/91bsd %{buildroot}%{_libexecdir}/os-probes/mounted/91bsd

if [ "$ARCH" = x86 ]; then
        install -m 755 -p os-probes/mounted/powerpc/20macosx \
            %{buildroot}%{_libexecdir}/os-probes/mounted
fi

%files
%doc README TODO debian/changelog
%license debian/copyright
%{_bindir}/*
%{_libexecdir}/*
%{_datadir}/%{name}
%{_localstatedir}/lib/%{name}
