%define pgsql 0

# commandline overrides:
# rpm -ba|--rebuild --with 'xxx'
%{?_with_pgsql: %{expand: %%global pgsql 1}}
%{?_without_pgsql: %{expand: %%global pgsql 0}}

%define major     16
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:		ossp_uuid
Version:	1.6.2
Release:	%mkrel 33
Summary:	OSSP uuid is a ISO-C:1999 application programming interface
License:	GPLv2+
Group:		Development/C
URL:		http://www.ossp.org/pkg/lib/uuid/
Source:		ftp://ftp.ossp.org/pkg/lib/uuid/uuid-%{version}.tar.gz
Patch0:		uuid-1.6.2-fix-perl-install.patch
Patch1:		uuid-1.6.2-fix-php-install.patch
# Fedora patches
Patch3:		uuid-1.6.1-ossp.patch
Patch4:		uuid-1.6.2-nostrip.patch
Patch5:		uuid-1.6.2-manfix.patch
Patch6:		uuid-aarch64.patch
%if %{pgsql}
BuildRequires:	postgresql-devel
%endif
BuildRequires:	perl-devel

%description
OSSP uuid is a ISO-C:1999 application programming interface (API)
and corresponding command line interface (CLI) for the generation of
DCE 1.1, ISO/IEC 11578:1996 and IETF RFC-4122 compliant Universally
Unique Identifier (UUID). It supports DCE 1.1 variant UUIDs of version
1 (time and node based), version 3 (name based, MD5), version 4
(random number based) and version 5 (name based, SHA-1). Additional
API bindings are provided for the languages ISO-C++:1998, Perl:5 and
PHP:4/5. Optional backward compatibility exists for the ISO-C DCE-1.1
and Perl Data::UUID APIs

%package -n     %{libname}
Summary:        Main library for ossp-uuid
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
OSSP uuid is a ISO-C:1999 application programming interface (API)
and corresponding command line interface (CLI) for the generation of
DCE 1.1, ISO/IEC 11578:1996 and IETF RFC-4122 compliant Universally
Unique Identifier (UUID). It supports DCE 1.1 variant UUIDs of version
1 (time and node based), version 3 (name based, MD5), version 4
(random number based) and version 5 (name based, SHA-1). Additional
API bindings are provided for the languages ISO-C++:1998, Perl:5 and
PHP:4/5. Optional backward compatibility exists for the ISO-C DCE-1.1
and Perl Data::UUID APIs

%package        -n     %{develname}
Summary:        Header files for the ossp-uuid library
Group:          Development/C
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description    -n %{develname}
OSSP uuid is a ISO-C:1999 application programming interface (API)
and corresponding command line interface (CLI) for the generation of
DCE 1.1, ISO/IEC 11578:1996 and IETF RFC-4122 compliant Universally
Unique Identifier (UUID). It supports DCE 1.1 variant UUIDs of version
1 (time and node based), version 3 (name based, MD5), version 4
(random number based) and version 5 (name based, SHA-1). Additional
API bindings are provided for the languages ISO-C++:1998, Perl:5 and
PHP:4/5. Optional backward compatibility exists for the ISO-C DCE-1.1
and Perl Data::UUID APIs
These are .h files.

%package -n perl-OSSP-uuid
Summary:        Perl bindings for ossp-uuid
Group:          System/Libraries

%description -n perl-OSSP-uuid
This package contains perl bindings for %{name}.

%if %{pgsql}
%package -n     %{libname}-pgsql
Summary:        Postgresql library for ossp-uuid
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}-pgsql
OSSP uuid is a ISO-C:1999 application programming interface (API)
and corresponding command line interface (CLI) for the generation of
DCE 1.1, ISO/IEC 11578:1996 and IETF RFC-4122 compliant Universally
Unique Identifier (UUID). It supports DCE 1.1 variant UUIDs of version
1 (time and node based), version 3 (name based, MD5), version 4
(random number based) and version 5 (name based, SHA-1). Additional
API bindings are provided for the languages ISO-C++:1998, Perl:5 and
PHP:4/5. Optional backward compatibility exists for the ISO-C DCE-1.1
and Perl Data::UUID APIs
%endif

%prep
%setup -q  -n uuid-%{version}
%patch -P 0 -p 1
%patch -P 1 -p 1

%patch -P 3 -p1 -b .ossp
%patch -P 4 -p1 -b .nostrip
%patch -P 5 -p1 -b .manfix
%patch -P 6 -p1 -b .aarch64

sed -i 's|\${exec_prefix}/lib|\${exec_prefix}/%{_lib}|' uuid.pc.in

%build
%configure \
    --disable-static \
    --includedir=%{_includedir}/ossp \
%if %{pgsql}
    --with-pgsql \
%endif
    --with-perl \
    --without-php
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

# ensure libraries are executable for proper -debuginfo extraction
chmod a+rx %{buildroot}%{_libdir}/libossp-uuid.so.*

%if %{pgsql}
%post -n  %{libname}-pgsql
/bin/ln -s %{_libdir}/postgresql/uuid.so %{_libdir}/postgresql/uuid-ossp.so

%postun -n  %{libname}-pgsql
/bin/rm -f %{_libdir}/postgresql/uuid-ossp.so
%endif

%files
%doc OVERVIEW
%{_bindir}/uuid
%{_mandir}/man1/uuid.1*

%files -n %{libname}
%{_libdir}/libossp-uuid.so.%{major}{,.*}

%files  -n %{develname}
%{_libdir}/pkgconfig/ossp-uuid.pc
%dir %{_includedir}/ossp
%{_includedir}/ossp/uuid.h
%{_bindir}/uuid-config
%{_libdir}/libossp-uuid.so
%{_mandir}/man1/uuid-config.1*
%{_mandir}/man3/ossp-uuid.3*

%files -n perl-OSSP-uuid
%{perl_vendorarch}/OSSP
%{perl_vendorarch}/auto/OSSP
%{_mandir}/man3/OSSP::uuid.3*

%if %{pgsql}
%files -n %{libname}-pgsql
%{_libdir}/postgresql/uuid.so
%{_usr}/share/postgresql/uuid.sql
%endif
