# Warning: This package is synchronized with Fedora!

%define		major     1
%define		api       1
%define		gir_major 1.0
%define		libname   %mklibname ostree %{major}
%define		girname   %mklibname ostree-gir %{gir_major}
%define		develname %mklibname ostree -d

Summary:	Tool for managing bootable, immutable filesystem trees
Name:		ostree
Version:	2025.1
Release:	%mkrel 1
Group:		System/Packaging
License:	LGPLv2+
URL:		https://ostree.readthedocs.io/en/latest/
Source0:	https://github.com/ostreedev/%{name}/releases/download/v%{version}/libostree-%{version}.tar.xz
Source1:	91-ostree.preset

BuildRequires:	git-core
# We always run autogen.sh
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	bison
# For docs
BuildRequires:	gtk-doc
# Core requirements
BuildRequires:	pkgconfig(libcurl)
# Ensure we don't get compat library
BuildRequires:	openssl-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libsoup-3.0)
BuildRequires:	libattr-devel
# Extras
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(libselinux)
BuildRequires:	pkgconfig(libcrypto)
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(fuse3)
BuildRequires:	pkgconfig(e2p)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	gpgme-devel
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	dracut

# Runtime requirements
Requires:	dracut
Requires:	gnupg2
Requires:	systemd-units

%description
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of traditional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n %{libname}
Summary:	Tool for managing bootable, immutable filesystem trees
Group:		System/Libraries

%description -n %{libname}
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of traditional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n %{develname}
Summary:	Development headers for %{name}
Group:		Development/C
Requires:	%{name}%{?_isa} =  %{?epoch:%{epoch}:}%{version}-%{release}
Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	%{girname}%{?_isa} = %{version}-%{release}

%description -n %{develname}
This package includes the header files for the %{name} library.

%package -n %{girname}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

%ifnarch s390 s390x
%package	grub2
Summary:	GRUB2 integration for OSTree
Group:		System/Boot and Init
%ifnarch aarch64 %{arm}
Requires:	grub2
%else
Requires:	grub2-efi
%endif

%description grub2
GRUB2 integration for OSTree.
%endif

%package	tests
Summary:	Tests for the %{name} package
Group:		Development/C
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description tests
This package contains tests that can be used to verify
the functionality of the installed %{name} package.


%prep
%autosetup -n libostree-%{version} -p1

%build
export YACC="bison -y"
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules \
	   --enable-gtk-doc \
	   --with-selinux \
	   --with-curl \
	   --with-openssl \
	   --with-soup3 \
	   --enable-installed-tests=exclusive \
	   --with-dracut=yesbutnoconf \
	   --disable-http2
%make_build

%install
%make_install

install -D -m 0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/systemd/system-preset/91-ostree.preset

%post
%systemd_post ostree-remount.service

%preun
%systemd_preun ostree-remount.service

%files
%license COPYING
%doc README.md
%{_bindir}/ostree
%{_bindir}/rofiles-fuse
%{_datadir}/ostree/
%{_datadir}/bash-completion/completions/*
%{_sysconfdir}/ostree
%dir %{_prefix}/lib/dracut/modules.d/98ostree
%{_unitdir}/ostree*.*
%{_prefix}/lib/dracut/modules.d/98ostree/*
%{_mandir}/man*/*.*
%{_systemdgeneratordir}/ostree-system-generator
%{_presetdir}/91-ostree.preset
%exclude %{_sysconfdir}/grub.d/*ostree
%{_tmpfilesdir}/*
%dir %{_prefix}/lib/ostree
%{_prefix}/lib/ostree/ostree-prepare-root
%{_prefix}/lib/ostree/ostree-remount

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}-%{api}.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_datadir}/gtk-doc/html/ostree
%{_datadir}/gir-1.0/OSTree-1.0.gir

%files -n %{girname}
%{_libdir}/girepository-1.0/OSTree-%{gir_major}.typelib

%ifnarch s390 s390x
%files grub2
%{_sysconfdir}/grub.d/*ostree
# Co-own
%dir %{_libexecdir}/libostree
%{_libexecdir}/libostree/grub2*
#{_libexecdir}/libostree/s390x-se-luks-gencpio
%endif

%files tests
%{_libexecdir}/installed-tests
%{_datadir}/installed-tests
# Co-own
%dir %{_libexecdir}/libostree
%{_libexecdir}/libostree/grub2-15_ostree
