# default to enable (and build only) mpi
# No mpi on 32bits with openmpi 5 in Mageia 10+
%ifarch %{ix86} %{arm32}
%bcond_with                     mpi
%else
%bcond_without                  mpi
%endif

# VTK currently requires fmt 9.x, currently we have 11.x
%bcond_with fmt

#reminder: pay attention to NOT compile openmpi with
#--enable-rpath-wrappers, otherwise paraview-mpi binaries end up
#having a RUNPATH taking precedence over /etc/ld.conf.d/ settings

%define baseversion             %(echo %{version} | cut -d. -f-2)
%define namever                 %{name}-%{baseversion}

%define staticdevelname         %mklibname -d -s %{name}

# some sources will need more than 4GB of memory to built
# (vtkExtractVOI.cxx), gcc gets killed, let's reduce on arm and
# i586 (mind the 32h limit)
%ifarch %{arm} %{ix86}
%define _smp_ncpus_max          $(expr $(nproc) / 2)
%define paraflags               %{optflags} -O1
%else
%define _smp_ncpus_max          $(expr $(nproc) / 2)
%define paraflags               %{optflags}
%endif

# Do not provide anything in paraview's library directory
%global __provides_exclude_from ^(%{_libdir}/paraview/|%{_libdir}/.*/lib/paraview/).*$

# Do not require anything provided in paraview's library directory
# This list needs to be maintained by hand
%global __requires_exclude ^lib(LegacyGhostCellsGenerator|IceT|pq|QtTesting|vtk|catalyst|StereoCursorViews).*

Name:           paraview
Version:        5.12.1
Release:        %mkrel 9
Summary:        Parallel visualization application
Group:          Sciences/Other
License:        BSD
URL:            https://www.paraview.org/
Source0:        https://www.paraview.org/files/v%{baseversion}/ParaView-v%{version}.tar.xz
Source1:        paraview.xml
Source2:        paraview.desktop
#remove source files corresponding to system libraries to force errors
#if they were silently built
Source3:        cleansources.bash

# Fix cmake files install location
# https://gitlab.kitware.com/paraview/paraview/issues/19724
Patch0:         paraview-cmakedir.patch

# Fix linking
Patch3:         paraview-5.12.0-vtk-linking.patch

# Fix build with python >= 3.7
Patch5:         ParaView-v5.8.0-PyUnicode_AsUTF8-const-char.patch

#https://gitlab.kitware.com/paraview/paraview/-/issues/20289
#modifed from https://gitlab.kitware.com/vtk/vtk/uploads/a5354808a4167e6fa9208c8c03ffd105/vtk-freetype-2.10.3-provide-FT_CALLBACK_DEF.patch
Patch9:         vtk-freetype-2.10.3-provide-FT_CALLBACK_DEF.patch
Patch12:        0001-Relax-fast_float-and-verdict-requirement.patch
Patch13:        0001-IOPDAL_Always-links-with-pdalcpp.patch

%if %{with mpi}
BuildRequires:  openmpi-devel
BuildRequires:  gcc-gfortran
BuildRequires:  python3-mpi4py-devel
%rename         paraview-mpi
Requires:       openmpi
%endif
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  ffmpeg-devel
#(eatdirt) broken
BuildRequires:  gl2ps-devel >= 1.4.0
BuildRequires:  gnuplot
BuildRequires:  graphviz
BuildRequires:  hdf5
BuildRequires:  hdf5-devel
BuildRequires:  imagemagick
BuildRequires:  jsoncpp-devel
BuildRequires:  netcdf-cxx-devel
BuildRequires:  pkgconfig(expat)
BuildRequires:  cmake(fastfloat)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)

BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  qtxmlpatterns5-xmlpatterns
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(gdal)
BuildRequires:  pkgconfig(pdal)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(tk)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(eigen3)
%if %{with fmt}
BuildRequires:  pkgconfig(fmt) < 10
%endif
#(eatdirt) broken
#BuildRequires:  osmesa-devel
BuildRequires:  sqlite3-tools
BuildRequires:  wget
BuildRequires:  python3dist(pygments)
BuildRequires:  cgns-devel
#(eatdirt) broken in spite of patching
#BuildRequires:  libharu-devel
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  cmake(double-conversion)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libutf8proc)
BuildRequires:  utf8cpp-devel

Requires:       python3dist(pygobject)
Requires:       python3dist(pygments)
Requires:       qt5-database-plugin-sqlite

%if !%{with fmt}
Provides:       bundled(fmt) = 10.1.1
%endif

Obsoletes:      %{name}-data <= 5.0

%description
ParaView is an open-source, multi-platform data analysis and
visualization application. ParaView users can quickly build
visualizations to analyze their data using qualitative and
quantitative techniques. The data exploration can be done
interactively in 3D or programmatically using ParaView’s batch
processing capabilities. ParaView was developed to analyze extremely
large datasets using distributed memory computing resources. It can be
run on supercomputers to analyze datasets of petascale as well as on
laptops for smaller data. ParaView is an application framework as well
as a turn-key application.
The ParaView code base is designed in such a way that all of its
components can be reused to quickly develop vertical
applications. This flexibility allows ParaView developers to quickly
develop applications that have specific functionality for a specific
problem domain. ParaView runs on distributed and shared memory
parallel and single processor systems.


%package        devel
Summary:        Development files for ParaView
Group:          Sciences/Other
Requires:       %{name} = %{version}-%{release}
Requires:       vtk-devel

%if %{with mpi}
%rename         paraview-mpi-devel
%endif

%description    devel
%{summary}.


%package -n %{staticdevelname}
Summary:        Static development files for ParaView
Group:          Sciences/Other
Provides:       paraview-static-devel = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
%if %{with mpi}
%rename         paraview-mpi-static-devel
%endif

%description -n %{staticdevelname}
%{summary}.


%prep
%autosetup -n ParaView-v%{version} -p1

sh %{_sourcedir}/cleansources.bash

%build
#(eatdirt) Those upstream punks fancy changing the name of the
#following options without notice. Inside the build directory,
#starting from a pristine configuration, ccmake ../ is your friend,
#"t" option activated

%cmake                                                                  \
        -DCMAKE_INSTALL_CMAKEDIR:PATH=%{_lib}/cmake                     \
        -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib}/%{name}                     \
        -DBUILD_EXAMPLES:BOOL=ON                                        \
        -DBUILD_TESTING:BOOL=OFF                                        \
        -DCMAKE_CXX_FLAGS="%{paraflags}"                                \
        -DCMAKE_C_FLAGS="%{paraflags}"                                  \
        -DCMAKE_CXX_STANDARD=17                                         \
        -DPARAVIEW_IGNORE_CMAKE_CXX11_CHECKS:BOOL=ON                    \
        -DCMAKE_VERBOSE_MAKEFILE:BOOL=OFF                               \
        -DCMAKE_RULE_MESSAGES:BOOL=OFF                                  \
        -DPARAVIEW_DATA_ROOT:PATH=%{_datadir}                           \
        -DPARAVIEW_BUILD_SHARED_LIBS:BOOL=ON                            \
        -DPARAVIEW_BUILD_WITH_EXTERNAL:BOOL=ON                          \
        -DPARAVIEW_USE_PYTHON:BOOL=ON                                   \
        -DPARAVIEW_ENABLE_GDAL:BOOL=ON                                  \
        -DPARAVIEW_ENABLE_PDAL:BOOL=ON                                  \
        -DPARAVIEW_ENABLE_FFMPEG:BOOL=ON                                \
        -DPARAVIEW_ENABLE_COSMOTOOLS:BOOL=OFF                           \
        -DPARAVIEW_INSTALL_DEVELOPMENT_FILES:BOOL=ON                    \
        -DPARAVIEW_USE_EXTERNAL_VTK:BOOL=ON                             \
        -DVTK_PYTHON_VERSION=3                                          \
        -DPARAVIEW_VERSIONED_INSTALL:BOOL=OFF                           \
%if %{with mpi}
        -DCMAKE_C_COMPILER=mpicc                                        \
        -DCMAKE_CXX_COMPILER=mpicxx                                     \
        -DPARAVIEW_USE_MPI:BOOL=ON                                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_mpi4py:BOOL=ON                    \
%else
        -DPARAVIEW_USE_MPI:BOOL=OFF                                     \
%endif
        -DQtTesting_INSTALL_LIB_DIR:PATH=%{_lib}/%{namever}             \
        -DQtTesting_INSTALL_CMAKE_DIR:PATH=%{_lib}/%{namever}/CMake     \
        -DVTK_MODULE_USE_EXTERNAL_VTK_doubleconversion:BOOL=ON          \
        -DVTK_MODULE_USE_EXTERNAL_VTK_cli11:BOOL=OFF                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_eigen:BOOL=ON                     \
        -DVTK_MODULE_USE_EXTERNAL_VTK_expat:BOOL=ON                     \
        -DVTK_MODULE_USE_EXTERNAL_VTK_exprtk:BOOL=OFF                   \
%if !%{with fmt}
        -DVTK_MODULE_USE_EXTERNAL_VTK_fmt:BOOL=OFF                      \
%endif
        -DVTK_MODULE_USE_EXTERNAL_VTK_freetype:BOOL=ON                  \
        -DVTK_MODULE_USE_EXTERNAL_VTK_gl2ps:BOOL=OFF                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_glew:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_hdf5:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_ioss:BOOL=OFF                     \
        -DVTK_MODULE_USE_EXTERNAL_VTK_jpeg:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_jsoncpp:BOOL=ON                   \
        -DVTK_MODULE_USE_EXTERNAL_VTK_libharu:BOOL=OFF                  \
        -DVTK_MODULE_USE_EXTERNAL_VTK_libxml2:BOOL=ON                   \
        -DVTK_MODULE_USE_EXTERNAL_VTK_lz4:BOOL=ON                       \
        -DVTK_MODULE_USE_EXTERNAL_VTK_lzma:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_netcdf:BOOL=ON                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_ogg:BOOL=ON                       \
        -DVTK_MODULE_USE_EXTERNAL_VTK_png:BOOL=ON                       \
        -DVTK_MODULE_USE_EXTERNAL_VTK_pugixml:BOOL=ON                   \
        -DVTK_MODULE_USE_EXTERNAL_VTK_token:BOOL=OFF                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_verdict:BOOL=OFF                  \
        -DVTK_MODULE_USE_EXTERNAL_VTK_theora:BOOL=ON                    \
        -DVTK_MODULE_USE_EXTERNAL_VTK_tiff:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_utf8:BOOL=ON                      \
        -DVTK_MODULE_USE_EXTERNAL_VTK_zlib:BOOL=ON                      \
        -DVTK_MODULE_ENABLE_ParaView_VTKExtensionsCGNSReader:BOOL=NO    \
        -DVTK_MODULE_ENABLE_ParaView_VTKExtensionsCGNSWriter:BOOL=NO    \
        -DQtTesting_INSTALL_LIB_DIR=%{_lib}/%{name}                     \
        -DQtTesting_INSTALL_CMAKE_DIR=%{_lib}/%{name}/CMake

%cmake_build

%install
%cmake_install

# Install MIME type and desktop file
install -D -m644 %{SOURCE1} %{buildroot}%{_datadir}/mime/packages/%{name}.xml
install -D -m644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop

# Use our own .desktop file
rm -r %{buildroot}%{_datadir}/applications/org.paraview.ParaView.desktop

# ld.conf.d file
install -d %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{namever} > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf

#Cleanup only vtk conflicting binaries
rm %{buildroot}%{_bindir}/vtk{ParseJava,Wrap{Hierarchy,Java,Python}}*


%files
%license %{_datadir}/licenses/ParaView/
%doc %{_docdir}/ParaView/
%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_bindir}/paraview
%{_bindir}/pv*
%{_bindir}/smTestDriver*
%{_bindir}/paraview-config
%{_bindir}/paraview.conf
%{_libdir}/paraview/
%{_datadir}/applications/paraview.desktop
%{_datadir}/mime/packages/paraview.xml
%{_metainfodir}/org.paraview.ParaView.appdata.xml
%{_datadir}/paraview/
%{_iconsdir}/hicolor/*/apps/paraview.png
%exclude %{_libdir}/paraview/*.a

%files          devel
%{_bindir}/vtkProcessXML
%{_bindir}/vtkWrap*
%{_bindir}/vtkProbeOpenGLVersion*
%{_includedir}/paraview/
%{_libdir}/cmake/paraview/

%files -n %{staticdevelname}
%{_libdir}/paraview/*.a
