%global __brp_check_rpaths %{nil}

%define	lib_major	9
%define	lib_name	%mklibname %{name}-gmp-tls %{lib_major}
%define develname	%mklibname %{name} -d

%ifarch %{ix86}
%bcond_with tests
%else
%bcond_without tests
%endif

Summary:	PARI/GP - Number Theory-oriented Computer Algebra System
Name:		pari
Version:	2.17.1
Release:	%mkrel 1
License:	GPLv2+
Group:		Sciences/Mathematics
URL:		https://pari.math.u-bordeaux.fr/
Source0:	https://pari.math.u-bordeaux.fr/pub/pari/unix/%{name}-%{version}.tar.gz
Source1:	https://pari.math.u-bordeaux.fr/pub/pari/packages/elldata.tgz
Source2:	https://pari.math.u-bordeaux.fr/pub/pari/packages/galdata.tgz
Source3:	https://pari.math.u-bordeaux.fr/pub/pari/packages/seadata.tgz
Source4:	https://pari.math.u-bordeaux.fr/pub/pari/packages/nftables.tgz
Source5:	https://pari.math.u-bordeaux.fr/pub/pari/packages/galpol.tgz
Patch0:		pari-arch.patch
Patch2:		pari-gphelp.patch
Patch3:		pari-runpath.patch
BuildRequires:	perl-devel
BuildRequires:	fltk-devel
BuildRequires:	pkgconfig(gmp)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xproto)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	texlive
BuildRequires:	texlive-texmf
BuildRequires:	emacs
Requires:	perl
Requires:	xdg-utils
Recommends:	%{name}-data = %{version}-%{release}

%description
PARI/GP is a widely used computer algebra system designed for fast
computations in number theory (factorizations, algebraic number theory,
elliptic curves...), but also contains a large number of other useful
functions to compute with mathematical entities such as matrices,
polynomials, power series, algebraic numbers, etc., and a lot of
transcendental functions. PARI is also available as a C library to allow
for faster computations.

%package	data
Group:		Sciences/Mathematics
Summary:	Optional pari data packages
Requires:	%{name} >= %{version}-%{release}
BuildArch:	noarch

%description	data
  elldata is PARI/GP version of J. E. Cremona Elliptic Curve Data,
needed by ellsearch and ellidentify.
  galdata is needed by polgalois to compute Galois group in degrees
8 through 11.
  seadata is needed by ellap for large primes.
  nftables is a repackaging of the historical megrez number field
tables (errors fixed, 1/10th the size, easier to use).

%package -n	%{lib_name}
Group:		System/Libraries
Summary:	Shared PARI library

%description -n	%{lib_name}
This package contains the libraries needed to run pari.

%package -n	%{develname}
Group:		System/Libraries
Summary:	Development files for PARI shared library
Requires:	%{lib_name} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the header files needed to develop
applications using pari.

%prep
%setup -q -a1 -a2 -a3 -a4 -a5
mv -f nftables data
%autopatch -p1

# OpenSuse: Don’t build DVI docs
sed -i -e 's/^\(doc all:\) .*/\1/' config/DOC_Make.SH

# OpenSuse: disable __DATE__, it’s pointless and can cause rebuilds.
sed -i -e 's/__DATE__/"today"/' src/language/paricfg.c

%build
%define pkgdocdir	%{_docdir}/%{name}
%define pkgdatadir	%{_datadir}/%{name}-%{version}
%set_build_flags

# Using --libdir to properly link with newer interface
# Using --disable-tls for safety due to other packages linked to pari
sh Configure						\
	--prefix=%{_prefix}				\
	--includedir=%{_includedir}			\
	--libdir=%{_libdir}				\
	--datadir=%{pkgdatadir}/data			\
	--sysdatadir=%{_libdir}/%{name}			\
	--share-prefix=%{_datadir}			\
	--host=%{_arch}-%{_os}				\
	--graphic=X11					\
	--with-fltk					\
	--with-gmp					\
	--mt=pthread					\
	--enable-tls

echo "echo %_build_arch-%_build_os" > config/arch-osname

export PERL_USE_UNSAFE_INC=1
%ifarch %arm
%__make gp
%else
%__make bench
%endif

%__make doc

%install
# pari, libpari & libpari-devel
%make_install						\
	LIBDIR='$(DESTDIR)'%{_libdir}			\
	DOCDIR='$(DESTDIR)'%{pkgdocdir}

# Install global configuration file.
mkdir %{buildroot}%{_sysconfdir}
# Add some more reasonable "commented" sample configurations
sed	-e 's@/usr/local/@%{_prefix}/@'				\
	-e 's@path =.*@path = "%{pkgdatadir}:.:~/gpdir"@'	\
	-e 's@lib/gpalias@misc/gpalias@'			\
	misc/gprc.dft > %{buildroot}/%{_sysconfdir}/gprc

# don't need to install this file...
rm -f %{buildroot}%{pkgdocdir}/*.{dvi,tex}
rm -f %{buildroot}%{pkgdocdir}/translations

# gphelp wants docs in %{pkgdatadir}/data/doc (removing the /data/ requirement)
ln -sf %{pkgdocdir} %{buildroot}%{pkgdatadir}/doc
perl -pi -e 's@%{pkgdatadir}/data@%{pkgdatadir}@;'		\
	%{buildroot}/%{_bindir}/gphelp

# remove %%{buildroot} from file contents
perl -pi -e 's@%{buildroot}@@g' \
	%{buildroot}%{_datadir}/%{name}-%{version}/data/examples/Makefile \
	%{buildroot}%{_libdir}/pari/pari.cfg

%check
%{?with_tests:%__make test-all}

%files
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/gprc
%{_bindir}/gp-*
%{_bindir}/gp
%{_bindir}/gphelp
%{_bindir}/tex2mail
%{_mandir}/man1/[^g]*.1*
%{_mandir}/man1/gp.1*
%{_mandir}/man1/gp-*.1*
%{_mandir}/man1/gphelp.1*
%doc AUTHORS CHANGES COMPAT NEW README
%dir %{pkgdatadir}
%{pkgdatadir}/doc

%files	data
%dir %{pkgdatadir}/data
%{pkgdatadir}/data/*

%files	-n %{lib_name}
%license COPYING LICENSE
%{_libdir}/libpari-gmp-tls.so.%{version}
%{_libdir}/libpari-gmp-tls.so.%{lib_major}

%files	-n %{develname}
%{_includedir}/%{name}/
%{_libdir}/libpari.so
%{_libdir}/%{name}/
