Name:		pcb
# Use upstream release versioning which is < date used previously
Epoch:		1
Version:	4.3.0
Release:	%mkrel 1
Summary:	An interactive printed circuit board editor
License:	GPLv2
Group:		Sciences/Other
URL:		http://pcb.geda-project.org/index.html
Source0:	https://sourceforge.net/projects/pcb/files/pcb/%{name}-%{version}/%{name}-%{version}.tar.gz

BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gerbv
BuildRequires:	gettext >= 0.16.0
BuildRequires:	imagemagick
BuildRequires:	intltool >= 0.35.0
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(gdlib)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(gtkglext-1.0)
BuildRequires:	texinfo >= 4.6
BuildRequires:	texinfo-tex
BuildRequires:	tk

Requires:	m4

%description
PCB is an interactive printed circuit board editor.
PCB includes a rats nest feature, design rule checking, and can provide
industry standard RS-274-X (Gerber), NC drill, and centroid data (X-Y data)
output for use in the board fabrication and assembly process. PCB offers
high end features such as an autorouter and trace optimizer which can
tremendously reduce layout time.

%prep
%setup -q

%{__sed} -i \
   's|examplesdir = $(pkgdatadir)/examples|examplesdir = @docdir@/examples|' \
   example/libraries/Makefile.*

%{__sed} -i \
   's|tutdir = $(pkgdatadir)/tutorial|tutdir = @docdir@/tutorial|' \
   tutorial/Makefile.*

%build
## TODO Remove --disable-dependency-tracking if
# https://bugs.launchpad.net/pcb/+bug/1661348 gets fixed
%configure \
	--disable-dependency-tracking \
	--with-gui=gtk \
	--enable-dbus \
	--enable-toporouter \
	--disable-update-mime-database \
	--disable-update-desktop-database \
	--docdir=%{_docdir}/%{name}-%{version}

%make_build

%install
%make_install

desktop-file-install \
    --dir %{buildroot}%{_datadir}/applications \
    --remove-category Engineering \
    --remove-category Electronics \
    --add-category Science \
    --add-category Engineering \
    --add-category Electronics \
    %{buildroot}%{_datadir}/applications/%{name}.desktop

#
# Additional Examples
#
set +x
dest=%{buildroot}%{_docdir}/%{name}-%{version}/examples
for d in thermal pad puller ; do
   echo -n -e "... Fixing path of $d  \t"
   mkdir -p $dest/$d
   mv $dest/../$d.* $dest/$d
   install -pm 0644 doc/$d.{pcb,pdf} $dest/$d
   sed -i "s|$d.png|examples/$d/$d.png|" $dest/../%{name}.html
   echo "done"
done
set -x

## --- pcb supports for acpcircuits
# http://www.apcircuits.com/resources/links/pcb_unix.html
unzip tools/apctools.zip
install -p -m 755 apc*.pl  %{buildroot}%{_datadir}/%{name}/tools

# Removes duplicates
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/apctools.zip

# Old versions of PCB don't support autoroute, pcb2ncap convert
# pcb format to ncap format used for mucspcb to autoroute the circuit.
# In newer versions of PCB, autoroute is included and pcb2ncap and mucspcb
# are no more needed.
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/pcb2ncap.tgz

chmod 755 %{buildroot}%{_datadir}/%{name}/tools/{PCB2HPGL,tgo2pcb.tcl,Merge*}

cp -p AUTHORS COPYING README NEWS ChangeLog README_FILES/CHANGES \
      README_FILES/Whats_new_in_2.0 README_FILES/Tools \
      %{buildroot}%{_docdir}/%{name}-%{version}/

%{__rm} -rf %{buildroot}%{_datadir}/info/dir

mv %{buildroot}%{_docdir}/%{name}-%{version}/refcard.pdf %{buildroot}%{_docdir}/%{name}-%{version}/pcb-reference-card.pdf

# remove duplicates
%{__rm} -f %{buildroot}%{_bindir}/Merge*

# L#854396 0.20110918 needlessly installs gts static library & header file
%{__rm} -f %{buildroot}%{_libdir}/libgts.a %{buildroot}%{_includedir}/gts.h

%find_lang %{name}

%check

# No test should fail in the latest version
# but there is some problem for now
%make_build check || :

%files -f %{name}.lang
%doc %{_docdir}/%{name}-%{version}/*
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_datadir}/gEDA/scheme/*
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*
%{_infodir}/%{name}.info*
%{_iconsdir}/hicolor/*/mimetypes/application-x-*
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_datadir}/mime/packages/pcb.xml
%{_datadir}/metainfo/pcb.appdata.xml
