%define libmajor	0
%define libname		%mklibname pcre 2 %{libmajor}

%define pcre2posixmajor	3
%define libnameposix	%mklibname pcre2posix %{pcre2posixmajor}

%define develname	%mklibname %{name} -d
%define staticname	%mklibname %{name} -s -d

Name:		pcre2
Version:	10.45
Release:	%mkrel 1
Summary:	Perl-compatible regular expression library
Group:		System/Libraries
# the library:                          BSD
# pcre2test (linked to GNU readline):   BSD (linked to GPLv3+)
#Not distributed in binary package
# autotools:                            GPLv3+ with exception
# install-sh:                           MIT
License:	BSD
URL:		https://www.pcre.org/
Source0:	https://github.com/PCRE2Project/pcre2/releases/download/pcre2-%{version}/%{name}-%{version}.tar.bz2
Source1:	https://github.com/PCRE2Project/pcre2/releases/download/pcre2-%{version}/%{name}-%{version}.tar.bz2.sig
# Do no set RPATH if libdir is not /usr/lib
Patch0:		pcre2-10.10-Fix-multilib.patch
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	coreutils
BuildRequires:	diffutils
BuildRequires:	gcc
BuildRequires:	libtool
BuildRequires:	make
BuildRequires:	pkgconfig(readline)

%description
PCRE2 is a re-working of the original PCRE (Perl-compatible regular
expression) library to provide an entirely new API.

PCRE2 is written in C, and it has its own API. There are three sets of
functions, one for the 8-bit library, which processes strings of bytes, one
for the 16-bit library, which processes strings of 16-bit values, and one for
the 32-bit library, which processes strings of 32-bit values. There are no C++
wrappers.

The distribution does contain a set of C wrapper functions for the 8-bit
library that are based on the POSIX regular expression API (see the pcre2posix
man page). These can be found in a library called libpcre2posix. Note that
this just provides a POSIX calling interface to PCRE2; the regular expressions
themselves still follow Perl syntax and semantics. The POSIX API is
restricted, and does not give full access to all of PCRE2's facilities.

%package -n	%{libname}
Summary:	Perl-compatible regular expression library
Group:		System/Libraries

%description -n	%{libname}
PCRE2 is a re-working of the original PCRE (Perl-compatible regular
expression) library to provide an entirely new API.

%package -n	%{libnameposix}
Summary:	Perl-compatible regular expression library
Group:		System/Libraries

%description -n	%{libnameposix}
This package contains the shared library libpcre2-posix.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libnameposix} = %{version}-%{release}
Requires:	gcc

%description -n	%{develname}
Development files (headers, libraries for dynamic linking, documentation)
for %{name}.  The header file for the POSIX-style functions is called
pcre2posix.h.

%package	tools
Summary:	Auxiliary utilities for %{name}
# pcre2test (linked to GNU readline)	BSD (linked to GPLv3+)
License:	BSD and GPLv3+
Group:		Development/Tools

%description	tools
Utilities demonstrating PCRE2 capabilities like pcre2grep or pcre2test.

%package -n	%{staticname}
Group:		Development/C
Summary:	Library file for linking statically to PCRE2
Provides:	%{name}-static-devel = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}

%description -n	%{staticname}
Library file for linking statically against PCRE2.

%prep
%autosetup -p1

%build
autoreconf -vfi
%configure \
    --enable-jit \
    --enable-pcre2grep-jit \
    --disable-bsr-anycrlf \
    --disable-coverage \
    --disable-ebcdic \
    --disable-fuzz-support \
    --disable-never-backslash-C \
    --enable-newline-is-lf \
    --enable-pcre2-8 \
    --enable-pcre2-16 \
    --enable-pcre2-32 \
    --enable-pcre2grep-callout \
    --enable-pcre2grep-callout-fork \
    --disable-pcre2grep-libbz2 \
    --disable-pcre2grep-libz \
    --disable-pcre2test-libedit \
    --enable-percent-zt \
    --enable-pcre2test-libreadline \
    --disable-rebuild-chartables \
    --enable-shared \
    --enable-stack-for-recursion \
    --enable-static \
    --enable-unicode \
    --disable-valgrind
%make_build

%install
%make_install

# These are handled by %%doc in %%files
rm -rf %{buildroot}%{_docdir}/pcre2

%check
make check VERBOSE=yes

%files -n %{libname}
%license COPYING LICENCE.md
%doc AUTHORS.md ChangeLog NEWS README
%{_libdir}/libpcre2-[0-9]*.so.%{libmajor}{,.*}

%files -n %{libnameposix}
%license COPYING
%{_libdir}/libpcre2-posix.so.%{pcre2posixmajor}{,.*}

%files -n %{develname}
%doc doc/*.txt doc/html
%doc HACKING ./src/pcre2demo.c
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*.h
%{_mandir}/man1/pcre2-config.*
%{_mandir}/man3/*
%{_bindir}/pcre2-config

%files tools
%{_bindir}/pcre2grep
%{_bindir}/pcre2test
%{_mandir}/man1/pcre2grep.*
%{_mandir}/man1/pcre2test.*

%files -n %{staticname}
%{_libdir}/*.a
