%global readers_dir %(pkg-config libpcsclite --variable=usbdropdir)

%define		main_version 3.99.5
%define		sub_version SP14

Name:		pcsc-cyberjack
Version:	%main_version.%sub_version
Release:	%mkrel 2
Summary:	PC/SC driver for REINER SCT cyberjack USB chipcard reader
License:	LGPLv2+
Group:		System/Kernel and hardware
URL:		https://www.reiner-sct.com/
Source0:	https://support.reiner-sct.de/downloads/LINUX/V%{main_version}_%{sub_version}/%{name}_%{main_version}final.%{sub_version}.tar.gz
# (doktor5000) useful hints on troubleshooting / debugging, taken from Fedora
Source1:	https://src.fedoraproject.org/rpms/pcsc-cyberjack/raw/master/f/%{name}-%{main_version}final.SP09-README-FEDORA
Source2:	libifd-cyberjack6.udev
# this patch replaces the obsoleted AC_PROG_LIBTOOLT macro with LT_INIT
# the patch is sent to upstream per email (20160528)
Patch0:		pcsc-cyberjack-3.99.5final.SP09-configure.patch
BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	readline-devel
BuildRequires:	sysfsutils-devel
# for macro definition:
BuildRequires:  pkgconfig(libsystemd)
Requires:	pcsc-lite
Requires:	udev

%description
REINER SCT cyberJack USB chip card reader user space driver.

This package includes the IFD driver for the cyberJack contactless (RFID)
and contact USB chipcard reader.

For more information regarding installation under Linux see the README.txt
in the documentation directory, esp. regarding compatibility with host
controllers.

For more information about the reader, software updates and a shop see
https://www.reiner-sct.com/


%prep
%setup -q -n %{name}-%{main_version}final.%{sub_version}
%autopatch -p1

install -pm 644 %{SOURCE1} README-MAGEIA.txt

install -pm 644 %{SOURCE2} debian/

%build
autoreconf -vfi

%configure --disable-static \
	--mandir=%{_mandir}/man8 \
	--enable-pcsc \
	--sysconfdir="%{_sysconfdir}" \
	--with-usbdropdir="%{readers_dir}" \
	--enable-release \
	--enable-udev \
	--enable-hal=no

%make_build

#manually build extra tools
%make_build -C tools/cjflash
%make_build -C tools/cjgeldkarte

pushd doc
iconv -f iso8859-1 -t utf-8 LIESMICH.txt > LIESMICH.txt.conv && mv -f LIESMICH.txt.conv LIESMICH.txt
iconv -f iso8859-1 -t utf-8 README.txt > README.txt.conv && mv -f README.txt.conv README.txt
popd

%install
%make_install

# cjflash and cjgeldkarte does not get installed automatically
%make_install -C tools/cjflash
%make_install -C tools/cjgeldkarte

#remove unneeded files
rm -f %{buildroot}%{_libdir}/cyberjack/pcscd_init.diff
rm -f %{buildroot}%{_libdir}/pcsc/drivers/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.la

mv %{buildroot}%{_sysconfdir}/cyberjack.conf.default %{buildroot}%{_sysconfdir}/cyberjack.conf

# udev rule based on the file from debian sub-folder
# we need the devices to be in group cyberjack
sed -i 's/GROUP="pcscd"/GROUP="cyberjack"/' debian/libifd-cyberjack6.udev
install -Dm 644 debian/libifd-cyberjack6.udev %{buildroot}%{_udevrulesdir}/93-cyberjack.rules


%pre
%_pre_groupadd cyberjack

%post
%udev_rules_update

%systemd_postun_with_restart pcscd.socket


%postun
%udev_rules_update

%systemd_postun_with_restart pcscd.socket


%files
# AUTHORS is 0 length and will not be packaged therefore
%doc etc/cyberjack.conf.default README-MAGEIA.txt ChangeLog
%doc doc/README.txt doc/README.pdf doc/README.html
%doc doc/LIESMICH.txt doc/LIESMICH.pdf doc/LIESMICH.html
%license COPYING COPYRIGHT.GPL COPYRIGHT.LGPL

%config(noreplace) %{_sysconfdir}/cyberjack.conf
%{_bindir}/cjflash
%{_bindir}/cjgeldkarte
%{_udevrulesdir}/93-cyberjack.rules
%{readers_dir}/libifd-cyberjack.bundle/Contents/Info.plist
%{readers_dir}/libifd-cyberjack.bundle/Contents/PkgInfo
%{readers_dir}/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.so
%{readers_dir}/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.so.*
