%define major           1
%define pcscspy_major   0
%define libname         %mklibname pcsclite %{major}
%define pcscspy_libname %mklibname pcscspy %{pcscspy_major}
%define develname       %mklibname pcsclite -d

Summary:	M.U.S.C.L.E. PC/SC Framework for Linux
Name:		pcsc-lite
Version:	2.3.1
Release:	%mkrel 1
License:	BSD-3-Clause AND BSD-2-Clause AND GPL-3.0-or-later
Group:		System/Servers
URL:		https://pcsclite.apdu.fr/
Source0:	https://pcsclite.apdu.fr/files/%{name}-%{version}.tar.xz
Source1:	https://pcsclite.apdu.fr/files/%{name}-%{version}.tar.xz.asc

BuildRequires:	meson
BuildRequires:	doxygen
BuildRequires:	flex
BuildRequires:	pkgconfig(polkit-agent-1)
BuildRequires:	pkgconfig(udev)

Requires(post):	rpm-helper >= 0.24.8-1
Requires(preun):	rpm-helper >= 0.24.8-1
Requires:	%{libname} = %{version}

# This is bundled in upstream without simple way to remove
Provides:	bundled(simclist) = 1.6

%description
The purpose of PC/SC Lite is to provide a Windows(R) SCard interface
in a very small form factor for communicating to smartcards and
readers.  PC/SC Lite uses the same winscard API as used under
Windows(R).  This package includes the PC/SC Lite daemon, a resource
manager that coordinates communications with smart card readers and
smart cards that are connected to the system, as well as other command
line tools.

%package -n	%{libname}
Summary:	Muscle PCSC Framework for Linux libraries
Group:		System/Libraries
Provides:	libpcsclite%{major} = %{version}-%{release}

%description -n	%{libname}
The purpose of PCSC Lite is to provide a Windows(R) SCard interface in a
very small form factor for communicating to smartcards and readers.
PCSC Lite uses the same winscard api as used under Windows(R).

The %{name}-devel package contains the header files and libraries
needed for compiling PCSC Lite programs. If you want to develop PCSC Lite-aware
programs, you'll need to install this package.

This package was tested to work with A.E.T. Europe B.V. SafeSign. This
package is supported by A.E.T. Europe B.V. when used in combination with
SafeSign.

%package -n	pcsc-spy
Summary:	PCSC API spy
Group:		System/Libraries

Requires:	python3
Requires:	pcsc-lite
Requires:	%{pcscspy_libname} = %{version}

%description -n	pcsc-spy
The purpose of pcsc-spy is to spy all the calls between the PC/SC client
and the PC/SC library.

%package -n	%{pcscspy_libname}
Summary:	PCSC Smart Card Library
Group:		System/Libraries

%description -n	%{pcscspy_libname}
Supporting library for the PC/SC spy tool.

%package -n	%{develname}
Summary:	Muscle PCSC Framework for Linux development files
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Requires:	%{pcscspy_libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	libpcsclite-devel = %{version}-%{release}

%description -n	%{develname}
The purpose of PCSC Lite is to provide a Windows(R) SCard interface in a
very small form factor for communicating to smartcards and readers.
PCSC Lite uses the same winscard api as used under Windows(R).

The %{name}-devel package contains the header files and libraries
needed for compiling PCSC Lite programs. If you want to develop PCSC Lite-aware
programs, you'll need to install this package.

This package was tested to work with A.E.T. Europe B.V. SafeSign. This
package is supported by A.E.T. Europe B.V. when used in combination with
SafeSign.

%package	doc
Summary:	PC/SC Lite developer documentation
Group:		Development/Other
BuildArch:	noarch

%description	doc
PC/SC Lite developer documentation.


%prep
%autosetup -p1

%build
%meson \
    -Dlibsystemd=true \
    -Dsystemdunit=system \
    -Dserial=true \
    -Dusbdropdir=%{_libdir}/pcsc/drivers \
    -Dpolkit=true

%meson_build
%meson_build doc

%install
%meson_install

# Create empty directories
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/reader.conf.d
mkdir -p $RPM_BUILD_ROOT%{_libdir}/pcsc/drivers

rm %{buildroot}%{_libdir}/libpcsclite.a

%post
%_post_service pcscd
# If install, test if pcscd socket is enabled.
# If enabled, then attempt to start it. This will silently fail
# in chroots or other environments where services aren't expected
# to be started.

if [ $1 -eq 1 ] ; then
	if systemctl -q is-enabled pcscd.socket > /dev/null 2>&1 ; then
		systemctl start pcscd.socket > /dev/null 2>&1 || :
	fi
fi

%preun
%_preun_service pcscd

%postun
%systemd_postun_with_restart pcscd.socket pcscd.service

%files
%doc AUTHORS ChangeLog HELP README SECURITY
%doc doc/README.polkit
%doc src/spy/setup_spy.sh
%dir %{_sysconfdir}/reader.conf.d/
%dir %{_libdir}/pcsc/drivers/
%{_sysconfdir}/default/pcscd
%{_datadir}/polkit-1/actions/org.debian.pcsc-lite.policy
%{_unitdir}/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/*
%{_metainfodir}/fr.apdu.pcsclite.metainfo.xml

%files -n %{libname}
%license COPYING
%{_libdir}/libpcsc*.so.%{major}{,.*}

%files -n pcsc-spy
%{_bindir}/pcsc-spy
%{_mandir}/man1/pcsc-spy.1.*

%files -n %{pcscspy_libname}
%{_libdir}/libpcscspy.so.%{pcscspy_major}{,.*}

%files -n %{develname}
%doc ChangeLog
%{_libdir}/pkgconfig/libpcsclite.pc
%{_includedir}/*
%{_libdir}/*.so

%files doc
%doc %{_vpath_builddir}/doc/api/ doc/example/pcsc_demo.c
