%define upstream_name    Lexical-SealRequireHints
%define upstream_version 0.012

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Prevent leakage of lexical hints
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Lexical/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Exporter)
BuildRequires: perl(Module::Build)
BuildRequires: perl(Test::More) >= 0.410.0
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildRequires: perl-devel
%{?perl_default_filter}

%description
This module works around two historical bugs in Perl's handling of the
'%^H' (lexical hints) variable. One bug causes lexical state in one file to
leak into another that is 'require'd/'use'd from it. This bug, [perl
#68590], was present from Perl 5.6 up to Perl 5.10, fixed in Perl 5.11.0.
The second bug causes lexical state (normally a blank '%^H' once the first
bug is fixed) to leak outwards from 'utf8.pm', if it is automatically
loaded during Unicode regular expression matching, into whatever source is
compiling at the time of the regexp match. This bug, [perl #73174], was
present from Perl 5.8.7 up to Perl 5.11.5, fixed in Perl 5.12.0.

Both of these bugs seriously damage the usability of any module relying on
'%^H' for lexical scoping, on the affected Perl versions. It is in practice
essential to work around these bugs when using such modules. On versions of
Perl that require such a workaround, this module globally changes the
behaviour of 'require', including 'use' and the implicit 'require'
performed in Unicode regular expression matching, so that it no longer
exhibits these bugs.

The workaround supplied by this module takes effect the first time its
'import' method is called. Typically this will be done by means of a 'use'
statement. This should be done as early as possible, because it only
affects 'require'/'use' statements that are compiled after the workaround
goes into effect. For 'use' statements, and 'require' statements that are
executed immediately and only once, it suffices to invoke the workaround
when loading the first module that will set up vulnerable lexical state.
Delayed-action 'require' statements, however, are more troublesome, and can
require the workaround to be loaded much earlier. Ultimately, an affected
Perl program may need to load the workaround as very nearly its first
action. Invoking this module multiple times, from multiple modules, is not
a problem: the workaround is only applied once, and applies to everything
subsequently compiled.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Build.PL --installdirs=vendor

./Build CFLAGS="%{optflags}"

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes META.json META.yml MYMETA.yml README SIGNATURE
%{_mandir}/man3/*
%perl_vendorarch/*
