%define upstream_name Lexical-Var
%define upstream_version 0.010

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Static variables without namespace pollution
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Lexical/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::CBuilder) >= 0.150.0
BuildRequires: perl(Lexical::SealRequireHints) >= 0.12.0
BuildRequires: perl(Module::Build)
BuildRequires: perl(Test::More)
BuildRequires: perl(XSLoader)
BuildRequires: perl(if)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildRequires: perl-devel
%{?perl_default_filter}

# Filter modules bundled for tests
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}^%{_libexecdir}
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(t::code.*\\)

%description
This module implements lexical scoping of static variables and
subroutines.  Although it can be used directly, it is mainly intended
to be infrastructure for modules that manage namespaces.

This module influences the meaning of single-part variable names that
appear directly in code, such as "$foo".  Normally, in the absence of any
particular declaration, or under the effect of an "our" declaration, this
would refer to the scalar variable of that name located in the current
package.  A "Lexical::Var" declaration can change this to refer to any
particular scalar, bypassing the package system entirely.  A variable
name that includes an explicit package part, such as "$main::foo", always
refers to the variable in the specified package, and is unaffected by this
module.  A symbolic reference through a string value, such as "${'foo'}",
also looks in the package system, and so is unaffected by this module.

The types of name that can be influenced are scalar ("$foo"), array
("@foo"), hash ("%foo"), subroutine ("&foo"), and glob ("*foo").
A definition for any of these names also affects code that logically
refers to the same entity, even when the name is spelled without its
usual sigil.  For example, any definition of "@foo" affects element
references such as "$foo[0]".  Barewords in filehandle context actually
refer to the glob variable.  Bareword references to subroutines, such as
"foo(123)", only work on Perl 5.11.2 and later; on earlier Perls you
must use the "&" sigil, as in "&foo(123)".

Where a scalar name is defined to refer to a constant (read-only) scalar,
references to the constant through the lexical namespace can participate
in compile-time constant folding.  This can avoid the need to check
configuration values (such as whether debugging is enabled) at runtime.

A name definition supplied by this module takes effect from the end
of the definition statement up to the end of the immediately enclosing
block, except where it is shadowed within a nested block.  This is the
same lexical scoping that the "my", "our", and "state" keywords supply.
Definitions from Lexical::Var and from "my"/"our"/"state" can shadow
each other.  These lexical definitions propagate into string "eval"s,
on Perl versions that support it (5.9.3 and later).

This module only manages variables of static duration (the kind of
duration that "our" and "state" variables have).  To get a fresh variable
for each invocation of a function, use "my".

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
# See https://rt.cpan.org/Public/Bug/Display.html?id=101058
%autopatch -p1

%build
%__perl Build.PL --installdirs=vendor

./Build

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes META.json META.yml MYMETA.yml README SIGNATURE
%{_mandir}/man3/*
%{perl_vendorarch}/*
