%define upstream_name    Sys-Virt
%define upstream_version v11.0.0

%{?perl_default_filter}
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}Test::Pod

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Interface to libvirt virtual machine management API
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}/
Source0:    https://cpan.metacpan.org/modules/by-module/Sys/%{upstream_name}-%{upstream_version}.tar.gz

# Build

BuildRequires: perl(ExtUtils::CBuilder)
BuildRequires: perl(Module::Build)
BuildRequires: perl(Sys::Hostname)
BuildRequires: perl(Test::CPAN::Changes)
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::Pod)
BuildRequires: perl(Test::Pod::Coverage)
BuildRequires: perl(Time::HiRes)
BuildRequires: perl(XML::XPath)
BuildRequires: perl(XML::XPath::XMLParser)
BuildRequires: pkgconfig(libvirt) >= %{version}
# Tests only
BuildRequires: libvirt-utils >= %{version}
BuildRequires: perl-devel
# Optional tests only

%description
The Sys::Virt module provides a Perl XS binding to the libvirt virtual
machine management APIs. This allows machines running within arbitrary
virtualization containers to be managed with a consistent API.

%package tests
Summary:    Tests for %{name}
Requires:   %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires:   perl-Test-Harness
%description tests
Tests from %{name}-%{version}. Execute them
with "%{_libexecdir}/%{name}/test".

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
# Help file to recognise the Perl scripts and normalize shebangs
for F in t/*.t; do
    if head -1 "$F" | grep -q -e '^#!.*perl' ; then
        perl -MConfig -pi -e 's|^#!.*perl\b|$Config{startperl}|' "$F"
    else
        perl -i -MConfig -ple 'print $Config{startperl} if $. == 1' "$F"
    fi
    chmod +x "$F"
done

# Remove release tests
for F in t/005-pod.t t/010-pod-coverage.t t/015-changes.t; do
    rm "$F"
    perl -i -ne 'print $_ unless m{^\Q'"$F"'\E}' MANIFEST
done

%build
perl Makefile.PL INSTALLDIRS=vendor
make CFLAGS="%{optflags}"

%install
%make_install

# Install tests
mkdir -p %{buildroot}/%{_libexecdir}/%{name}
cp -a t %{buildroot}/%{_libexecdir}/%{name}
cat > %{buildroot}/%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name} && exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}/%{_libexecdir}/%{name}/test

%check
export HARNESS_OPTIONS=j$(perl -e 'if ($ARGV[0] =~ /.*-j([0-9][0-9]*).*/) {print $1} else {print 1}' -- '%{?_smp_mflags}')
make test

%files
%license LICENSE
%doc AUTHORS Changes HACKING INSTALL LICENSE META.json META.yml MYMETA.yml README examples
%{perl_vendorarch}/Sys
%{perl_vendorarch}/auto/Sys
%{_mandir}/man3/Sys::Virt*3pm*

%files tests
%{_libexecdir}/%{name}