%define	upstream_name    Tk
%define upstream_version 804.036

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 6

Summary:    Tk modules for Perl
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Tk/%{upstream_name}-%{upstream_version}.tar.gz
Patch0:         perl-Tk-widget.patch
# modified version of http://ftp.de.debian.org/debian/pool/main/p/perl-tk/perl-tk_804.027-8.diff.gz
Patch1:     perl-Tk-debian.patch
# fix segfaults as in #235666 because of broken cashing code
Patch2:     perl-Tk-seg.patch
Patch3:     perl-Tk-c99.patch
# Fix STRLEN vs int pointer confusion in Tcl_GetByteArrayFromObj()
# It breaks tests with Perl 5.38 on s390* (BZ#2222638)
Patch4:         perl-Tk-Fix-STRLEN-vs-int-pointer-confusion-in-Tcl_GetByteAr.patch
# Fix build with clang 16
# https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=271521
Patch5:         perl-Tk-Fix-build-with-clang-16.patch
# Avoid using incompatible pointer type in pregcomp2.c
Patch6:         perl-Tk-pregcomp2.c-Avoid-using-incompatible-pointer-type.patch
# Avoid using incompatible pointer type for `old_warn`
# https://github.com/eserte/perl-tk/issues/98
Patch7:         perl-Tk-Avoid-using-incompatible-pointer-type-for-old_warn.patch
# Avoid using incompatible pointer type in function 'GetTextIndex'
# https://github.com/eserte/perl-tk/issues/103
Patch8:         perl-Tk-Fix-incompatible-pointer-type-in-function-GetTextIndex.patch
# (tv) further fix: pTK/Xlib.t is regenerated by "mkVFunc -t x Xlib.h":
Patch9:        further-fixes.diff
Patch10:        fix-build-with-clang-16.diff
Patch20:         80-Fix-STRLEN-vs-int-pointer-confusion-in-Tcl_GetByteAr.patch
Patch21:        gcc-14.patch

BuildRequires: perl(Encode)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Test::More)
BuildRequires: perl-devel
BuildRequires: pkgconfig(libjpeg)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(xft)
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(libnsl)
Provides:   perl(Tk::TextReindex)
Provides:   perl(Tk::LabRadio)
# to remove on upgrade (misc)
Obsoletes:  perl-Tk-PNG

%package	devel
Summary:    Tk modules for Perl (development package)
Group:      Development/Perl
Requires:   perl-Tk = %{version}-%{release}
%package	doc
Summary:    Tk modules for Perl (documentation package)
Group:      Development/Perl
Requires:   perl-Tk = %{version}-%{release}
%global __requires_exclude perl\\(.*LabEnLabRad\\)

%{?perl_default_filter}

%description
This package provides the modules and Tk code for Perl/Tk,
as written by Nick Ing-Simmons (pTk), John Ousterhout(Tk),
and Ioi Kim Lam(Tix).
It gives you the ability to develop perl applications using the Tk GUI.
It includes the source code for the Tk and Tix elements it uses.
The licences for the various components differ, so check the copyright.

%description	devel
This package provides the modules and Tk code for Perl/Tk,
as written by Nick Ing-Simmons (pTk), John Ousterhout(Tk),
and Ioi Kim Lam(Tix).
It gives you the ability to develop perl applications using the Tk GUI.
It includes the source code for the Tk and Tix elements it uses.
The licences for the various components differ, so check the copyright.

This is the development package.

%description	doc
This package provides the modules and Tk code for Perl/Tk,
as written by Nick Ing-Simmons (pTk), John Ousterhout(Tk),
and Ioi Kim Lam(Tix).
It gives you the ability to develop perl applications using the Tk GUI.
It includes the source code for the Tk and Tix elements it uses.
The licences for the various components differ, so check the copyright.

This is the documentation package.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
chmod -x pod/Popup.pod Tixish/lib/Tk/balArrow.xbm
# debian patch
#%%patch -P 1 -p1
# patch to fix #235666 ... seems like caching code is broken
%patch -P 2 -p1 -b .seg
%patch -P 3 -p1 -b .c99
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p1
 

find . -type f | xargs perl -pi -e 's|^#!.*/bin/perl\S*|#!/usr/bin/perl|'
# Make it lib64 aware, avoid patch
perl -pi -e "s,(/usr/X11(R6|\\*)|\\\$X11|\(\?:)/lib,\1/%{_lib},g" \
  myConfig pTk/mTk/unix/configure
#(peroyvind) --center does no longer seem to be working, obsoleted by -c
perl -pi -e "s#--center#-c#" ./Tk/MMutil.pm

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor XFT=1
%make_build

%install
%make_install
%{__chmod} 644 %{buildroot}%{_mandir}/man3*/*

# Remove unpackaged files, add them if you find a use
# Tie::Watch is packaged separately
rm -f %{buildroot}%{perl_vendorarch}/Tk/prolog.ps
rm -f %{buildroot}%{_mandir}/man1/{ptk{ed,sh},widget}.1*

## compress all .pm files (as using perl-PerlIO-gzip).
#find %{buildroot} -name "*.pm" | xargs gzip -9

# fix rights
find %{buildroot} -name "*.so" -exec chmod u+w {} \;

%files
%doc COPYING Changes INSTALL IO JPEG META.json META.yml MYMETA.yml PNG README VERSIONS demos examples
%{_bindir}/*
%{_mandir}/man*/*
%{perl_vendorarch}/Tk.pm*
%dir %{perl_vendorarch}/Tk
%{perl_vendorarch}/Tie/Watch.pm
%{perl_vendorarch}/Tk/*.pm*
%{perl_vendorarch}/Tk/*.gif
%{perl_vendorarch}/Tk/*.xbm
%{perl_vendorarch}/Tk/*.xpm
%{perl_vendorarch}/Tk/license.terms
%{perl_vendorarch}/Tk/Credits
%{perl_vendorarch}/Tk/DragDrop
%{perl_vendorarch}/Tk/Event
%{perl_vendorarch}/Tk/Menu
%{perl_vendorarch}/Tk/Text
%{perl_vendorarch}/Tk/demos
%{perl_vendorarch}/auto/Tk

%files devel
%doc COPYING Funcs.doc INSTALL
%{perl_vendorarch}/Tk/pTk
%{perl_vendorarch}/Tk/*.def
%{perl_vendorarch}/Tk/*.h
%{perl_vendorarch}/Tk/*.m
%{perl_vendorarch}/Tk/*.t
%{perl_vendorarch}/Tk/typemap

%files doc
%doc COPYING
%{perl_vendorarch}/Tk.pod
%{perl_vendorarch}/Tk/*.pod
%{perl_vendorarch}/Tk/README.Adjust
