%global         __python %{__python3}



%define         major                         3
%define         libname                       %mklibname %{name} %{major}
%define         libdevelname                  %mklibname %{name} -d


%define         gccinstalldir   %(LC_ALL=C %__cc --print-search-dirs | grep install | %__awk '{print $2}')
%define         fincludedir     %{gccinstalldir}finclude

%ifnarch %arm32 %ix86
%bcond_without  mpi
%else
%bcond_with     mpi
%endif

%bcond_without superlu

Name:           petsc
Summary:        A tools suite for partial differential equations
Version:        3.22.2
Release:        %mkrel 1
License:        BSD-like
Group:          System/Libraries
Url:            https://petsc.gitlab.io/petsc/release
Source0:        https://web.cels.anl.gov/projects/petsc/download/release-snapshots/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(hwloc)
BuildRequires:  pkgconfig(blas)
BuildRequires:  pkgconfig(lapack)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(muparser)
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(valgrind)
BuildRequires:  hdf5-devel
#look for static lib only
#BuildRequires:  sundials-devel
#BuildRequires:  suitesparse-devel
BuildRequires:  libgomp-devel
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  boost-devel
BuildRequires:  libcgns-devel
BuildRequires:  gmp-devel
BuildRequires:  yaml-devel
%if %{with mpi}
BuildRequires:  pkgconfig(ompi)
BuildRequires:  ptscotch-openmpi-devel
BuildRequires:  lib64ptscotch-parmetis-openmpi-devel
BuildRequires:  python3-mpi4py
%endif
%if %{with superlu}
BuildRequires:  pkgconfig(superlu) >= 5.2.0
%endif

%description
PETSc, pronounced PET-see (the S is silent), is a suite of data
structures and routines for the scalable (parallel) solution of
scientific applications modeled by partial differential equations. It
supports MPI, and GPUs through CUDA or OpenCL, as well as hybrid
MPI-GPU parallelism. PETSc (sometimes called PETSc/Tao) also contains
the Tao optimization software library.



%package -n %{libname}
Summary:        Shared objects for PETSc
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
%{summary}


%package -n %{libdevelname}
Summary:        Development files for the PETSc library
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{libdevelname}
%{summary}.



%prep
%autosetup -p1

%py_shebang_fix config/ lib/

%build
#let's do this by hand, the configure script is home made. Do not
#force optflags here on purpose, petsc is compiled with -O0

%before_configure
%_configure \
	    --prefix=%{_prefix} --with-avx512-kernels=0              \
            --with-python-exec=%{__python3}                          \
            --with-openmp=1 --with-blaslapack=1         	     \
            --with-hwloc=1 --with-zlib --with-hdf5=1 --with-netcdf=1 \
	    --with-eigen=1 --with-suitesparse=0                      \
%if %{with mpi}
            --with-fc="mpif90 -I%{_includedir}"			     \
            --with-mpi=1                                             \
            --known-mpi-shared-libraries=1                           \
    	    --with-ptscotch=1  					     \
	    --with-ptscotch-dir=%{_libdir}/mpi/gcc/openmpi           \
%else
            --with-mpi=0					     \
	    --with-ptscotch=0                                        \
%endif
%if %{with superlu}
            --with-superlu=1                                         \
            --with-superlu-include=%{_includedir}/superlu            \
            --with-superlu-lib=-lsuperlu                             \
%endif
	    --with-boost=1 --with-cgns=0 --with-fftw=1               \
	    --with-gmp=1 --with-libjpeg=1 --with-mpfr=1              \
	    --with-muparser=1 --with-opencl=1                        \
	    --with-yaml=1 --with-zstd=1 --with-valgrind=1

%make_build

%install
%make_install

#the bloody /usr/lib is hardcoded everywhere
%if "%{?_lib}" == "lib64"
pushd %{buildroot}/%{_prefix}
%__mv -f lib %{_lib}
popd
%endif

#put fortran module files where they should
%__mkdir -p %{buildroot}/%{fincludedir}
%__mv -f %{buildroot}/%{_includedir}/*.mod %{buildroot}/%{fincludedir}/
sed -i 's|libdir=${prefix}/lib|libdir=${prefix}/%{_lib}|g' %{buildroot}/%{_libdir}/pkgconfig/PETSc.pc


%files -n %{name}
%doc LICENSE
%{_datadir}/petsc

%files -n %{libname}
%{_libdir}/libpetsc.so.%{major}{,.*}
%{_libdir}/petsc

%files -n %{libdevelname}
%{_includedir}/petsc*.h
%{_includedir}/petsc*.hpp
%{fincludedir}/*.mod
%{_includedir}/petsc
%{_libdir}/libpetsc.so
%{_libdir}/pkgconfig/*.pc
