%define major		2
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define octlibdir       %(LC_ALL=C octave-config -p OCTLIBDIR)

Name:		pfstools
Version:	2.2.0
Release:	%mkrel 14
Summary:	Programs for handling high-dynamic range images
Group:		Graphics/Utilities
License:	GPLv2+
URL:		https://pfstools.sourceforge.net/
Source0:	https://sourceforge.net/projects/pfstools/files/%{name}/%{version}/%{name}-%{version}.tgz
Patch0:		pfstools-2.1.0-30_parallel_build.patch
# patch derived from https://github.com/pld-linux/pfstools/commit/67bd2304e516545f2b203f975ac5dd30d2b479b3
# I guess it could go upstream as is; sent email to mantiuk at gmail
Patch1:		pfstools-2.0.6-ImageMagick7.patch
#(eatdirt) find glut library
Patch2:		pfstools-freeglut.patch
Patch3:		pfstools-openexr3.patch
#(eatdirt) normalization option (reported upstream)
Patch4:         pfstools-2.2.0-normoptions.patch
BuildRequires:	cmake
BuildRequires:	texlive
BuildRequires:	netpbm-devel

BuildRequires:	octave-devel
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(ImageMagick)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(xi)
BuildRequires:  pkgconfig(libexif)
#BuildRequires:  pkgconfig(opencv)

Obsoletes:	pfstools-gdal < 1.8.5-3


%description
pfstools is a set of command line programs for reading,
writing, manipulating and viewing high-dynamic range (HDR) images and
video frames. All programs in the package exchange data using unix
pipes and a simple generic HDR image format (pfs). The concept of the
pfstools is similar to netpbm package for low-dynamic range images.


%package -n	pfscalibration
Summary:	Scripts and programs for photometric calibration
Group:		Graphics/Utilities
Requires:	perl
Requires:	dcraw
Requires:	jhead

%description -n	pfscalibration
PFScalibration package provides an implementation of the Robertson et al. 2003
method for the photometric calibration of cameras, Mitsunaga and Nayar's
algorithm "Radiometric Self Calibration", and for the recovery of high dynamic
range (HDR) images from the set of low dynamic range (LDR) exposures.


%package -n	pfstmo
Summary:	PFS tone mapping operators
Group:		Graphics/Utilities

%description -n	pfstmo
The pfstmo package contains the implementation of state-of-the-art tone
mapping operators. The motivation here is to provide an implementation of
tone mapping operators suitable for convenient processing of both static
images and animations.


%package -n	%{libname}
Summary:	Libraries for HDR processing
Group:		System/Libraries
License:	LGPLv2+

%description -n	%{libname}
The %{libname} package contains a runtime library of functions for
handling HDR graphics files.


%package	qt
Summary:	Qt5-based viewer for HDR files
Group:		Graphics/Viewers

%description	qt
The pfstools-qt package contains viewer programs based on qt5 for
viewing HDR graphics files.


%package	glview
Summary:	GL-based viewer for HDR files
Group:		Graphics/Viewers

%description	glview
The pfstools-glview package contains viewer programs based on OpenGL for
viewing HDR graphics files.


%package	exr
Summary:	EXR file import for PFS tools
Group:		Graphics/Utilities

%description	exr
The pfstools-exr package contains input and output filters for EXR files
to and from the HDR graphics file format used in pfstools.


%package	yuy
Summary:	YUY file import for PFS tools
Group:		Graphics/Utilities

%description	yuy
The pfstools-yuy package contains input and output filters for YUY files
to handle uncompressed video used by many video codecs in pfstools.


%package	imgmagick
Summary:	ImageMagick file import for PFS tools
Group:		Graphics/Utilities

%description	imgmagick
The pfstools-imgmagick package contains input and output filters based in
ImageMagick to and from the HDR graphics file format used in pfstools.


%package	octave
Summary:	Octave interaction with PFS tools
Group:		Graphics/Utilities

%description	octave
The pfstools-octave package contains programs to process red, green and blue
channels or luminance channels in pfs stream using Octave.


%package -n	%{develname}
Summary:	Files for development with PFS tools
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains the header files and link libraries,
etc., for developing programs which can handle HDR graphics files.


%prep
%setup -q
%autopatch -p1

%build
#(eatdirt) openCV is off because pfsalign requires nonfree part that
#we do not distribute
export LDFLAGS="%{ldflags} -L%{octlibdir} -loctave -loctinterp"
%cmake \
	-DLIB_DIR=%{_lib} \
        -DWITH_OpenCV=OFF
%cmake_build

%install
%cmake_install

# nuke unpackaged files
find %{buildroot} -name 'pfsinjpeghdr.1' -delete
find %{buildroot} -name 'pfsoutjpeghdr.1' -delete

%files
%doc AUTHORS ChangeLog README doc/faq.txt
%{_bindir}/pfsabsolute
%{_bindir}/pfscat
%{_bindir}/pfsclamp
%{_bindir}/pfscut
%{_bindir}/pfsextractchannels
%{_bindir}/pfsdisplayfunction
%{_bindir}/pfsflip
%{_bindir}/pfsgamma
%{_bindir}/pfsin
%{_bindir}/pfsindcraw
%{_bindir}/pfsinpfm
%{_bindir}/pfsinppm
%{_bindir}/pfsinrgbe
%{_bindir}/pfsintiff
%{_bindir}/pfsout
%{_bindir}/pfsouthdrhtml
%{_bindir}/pfsoutpfm
%{_bindir}/pfsoutppm
%{_bindir}/pfsoutrgbe
%{_bindir}/pfsouttiff
%{_bindir}/pfspad
%{_bindir}/pfspanoramic
%{_bindir}/pfsrotate
%{_bindir}/pfssize
%{_bindir}/pfstag
%{_bindir}/pfscolortransform
%{_bindir}/pfsretime
%{_bindir}/pfs_automerge
%{_bindir}/pfs_split_exposures.py
%{_datadir}/pfstools/hdrhtml_c_b2.csv
%{_datadir}/pfstools/hdrhtml_c_b3.csv
%{_datadir}/pfstools/hdrhtml_c_b4.csv
%{_datadir}/pfstools/hdrhtml_c_b5.csv
%{_datadir}/pfstools/hdrhtml_default_templ/
%{_datadir}/pfstools/hdrhtml_hdrlabs_templ/
%{_datadir}/pfstools/hdrhtml_t_b2.csv
%{_datadir}/pfstools/hdrhtml_t_b3.csv
%{_datadir}/pfstools/hdrhtml_t_b4.csv
%{_datadir}/pfstools/hdrhtml_t_b5.csv
%{_mandir}/man1/pfsabsolute.1*
%{_mandir}/man1/pfscat.1*
%{_mandir}/man1/pfsclamp.1*
%{_mandir}/man1/pfscut.1*
%{_mandir}/man1/pfsdisplayfunction.1*
%{_mandir}/man1/pfsextractchannels.1*
%{_mandir}/man1/pfsflip.1*
%{_mandir}/man1/pfsgamma.1*
%{_mandir}/man1/pfsin.1*
%{_mandir}/man1/pfsindcraw.1*
%{_mandir}/man1/pfsinpfm.1*
%{_mandir}/man1/pfsinppm.1*
%{_mandir}/man1/pfsinrgbe.1*
%{_mandir}/man1/pfsintiff.1*
%{_mandir}/man1/pfsout.1*
%{_mandir}/man1/pfsouthdrhtml.1*
%{_mandir}/man1/pfsoutpfm.1*
%{_mandir}/man1/pfsoutppm.1*
%{_mandir}/man1/pfsoutrgbe.1*
%{_mandir}/man1/pfsouttiff.1*
%{_mandir}/man1/pfspad.1*
%{_mandir}/man1/pfspanoramic.1*
%{_mandir}/man1/pfsrotate.1*
%{_mandir}/man1/pfssize.1*
%{_mandir}/man1/pfstag.1*
%{_mandir}/man1/pfscolortransform.1*
%{_mandir}/man1/pfsretime.1*
%{_mandir}/man1/pfs_automerge.1*

%files -n pfscalibration
%{_bindir}/dcraw2hdrgen
%{_bindir}/jpeg2hdrgen
%{_bindir}/pfshdrcalibrate
%{_bindir}/pfsinhdrgen
%{_bindir}/pfsinme
%{_bindir}/pfsplotresponse
%{_mandir}/man1/dcraw2hdrgen.1*
%{_mandir}/man1/jpeg2hdrgen.1*
%{_mandir}/man1/pfshdrcalibrate.1*
%{_mandir}/man1/pfsinhdrgen.1*
%{_mandir}/man1/pfsinme.1*
%{_mandir}/man1/pfsplotresponse.1*

%files -n pfstmo
%{_bindir}/pfstmo_reinhard05
%{_bindir}/pfstmo_pattanaik00
%{_bindir}/pfstmo_mantiuk06
%{_bindir}/pfstmo_fattal02
%{_bindir}/pfstmo_drago03
%{_bindir}/pfstmo_reinhard02
%{_bindir}/pfstmo_durand02
%{_bindir}/pfstmo_mantiuk08
%{_bindir}/pfstmo_ferradans11
%{_bindir}/pfstmo_mai11
%{_mandir}/man1/pfstmo_reinhard05.1*
%{_mandir}/man1/pfstmo_pattanaik00.1*
%{_mandir}/man1/pfstmo_mantiuk06.1*
%{_mandir}/man1/pfstmo_fattal02.1*
%{_mandir}/man1/pfstmo_drago03.1*
%{_mandir}/man1/pfstmo_reinhard02.1*
%{_mandir}/man1/pfstmo_durand02.1*
%{_mandir}/man1/pfstmo_mantiuk08.1*
%{_mandir}/man1/pfstmo_ferradans11.1*
%{_mandir}/man1/pfstmo_mai11.1*

%files -n %{libname}
%{_libdir}/libpfs.so.%{major}
%{_libdir}/libpfs.so.%{major}.*

%files qt
%{_bindir}/pfsv
%{_bindir}/pfsview
%{_mandir}/man1/pfsview.1*

%files glview
%{_bindir}/pfsglview
%{_mandir}/man1/pfsglview.1*

%files exr
%{_bindir}/pfsinexr
%{_bindir}/pfsoutexr
%{_mandir}/man1/pfsinexr.1*
%{_mandir}/man1/pfsoutexr.1*

%files yuy
%{_bindir}/pfsinyuv
%{_bindir}/pfsoutyuv
%{_mandir}/man1/pfsinyuv.1*
%{_mandir}/man1/pfsoutyuv.1*

%files imgmagick
%{_bindir}/pfsinimgmagick
%{_bindir}/pfsoutimgmagick
%{_mandir}/man1/pfsinimgmagick.1*
%{_mandir}/man1/pfsoutimgmagick.1*

%files octave
%{_bindir}/pfsoctavelum
%{_bindir}/pfsoctavergb
%{_bindir}/pfsstat
%{_libdir}/octave/*/site/oct/*/pfstools
%{_datadir}/octave/*/site/m/pfstools
%{_mandir}/man1/pfsoctavelum.1*
%{_mandir}/man1/pfsoctavergb.1*
%{_mandir}/man1/pfsstat.1*

%files -n %{develname}
%doc doc/pfs_format_spec.tex
%{_libdir}/libpfs.so
%{_libdir}/pkgconfig/pfs.pc
%{_includedir}/pfs
