# git revision (as reported by git describe) is used as version minor for snapshots
# set git 0 for full release, 1 for snapshot tarball
%define git	1

Name:		phototonic
Version:	2.1.137
Release:	%mkrel 1
Summary:	An image viewer and organizer
Group:		Graphics/Viewers
License:	GPLv3
Url:		https://oferkv.github.io/phototonic/
%if %{git}
Source0:	%{name}-%{version}.tar.gz
%else
Source0:	https://downloads.sourceforge.net/project/%{name}/%{name}-%{version}.tar.gz
%endif
# Run ./mk-tar-git-rev in SOURCES to create snapshot tarball
Source1:	mk-tar-git-rev
Patch1:		0001-Update-French-translation.patch

BuildRequires:	git-core
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(exiv2)

Recommends:	%{_lib}qtsvg5
Recommends:	qtimageformats5

%description
Phototonic is an image viewer and organizer with the following features:
* Light weight with a smooth and clear user interface
* Does not depend on any desktop environment
* Supports several customized thumbnail layouts
* Load thumbnails and browse images recursively
* Dynamic thumbnails loading, enabling fast browsing of very large folders
* Filter thumbnails
* Image navigation and file management
* Slide show
* View random image
* Transformation: rotation, flipping, cropping, image mirroring
* Adjust image colors
* Keep transformations zoom and colors while browsing multiple images
* Extensive automatic and manual zoom options
* Supported image formats: 
BMP, GIF, ICO, JPEG, MNG, PBM, PGM, PNG, PPM, SVG, SVGZ, TGA, TIFF, XBM, XPM
* Supports GIF animations
* Keyboard shortcuts and mouse behavior customization
* Load image files or folders from command line
* Open images with external applications

%prep
%autosetup -p1 -Sgit

%build
%qmake_qt5
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

# Install translations
mkdir -p %{buildroot}%{_datadir}/%{name}/translations
cp -r translations/*.qm %{buildroot}%{_datadir}/%{name}/translations

# Tweak upstream desktop file
desktop-file-install \
	--dir=%{buildroot}%{_datadir}/applications \
	--add-category='X-Mageia-CrossDesktop' \
	%{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%doc COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/translations
%{_iconsdir}/hicolor/*x*/apps/%{name}.png
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/metainfo/phototonic.appdata.xml
