# inspired from fedora spec file
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# https://creativecommons.org/licenses/by-sa/4.0/

%global github_owner laminas
%global github_name  laminas-cache
%global zf_name      zend-cache
%global namespace    Laminas
%global library      Cache

%define php_libdir %{_datadir}/php

%define __requires_exclude_from ^%{_datadir}/.*$

Name:           php-%{github_name}
Version:        2.10.0
Release:        %mkrel 2
Summary:        Laminas Framework %{library} component
License:        BSD
Group:          Development/PHP
URL:            https://github.com/%{github_owner}/%{github_name}
Source0:        https://github.com/%{github_owner}/%{github_name}/archive/%{github_name}-%{version}.tar.gz

BuildArch:      noarch

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "laminas/laminas-eventmanager": "^2.6.3 || ^3.2",
#        "laminas/laminas-servicemanager": "^2.7.8 || ^3.3",
#        "laminas/laminas-stdlib": "^3.2.1",
#        "laminas/laminas-zendframework-bridge": "^1.0",
#        "psr/cache": "^1.0",
#        "psr/simple-cache": "^1.0"
Requires:       php >= 5.6
Requires:       php-autoloader(%{github_owner}/laminas-eventmanager)         >= 3.2
Requires:       php-autoloader(%{github_owner}/laminas-servicemanager)       >= 3.3
Requires:       php-autoloader(%{github_owner}/laminas-stdlib)               >= 3.2.1
Requires:       php-autoloader(%{github_owner}/laminas-zendframework-bridge) >= 1.0
Requires:       php-composer(psr/cache)                                  >= 1.0
Requires:       php-composer(psr/simple-cache)                           >= 1.0
# From composer, "suggest": {
#        "ext-apc": "APC or compatible extension, to use the APC storage adapter",
#        "ext-apcu": "APCU >= 5.1.0, to use the APCu storage adapter",
#        "ext-dba": "DBA, to use the DBA storage adapter",
#        "ext-memcache": "Memcache >= 2.0.0 to use the Memcache storage adapter",
#        "ext-memcached": "Memcached >= 1.0.0 to use the Memcached storage adapter",
#        "ext-mongo": "Mongo, to use MongoDb storage adapter",
#        "ext-mongodb": "MongoDB, to use the ExtMongoDb storage adapter",
#        "ext-redis": "Redis, to use Redis storage adapter",
#        "ext-wincache": "WinCache, to use the WinCache storage adapter",
#        "ext-xcache": "XCache, to use the XCache storage adapter",
#        "laminas/laminas-serializer": "Laminas\\Serializer component",
#        "laminas/laminas-session": "Laminas\\Session component",
#        "mongodb/mongodb": "Required for use with the ext-mongodb adapter",
#        "mongofill/mongofill": "Alternative to ext-mongo - a pure PHP implementation designed as a drop in replacement"
Suggests:       php-apcu
Suggests:       php-dba
Suggests:       php-memcache
Suggests:       php-memcached
Suggests:       php-redis
Suggests:       php-composer(%{github_owner}/laminas-serializer)
Suggests:       php-composer(%{github_owner}/laminas-session)
Suggests:       php-composer(mongodb/mongodb)
# From phpcompatinfo report for version 2.9.0
Requires:       php-pcre
# Autoloader
BuildRequires:  php-fedora-autoloader-devel
Requires:       php-composer(fedora/autoloader)

# Compatibily ensure by the bridge
Obsoletes:      php-zendframework-%{zf_name}              < 2.9.0-99
Provides:       php-zendframework-%{zf_name}              = %{version}-99
Obsoletes:      php-ZendFramework2-Cache
Provides:       php-composer(%{github_owner}/%{github_name})   = %{version}
Provides:       php-composer(zendframework/%{zf_name})    = %{version}
Provides:       php-autoloader(%{github_owner}/%{github_name}) = %{version}
Provides:       php-autoloader(zendframework/%{zf_name})  = %{version}
Provides:       php-composer(psr/cache-implementation)        = 1.0
Provides:       php-composer(psr/simple-cache-implementation) = 1.0


%description
%{namespace}\Cache provides a general cache system for PHP.
The %{namespace}\Cache component is able to cache different patterns
(class, object, output, etc) using different storage adapters
(DB, File, Memcache, etc).

Documentation: https://docs.laminas.dev/%{github_name}/


%prep
%setup -q -n %{github_name}-%{version}

mv LICENSE.md LICENSE

mv autoload/*.php src

%build
: Create autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/Psr/Cache/autoload.php',
    '%{php_libdir}/Psr/SimpleCache/autoload.php',
    '%{php_libdir}/%{namespace}/Stdlib/autoload.php',
    '%{php_libdir}/%{namespace}/ServiceManager/autoload.php',
    '%{php_libdir}/%{namespace}/EventManager/autoload.php',
    __DIR__ . '/patternPluginManagerPolyfill.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_libdir}/%{namespace}/Serializer/autoload.php',
    '%{php_libdir}/%{namespace}/Session/autoload.php',
    '%{php_libdir}/MongoDB/autoload.php',
]);
EOF

cat << 'EOF' | tee zf.php
<?php
require_once '%{php_libdir}/Fedora/Autoloader/autoload.php';
\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/%{namespace}/ZendFrameworkBridge/autoload.php',
    dirname(dirname(__DIR__)) . '/%{namespace}/%{library}/autoload.php',
]);
EOF


%install
: Laminas library
mkdir -p   %{buildroot}%{php_libdir}/%{namespace}/
cp -pr src %{buildroot}%{php_libdir}/%{namespace}/%{library}

: Zend equiv
mkdir -p      %{buildroot}%{php_libdir}/Zend/%{library}
cp -pr zf.php %{buildroot}%{php_libdir}/Zend/%{library}/autoload.php

%files
%doc LICENSE
%doc *.md
%doc composer.json
%{php_libdir}/Zend/%{library}
%{php_libdir}/%{namespace}/%{library}
