# inspired from fedora spec file
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# https://creativecommons.org/licenses/by-sa/4.0/

%global bootstrap    0
%global github_owner laminas
%global github_name  laminas-db
%global zf_name      zend-db
%global namespace    Laminas
%global library      Db

%define php_libdir %{_datadir}/php

%define __requires_exclude_from ^%{_datadir}/.*$

Name:           php-%{github_name}
Version:        2.11.3
Release:        %mkrel 2
Summary:        %{namespace} Framework %{library} component
Group:          Development/PHP
License:        BSD
URL:            https://github.com/%{github_owner}/%{github_name}
Source0:        https://github.com/%{github_owner}/%{github_name}/archive/%{github_name}-%{version}.tar.gz

BuildArch:      noarch
# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "laminas/laminas-stdlib": "^2.7 || ^3.0",
#        "laminas/laminas-zendframework-bridge": "^1.0"
Requires:       php >= 5.6
%if ! %{bootstrap}
Requires:      php-autoloader(%{github_owner}/laminas-stdlib)               >= 3.0
Requires:      php-autoloader(%{github_owner}/laminas-zendframework-bridge) >= 1.0
# From composer, "suggest": {
#        "laminas/laminas-eventmanager": "Laminas\\EventManager component",
#        "laminas/laminas-hydrator": "Laminas\\Hydrator component for using HydratingResultSets",
#        "laminas/laminas-servicemanager": "Laminas\\ServiceManager component"
Suggests:       php-autoloader(%{github_owner}/laminas-eventmanager)
Suggests:       php-autoloader(%{github_owner}/laminas-hydrator)
Suggests:       php-autoloader(%{github_owner}/laminas-servicemanager)
%endif
# Autoloader
Requires:       php-composer(fedora/autoloader)
# From phpcompatinfo report for version 2.11.2
Requires:       php-pcre
Requires:       php-pdo

# Compatibily ensure by the bridge
Obsoletes:      php-zendframework-%{zf_name}              < 2.11.1
Provides:       php-zendframework-%{zf_name}              = %{version}
Obsoletes:      php-ZendFramework2-Db
Provides:       php-composer(%{github_owner}/%{github_name})   = %{version}
Provides:       php-composer(zendframework/%{zf_name})    = %{version}
Provides:       php-autoloader(%{github_owner}/%{github_name}) = %{version}
Provides:       php-autoloader(zendframework/%{zf_name})  = %{version}


%description
%{namespace}\Db is a component that abstract the access to a Database using an
object oriented API to build the queries. %{namespace}\Db consumes different
storage adapters to access different database vendors such as MySQL,
PostgreSQL, Oracle, IBM DB2, Microsoft Sql Server, PDO, etc.

Documentation: https://docs.laminas.dev/%{github_name}/


%prep
%setup -q -n %{github_name}-%{version}

mv LICENSE.md LICENSE


%build
: Generate autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/%{namespace}/Stdlib/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_libdir}/%{namespace}/EventManager/autoload.php',
    [
        '%{php_libdir}/%{namespace}/Hydrator3/autoload.php',
        '%{php_libdir}/%{namespace}/Hydrator/autoload.php',
    ],
    '%{php_libdir}/%{namespace}/ServiceManager/autoload.php',
]);
EOF

cat << 'EOF' | tee zf.php
<?php
require_once '%{php_libdir}/Fedora/Autoloader/autoload.php';
\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/%{namespace}/ZendFrameworkBridge/autoload.php',
    dirname(dirname(__DIR__)) . '/%{namespace}/%{library}/autoload.php',
]);
EOF


%install
: Laminas library
mkdir -p   %{buildroot}%{php_libdir}/%{namespace}/
cp -pr src %{buildroot}%{php_libdir}/%{namespace}/%{library}

: Zend equiv
mkdir -p      %{buildroot}%{php_libdir}/Zend/%{library}
cp -pr zf.php %{buildroot}%{php_libdir}/Zend/%{library}/autoload.php

%files
%doc LICENSE
%doc *.md
%doc composer.json
%{php_libdir}/Zend/%{library}
%{php_libdir}/%{namespace}/%{library}
