# inspired from fedora spec file
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# https://creativecommons.org/licenses/by-sa/4.0/

%global bootstrap    0
%global github_owner laminas
%global github_name  laminas-eventmanager
%global zf_name      zend-eventmanager
%global namespace    Laminas
%global library      EventManager

%define php_libdir %{_datadir}/php

%define __requires_exclude_from ^%{_datadir}/.*$

Name:           php-%{github_name}
Version:        3.3.0
Release:        %mkrel 2
Summary:        Laminas Framework %{library} component
License:        BSD
Group:          Development/PHP
URL:            https://github.com/%{github_owner}/%{github_name}
Source0:        https://github.com/%{github_owner}/%{github_name}/archive/%{github_name}-%{version}.tar.gz

BuildArch:      noarch

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "laminas/laminas-zendframework-bridge": "^1.0"
Requires:       php >= 5.6
Requires:       php-composer(%{github_owner}/laminas-zendframework-bridge) >= 1.0
%if ! %{bootstrap}
# From composer, "suggest": {
#        "container-interop/container-interop": "^1.1.0, to use the lazy listeners feature",
#        "laminas/laminas-stdlib": "^2.7.3 || ^3.0, to use the FilterChain feature"
Suggests:       php-composer(container-interop/container-interop)
Suggests:       php-composer(%{github_owner}/laminas-stdlib)
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel
Requires:       php-composer(fedora/autoloader)

# Compatibily ensure by the bridge
Obsoletes:      php-zendframework-%{zf_name}              < 3.2.1-99
Provides:       php-zendframework-%{zf_name}              = %{version}-99
Obsoletes:      php-ZendFramework2-EventManager
Provides:       php-composer(%{github_owner}/%{github_name})   = %{version}
Provides:       php-composer(zendframework/%{zf_name})    = %{version}
Provides:       php-autoloader(%{github_owner}/%{github_name}) = %{version}
Provides:       php-autoloader(zendframework/%{zf_name})  = %{version}


%description
The %{github_name} is a component designed for the following use cases:

* Implementing simple subject/observer patterns.
* Implementing Aspect-Oriented designs.
* Implementing event-driven architectures.

The basic architecture allows you to attach and detach listeners to named
events, both on a per-instance basis as well as via shared collections;
trigger events; and interrupt execution of listeners.

Documentation: https://docs.laminas.dev/%{github_name}/


%prep
%setup -q -n %{github_name}-%{version}

mv LICENSE.md LICENSE


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::optional([
    '%{php_libdir}/Interop/Container/autoload.php',
    '%{php_libdir}/%{namespace}/Stdlib/autoload.php',
]);
EOF

cat << 'EOF' | tee zf.php
<?php
require_once '%{php_libdir}/Fedora/Autoloader/autoload.php';
\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/%{namespace}/ZendFrameworkBridge/autoload.php',
    dirname(dirname(__DIR__)) . '/%{namespace}/%{library}/autoload.php',
]);
EOF


%install
: Laminas library
mkdir -p   %{buildroot}%{php_libdir}/%{namespace}/
cp -pr src %{buildroot}%{php_libdir}/%{namespace}/%{library}

: Zend equiv
mkdir -p      %{buildroot}%{php_libdir}/Zend/%{library}
cp -pr zf.php %{buildroot}%{php_libdir}/Zend/%{library}/autoload.php

%files
%doc LICENSE
%doc *.md
%doc composer.json
%{php_libdir}/Zend/%{library}
%{php_libdir}/%{namespace}/%{library}
