# inspired from fedora spec file
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# https://creativecommons.org/licenses/by-sa/4.0/

%global bootstrap    0
%global github_owner laminas
%global github_name  laminas-servicemanager
%global zf_name      zend-servicemanager
%global namespace    Laminas
%global library      ServiceManager

%define php_libdir %{_datadir}/php

%define __requires_exclude_from ^%{_datadir}/.*$

Name:           php-%{github_name}
Version:        3.4.1
Release:        %mkrel 2
Summary:        Laminas Framework %{library} component
License:        BSD
Group:          Development/PHP
URL:            https://github.com/%{github_owner}/%{github_name}
Source0:        https://github.com/%{github_owner}/%{github_name}/archive/%{github_name}-%{version}.tar.gz

BuildArch:      noarch

# Autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "container-interop/container-interop": "^1.2",
#        "laminas/laminas-stdlib": "^3.2.1",
#        "laminas/laminas-zendframework-bridge": "^1.0",
#        "psr/container": "^1.0"
Requires:       php >= 5.6
Requires:       php-composer(container-interop/container-interop)      >= 1.2
Requires:       php-autoloader(%{github_owner}/laminas-stdlib)             >= 3.2.1
Requires:       php-composer(%{github_owner}/laminas-zendframework-bridge) >= 1.0
Requires:       php-composer(psr/container)                            >= 1.0
# From phpcompatinfo report for version 3.4.0
Requires:       php-json
%if ! %{bootstrap}
# From composer, "suggest": {
#        "laminas/laminas-stdlib": "laminas-stdlib ^2.5 if you wish to use the MergeReplaceKey or MergeRemoveKey features in Config instances",
#        "ocramius/proxy-manager": "ProxyManager 1.* to handle lazy initialization of services"
Suggests:       php-composer(ocramius/proxy-manager)
# Autoloader
BuildRequires:  php-fedora-autoloader-devel
Requires:       php-composer(fedora/autoloader)
%endif

# Compatibily ensure by the bridge
Obsoletes:      php-zendframework-%{zf_name}              < 3.4.1
Provides:       php-zendframework-%{zf_name}              = %{version}
Obsoletes:      php-ZendFramework2-ServiceManager
Provides:       php-composer(%{github_owner}/%{github_name})   = %{version}
Provides:       php-composer(zendframework/%{zf_name})    = %{version}
Provides:       php-autoloader(%{github_owner}/%{github_name}) = %{version}
Provides:       php-autoloader(zendframework/%{zf_name})  = %{version}
Provides:       php-composer(container-interop/container-interop-implementation) = 1.2
Provides:       php-composer(psr/container-implementation) = 1.0


%description
The Service Locator design pattern is implemented by the %{github_name}
component. The Service Locator is a service/object locator, tasked with
retrieving other objects.

Documentation: https://docs.laminas.dev/%{github_name}/


%prep
%setup -q -n %{github_name}-%{version}

mv LICENSE.md LICENSE


%build
: Create autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/Interop/Container/autoload.php',
    '%{php_libdir}/Psr/Container/autoload.php',
    '%{php_libdir}/%{namespace}/Stdlib/autoload.php',
]);
\Fedora\Autoloader\Dependencies::optional([
    '%{php_libdir}/ProxyManager/autoload.php',
]);
EOF

cat << 'EOF' | tee zf.php
<?php
require_once '%{php_libdir}/Fedora/Autoloader/autoload.php';
\Fedora\Autoloader\Dependencies::required([
    '%{php_libdir}/%{namespace}/ZendFrameworkBridge/autoload.php',
    dirname(dirname(__DIR__)) . '/%{namespace}/%{library}/autoload.php',
]);
EOF


%install
: Laminas library
mkdir -p   %{buildroot}%{php_libdir}/%{namespace}/
cp -pr src %{buildroot}%{php_libdir}/%{namespace}/%{library}

: Zend equiv
mkdir -p      %{buildroot}%{php_libdir}/Zend/%{library}
cp -pr zf.php %{buildroot}%{php_libdir}/Zend/%{library}/autoload.php

%files
%doc LICENSE
%doc *.md
%doc composer.json
%{php_libdir}/Zend/%{library}
%{php_libdir}/%{namespace}/%{library}
