# Mainly inspired from Fedora's .spec

%define major        1
%define libname      %mklibname %{name} %{major}
%define libnametrace %mklibname %{name}-trace %{major}
%define libnamedevel %mklibname %{name} -d

Name:           picosat
Summary:        Lightweight SAT solver
Version:        965
Release:        %mkrel 3
Source0:        https://fmv.jku.at/%{name}/%{name}-%{version}.tar.gz
URL:            https://fmv.jku.at/picosat/
# Thanks to David Wheeler for the man page.
Source1:        picosat.1
# Man page link for picosat.trace
Source2:        picosat.trace.1
# Man page for picomus
Source3:        picomus.1
# This patch has not been sent upstream.  It is specific to Fedora's build of
# two distinct binaries, one with trace support and one without.
Patch0:         picosat-trace.patch

Group:          Sciences/Computer science
License:        MIT-like
# gzip required (see app.c); find-requires can't see into C code to find it
Requires:       gzip

%description
The SAT problem is the classical NP complete problem of searching
for a satisfying assignment of a propositional formula in
conjunctive normal form (CNF). General information on SAT can be
found at http://www.satlive.org or http://www.satlib.org.

%package -n     %{libname}
Group:          Development/C
Summary:        A SAT solver library

%description -n %{libname}
The PicoSAT library, which contains routines that solve the SAT problem.
The library has a simple API which is similar to that of previous
solvers by the same authors.

%package -n     %{libnametrace}
Group:          Development/C
Summary:        A SAT solver library

%description -n %{libnametrace}
The PicoSAT library, which contains routines that solve the SAT problem.
The library has a simple API which is similar to that of previous
solvers by the same authors.

%package -n     %{libnamedevel}
Group:          Development/C
Summary:        Development files for PicoSAT
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 965-3

%description -n %{libnamedevel}
Headers and other development files for PicoSAT.

%prep
%autosetup -p0

%build
# The configure script is NOT autoconf-generated and chooses its own CFLAGS,
# so we mimic its effects instead of using it.

# Build the version with trace support
sed -e "s|@CC@|gcc|" \
    -e "s|@CFLAGS@|${RPM_OPT_FLAGS} -DTRACE -DNDEBUG|" \
    -e "s|-Xlinker libpicosat.so|-Xlinker libpicosat.so.%{major}|" \
    -e "s|libpicosat|libpicosat-trace|g" \
    -e "s|-lpicosat|-lpicosat-trace|g" \
    -e "s|@TARGETS@|libpicosat-trace.so picosat picomus|" \
  makefile.in > makefile
make
mv picosat picosat.trace

# Build the fast version.
# Note that picomus needs trace support, so we don't rebuild it.
rm -f *.o *.s config.h
sed -e "s|@CC@|gcc|" \
    -e "s|@CFLAGS@|${RPM_OPT_FLAGS} -DNDEBUG|" \
    -e "s|-Xlinker libpicosat.so|-Xlinker libpicosat.so.%{major}|" \
    -e "s|@TARGETS@|libpicosat.so picosat|" \
  makefile.in > makefile
make

%install
# Install the header file
mkdir -p $RPM_BUILD_ROOT%{_includedir}/%{name}
cp -p picosat.h $RPM_BUILD_ROOT%{_includedir}/%{name}

# Install the libraries
mkdir -p $RPM_BUILD_ROOT%{_libdir}
cp -p libpicosat-trace.so $RPM_BUILD_ROOT%{_libdir}/libpicosat-trace.so.%{major}.0.%{version}
ln -s libpicosat-trace.so.%{major}.0.%{version} $RPM_BUILD_ROOT%{_libdir}/libpicosat-trace.so.%{major}
ln -s libpicosat-trace.so.%{major} $RPM_BUILD_ROOT%{_libdir}/libpicosat-trace.so
cp -p libpicosat.so $RPM_BUILD_ROOT%{_libdir}/libpicosat.so.%{major}.0.%{version}
ln -s libpicosat.so.%{major}.0.%{version} $RPM_BUILD_ROOT%{_libdir}/libpicosat.so.%{major}
ln -s libpicosat.so.%{major} $RPM_BUILD_ROOT%{_libdir}/libpicosat.so

# Install the binaries
mkdir -p $RPM_BUILD_ROOT%{_bindir}
cp -p picosat picosat.trace picomus $RPM_BUILD_ROOT%{_bindir}

# Install the man pages
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
cp -p %{SOURCE1} %{SOURCE2} %{SOURCE3} $RPM_BUILD_ROOT%{_mandir}/man1

# The LICENSE file is placed in the -libs package rather than the base package,
# because the -libs package is always installed when the base package is
# installed, but not vice versa.
%files
%{_bindir}/picosat*
%{_bindir}/picomus
%{_mandir}/man1/picosat*
%{_mandir}/man1/picomus*

%files -n %{libname}
%doc NEWS
%license LICENSE
%{_libdir}/libpicosat.so.%{major}{,.*}

%files -n %{libnametrace}
%doc NEWS
%license LICENSE
%{_libdir}/libpicosat-trace.so.%{major}{,.*}

%files -n %{libnamedevel}
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/picosat.h
%{_libdir}/libpicosat-trace.so
%{_libdir}/libpicosat.so
