%global __requires_exclude perl\\\(PDA::Pilot\\\)

%define	lib_major	9
%define	libname		%mklibname pisock %{lib_major}
%define develname	%mklibname pisock -d
%define	libsync		%mklibname pisync %{sync_major}
%define	sync_major	1

Summary:	File transfer utilities between Linux and PalmPilots
Name:		pilot-link
Version:	0.12.5
Release:	%mkrel 40
License:	GPLv2+ and LGPLv2+
Group:		Communications/Mobile
URL:		https://github.com/jichu4n/pilot-link/
# This link is defunct as of 2024
# Alternate link is https://github.com/jichu4n/pilot-link/archive/refs/tags/0.12.5.tar.gz
Source0:	http://www.pilot-link.org/source/pilot-link-%{version}.tar.bz2 
Source1:	connect-palm-ppp.tar.bz2
Source2:	19-palm-acl-management.fdi
Source3:	pilot-device-file.policy
Source4:	50pilot.sh
Source5:	50pilot.csh
# (fc) 0.12.3-3mdv fix undefined value (Fedora)
Patch3:		pilot-link-0.12.1-var.patch
# (fc) 0.12.3-3mdv fix open calls (Fedora)
Patch4:		pilot-link-0.12.5-open.patch
# (fc) 0.12.3-4mdv fix SJ-22 support (Michael Ekstrand)
Patch5:		pilot-link-0.12.3-sj22.patch
#gw this code doesn't work with our setting of Werror
Patch6: 	pilot-link-0.12.3-no-werror-messup.patch
# fix build with perl 5.14
Patch8:		pilot-link-0.12.5-build_with_perl514.patch
# fix build with autoconf > 2.69
Patch10:	pilot-link-autoconf.patch
Patch11:	pilot-link-configure-c99.patch
Patch12:	pilot-link-c99.patch 
Patch25:	pilot-link-0.12.5-compiler_warnings.patch

BuildRequires:	bison
BuildRequires:	perl-devel
BuildRequires:	automake
BuildRequires:	chrpath
BuildRequires:	pkgconfig(libusb)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(bluez)
BuildRequires:	pkgconfig(readline)

Provides:	%{name}-tcl


%description
This suite of tools allows you to upload and download programs and
data files between a Linux/UNIX machine and the PalmPilot.  It has a
few extra utils that will allow for things like syncing the
PalmPilot's calendar app with Ical.  Note that you might still need to
consult the sources for pilot-link if you would like the Python, Tcl,
or Perl bindings.

Install pilot-link if you want to synchronize your Palm with your
Linux system.

%package -n	%{libname}
Summary:	Libraries needed to use pilot-link
Group:		System/Libraries
Requires:	%{name}-common >= %{version}-%{release}

%description -n	%{libname}
Libraries needed to use pilot-link

%package common
Summary:	Files used by pilot-link packages
Group:		Communications/Mobile

%description common
Files used by pilot-link packages.

%package -n	%{libsync}
Summary:	Libraries needed to use pilot-link
Group:		System/Libraries

%description -n	%{libsync}
Libraries needed to use pilot-link

%package -n	%{develname}
Summary:	PalmPilot development header files
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libsync} = %{version}-%{release}
Obsoletes:	%{name}-devel
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	libpisock-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the development headers that are used to build
the pilot-link package.  It also includes the static libraries
necessary to build static pilot apps.

If you want to develop PalmPilot synchronizing applications, you'll
need to install this package.

%package -n	perl-PDA-Pilot
Summary:	Perl module for Palm
Group:		Communications/Mobile
Requires:	%{name} = %{version}-%{release}

%description -n	perl-PDA-Pilot
This package provides perl modules for supporting Palm.

%prep
%autosetup -p1 -a 1

%build
autoreconf -vfi
%configure  --with-perl --enable-conduits --enable-libusb --enable-threads --disable-static

# parallel compilation is broken
make

%install
%make_install

# fix manpage install 
%make_install -C doc/man

find %{buildroot} -name '*.la' -delete

find %{buildroot}%{perl_vendorarch} -name "*.so" -exec chmod 755 {} \;

mkdir -p %{buildroot}%{_sysconfdir}/modprobe.d/
cat << EOF > %{buildroot}%{_sysconfdir}/modprobe.d/visor.conf
blacklist visor
EOF

# remove unneeded files
rm -f %{buildroot}%{_libdir}/perl5/*/*/*/PDA/dump.pl

# remove broken prog
rm -f %{buildroot}%{_bindir}/pilot-prc

# Install hal rules file.
mkdir -p %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/
install -p -m644 %{SOURCE2} %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/19-palm-acl-management.fdi

# Install PolicyKit
mkdir -p %{buildroot}%{_datadir}/PolicyKit/policy
install -p -m644 %{SOURCE3} %{buildroot}%{_datadir}/PolicyKit/policy/pilot-device-file.policy

# Install udev rules
mkdir -p %{buildroot}%{_udevrulesdir}
sed -e 's/MODE="0664"$/MODE="0664", ENV{ACL_MANAGE}="1"/g' doc/60-libpisock.rules >  %{buildroot}%{_udevrulesdir}/60-libpisock.rules

# install profile.d files
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/profile.d/
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/profile.d/

%pre common
if [ -e /etc/modprobe.d/visor ]; then
	mv /etc/modprobe.d/visor{,.conf}
fi

%files
%doc COPYING ChangeLog README NEWS
%doc connect-palm-ppp/
%doc doc/README.usb doc/TODO doc/README.libusb

%{_bindir}/pilot-*
%exclude %{_bindir}/pilot-undelete
%{_mandir}/man1/pilot-*
%{_mandir}/man7/*
%{_datadir}/pilot-link

%files common
%config(noreplace) %{_sysconfdir}/profile.d/50pilot.*
%config(noreplace) %{_sysconfdir}/modprobe.d/visor.conf
%{_udevrulesdir}/*.rules
%{_datadir}/hal/fdi/policy/10osvendor/19-palm-acl-management.fdi
%{_datadir}/PolicyKit/policy/pilot-device-file.policy

%files -n %{libname}
%{_libdir}/libpisock.so.%{lib_major}{,.*}

%files -n %{libsync}
%{_libdir}/libpisync.so.%{sync_major}{,.*}

%files -n %{develname}
%{_libdir}/*.so
%{_includedir}/*
%{_datadir}/aclocal/pilot-link.m4
%{_libdir}/pkgconfig/*

%files -n perl-PDA-Pilot
%{_bindir}/pilot-undelete
%{_mandir}/man1/ietf2datebook*
%{_mandir}/man3/PDA::Pilot.*
%{perl_vendorarch}/PDA/*
%{perl_vendorarch}/auto/PDA/*
