%define major      2
%define libname    %mklibname %{name} %{major}
%define libnamedev %mklibname %{name} -d

%bcond_with syswebrtc
%bcond_without python

Name:           pjproject
Version:        2.14.1
Release:        %mkrel 2
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries
License:        GPLv2+
URL:            https://www.pjsip.org/
Source0:        https://github.com/pjsip/pjproject/archive/%{version}/pjproject-%{version}.tar.gz

# Tell the build system not to use most of the third_party directory
Patch101:       0101-Tell-the-build-system-not-to-use-most-of-the-third_p.patch
# Keep the .pc file clean
# see https://bugzilla.redhat.com/show_bug.cgi?id=728302#c66
Patch102:       0102-Keep-the-.pc-file-clean.patch
# Fix ARMv7 endianness
Patch104:       0104-Fix-ARMv7-endianness.patch
# Add aarch64 detection
Patch105:       0105-Add-aarch64-detection.patch
# Don't use SSE2 if it is not available
Patch108:       0108-Don-t-use-SSE2-if-it-is-not-available.patch
# Fix LDFLAGS usage
Patch131:       0131-Fix-LDFLAGS-usage.patch

BuildRequires:  git-core
BuildRequires:  gsm-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(portaudio-2.0)
%if %{with python}
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig
%endif
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)

%description
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA


%package -n     %{libname}
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries
%if ! %{with python}
Obsoletes:      python3-pjsua2 < %{version}-%{release}
%endif

%description -n %{libname}
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA

This package contains the shared library part of ccrtp.


%package -n     %{libnamedev}
Summary:        Development files to use pjproject
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{libnamedev}
Header information for:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library


%package -n     pjsua
Summary:        command line SIP user agent
Group:          System/Libraries

%description -n pjsua
pjsua is an open source command line SIP user agent (softphone)
that is used as the reference implementation for PJSIP, PJNATH, and PJMEDIA.
Despite its simple command line appearance, it does pack many features!


%package -n     python3-pjsua2
Summary:        PJSUA2 Python Module
Group:          Development/Python
Provides:       python-pjsua = %{version}-%{release}
Provides:       python-pjsua2 = %{version}-%{release}

%description -n python3-pjsua2
The PJSUA2 for Python Module is an object oriented Python
wrapper/abstraction/modules for PJSUA API.

%prep
%autosetup -p1 -Sgit_am

# make sure we don't bundle these third-party libraries
# (They're excluded through ./configure, but this is an
# additional safety net)
rm -rf third_party/BaseClasses
rm -rf third_party/bdsound
rm -rf third_party/bin
rm -rf third_party/g7221
rm -rf third_party/gsm
rm -rf third_party/milenage
rm -rf third_party/mp3
rm -rf third_party/portaudio
rm -rf third_party/resample
rm -rf third_party/speex
rm -rf third_party/srtp
rm -rf third_party/ilbc
%if %{with syswebrtc}
rm -rf third_party/webrtc
%endif
rm -rf third_party/build/baseclasses
rm -rf third_party/build/g7221
rm -rf third_party/build/gsm
rm -rf third_party/build/milenage
rm -rf third_party/build/portaudio/src
rm -rf third_party/build/resample
rm -rf third_party/build/samplerate
rm -rf third_party/build/speex
rm -rf third_party/build/srtp
rm -rf third_party/build/ilbc
%if %{with syswebrtc}
rm -rf third_party/build/webrtc
%endif

%build
# Regenerate aconfigure for Patch8
autoconf aconfigure.ac > aconfigure

# We're building without audio or video support, as Asterisk isn't using
# that functionality, and it made it easier to ensure that we don't
# bundle any unnecessary libraries.  Please contact me if your project
# needs this support, and I'll re-enable it
export CFLAGS="-DPJ_HAS_IPV6=1 -DNDEBUG ${ARCHFLAGS} %{optflags}"

%configure \
	--enable-shared        \
	--with-external-gsm    \
	--with-external-pa     \
	--with-external-speex  \
	--with-external-srtp   \
%if %{with syswebrtc}
	--with-external-webrtc \
%endif
	--disable-opencore-amr \
	--disable-resample     \
	--disable-sound        \
	--disable-video        \
	--disable-v4l2         \
	--disable-ilbc-codec   \
	--disable-libyuv       \
	--disable-g7221-codec

%make_build dep
%make_build

%if %{with python}
sed -i 's|LANG = python java|LANG = python|' pjsip-apps/src/swig/Makefile
%__make -C pjsip-apps/src/swig V=1 VERBOSE=1
pushd pjsip-apps/src/swig/python
    %pyproject_wheel
popd
%endif

%install
%make_install

%if %{with python}
pushd pjsip-apps/src/swig/python
    %pyproject_install
popd
%endif

install -p -D -m 0755 pjsip-apps/bin/pjsua-* %{buildroot}%{_bindir}/pjsua

# Remove the static libraries, as they aren't wanted
find %{buildroot} -type f -name "*.a" -delete


%files -n %{libname}
%doc README.md
%license COPYING
%{_libdir}/lib*.so.%{major}{,.*}

%files -n %{libnamedev}
%doc README.md SECURITY.md
%{_libdir}/lib*.so
%{_includedir}/pj++/
%{_includedir}/pj/
%{_includedir}/pjlib-util/
%{_includedir}/pjmedia-audiodev/
%{_includedir}/pjmedia-codec/
%{_includedir}/pjmedia-videodev/
%{_includedir}/pjmedia/
%{_includedir}/pjnath/
%{_includedir}/pjsip-simple/
%{_includedir}/pjsip-ua/
%{_includedir}/pjsip/
%{_includedir}/pjsua-lib/
%{_includedir}/pjsua2/
%{_includedir}/*.h
%{_includedir}/*.hpp
%{_libdir}/pkgconfig/libpjproject.pc

%if %{with python}
%files -n python3-pjsua2
%doc pjsip-apps/src/python/samples
%{python3_sitearch}/_pjsua2*.so
%{python3_sitearch}/pjsua2-%{version}.dist-info/
%{python3_sitearch}/pjsua2.py*
%{python3_sitearch}/__pycache__/pjsua2*.pyc
%endif

%files -n pjsua
%doc README.md
%{_bindir}/pjsua
