# (akien) bear-engine is built in the bear SRPM (same for bear-factory)
# We build against the same version but drop the conflicting files (libs and translations)
# TODO: Work with upstream to make bear-engine a real library and prevent building it
# in each game based upon the engine (so far two, but there's a third one we might package)
%define bear_version 20200220

Name:           plee-the-bear
Version:        0.7.1
Release:        %mkrel 14
Summary:        2D platform game starring Plee the Bear
Group:          Games/Arcade
License:        GPLv3+ and CC-BY-SA 3.0
URL:            https://www.stuff-o-matic.com/plee-the-bear/
# https://github.com/j-jorge/plee-the-bear
Source0:        https://github.com/j-jorge/plee-the-bear/archive/%{version}/plee-the-bear-%{version}.tar.gz
# Should be synced with the bear SRPM
Source1:        bear-%{bear_version}.tar.xz
Source10:	CMakeLists.txt
Patch1:         bear-boost-placeholders.patch
Patch2:		bear-rpath.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  docbook-to-man
BuildRequires:  gettext
BuildRequires:  libclaw-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)

Requires:       %{name}-data >= %{version}
Requires:       bear-engine >= 1:0.7.0-1.%{bear_version}

%description
Plee the Bear is a platform game in which you play an angry bear whose
son has been kidnapped by god. Here is a guy hard to brave! Jump in
this amazing journey to find and rescue your son. Because you want
to rescue him, don't you? Or to slap him? Maybe both…

%files -f %{name}.lang
%doc plee-the-bear/README.md plee-the-bear/LICENSE
%{_gamesbindir}/%{name}
%{_libdir}/bear/libplee_the_bear.so
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/ptb.png
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------

%package        data
Summary:        Data files for Plee the Bear
License:        CC-BY-SA 3.0
BuildArch:      noarch

%description    data
Data files for Plee the Bear, a 2D platform game.

%files          data
%{_gamesdatadir}/%{name}/
%{_datadir}/bear-factory/%{name}/

#----------------------------------------------------------------------

%prep
%setup -q -T -c %{name}-%{version} -a0 -a1
%autopatch -p1

install -pm644 %{SOURCE10} .

mv bear-%{bear_version} bear
mv plee-the-bear-%{version} plee-the-bear

# convenience.hpp was removed in boost 1.85.0
sed -i -e 's,filesystem/convenience.hpp,filesystem.hpp,g' $(grep -rl convenience.hpp)

# Boost.Math requires C++14
sed -i -e 's,c++11,c++14,g' $(grep -rl c++11)

%build
%cmake -GNinja -DBEAR_ENGINE_INSTALL_LIBRARY_DIR=%{_lib}/bear \
       -DBEAR_EDITORS_ENABLED=OFF \
       -DPTB_INSTALL_CUSTOM_LIBRARY_DIR=%{_lib}/bear \
       -DPTB_INSTALL_DATA_DIR=share/games/%{name} \
       -DPTB_INSTALL_EXECUTABLE_DIR=games
%cmake_build

%install
%cmake_install

%find_lang %{name}

# Remove the content already provided in the bear-engine package
rm -rf %{buildroot}%{_datadir}/cmake \
       %{buildroot}%{_datadir}/locale/*/LC_MESSAGES/bear-engine.mo \
       %{buildroot}%{_datadir}/pixmaps \
       %{buildroot}%{_libdir}/bear/libbear*.so \
       %{buildroot}%{_mandir}/man6/running-bear.6*
