# Please keep this package sync with FC
#
%global major 19.1
%global __requires_exclude	devel\\(libPollyPPCG|libPollyISL

%define libname %mklibname polly %{major}
%define devname %mklibname polly -d

%bcond_with cuda
%bcond_with gpgpu

%global toolchain clang
%global polly_version 19.1.3
#global rc_ver 4
%global polly_srcdir polly-%{polly_version}%{?rc_ver:-rc%{rc_ver}}.src

# Opt out of https://fedoraproject.org/wiki/Changes/fno-omit-frame-pointer
# https://bugzilla.redhat.com/show_bug.cgi?id=2158587
%undefine _include_frame_pointers


Name: polly
Version: %{polly_version}%{?rc_ver:~rc%{rc_ver}}
Release: %mkrel 1
Summary: LLVM Framework for High-Level Loop and Data-Locality Optimizations
Group: Development/Other
License: NCSA
URL: https://polly.llvm.org/
Source0: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{polly_version}%{?rc_ver:-rc%{rc_ver}}/%{polly_srcdir}.tar.xz
Source1: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{polly_version}%{?rc_ver:-rc%{rc_ver}}/%{polly_srcdir}.tar.xz.sig
Source2: release-keys.asc

Patch0: 0001-PATCH-polly-Portability-of-subproject-extension.patch

BuildRequires: cmake
BuildRequires: zlib-devel
BuildRequires: llvm-devel = %{version}
BuildRequires: llvm-cmake-utils = %{version}
BuildRequires: llvm-test = %{version}
BuildRequires: clang-devel = %{version}
BuildRequires: ninja-build
BuildRequires: python3-lit
BuildRequires: python3-sphinx
%if %{with cuda}
BuildRequires:	nvidia-cuda-toolkit
%endif

# For origin certification
BuildRequires:	gnupg2

%description
Polly is a high-level loop and data-locality optimizer and optimization
infrastructure for LLVM. It uses an abstract mathematical representation based
on integer polyhedron to analyze and optimize the memory access pattern of a
program.

%package -n %{libname}
Summary: LLVM Framework for High-Level Loop and Data-Locality Optimizations
Group: System/Libraries
Requires: %{name}-plugins%{?_isa} = %{version}-%{release}
Provides: %{name}%{?_isa} = %{version}-%{release}
Provides: %{name} = %{version}-%{release}
Obsoletes: %{name} < 19.1.3

%description -n %{libname}
Polly is a high-level loop and data-locality optimizer and optimization
infrastructure for LLVM. It uses an abstract mathematical representation based
on integer polyhedron to analyze and optimize the memory access pattern of a
program.

%package -n %{_lib}polly-plugins
Summary: Plugins and bindings for %{name}
Provides: %{name}-plugins%{?_isa} = %{version}-%{release}
Provides: %{name}-plugins%{?_isa} = %{version}-%{release}
Conflicts: %{name} < 19.1.3

%description -n %{_lib}polly-plugins
Plugins and bindings for %{name}.

%package -n %{devname}
Summary: Polly header files
Group: Development/Other
Requires: %{name}%{?_isa} = %{version}-%{release}
Provides: polly-devel%{?_isa} = %{version}-%{release}
Provides: polly-devel = %{version}-%{release}

%description -n %{devname}
Polly header files.

%package doc
Summary: Documentation for Polly
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description doc
Documentation for the Polly optimizer.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{polly_srcdir} -p2

%build

%cmake -GNinja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DCMAKE_PREFIX_PATH=%{_libdir}/cmake/llvm/ \
	-DLLVM_COMMON_CMAKE_UTILS=%{_datadir}/llvm/cmake \
\
	-DLLVM_ENABLE_SPHINX:BOOL=ON \
	-DSPHINX_WARNINGS_AS_ERRORS=OFF \
	-DSPHINX_EXECUTABLE=%{_bindir}/sphinx-build-3 \
\
%if %{with gpgpu}
	-DPOLLY_ENABLE_GPGPU_CODEGEN:BOOL=ON \
%endif
%if %{with cuda}
	-DCUDA_NVCC_EXECUTABLE:FILEPATH=%{_bindir}/nvcc
%endif
\
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64
%else
	-DLLVM_LIBDIR_SUFFIX=
%endif

%cmake_build
%cmake_build --target docs-polly-html


%install
%cmake_install

install -d %{buildroot}%{_pkgdocdir}/html
cp -r %{_vpath_builddir}/docs/html/* %{buildroot}%{_pkgdocdir}/html/

%check
# Test execution normally relies on RPATH, so set LD_LIBRARY_PATH instead.
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}
%cmake_build --target check-polly

%files -n %{libname}
%license LICENSE.TXT
%{_libdir}/libPolly.so.%{major}

%files -n %{_lib}polly-plugins
# these are libraries without .so versions, not devel
%{_libdir}/LLVMPolly.so
%if %{with gpgpu}
%ifarch %ix86 x86_64
%{_libdir}/libGPURuntime.so
%endif
%endif
%{_libdir}/libPollyISL.so

%files -n %{devname}
%{_libdir}/libPolly.so
%{_includedir}/polly
%{_libdir}/cmake/polly

%files doc
%doc %{_pkgdocdir}/html
