%bcond_with bootstrap

# build with boost
%bcond_without boost

# always extract lib majors before updating because they will change every time:
# grep -E -r 'SOVERSION[_NUMBER]*\s+"*[0-9]+' BUILD/poppler-*/
%define cppmajor 2
%define glibmajor 8
%define qt5major 1
%define qt6major 3
%define major 148

%define girmajor 0.18

%define libname		%mklibname %{name} %{major}
%define libnameglib	%mklibname %{name}-glib %{glibmajor}
%define libnameqt5	%mklibname %{name}-qt5_ %{qt5major}
%define libnameqt6	%mklibname %{name}-qt6_ %{qt6major}
%define libnamecpp	%mklibname %{name}-cpp %{cppmajor}
%define libnamedev	%mklibname -d %{name}
%define libnameglibdev	%mklibname -d %{name}-glib
%define libnameqt5dev	%mklibname -d %{name}-qt5
%define libnameqt6dev   %mklibname -d %{name}-qt6
%define libnamecppdev   %mklibname -d %{name}-cpp
%define libnamegir	%mklibname %{name}-gir %{girmajor}

Name:		poppler
Summary: 	PDF rendering library
Group:		Publishing
Version:	25.04.0
Release:	%mkrel 1
License:	GPLv2+
URL:		https://poppler.freedesktop.org
Source:		https://poppler.freedesktop.org/%{name}-%{version}.tar.xz
Patch0:		poppler-CVE-2024-4141.patch
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(cairo-ft)
BuildRequires:	pkgconfig(cairo-pdf)
BuildRequires:	pkgconfig(cairo-ps)
BuildRequires:	pkgconfig(cairo-svg)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freetype2)
%if ! %{with bootstrap}
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  gtk-doc
BuildRequires:	python3
%endif
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(nss)
%if ! %{with bootstrap}
# Qt5
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Test)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
# Qt6
BuildRequires:	qtbase6-qtpaths
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
%endif
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(poppler-data)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:	gettext-devel
BuildRequires:	cmake
BuildRequires:	cmake(gpgmepp)
BuildRequires:	ninja
%if %{with boost}
BuildRequires:  boost-devel
%endif
Provides:	xpdf-tools
Provides:	pdftohtml

%description
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libname}
Summary:	PDF rendering library
Group:          System/Libraries
Recommends:	poppler-data

%description -n	%{libname}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libnamedev}
Summary:	Development files for %{name}
Group:		Development/C++
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
%if %{with boost}
# /usr/include/poppler/splash/SplashXPathScanner.h:31:10: fatal error:
# boost/container/small_vector.hpp: No such file or directory
Requires:	boost-devel
%endif

%description -n	%{libnamedev}
Development files for %{name}

%package -n	%{libnamecpp}
Summary:	PDF rendering library - C++ backend
Group:          System/Libraries

%description -n	%{libnamecpp}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the C++ backend version.

%package -n	%{libnameqt5dev}
Summary: 	Development files for %{name}-qt5
Group:		Development/KDE and Qt
Provides:	%{name}-qt5-devel = %{version}-%{release}
Requires:	%{libnameqt5} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnameqt5dev}
Development files for %{name}-qt5.

%package -n	%{libnameqt5}
Summary: 	PDF rendering library - Qt5 backend
Group:		System/Libraries

%description -n	%{libnameqt5}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the Qt5 backend version.

%package -n     %{libnameqt6dev}
Summary:        Development files for %{name}-qt6
Group:          Development/KDE and Qt
Provides:	%{name}-qt6-devel = %{version}-%{release}
Requires:	%{libnameqt6} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n %{libnameqt6dev}
Development files for %{name}-qt6.

%package -n     %{libnameqt6}
Summary:        PDF rendering library - Qt6 backend
Group:          System/Libraries

%description -n %{libnameqt6}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the Qt6 backend version.

%package -n	%{libnameglib}
Summary:	PDF rendering library - glib binding
Group:		System/Libraries

%description -n	%{libnameglib}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libnamegir}
Summary:	Gobject-introspection files for %{name}
Group:		System/Libraries
Requires:	%{libnameglib} = %{version}-%{release}

%description -n	%{libnamegir}
Gobject-introspection files for %{name}.

%package -n	%{libnameglibdev}
Summary:	Development files for %{name}'s glib binding
Group:		Development/C++
Provides:	%{name}-glib-devel = %{version}-%{release}
Requires:	%{libnameglib} = %{version}-%{release}
%if ! %{with bootstrap}
Requires:	%{libnamegir} = %{version}-%{release}
%endif
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnameglibdev}
Development files for %{name}'s glib binding.

%package -n	%{libnamecppdev}
Summary:	Development files for %{name}-cpp
Group:		Development/C++
Provides:	%{name}-cpp-devel = %{version}-%{release}
Requires:	%{libnamecpp} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnamecppdev}
Development files for %{name}-cpp.

%prep
%setup -q
%autopatch -p1

%build
%if ! %{with bootstrap}
export MOCQT5=%{_qt5_bindir}/moc
export MOCQT6=%{_qt6_bindir}/moc
%endif

%cmake -GNinja \
  -DBUILD_GTK_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DBUILD_QT5_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DBUILD_QT6_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_CMS=lcms2 \
  -DENABLE_DCTDECODER=libjpeg \
  -DENABLE_LIBOPENJPEG=openjpeg2 \
  -DENABLE_QT5=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_QT6=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_UNSTABLE_API_ABI_HEADERS=ON \
  -DENABLE_GTK_DOC=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON}

%cmake_build

%install
%cmake_install

cp -a %{_vpath_builddir}/config.h %{buildroot}%{_includedir}/poppler/

%find_lang pdfsig

%files -f pdfsig.lang
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libpoppler.so.%{major}{,.*}

%files -n %{libnamedev}
%{_libdir}/libpoppler.so
%dir %{_includedir}/poppler/
%{_includedir}/poppler/config.h
%{_includedir}/poppler/[A-Z]*
%{_includedir}/poppler/fofi
%{_includedir}/poppler/goo
%{_includedir}/poppler/splash
%{_includedir}/poppler/poppler_private_export.h
%{_includedir}/poppler/poppler-config.h
%{_libdir}/pkgconfig/poppler.pc
%if ! %{with bootstrap}
%doc %{_datadir}/gtk-doc/html/%{name}/
%endif

%files -n %{libnameglib}
%{_libdir}/libpoppler-glib.so.%{glibmajor}{,.*}

%if ! %{with bootstrap}
%files -n %{libnamegir}
%{_libdir}/girepository-1.0/Poppler-%{girmajor}.typelib
%endif

%files -n %{libnameglibdev}
%{_libdir}/libpoppler-glib.so
%{_libdir}/pkgconfig/poppler-glib.pc
%{_includedir}/poppler/glib/
%if ! %{with bootstrap}
%{_datadir}/gir-1.0/Poppler-%{girmajor}.gir
%endif

%if ! %{with bootstrap}
%files -n %{libnameqt5dev}
%{_includedir}/poppler/qt5/
%{_libdir}/pkgconfig/poppler-qt5.pc
%{_libdir}/libpoppler-qt5.so

%files -n %{libnameqt5}
%{_libdir}/libpoppler-qt5.so.%{qt5major}{,.*}

%files -n %{libnameqt6dev}
%{_includedir}/poppler/qt6/
%{_libdir}/pkgconfig/poppler-qt6.pc
%{_libdir}/libpoppler-qt6.so

%files -n %{libnameqt6}
%{_libdir}/libpoppler-qt6.so.%{qt6major}{,.*}
%endif

%files -n %{libnamecpp}
%{_libdir}/libpoppler-cpp.so.%{cppmajor}{,.*}

%files -n %{libnamecppdev}
%{_libdir}/libpoppler-cpp.so
%{_libdir}/pkgconfig/poppler-cpp.pc
%{_includedir}/poppler/cpp
