%define PKGRELEASE %(echo %{version} | cut -d. -f1,2)

Name:		povray
Version:	3.7.0.10
Summary:	The Persistence of Vision Raytracer
Release:	%mkrel 13
Group:		Sciences/Computer science
# Examples below distribution/ are CC-BY-SA
# The sources are AGPLv3+
License:	AGPLv3+
URL:		https://www.povray.org/
Source:		https://github.com/POV-Ray/povray/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	povray.bash-completion
# Fedora patches:
Patch10:	0001-Fix-encoding.patch
Patch11:	0002-Autotool-massaging.patch
Patch12:	0003-Remove-povuser.patch
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(sdl)
BuildRequires:	pkgconfig(xpm)
BuildRequires:	autoconf
BuildRequires:	automake

%description
The Persistence of Vision Ray tracer creates three-dimensional,
photo-realistic images using a rendering technique called ray tracing.
It reads in a text file containing information describing the objects and
lighting in a scene and generates an image of that scene from the view
point of a camera also described in the text file. Ray tracing is not
a fast process by any means, (the generation of a complex image can
take several hours) but it produces very high quality images
with realistic reflections, shading, perspective, and other effects.
POV-Ray is a free, full-featured ray tracer.

%package scenes
Summary:	POV-Ray example scenes
License:	CC-BY-SA
BuildArch:	noarch

%description scenes
POV-Ray example scenes.

%prep
%setup -q
%autopatch -p1

# Make sure not to be using bundled libs
rm -rf libraries

# Workaround to automake incompatibility
rm -f config/missing

%build
pushd unix
sed -i \
 -e 's,automake --warnings=all,automake -a -f,' \
 prebuild.sh

sed -i \
 -e 's,AM_INIT_AUTOMAKE(\[1.9 dist-bzip2\]),AM_INIT_AUTOMAKE([1.9 dist-bzip2 subdir-objects]),' \
 configure.ac

./prebuild.sh
popd

%configure \
  --disable-silent-rules \
  --disable-optimiz \
  --disable-strip \
  --x-includes=%{_includedir} \
  --x-libraries=%{_libdir} \
  --with-boost-libdir=%{_libdir} \
  --with-x \
  COMPILED_BY="%_vendor"

# Filter out bogus and potentially harmful
# -I%%{_includedir} -L%%{_libdir}
# from Makefiles
find -name Makefile -exec sed -i \
  -e 's,-I%{_includedir}$,,g;s,-I%{_includedir} ,,g;' \
  -e 's,-L%{_libdir}$,,g;s,-L%{_libdir} ,,g' {} \;

# Adjust bogus paths
sed -i \
  -e '/DEFAULT_DIR=/d' \
  -e 's,SYSCONFDIR=\$DEFAULT_DIR/etc,SYSCONFDIR=%{_sysconfdir},' \
  unix/scripts/{allanim,allscene,portfolio}.sh

%make_build

%install
%make_install povdocdir=%{_docdir}/%{name}

# Fixup permissions
chmod +x %{buildroot}%{_datadir}/%{name}-%{PKGRELEASE}/scenes/camera/mesh_camera/bake.sh

install -d -m 755 %{buildroot}%{_sysconfdir}/bash_completion.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

%files
%config(noreplace) %{_sysconfdir}/bash_completion.d/%{name}
%doc %{_docdir}/%{name}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*
%{_datadir}/%{name}-%{PKGRELEASE}
%exclude %{_datadir}/%{name}-%{PKGRELEASE}/scenes
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/%{PKGRELEASE}
%config(noreplace) %{_sysconfdir}/%{name}/%{PKGRELEASE}/%{name}*

%files scenes
%dir %{_datadir}/%{name}-%{PKGRELEASE}
%{_datadir}/%{name}-%{PKGRELEASE}/scenes
