%define oname   The-Powder-Toy

# Comment/undefine snapshot to use the stable release.
#define snapshot 377

%define tar_tag  %{!?snapshot:%{version}}%{?snapshot:snapshot-%{snapshot}}

Name:           powdertoy
Version:        99.2.%{!?snapshot:382}%{?snapshot:%snapshot}
Release:        %mkrel 1
Summary:        Falling-sand physics sandbox game
Group:          Games/Simulation
License:        GPLv3+
Url:            https://powdertoy.co.uk/
Source0:        https://github.com/simtr/The-Powder-Toy/archive/%{!?snapshot:v%{version}}%{?snapshot:snapshot-%{snapshot}}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  cmake
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  desktop-file-utils

%description
The Powder Toy is a free physics sandbox game, which simulates
air pressure and velocity, heat, gravity and a countless number
of interactions between different substances! The game provides
you with various building materials, liquids, gases and electronic
components which can be used to construct complex machines, guns,
bombs, realistic terrains and almost anything else.

%prep
%autosetup -p1 -n %{oname}-%{tar_tag}

%build
%meson \
	--bindir=%{_gamesbindir} \
	-Dapp_data=%{name} \
	-Dapp_exe=%{name} \
	-Dapp_comment="Falling-sand physics sandbox game" \
	-Dcan_install=no \
	-Dlua=luajit \
%ifnarch x86_64
	-Dx86_sse=none \
%endif
	%nil
%meson_build

%install
%meson_install

%define app_mime  application-vnd.%{name}.save
# Default app_id: "powdertoy-uk.co.powdertoy.tpt"
%define app_id %{name}-$(grep '<id>' build/resources/appdata.xml | sed 's|.*<id>||;s|<\/id.*||')

# Icons
pushd resources/generated_icons
  install -D -m644 icon_exe_16.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
  install -D -m644 icon_exe_32.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
  install -D -m644 icon_exe_48.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png
  install -D -m644 icon_exe.png    %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}.png
  install -D -m644 ../icon_exe.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

  install -D -m644 icon_cps_16.png %{buildroot}%{_iconsdir}/hicolor/16x16/mimetypes/%{app_mime}.png
  install -D -m644 icon_cps_32.png %{buildroot}%{_iconsdir}/hicolor/32x32/mimetypes/%{app_mime}.png
  install -D -m644 icon_cps_48.png %{buildroot}%{_iconsdir}/hicolor/48x48/mimetypes/%{app_mime}.png
  install -D -m644 icon_cps.png    %{buildroot}%{_iconsdir}/hicolor/256x256/mimetypes/%{app_mime}.png
  install -D -m644 ../icon_cps.svg %{buildroot}%{_iconsdir}/hicolor/scalable/mimetypes/%{app_mime}.svg
popd

# Mimetypes, manpages, metainfo and desktop files
install -D -m644 resources/save.xml %{buildroot}%{_datadir}/mime/application/vnd.%{name}.save.xml
install -D -m644 resources/powder.man %{buildroot}%{_mandir}/man6/%{name}.6
install -D -m644 build/resources/appdata.xml %{buildroot}%{_metainfodir}/%{app_id}.appdata.xml
install -D -m644 build/resources/powder.desktop %{buildroot}%{_datadir}/applications/%{app_id}.desktop
desktop-file-install %{buildroot}%{_datadir}/applications/%{app_id}.desktop \
  --set-icon=%{name} --set-generic-name="Physics sandbox" \
  --set-key=Terminal --set-value=false

%files
%doc README.md
%license LICENSE
%{_gamesbindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/mime/application/vnd.%{name}.save.xml
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/*/mimetypes/%{app_mime}.png
%{_iconsdir}/hicolor/scalable/mimetypes/%{app_mime}.svg
%{_metainfodir}/*.appdata.xml
%{_mandir}/man6/%{name}.6*
