# This emulator doesn't require copyrighted data (e.g. console BIOS)
# to function, it can thus go in core.

Summary:        Sony PlayStation Portable (PSP) emulator
Name:           ppsspp
Version:        1.14.4
Release:        %mkrel 6
License:        GPLv2+
Group:          Emulators
Url:            https://www.ppsspp.org
# git clone https://github.com/hrydgard/ppsspp && cd ppsspp
# git submodule update --init --recursive assets/lang ext/SPIRV-Cross ext/armips ext/discord-rpc ext/glslang ext/zstd ext/miniupnp ext/cpu_features ffmpeg
# Edit .gitmodules to comment out the ones not use, or git archive-all will fail.
# Remove each ffmpeg build (android, Windows10 ...)
# git archive-all --prefix=ppsspp-%%{version}/ ppsspp-%%{version}.tar.xz
Source0:        %{name}-%{version}.tar.xz
# Patch1:         ppsspp-1.10.3-git-version.patch
Patch2:         ppsspp-1.7.2-mga-system-rapidjson.patch
Patch3:         ffmpeg.git-effadce6c756247ea8bae32dc13bb3e6f464f0eb.patch
Patch4:         ppsspp-1.14.4-fix-building-ix86-with-gcc14.patch
Patch5:         ppsspp-1.14.4-fix-building-with-gcc14.patch

BuildRequires:  cmake
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
# Needs libpng 1.7+, not packaged in mga7 for now
#BuildRequires:  pkgconfig(libpng) >= 1.7
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(snappy)
BuildRequires:  pkgconfig(zlib)
# TODO: Try to unbundle glslang now that we package it.

%ifarch %{arm}
BuildRequires:  libatomic-devel
BuildRequires:  pkgconfig(egl)
%endif

Provides:   bundled(ffmpeg)=3.1

%description
PPSSPP is a cross-platform Sony PlayStation Portable (PSP) emulator.

PPSSPP can run your PSP games on your PC in full HD resolution, and play
them on Android too. It can even upscale textures that would otherwise be
too blurry as they were made for the small screen of the original PSP.

%files
%doc LICENSE.TXT README.md
%{_datadir}/applications/%{name}.desktop
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/%{name}.png

#----------------------------------------------------------------------------

%prep
%setup -q
%patch -P 2 -p1
%patch -P 3 -p1
%ifarch %{ix86}
%patch -P 4 -p1
%endif
%patch -P 5 -p1

# Fix version string
sed s,"unknown_version","%{version}-%{release}",g -i git-version.cmake

# Make sure those are not used
rm -rf ext/zlib
rm -rf ext/native/ext/libzip
#rm -rf ext/native/ext/libpng17
# We need to keep the CMakeLists.txt for USE_SYSTEM_SNAPPY and GLEW_FOUND
rm -rf ext/glew/{GL,*.c}
rm -rf ext/snappy/*.{cpp,h}

%build
pushd ffmpeg
export CFLAGS="%{optflags} -fPIC"
export LDFLAGS="%{ldflags}"

./configure  --target-os=linux \
    --arch=${_arch} \
    --prefix=./linux \
    --disable-shared \
    --enable-static \
    --enable-zlib \
    --disable-everything \
   --disable-avdevice \
   --disable-filters \
   --disable-programs \
   --disable-network \
   --disable-avfilter \
   --disable-postproc \
   --disable-encoders \
   --disable-protocols \
   --disable-hwaccels \
   --disable-doc \
    --disable-yasm \
    --disable-ffplay \
    --disable-ffprobe \
    --disable-ffserver \
    --disable-ffmpeg \
   --enable-decoder=h264 \
   --enable-decoder=mpeg4 \
   --enable-decoder=mpeg2video \
   --enable-decoder=mjpeg \
   --enable-decoder=mjpegb \
    --enable-decoder=aac \
    --enable-decoder=aac_latm \
    --enable-decoder=atrac3 \
    --enable-decoder=atrac3p \
    --enable-decoder=mp3 \
    --enable-decoder=pcm_s16le \
    --enable-decoder=pcm_s8 \
    --enable-demuxer=h264 \
    --enable-demuxer=m4v \
    --enable-demuxer=mpegvideo \
    --enable-demuxer=mpegps \
    --enable-demuxer=mp3 \
    --enable-demuxer=avi \
    --enable-demuxer=aac \
    --enable-demuxer=pmp \
    --enable-demuxer=oma \
    --enable-demuxer=pcm_s16le \
    --enable-demuxer=pcm_s8 \
    --enable-demuxer=wav \
	  --enable-encoder=huffyuv \
	  --enable-encoder=ffv1 \
	  --enable-encoder=mjpeg \
	  --enable-encoder=pcm_s16le\
  	  --enable-muxer=avi\
    --enable-parser=h264 \
    --enable-parser=mpeg4video \
    --enable-parser=mpegaudio \
    --enable-parser=mpegvideo \
    --enable-parser=aac \
    --enable-parser=aac_latm
make clean
make install
popd
%cmake \
  -DBUILD_SHARED_LIBS=OFF \
  -DHEADLESS=OFF \
  -DUSE_FFMPEG=ON \
  -DFFMPEG_DIR=ffmpeg/linux \
  -DUSE_SYSTEM_FFMPEG=OFF \
  -DUSE_SYSTEM_LIBZIP=ON \
  -DUSE_SYSTEM_SNAPPY=ON \
%ifarch %{arm}
  -DARMV7:BOOL=ON \
%endif

%cmake_build

%install
# no make install for ppsspp, only for its bundled deps
install -D -m755 %{_vpath_builddir}/PPSSPPSDL %{buildroot}%{_gamesbindir}/%{name}

install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -a build/assets %{buildroot}%{_gamesdatadir}/%{name}

install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Type=Application
Name=PPSSPP
GenericName=PSP Emulator
Comment=PlayStation Portable Simulator Suitable for Playing Portably (PPSSPP)
Exec=ppsspp %f
Icon=ppsspp
Categories=Game;Emulator;
EOF

install -d %{buildroot}%{_iconsdir}
cp -a icons/hicolor %{buildroot}%{_iconsdir}
