%define pyname  PySide6

%define qttarballdir pyside-setup-everywhere-src

%ifarch x86_64 aarch64
%bcond_without webengine
%else
%bcond_with webengine
%endif

Name:           pyside6
Version:        6.8.3
Release:        %mkrel 1
License:        LGPLv2+
Summary:        The PySide6 project provides LGPL-licensed Python bindings for the Qt6
Group:          Development/KDE and Qt
URL:            https://wiki.qt.io/Qt_for_Python
Source0:        https://download.qt.io/official_releases/QtForPython/pyside6/PySide6-%{version}-src/%{qttarballdir}-%{version}.tar.xz
# Upstream patches
## https://bugreports.qt.io/browse/PYSIDE-2491
Patch0:         147389_fix-build.patch
#

BuildRequires:  cmake
BuildRequires:  cmake(Qt63DCore)
BuildRequires:  cmake(Qt6Bluetooth)
BuildRequires:  cmake(Qt6Charts)
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DataVisualization)
BuildRequires:  cmake(Qt6Designer)
BuildRequires:  cmake(Qt6ExampleIconsPrivate)
BuildRequires:  cmake(Qt6Graphs)
BuildRequires:  cmake(Qt6GraphsWidgets)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6HttpServer)
BuildRequires:  cmake(Qt6Location)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6MultimediaWidgets)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6NetworkAuth)
BuildRequires:  cmake(Qt6Nfc)
BuildRequires:  cmake(Qt6OpenGL)
%if %{with webengine}
BuildRequires:  cmake(Qt6Pdf)
BuildRequires:  cmake(Qt6PdfWidgets)
%endif
BuildRequires:  cmake(Qt6Positioning)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Qml)
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6QuickTest)
BuildRequires:  cmake(Qt6Quick3D)
BuildRequires:  cmake(Qt6QuickControls2)
BuildRequires:  cmake(Qt6QuickWidgets)
BuildRequires:  cmake(Qt6RemoteObjects)
BuildRequires:  cmake(Qt6Scxml)
BuildRequires:  cmake(Qt6Sensors)
BuildRequires:  cmake(Qt6SerialBus)
BuildRequires:  cmake(Qt6SerialPort)
BuildRequires:  cmake(Qt6SpatialAudio)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6StateMachine)
BuildRequires:  cmake(Qt6SvgWidgets)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6TextToSpeech)
BuildRequires:  cmake(Qt6UiTools)
BuildRequires:  cmake(Qt6WebChannel)
%if %{with webengine}
BuildRequires:  cmake(Qt6WebEngineCore)
BuildRequires:  cmake(Qt6WebEngineWidgets)
%endif
BuildRequires:  cmake(Qt6WebSockets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(shiboken6) >= %{version}
BuildRequires:  cmake(clang)
BuildRequires:  pyproject-rpm-macros
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(sphinx)
BuildRequires:  doxygen

%description
The PySide6 project provides LGPL-licensed Python3 bindings for the Qt6
cross-platform application and UI framework. PySide6 Qt6 bindings allow both free
open source and proprietary software development and ultimately aim to support
all of the platforms as Qt6 itself.

#------------------------------------------------------------------------------

%define py3major   6.8
%define py3libname %mklibname %{name}-abi3_ %{py3major}

%package -n     %{py3libname}
Summary:        PySide6 core library
Group:          System/Libraries

%description -n %{py3libname}
Python3 PySide6 core library.

%files -n %{py3libname}
%{_libdir}/lib%{name}.abi3*.so.%{py3major}{,.*}
%{_libdir}/lib%{name}qml.abi3*.so.%{py3major}{,.*}

#------------------------------------------------------------------------------

%define py3libname_dev %mklibname %{name} -d

%package -n     %{py3libname_dev}
Summary:        Development files for Python3 PySide6
Group:          Development/KDE and Qt
Requires:       %{py3libname} = %{version}-%{release}
Requires:       python3-%{name} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{_lib}%{name}-python%{python3_version}-devel

%description -n %{py3libname_dev}
Development files for Python3 PySide6.

%files -n %{py3libname_dev}
%{_includedir}/%{pyname}/
%{_libdir}/lib%{name}.abi3*.so
%{_libdir}/libpyside6qml.*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{pyname}/
%{_libdir}/cmake/%{pyname}Qml/
%dir %{_datadir}/%{pyname}
%{_datadir}/%{pyname}/doc/
%{_datadir}/%{pyname}/glue/
%{_datadir}/%{pyname}/typesystems/

#------------------------------------------------------------------------------

%package -n     python3-%{name}
Summary:        The PySide6 project provides LGPL-licensed Python3 bindings for the Qt6
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core
Requires:       python3-%{name}-3dcore
Requires:       python3-%{name}-3danimation
Requires:       python3-%{name}-3dextras
Requires:       python3-%{name}-3dinput
Requires:       python3-%{name}-3dlogic
Requires:       python3-%{name}-3drender
Recommends:     python3-%{name}-bluetooth
Requires:       python3-%{name}-charts
Requires:       python3-%{name}-concurrent
Requires:       python3-%{name}-datavisualization
Recommends:     python3-%{name}-dbus
Recommends:     python3-%{name}-designer
Recommends:     python3-%{name}-exampleicons
Recommends:     python3-%{name}-graphs
Recommends:     python3-%{name}-graphswidgets
Requires:       python3-%{name}-gui
Requires:       python3-%{name}-help
Recommends:     python3-%{name}-httpserver
Recommends:     python3-%{name}-location
Requires:       python3-%{name}-multimedia
Requires:       python3-%{name}-multimediawidgets
Requires:       python3-%{name}-network
Recommends:     python3-%{name}-networkauth
Recommends:     python3-%{name}-nfc
Requires:       python3-%{name}-opengl
Recommends:     python3-%{name}-openglwidgets
%if %{with webengine}
Recommends:     python3-%{name}-pdf
Recommends:     python3-%{name}-pdfwidgets
%endif
Requires:       python3-%{name}-positioning
Requires:       python3-%{name}-printsupport
Requires:       python3-%{name}-qml
Requires:       python3-%{name}-quick
Recommends:     python3-%{name}-quick3d
Requires:       python3-%{name}-quickcontrols2
Recommends:     python3-%{name}-quicktest
Requires:       python3-%{name}-quickwidgets
Requires:       python3-%{name}-remoteobjects
Requires:       python3-%{name}-scxml
Requires:       python3-%{name}-sensors
Requires:       python3-%{name}-serialbus
Requires:       python3-%{name}-serialport
Recommends:     python3-%{name}-spatialaudio
Recommends:     python3-%{name}-statemachine
Requires:       python3-%{name}-sql
Requires:       python3-%{name}-svg
Recommends:     python3-%{name}-svgwidgets
Requires:       python3-%{name}-test
Recommends:     python3-%{name}-texttospeech
Requires:       python3-%{name}-uitools
Requires:       python3-%{name}-webchannel
%if %{with webengine}
Requires:       python3-%{name}-webenginecore
Requires:       python3-%{name}-webenginewidgets
Recommends:     python3-%{name}-webenginequick
%endif
Requires:       python3-%{name}-websockets
Requires:       python3-%{name}-widgets
Requires:       python3-%{name}-xml

%description -n python3-%{name}
The PySide6 project provides LGPL-licensed Python3 bindings for the Qt6
cross-platform application and UI framework. PySide6 Qt6 bindings allow both free
open source and proprietary software development and ultimately aim to support
all of the platforms as Qt6 itself.

This is the Python3 version.

%files -n       python3-%{name}
%doc README.md README.pyside6.md
%license sources/pyside6/COPYING
%{python3_sitearch}/%{pyname}-%{version}-py%{python3_version}.egg-info/

#------------------------------------------------------------------------------

%package -n     python3-%{name}-core
Summary:        PySide6 core module
Group:          Development/KDE and Qt
Requires:       python3-shiboken6 >= %{version}

%description -n python3-%{name}-core
Python3 PySide6 core module.

%files -n       python3-%{name}-core
%dir %{python3_sitearch}/PySide6
%{python3_sitearch}/PySide6/QtCore.abi3*.so
%{python3_sitearch}/PySide6/QtCore.pyi
%{python3_sitearch}/PySide6/__init__.py*
%{python3_sitearch}/PySide6/_config.py*
%{python3_sitearch}/PySide6/_git_pyside_version.py*
%{python3_sitearch}/PySide6/__pycache__/
%{python3_sitearch}/PySide6/__feature__.py*
%{python3_sitearch}/PySide6/support/
%{python3_sitearch}/PySide6/QtAsyncio/

#------------------------------------------------------------------------------

%package -n     python3-%{name}-3dcore
Summary:        PySide6 3D core module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-3dcore
Python3 PySide6 3D core module.

%files -n       python3-%{name}-3dcore
%{python3_sitearch}/PySide6/Qt3DCore.abi3*.so
%{python3_sitearch}/PySide6/Qt3DCore.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-3danimation
Summary:        PySide6 3D animation module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-3danimation
Python3 PySide6 3D animation module.

%files -n       python3-%{name}-3danimation
%{python3_sitearch}/PySide6/Qt3DAnimation.abi3*.so
%{python3_sitearch}/PySide6/Qt3DAnimation.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-3dextras
Summary:        PySide6 3D extras module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-3dextras
Python3 PySide6 3D extras module.

%files -n       python3-%{name}-3dextras
%{python3_sitearch}/PySide6/Qt3DExtras.abi3*.so
%{python3_sitearch}/PySide6/Qt3DExtras.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-3dinput
Summary:        PySide6 3D input module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-3dinput
Python3 PySide6 3D input module.

%files -n       python3-%{name}-3dinput
%{python3_sitearch}/PySide6/Qt3DInput.abi3*.so
%{python3_sitearch}/PySide6/Qt3DInput.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-3dlogic
Summary:        PySide6 3D logic module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-3dlogic
Python3 PySide6 3D logic module.

%files -n       python3-%{name}-3dlogic
%{python3_sitearch}/PySide6/Qt3DLogic.abi3*.so
%{python3_sitearch}/PySide6/Qt3DLogic.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-3drender
Summary:        PySide6 3D render module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-3drender
Python3 PySide6 3D render module.

%files -n       python3-%{name}-3drender
%{python3_sitearch}/PySide6/Qt3DRender.abi3*.so
%{python3_sitearch}/PySide6/Qt3DRender.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-bluetooth
Summary:        PySide6 bluetooth module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-bluetooth
Python3 PySide6 bluetooth module.

%files -n       python3-%{name}-bluetooth
%{python3_sitearch}/PySide6/QtBluetooth.abi3*.so
%{python3_sitearch}/PySide6/QtBluetooth.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-charts
Summary:        PySide6 charts module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-charts
Python3 PySide6 charts module.

%files -n       python3-%{name}-charts
%{python3_sitearch}/PySide6/QtCharts.abi3*.so
%{python3_sitearch}/PySide6/QtCharts.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-concurrent
Summary:        PySide6 concurrent module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-concurrent
Python3 PySide6 concurrent module.

%files -n       python3-%{name}-concurrent
%{python3_sitearch}/PySide6/QtConcurrent.abi3*.so
%{python3_sitearch}/PySide6/QtConcurrent.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-datavisualization
Summary:        PySide6 Data Visualization module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-datavisualization
Python3 PySide6 Data Visualization module.

%files -n       python3-%{name}-datavisualization
%{python3_sitearch}/PySide6/QtDataVisualization.abi3*.so
%{python3_sitearch}/PySide6/QtDataVisualization.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-dbus
Summary:        PySide6 DBus module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-dbus
Python3 PySide6 dbus module.

%files -n       python3-%{name}-dbus
%{python3_sitearch}/PySide6/QtDBus.abi3*.so
%{python3_sitearch}/PySide6/QtDBus.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-designer
Summary:        PySide6 designer module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-designer
Python3 PySide6 designer module.

%files -n       python3-%{name}-designer
%{python3_sitearch}/PySide6/QtDesigner.abi3*.so
%{python3_sitearch}/PySide6/QtDesigner.pyi
%{_qt6_plugindir}/designer/libPySidePlugin.so

#------------------------------------------------------------------------------

%package -n     python3-%{name}-exampleicons
Summary:        PySide6 example icons module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-exampleicons
Python3 PySide6 example icons module.

%files -n       python3-%{name}-exampleicons
%{python3_sitearch}/PySide6/QtExampleIcons.abi3*.so

#------------------------------------------------------------------------------

%package -n     python3-%{name}-graphs
Summary:        PySide6 graphs module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-graphs
Python3 PySide6 graphs module.

%files -n       python3-%{name}-graphs
%{python3_sitearch}/PySide6/QtGraphs.abi3*.so
%{python3_sitearch}/PySide6/QtGraphs.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-graphswidgets
Summary:        PySide6 graphs widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-graphswidgets
Python3 PySide6 graphs widgets module.

%files -n       python3-%{name}-graphswidgets
%{python3_sitearch}/PySide6/QtGraphsWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtGraphsWidgets.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-gui
Summary:        PySide6 gui module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-gui
Python3 PySide6 gui module.

%files -n       python3-%{name}-gui
%{python3_sitearch}/PySide6/QtGui.abi3*.so
%{python3_sitearch}/PySide6/QtGui.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-help
Summary:        PySide6 help module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-help
Python3 PySide6 help module.

%files -n       python3-%{name}-help
%{python3_sitearch}/PySide6/QtHelp.abi3*.so
%{python3_sitearch}/PySide6/QtHelp.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-httpserver
Summary:        PySide6 httpserver module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-httpserver
Python3 PySide6 httpserver module.

%files -n       python3-%{name}-httpserver
%{python3_sitearch}/PySide6/QtHttpServer.abi3*.so
%{python3_sitearch}/PySide6/QtHttpServer.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-location
Summary:        PySide6 location module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-location
Python3 PySide6 location module.

%files -n       python3-%{name}-location
%{python3_sitearch}/PySide6/QtLocation.abi3*.so
%{python3_sitearch}/PySide6/QtLocation.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-multimedia
Summary:        PySide6 multimedia module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-multimedia
Python3 PySide6 multimedia module.

%files -n       python3-%{name}-multimedia
%{python3_sitearch}/PySide6/QtMultimedia.abi3*.so
%{python3_sitearch}/PySide6/QtMultimedia.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-multimediawidgets
Summary:        PySide6 multimedia widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-multimediawidgets
Python3 PySide6 multimedia widgets module.

%files -n       python3-%{name}-multimediawidgets
%{python3_sitearch}/PySide6/QtMultimediaWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtMultimediaWidgets.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-network
Summary:        PySide6 network module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-network
Python3 PySide6 network module.

%files -n       python3-%{name}-network
%{python3_sitearch}/PySide6/QtNetwork.abi3*.so
%{python3_sitearch}/PySide6/QtNetwork.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-networkauth
Summary:        PySide6 networkauth module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-networkauth
Python3 PySide6 networkauth module.

%files -n       python3-%{name}-networkauth
%{python3_sitearch}/PySide6/QtNetworkAuth.abi3*.so
%{python3_sitearch}/PySide6/QtNetworkAuth.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-nfc
Summary:        PySide6 nfc module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-nfc
Python3 PySide6 nfc module.

%files -n       python3-%{name}-nfc
%{python3_sitearch}/PySide6/QtNfc.abi3*.so
%{python3_sitearch}/PySide6/QtNfc.pyi

#------------------------------------------------------------------------------

%if %{with webengine}
%package -n     python3-%{name}-pdf
Summary:        PySide6 pdf module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-pdf
Python3 PySide6 pdf module.

%files -n       python3-%{name}-pdf
%{python3_sitearch}/PySide6/QtPdf.abi3*.so
%{python3_sitearch}/PySide6/QtPdf.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-pdfwidgets
Summary:        PySide6 pdf widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-pdfwidgets
Python3 PySide6 pdf widgets module.

%files -n       python3-%{name}-pdfwidgets
%{python3_sitearch}/PySide6/QtPdfWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtPdfWidgets.pyi
%endif

#------------------------------------------------------------------------------

%package -n     python3-%{name}-opengl
Summary:        PySide6 opengl module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-opengl
Python3 PySide6 opengl module.

%files -n       python3-%{name}-opengl
%{python3_sitearch}/PySide6/QtOpenGL.abi3*.so
%{python3_sitearch}/PySide6/QtOpenGL.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-openglwidgets
Summary:        PySide6 opengl widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-openglwidgets
Python3 PySide6 opengl widgets module.

%files -n       python3-%{name}-openglwidgets
%{python3_sitearch}/PySide6/QtOpenGLWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtOpenGLWidgets.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-positioning
Summary:        PySide6 positioning module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}
Requires:       qtpositioning6

%description -n python3-%{name}-positioning
Python3 PySide6 positioning module.

%files -n       python3-%{name}-positioning
%{python3_sitearch}/PySide6/QtPositioning.abi3*.so
%{python3_sitearch}/PySide6/QtPositioning.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-printsupport
Summary:        PySide6 printsupport module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-printsupport
Python3 PySide6 printsupport module.

%files -n       python3-%{name}-printsupport
%{python3_sitearch}/PySide6/QtPrintSupport.abi3*.so
%{python3_sitearch}/PySide6/QtPrintSupport.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-qml
Summary:        PySide6 qml module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-qml
Python3 PySide6 qml module.

%files -n       python3-%{name}-qml
%{python3_sitearch}/PySide6/QtQml.abi3*.so
%{python3_sitearch}/PySide6/QtQml.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-quick
Summary:        PySide6 quick module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-quick
Python3 PySide6 quick module.

%files -n       python3-%{name}-quick
%{python3_sitearch}/PySide6/QtQuick.abi3*.so
%{python3_sitearch}/PySide6/QtQuick.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-quick3d
Summary:        PySide6 quick3D module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-quick3d
Python3 PySide6 quick3D module.

%files -n       python3-%{name}-quick3d
%{python3_sitearch}/PySide6/QtQuick3D.abi3*.so
%{python3_sitearch}/PySide6/QtQuick3D.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-quickcontrols2
Summary:        PySide6 quick controls2  module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-quickcontrols2
Python3 PySide6 quick controls2 module.

%files -n       python3-%{name}-quickcontrols2
%{python3_sitearch}/PySide6/QtQuickControls2.abi3*.so
%{python3_sitearch}/PySide6/QtQuickControls2.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-quicktest
Summary:        PySide6 quick test module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-quicktest
Python3 PySide6 quick test module.

%files -n       python3-%{name}-quicktest
%{python3_sitearch}/PySide6/QtQuickTest.abi3*.so
%{python3_sitearch}/PySide6/QtQuickTest.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-quickwidgets
Summary:        PySide6 quick widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-quickwidgets
Python3 PySide6 quick widgets module.

%files -n       python3-%{name}-quickwidgets
%{python3_sitearch}/PySide6/QtQuickWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtQuickWidgets.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-remoteobjects
Summary:        PySide6 remote objects module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-remoteobjects
Python3 PySide6 remote objects module.

%files -n       python3-%{name}-remoteobjects
%{python3_sitearch}/PySide6/QtRemoteObjects.abi3*.so
%{python3_sitearch}/PySide6/QtRemoteObjects.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-spatialaudio
Summary:        PySide6 spatialaudio module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-spatialaudio
Python3 PySide6 spatial audio module.

%files -n       python3-%{name}-spatialaudio
%{python3_sitearch}/PySide6/QtSpatialAudio.abi3*.so
%{python3_sitearch}/PySide6/QtSpatialAudio.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-statemachine
Summary:        PySide6 state machine module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-statemachine
Python3 PySide6 state machine module.

%files -n       python3-%{name}-statemachine
%{python3_sitearch}/PySide6/QtStateMachine.abi3*.so
%{python3_sitearch}/PySide6/QtStateMachine.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-scxml
Summary:        PySide6 scxml module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}
Requires:       qtscxml6

%description -n python3-%{name}-scxml
Python3 PySide6 scxml module.

%files -n       python3-%{name}-scxml
%{python3_sitearch}/PySide6/QtScxml.abi3*.so
%{python3_sitearch}/PySide6/QtScxml.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-sensors
Summary:        PySide6 sensors module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-sensors
Python3 PySide6 sensors module.

%files -n       python3-%{name}-sensors
%{python3_sitearch}/PySide6/QtSensors.abi3*.so
%{python3_sitearch}/PySide6/QtSensors.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-serialbus
Summary:        PySide6 serial bus module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-serialbus
Python3 PySide6 serial bus module.

%files -n       python3-%{name}-serialbus
%{python3_sitearch}/PySide6/QtSerialBus.abi3*.so
%{python3_sitearch}/PySide6/QtSerialBus.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-serialport
Summary:        PySide6 serial port module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-serialport
Python3 PySide6 serial port module.

%files -n       python3-%{name}-serialport
%{python3_sitearch}/PySide6/QtSerialPort.abi3*.so
%{python3_sitearch}/PySide6/QtSerialPort.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-sql
Summary:        PySide6 sql module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-sql
Python3 PySide6 sql module.

%files -n       python3-%{name}-sql
%{python3_sitearch}/PySide6/QtSql.abi3*.so
%{python3_sitearch}/PySide6/QtSql.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-svg
Summary:        PySide6 svg module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-svg
Python3 PySide6 svg module.

%files -n       python3-%{name}-svg
%{python3_sitearch}/PySide6/QtSvg.abi3*.so
%{python3_sitearch}/PySide6/QtSvg.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-svgwidgets
Summary:        PySide6 svg widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-svgwidgets
Python3 PySide6 svg widgets module.

%files -n       python3-%{name}-svgwidgets
%{python3_sitearch}/PySide6/QtSvgWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtSvgWidgets.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-test
Summary:        PySide6 test module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-test
Python3 PySide6 test module.

%files -n       python3-%{name}-test
%{python3_sitearch}/PySide6/QtTest.abi3*.so
%{python3_sitearch}/PySide6/QtTest.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-texttospeech
Summary:        PySide6 text to speech module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-texttospeech
Python3 PySide6 text to speech module.

%files -n       python3-%{name}-texttospeech
%{python3_sitearch}/PySide6/QtTextToSpeech.abi3*.so
%{python3_sitearch}/PySide6/QtTextToSpeech.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-uitools
Summary:        PySide6 ui tools module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-uitools
Python3 PySide6 ui tools module.

%files -n       python3-%{name}-uitools
%{python3_sitearch}/PySide6/QtUiTools.abi3*.so
%{python3_sitearch}/PySide6/QtUiTools.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-webchannel
Summary:        PySide6 web channel module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-webchannel
Python3 PySide6 web channel module.

%files -n       python3-%{name}-webchannel
%{python3_sitearch}/PySide6/QtWebChannel.abi3*.so
%{python3_sitearch}/PySide6/QtWebChannel.pyi

#------------------------------------------------------------------------------

%if %{with webengine}
%package -n     python3-%{name}-webenginecore
Summary:        PySide6 web engine core module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-webenginecore
Python3 PySide6 web engine core module.

%files -n       python3-%{name}-webenginecore
%{python3_sitearch}/PySide6/QtWebEngineCore.abi3*.so
%{python3_sitearch}/PySide6/QtWebEngineCore.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-webenginewidgets
Summary:        PySide6 web engine widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-webenginewidgets
Python3 PySide6 web engine widgets module.

%files -n       python3-%{name}-webenginewidgets
%{python3_sitearch}/PySide6/QtWebEngineWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtWebEngineWidgets.pyi
#------------------------------------------------------------------------------

%package -n     python3-%{name}-webenginequick
Summary:        PySide6 web engine quick module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-webenginequick
Python3 PySide6 web engine quick module.

%files -n       python3-%{name}-webenginequick
%{python3_sitearch}/PySide6/QtWebEngineQuick.abi3*.so
%{python3_sitearch}/PySide6/QtWebEngineQuick.pyi
%endif

#------------------------------------------------------------------------------

%package -n     python3-%{name}-websockets
Summary:        PySide6 web sockets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-websockets
Python3 PySide6 web sockets module.

%files -n       python3-%{name}-websockets
%{python3_sitearch}/PySide6/QtWebSockets.abi3*.so
%{python3_sitearch}/PySide6/QtWebSockets.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-widgets
Summary:        PySide6 widgets module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-widgets
Python3 PySide6 widgets module.

%files -n       python3-%{name}-widgets
%{python3_sitearch}/PySide6/QtWidgets.abi3*.so
%{python3_sitearch}/PySide6/QtWidgets.pyi

#------------------------------------------------------------------------------

%package -n     python3-%{name}-xml
Summary:        PySide6 xml module
Group:          Development/KDE and Qt
Requires:       python3-%{name}-core = %{version}

%description -n python3-%{name}-xml
Python3 PySide6 xml module.

%files -n       python3-%{name}-xml
%{python3_sitearch}/PySide6/QtXml.abi3*.so
%{python3_sitearch}/PySide6/QtXml.pyi

### End of Python 3

#------------------------------------------------------------------------------

%prep
# (akien) Sigh... Maintenance update, they didn't bother changing the dir name.
%autosetup -p1 -n %{qttarballdir}-%{version}

%build
%global _vpath_srcdir sources/pyside6
%cmake \
        -DBUILD_TESTS:BOOL=OFF \
        -DCMAKE_SKIP_RPATH:BOOL=ON \
        -DSHIBOKEN_PYTHON_LIBRARIES=`pkgconf python3-embed --libs` \
        -DPYTHON_EXECUTABLE:STRING=%{python3}
%cmake_build

%install
%cmake_install

# and hack re-installation, since cmake seems doing it wrong (mga#25214)
cp -a %{_vpath_builddir}/PySide6/*.pyi %{buildroot}%{python3_sitearch}/PySide6/

#
# Generate egg-info manually and install since we're performing a cmake build.
#
# Copy CMake configuration files from the BINARY dir back to the SOURCE dir so
# setuptools can find them.
cp %{_vpath_builddir}/PySide6/*.py sources/pyside6/PySide6/
%{python3} setup.py egg_info
mkdir -p %{buildroot}%{python3_sitearch}/PySide6-%{version}-py%{python3_version}.egg-info
cp -p PySide6.egg-info/{PKG-INFO,top_level.txt} \
  %{buildroot}%{python3_sitearch}/PySide6-%{version}-py%{python3_version}.egg-info/
