%global pypi_name astropy

Name:           python-astropy
Version:        7.0.0
Release:        %mkrel 2
Group:          Sciences/Astronomy
Summary:        Community-developed python astronomy tools

License:        BSD
URL:            https://www.astropy.org/
Source0:        https://pypi.org/project/astropy/%{pypi_source}
Patch0:         python-astropy-system-configobj.patch
Patch1:         astropy-6.1.0-system-ply.patch
Patch2:         astropy-6.1.0-linking.patch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  expat-devel
BuildRequires:  wcslib-devel >= 8.2.2

#(eatdirt) manual to workaround too strict versionning
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(extension-helpers)
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(setuptools-scm)

%description
Astropy is a package intended to contain core functionality and some
common tools needed for performing astronomy and astrophysics research
with Python. It also provides an index for other astronomy packages
and tools for managing them.

%package -n python3-%{pypi_name}
Summary:        Community-developed python astronomy tools
Requires:       python3dist(numpy)
Requires:       python3dist(configobj)
Requires:       python3dist(ply)
%{?python_provide:%python_provide python3-%{pypi_name}}
Provides:       bundled(jquery) = 3.11

%description -n python3-%{pypi_name}
Astropy is a package intended to contain core functionality and some
common tools needed for performing astronomy and astrophysics research
with Python. It also provides an index for other astronomy packages
and tools for managing them.

%package -n %{pypi_name}-tools
Summary:        Astropy utility tools
BuildArch:      noarch
Requires:       python3dist(astropy) >= 6

%description -n %{pypi_name}-tools
Utilities provided by Astropy: 'volint' for validating a Virtual Observatory
files, 'wcslint' for validating the WCS keywords in a FITS file.

%prep
%autosetup -n %{pypi_name}-%{version} -p1

# Force Cython re-run
echo "cython_version = 'unknown'" > astropy/cython_version.py

# Remove bundled pkgs
rm -rf astropy/extern/configobj
rm -rf astropy/extern/ply
rm -rf cextern/expat
rm -rf cextern/wcslib

%generate_buildrequires
export ASTROPY_USE_SYSTEM_ALL=1
#(eatdirt) temporarilly disabled
#pyproject_buildrequires

%build
# Use cairo backend due to https://bugzilla.redhat.com/show_bug.cgi?id=1394975
export ASTROPY_USE_SYSTEM_ALL=1
#export MPLBACKEND=cairo
#(eatdirt) let's try with no-X backend (as Debian does)
export MPLBACKEND=agg
#(eatdirt) workaround the usual astropy crap...
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

%files -n %{pypi_name}-tools
%{_bindir}/volint
%{_bindir}/fitscheck
%{_bindir}/fitsdiff
%{_bindir}/fitsheader
%{_bindir}/samp_hub
%{_bindir}/wcslint
%{_bindir}/fits2bitmap
%{_bindir}/fitsinfo
%{_bindir}/showtable

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst
