%define pypi_name autobahn

%bcond_with xbr
%bcond_without nvx

Name:           python-%{pypi_name}
Version:        24.4.2
Release:        %mkrel 3
Summary:        Python networking library for WebSocket and WAMP
License:        MIT
Group:          Development/Python
URL:            https://pypi.org/project/autobahn/
Source0:        %{pypi_source}
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(cffi)
BuildRequires:  python3dist(cryptography)
BuildRequires:  python3dist(pynacl)
BuildRequires:  python3dist(twisted)
# tests
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(txaio)
BuildRequires:  python3dist(pytest-asyncio)
BuildRequires:  python3dist(argon2-cffi)
BuildRequires:  python3dist(cbor2)
BuildRequires:  python3dist(passlib)

%description
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and asyncio and for writing servers and clients.

%package -n     python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}
Obsoletes:      python-autobahn-doc < 22.12.1
Obsoletes:      python3-autobahn+dev < 24.4.2-2

%description -n python3-%{pypi_name}
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and asyncio and for writing servers and clients.

%pyproject_extras_subpkg -n python3-%{pypi_name} asyncio twisted accelerate compress serialization encryption scram %{?with_nvx:nvx} ui %{?with_xbr:xbr} all

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%if ! %{with xbr}
sed -i -e 's/extras_require_xbr\s\++//' setup.py
%endif
%if ! %{with nvx}
sed -i -e 's/extras_require_nvx\s\++//' setup.py
%endif

%generate_buildrequires
%pyproject_buildrequires

%build
%if ! %{with xbr}
export AUTOBAHN_STRIP_XBR=1
%endif
%if ! %{with nvx}
export AUTOBAHN_USE_NVX=0
%endif
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name} twisted %{?with_nvx:_nvx*}

%check
# Ignore tests that rely on optional and not packaged deps.
#USE_ASYNCIO=1 %%pytest --pyargs autobahn -k 'not test_no_memory_arg and not test_basic and not test_websocket_custom_loop and not TestSerializer'

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%{_bindir}/wamp
%if %{with xbr}
%{_bindir}/xbrnetwork
%{_bindir}/xbrnetwork-ui
%endif
