%global pypi_name cryptography

%bcond_without check

Name:           python-%{pypi_name}
Version:        44.0.1
Release:        %mkrel 2
Summary:        PyCA's cryptography library
Group:          Development/Python
License:        ASL 2.0 or BSD
URL:            https://cryptography.io/en/latest/
Source0:        https://github.com/pyca/cryptography/archive/%{version}/%{pypi_name}-%{version}.tar.gz
Patch1:         0001-build-remove-cargo.toml-files-from-wheels-12091.patch
BuildRequires:  openssl-devel
BuildRequires:  gcc
BuildRequires:  gnupg2
BuildRequires:  git-core
BuildRequires:  rust-packaging
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  %{name}-vectors >= %{version}

%description
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.

%package -n  python3-%{pypi_name}
Group:          Development/Python
Summary:        PyCA's cryptography library
%{?python_provide:%python_provide python3-%{pypi_name}}


%description -n python3-%{pypi_name}
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.

%prep
%autosetup -p1 -n %{pypi_name}-%{version} -Sgit_am
%cargo_prep

sed -i 's/locked = true//g' pyproject.toml

# Fix BRs
sed -i -e "s/\(['\"]\w\+\s*\)!=\([0-9]\+\(\.[0-9]\+\)\+\)\(,!=[0-9]\+\(\.[0-9]\)\+\)*/\1>\2/" pyproject.toml

%generate_buildrequires
%pyproject_buildrequires -x test
cd src/rust
%cargo_generate_buildrequires
cd ../..

%build
%pyproject_wheel

%install
# Actually other *.c and *.h are appropriate
# see https://github.com/pyca/cryptography/issues/1463
find . -name .keep -print -delete
%pyproject_install
%pyproject_save_files %{pypi_name}

%check
%if %{with check}
# see https://github.com/pyca/cryptography/issues/4885 and
# see https://bugzilla.redhat.com/show_bug.cgi?id=1761194 for deselected tests
# see rhbz#2042413 for memleak. It's unstable under Python 3.11 and makes
# not much sense for downstream testing.
# see rhbz#2171661 for test_load_invalid_ec_key_from_pem: error:030000CD:digital envelope routines::keymgmt export failure
PYTHONPATH=${PWD}/vectors:%{buildroot}%{python3_sitearch} \
    %{__python3} -m pytest \
    --ignore vendor \
    -k "not (test_buffer_protocol_alternate_modes or test_dh_parameters_supported or test_load_ecdsa_no_named_curve or test_decrypt_invalid_decrypt or test_openssl_memleak or test_load_invalid_ec_key_from_pem)"
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst docs
%license LICENSE*
