%define pypi_name Django
%define pkg_name django

Name:		python-%{pkg_name}
Version:	5.1.7
Release:	%mkrel 1
Summary:	A high-level Python Web framework
License:	BSD
Group:		Development/Python
Url:		https://pypi.org/project/Django
Source0:	%{pypi_source}
BuildArch:	noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:	pkgconfig(python3)

# for docs
BuildRequires:	python3dist(sphinx) >= 4.5.0
BuildRequires:	python3dist(sphinx-rtd-theme)

%description
Django is a high-level Python Web framework that encourages rapid development
and clean, pragmatic design.

Developed and used over the past two years by a fast-moving online-news
operation, Django was designed from scratch to handle two challenges: the
intensive deadlines of a newsroom and the stringent requirements of experienced
Web developers. It has convenient niceties for developing content-management
systems, but it's an excellent tool for building any Web site.

Django focuses on automating as much as possible and adhering to the
DRY principle.

%package -n python3-%{pkg_name}
Summary:	%{summary}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pkg_name}}

%description -n python3-%{pkg_name}
Django is a high-level Python Web framework that encourages rapid development
and clean, pragmatic design.

Developed and used over the past two years by a fast-moving online-news
operation, Django was designed from scratch to handle two challenges: the
intensive deadlines of a newsroom and the stringent requirements of experienced
Web developers. It has convenient niceties for developing content-management
systems, but it's an excellent tool for building any Web site.

Django focuses on automating as much as possible and adhering to the
DRY principle.

%prep
%setup -q -n %{pypi_name}-%{version}

# fix shebangs
find . \( -name "*.py" -o -name "*.py-tpl" \) -exec sed -i -e '1s|#!.*python[2,3]\?|#!%{__python3}|' {} \;

# empty files
for f in \
    django/contrib/staticfiles/models.py \
    django/contrib/humanize/models.py \
; do
  echo "# just a comment" > $f
done

# Fix Sphinx Build
sed -i 's|sphinx-build|sphinx-build-3|' docs/Makefile

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files django

# build documentation
rm -rf docs/{html,man}/*
make -C docs man
make -C docs html
rm -rf docs/_build/html/.{buildinfo,doctrees}

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1/
cp -a docs/_build/man/* %{buildroot}%{_mandir}/man1/

# install bash completion script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -m 0644 -p extras/django_bash_completion \
   %{buildroot}%{_sysconfdir}/bash_completion.d/

%files -n python3-%{pkg_name} -f %{pyproject_files}
%doc AUTHORS LICENSE README.rst
%doc docs/_build/html
%{_mandir}/man1/*
%{_bindir}/django-admin
%{_sysconfdir}/bash_completion.d/django_bash_completion
