# circular build dependency on requests-download and testpath
%bcond_without tests

%global pypi_name flit

Name:           python-%{pypi_name}
Version:        3.9.0
Release:        %mkrel 4
Summary:        Simplified packaging of Python modules
Group:          Development/Python
# ./flit/log.py: Apache-2.0
# ./flit/upload.py: PSF-2.0
License:        BSD-3-Clause AND Apache-2.0 AND PSF-2.0

URL:            https://flit.pypa.io/
Source0:        https://github.com/pypa/flit/archive/%{version}/flit-%{version}.tar.gz

# For the tests
Source1:        https://pypi.org/pypi?%3Aaction=list_classifiers#/classifiers.lst
Patch1:         flit-reqs.patch
BuildArch:      noarch
BuildRequires:  python3-devel

%if %{with tests}
BuildRequires:  python3
BuildRequires:  python3-pytest
BuildRequires:  python3-responses
BuildRequires:  python3-testpath
BuildRequires:  python3-requests-download
BuildRequires:  git-core
%endif

%global _description %{expand:
Flit is a simple way to put Python packages and modules on PyPI.
It tries to require less thought about packaging and help you avoid common
mistakes.

Flit packages a single importable module or package at a time, using the import
name as the name on PyPI. All sub-packages and data files within a package are
included automatically.}

%description %_description


%package -n python3-%{pypi_name}
Summary:        %{summary}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}

# https://pypi.python.org/pypi/tornado
# ./flit/log.py unknown version
Provides:       bundled(python3dist(tornado))

# soft dependency: (WARNING) Cannot analyze code. Pygments package not found.
Recommends:     python3-pygments

%description -n python3-%{pypi_name} %_description

%prep
%autosetup -p1 -n %{pypi_name}-%{version}


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files flit


%check
%pyproject_check_import

%if %{with tests}
# flit attempts to download list of classifiers from PyPI, but not if it's cached
# test_invalid_classifier fails without the list
mkdir -p fake_cache/flit
cp %{SOURCE1} fake_cache/flit
export XDG_CACHE_HOME=$PWD/fake_cache

# This also runs tests of flit_core but deselecting them breaks the flit tests,
# so we run them anyway:
%pytest
%endif


%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%{_bindir}/flit
