# https://gitlab.gnome.org/GNOME/pygobject/issues/253#note_317277
# We don't need to ever pass --no-undefined to Meson because it is enabled by
# default (see: b_lundef option) and is automatically disabled on build targets
# (such as modules) that need it to not be set.

# One issue with this package is that it python3-gobject can pull in a lot
# of extra packages.  There are two ways other distributions deal with this
# Fedora splits out cairo into a separate package but does not do typelib
# dependence.
#
# Opensuse splits out python3-gobject,python3-gobject-gdk,python3-gobject-cairo
#
# We split up gobject into base and the general package but more of the
# package is placed in the main package.  Also splitting out cairo doesn't
# help much because gtk will pull in cairo anyway.

%define _disable_ld_no_undefined 1

%define oname   pygobject

%global __provides_exclude_from ^(%{python3_sitelib}|%{python3_sitearch})/(pygtkcompat|gi/pygtkcompat.py|gi/_gobject/__init__.py|gi/module.py|gi/__init__.py|gi/overrides/GIMarshallingTests.py)
%global __requires_exclude_from ^(%{python3_sitelib}|%{python3_sitearch})/(pygtkcompat|gi/pygtkcompat.py|gi/_gobject/__init__.py|gi/module.py|gi/__init__.py|gi/overrides/GIMarshallingTests.py)

%global __requires_exclude typelib\\(%%namespaces

Summary:	Python bindings for GObject Introspection
Name:		python-gobject
Version:	3.52.3
Release:	%mkrel 1
License:	LGPLv2+ and MIT
Group:		Development/Python
Url:		https://www.gnome.org/
Source0:	https://download.gnome.org/sources/pygobject/%{url_ver}/%{oname}-%{version}.tar.gz

# https://bugzilla.redhat.com/show_bug.cgi?id=2329587
# https://gitlab.gnome.org/GNOME/pygobject/-/issues/658
# Revert override of connection.register_object to avoid breaking anaconda
Patch:          0001-revert-override-of-connection.register_object.patch

BuildRequires:	gnome-common
BuildRequires:	gtk-doc
BuildRequires:	meson
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(py3cairo)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python-srpm-macros
BuildRequires:	python3dist(pytest)
BuildRequires:	gtk4.0
BuildRequires:	x11-server-xvfb

%description
The %{name} package provides a convenient wrapper for the GObject library
for use in Python programs.

%package -n python3-gobject-devel
Group:		Development/C
Summary:	Python-gobject development files
Requires:	python3-gobject = %{version}-%{release}
Provides:	python3-gobject3-devel = %{version}-%{release}
Provides:	python-gobject3-devel = %{version}-%{release}

%description -n python3-gobject-devel
This contains the python-gobject development files, including C
header, pkg-config file.

%package     -n python3-gobject-base
Summary:        Python 3 bindings for GObject Introspection base package
Requires:       gobject-introspection

%description -n python3-gobject-base
This package provides the non-cairo specific bits of the GObject Introspection
library.

%package -n python3-gobject
Summary:	Python 3 bindings for GObject Introspection
Group:		Development/Python
Requires:	python3-cairo >= 1.10.0-15
Requires:	python3-gobject-base = %{version}-%{release}
Provides:	python3-gi = %{version}-%{release}
Provides:	python3-gobject3 = %{version}-%{release}
Provides:	python3-gobject3%{_isa} = %{version}-%{release}

%description -n python3-gobject
This package provides a convenient wrapper for the GObject library and other
libraries that are compatible with GObject Introspection, for use with Python 3
programs.

%prep
%setup -qn %{oname}-%{version}

%build
%meson -Dpython=%{python3}
%meson_build

%install
%meson_install

%check
%{shrink:xvfb-run -s "-screen 0 1600x1200x24" %meson_test --timeout-multiplier=5 || :} 

%files -n python3-gobject-devel
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc

%files -n python3-gobject
%{python3_sitearch}/gi/_gi_cairo*.so
%{python3_sitearch}/gi/_gtktemplate.py
%{python3_sitearch}/gi/pygtkcompat.py
%{python3_sitearch}/gi/overrides/Gdk.*
%{python3_sitearch}/gi/overrides/GdkPixbuf.py
%{python3_sitearch}/gi/overrides/Gtk.*
%{python3_sitearch}/gi/overrides/Pango.*
%{python3_sitearch}/gi/overrides/__pycache__/Gdk*
%{python3_sitearch}/gi/overrides/__pycache__/Gtk.*
%{python3_sitearch}/gi/overrides/__pycache__/Pango.*
%{python3_sitearch}/pygtkcompat/
%{python3_sitearch}/gi/__pycache__/pygtkcompat.*

%files -n python3-gobject-base
%{python3_sitearch}/gi/
%{python3_sitearch}/PyGObject-*.dist-info/
%exclude %{python3_sitearch}/gi/pygtkcompat.py
%exclude %{python3_sitearch}/gi/_gi_cairo*.so
%exclude %{python3_sitearch}/gi/__pycache__/pygtkcompat.*
%exclude %{python3_sitearch}/gi/_gtktemplate.py
%exclude %{python3_sitearch}/gi/overrides/Gdk.*
%exclude %{python3_sitearch}/gi/overrides/GdkPixbuf.py
%exclude %{python3_sitearch}/gi/overrides/Gtk.*
%exclude %{python3_sitearch}/gi/overrides/Pango.*
%exclude %{python3_sitearch}/pygtkcompat/
%exclude %{python3_sitearch}/gi/overrides/__pycache__/Gdk*
%exclude %{python3_sitearch}/gi/overrides/__pycache__/Gtk.*
%exclude %{python3_sitearch}/gi/overrides/__pycache__/Pango.*

