%global upstream_name marshmallow

Name:           python-%{upstream_name}
Version:        3.20.1
Release:        %mkrel 2
Summary:        Python library for converting complex datatypes to and from primitive types
Group:          Development/Python
License:        MIT
URL:            https://marshmallow.readthedocs.org/
# Using Github instead of PyPI because the PyPI tarballs don't include tests,
# docs, or examples, and upstream does not want to change that.
# https://github.com/marshmallow-code/marshmallow/issues/201
Source0:        https://github.com/marshmallow-code/marshmallow/archive/%{version}/%{upstream_name}-%{version}.tar.gz
# remove dependency on bundled ordered_set
Patch0:         ordered_set.patch

BuildArch:      noarch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-ordered-set

%description
Marshmallow is a framework-agnostic library for converting complex datatypes,
such as objects, to and from primitive Python datatypes.

Marshmallow schemas can be used to:
* Validate input data.
* Deserialize input data to app-level objects.
* Serialize app-level objects to primitive Python types. The serialized objects
  can then be rendered to standard formats such as JSON for use in an HTTP API.

%package -n python3-%{upstream_name}
Summary:        Python 3 library for converting complex datatypes to and from primitive types
Group:          Development/Python
Requires:       python3-dateutil
Requires:       python3-ordered-set

%description -n python3-%{upstream_name}
Marshmallow is a framework-agnostic library for converting complex datatypes,
such as objects, to and from primitive Python datatypes.

Marshmallow schemas can be used to:
* Validate input data.
* Deserialize input data to app-level objects.
* Serialize app-level objects to primitive Python types. The serialized objects
  can then be rendered to standard formats such as JSON for use in an HTTP API.

%prep
%autosetup -n %{upstream_name}-%{version} -p1

# remove bundled library
# instead of orderedsett we patch code to usu python-ordered-set
# ordereddict.py is used only for compatibility with python2.6,
# which we do not need
rm -f ./marshmallow/ordereddict.py ./marshmallow/orderedset.py

%generate_buildrequires
%pyproject_buildrequires -t -x tests

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files marshmallow

%check
%tox

%files -n python3-%{upstream_name} -f %{pyproject_files}
%license LICENSE
%doc CHANGELOG.rst AUTHORS.rst README.rst
