%define _disable_ld_no_undefined 1

%bcond_with html
%bcond_with check
# https://fedorahosted.org/fpc/ticket/381
%bcond_without bundled_fonts

# the default backend; one of GTK3Agg GTK3Cairo MacOSX Qt4Agg Qt5Agg TkAgg
# WXAgg Agg Cairo PS PDF SVG
%global backend                 Qt5Agg

%if "%{backend}" == "TkAgg"
%global backend_subpackage tk
%else
    %if "%{backend}" == "Qt5Agg"
%global backend_subpackage qt5
    %else
      %if "%{backend}" == "WXAgg"
%global backend_subpackage wx
      %endif
    %endif
%endif

%global build_backend_args -Csetup-args="-Dsystem-freetype=true" -Csetup-args="-Dsystem-qhull=true" -Cinstall-args="--tags=data,python-runtime,runtime,tests"

# Use the same directory of the main package for subpackage licence and docs
%global _docdir_fmt %{name}

# Updated test images for new FreeType.
%global mpl_images_version 3.9.1

# The version of FreeType in this Fedora branch.
%global ftver 2.13.1

Name:           python-matplotlib
Version:        3.9.1
Release:        %mkrel 2
Summary:        Python 2D plotting library
Group:          Development/Python
# qt4_editor backend is MIT
License:        Python and MIT
URL:            https://matplotlib.org/
Source0:        https://github.com/matplotlib/matplotlib/archive/v%{version}%{?rctag}/matplotlib-%{version}%{?rctag}.tar.gz

# Fedora-specific patches; see:
# https://github.com/fedora-python/matplotlib/tree/fedora-patches
# Updated test images for new FreeType.
Source1000:     https://github.com/QuLogic/mpl-images/archive/v%{mpl_images_version}-with-freetype-%{ftver}/matplotlib-%{mpl_images_version}-with-freetype-%{ftver}.tar.gz
# Define location of matplotlibrc file
Patch1001:      0001-matplotlibrc-path-search-fix.patch 
# We don't need to use NumPy 1.25.
Patch1002:      0002-Unpin-NumPy-build-requirement.patch
# Increase tolerances for new FreeType everywhere:
Patch1003:      0003-Set-FreeType-version-to-%{ftver}-and-update-tolerances.patch

# https://github.com/matplotlib/matplotlib/pull/21190#issuecomment-1223271888
Patch0001:      0004-Use-old-stride_windows-implementation-on-32-bit-x86.patch

# Mageia patches
# Patch5000:      matplotlib-matplotlib-3.3.1-pyparsing-reqs.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  locales-en
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  qhull-devel
BuildRequires:  texlive
BuildRequires:  texlive-dist
BuildRequires:  x11-server-xvfb
BuildRequires:  pkgconfig(zlib)
BuildRequires:  fonts-ttf-dejavu
BuildRequires:  python3-pip
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(setuptools-scm)
BuildRequires:  pkgconfig(pybind11)

%description
Matplotlib is a Python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. Matplotlib can be used in Python
scripts, the Python and IPython shell, web application servers, and
various graphical user interface toolkits.

Matplotlib tries to make easy things easy and hard things possible.
You can generate plots, histograms, power spectra, bar charts,
errorcharts, scatterplots, etc, with just a few lines of code.

%package -n python3-matplotlib-data
Summary:        Data used by python-matplotlib
BuildArch:      noarch
Group:          Development/Python
%if %{with bundled_fonts}
Requires:       python3-matplotlib-data-fonts = %{version}-%{release}
%endif
%{?python_provide:%python_provide python3-matplotlib-data}

%description -n python3-matplotlib-data
%{summary}.

%if %{with bundled_fonts}
%package -n python3-matplotlib-data-fonts
Summary:        Fonts used by python-matplotlib
# STIX and Computer Modern is OFL
# DejaVu is Bitstream Vera and Public Domain
License:        OFL and Bitstream Vera and Public Domain
BuildArch:      noarch
Requires:       python3-matplotlib-data = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-data-fonts}

%description -n python3-matplotlib-data-fonts
%{summary}.
%endif

%package -n     python3-matplotlib
%{?python_provide:%python_provide python3-matplotlib}
Summary:        Python 2D plotting library
Group:          Development/Python
BuildRequires:  python3-cairo
BuildRequires:  python3-certifi >= 2020.06.20
BuildRequires:  python3-cycler >= 0.10.0
BuildRequires:  python3-dateutil
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-gobject
BuildRequires:  python3-kiwisolver
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-pillow
BuildRequires:  python3-pyparsing
BuildRequires:  python3-pytz
BuildRequires:  python3-sphinx
BuildRequires:  python3-meson-python
Requires:       fonts-ttf-dejavu
# for dvipng
Requires:       texlive
Requires:       python3-matplotlib-data = %{version}-%{release}
Requires:       python3-cairo
Requires:       python3-cycler >= 0.10.0
Requires:       python3-dateutil
Requires:       python3-kiwisolver
Requires:       python3-matplotlib-%{?backend_subpackage}%{!?backend_subpackage:tk}%{?_isa} = %{version}-%{release}
%if %{with check}
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-rerunfailures)
BuildRequires:  python3dist(pytest-timeout)
BuildRequires:  python3dist(pytest-xdist)
BuildRequires:  python3dist(pikepdf)
%endif
Requires:       python3-numpy
Recommends:     python3-pillow
Requires:       python3-pyparsing
%if %{without bundled_fonts}
Requires:       stix-math-fonts
%else
Provides:       bundled(stix-math-fonts)
%endif
%{?python_provide:%python_provide python3-matplotlib}

%description -n python3-matplotlib
Matplotlib is a Python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. Matplotlib can be used in Python
scripts, the Python and IPython shell, web application servers, and
various graphical user interface toolkits.

Matplotlib tries to make easy things easy and hard things possible.
You can generate plots, histograms, power spectra, bar charts,
errorcharts, scatterplots, etc, with just a few lines of code.

%package -n     python3-matplotlib-qt5
Summary:        Qt5 backend for python3-matplotlib
Group:          Development/Python
BuildRequires:  python3-qt5
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3-qt5
%{?python_provide:%python_provide python3-matplotlib-qt5}

%description -n python3-matplotlib-qt5
%{summary}.

%package -n     python3-matplotlib-qt6
Summary:        Qt6 backend for python3-matplotlib
Group:          Development/Python
BuildRequires:  python3dist(cairocffi)
BuildRequires:  python3-qt6
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3dist(cairocffi)
Requires:       python3-qt6
%{?python_provide:%python_provide python3-matplotlib-qt6}

%description -n python3-matplotlib-qt6
%{summary}.

%package -n     python3-matplotlib-gtk3
Summary:        GTK3 backend for python3-matplotlib
Group:          Development/Python
# This should be converted to typelib(Gtk) when supported
BuildRequires:  gtk3-devel
BuildRequires:  python3-gobject
Requires:       python3-gobject%{?_isa}
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-gtk3}

%description -n python3-matplotlib-gtk3
%{summary}.

%package -n     python3-matplotlib-tk
Summary:        Tk backend for python3-matplotlib
Group:          Development/Python
BuildRequires:  python3-tkinter
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3-tkinter
%{?python_provide:%python_provide python3-matplotlib-tk}

%description -n python3-matplotlib-tk
%{summary}.

%package -n     python3-matplotlib-wx
Summary:        WX backend for python3-matplotlib
BuildRequires:  python3-wxpython4
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3-wxpython4
%{?python_provide:%python_provide python3-matplotlib-wx}

%description -n python3-matplotlib-wx
%{summary}.

%package -n python3-matplotlib-doc
Summary:        Documentation files for python-matplotlib
%if %{with html}
BuildRequires:  dvipng
BuildRequires:  graphviz
BuildRequires:  python3-sphinx
BuildRequires:  tex(latex)
BuildRequires:  tex-preview
BuildRequires:  js-jquery >= 3.2.1
BuildRequires:  xstatic-jquery-ui-common
BuildRequires:  ipython
Requires:       js-jquery >= 3.2.1
Requires:       xstatic-jquery-ui-common
%endif
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-doc}

%description -n python3-matplotlib-doc
%{summary}.

%package -n python3-matplotlib-test-data
Summary:        Test data for python3-matplotlib
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-test-data}

%description -n python3-matplotlib-test-data
%{summary}.


%prep
%autosetup -n matplotlib-%{version} -N

# Fedora-specific patches follow:
%autopatch -p1 -m 1000
# Updated test images for new FreeType.
gzip -dc %SOURCE1000 | tar xf - --transform='s~^mpl-images-%{mpl_images_version}-with-freetype-%{ftver}/~~'

# Backports or reported upstream
%autopatch -p1 -M 999


%generate_buildrequires
%pyproject_buildrequires -w %%build_backend_args


%build
%set_build_flags
export http_proxy=http://127.0.0.1/

MPLCONFIGDIR=$PWD %pyproject_wheel %build_backend_args
%if %{with html}
# Need to make built matplotlib libs available for the sphinx extensions:
MPLCONFIGDIR=$PWD \
PYTHONPATH="%{pyproject_site_lib}" \
    make -C doc html
%endif
# Ensure all example files are non-executable so that the -doc
# package doesn't drag in dependencies
find galleries -name '*.py' -exec chmod a-x '{}' \;

%install
export http_proxy=http://127.0.0.1/

MPLCONFIGDIR=$PWD %pyproject_install

# Delete unnecessary files.
rm %{buildroot}%{python3_sitearch}/matplotlib/tests/tinypages/.gitignore
rm %{buildroot}%{python3_sitearch}/matplotlib/tests/tinypages/_static/.gitignore

# Move files to Fedora-specific locations.
mkdir -p %{buildroot}%{_sysconfdir} %{buildroot}%{_datadir}/matplotlib
mv %{buildroot}%{python3_sitearch}/matplotlib/mpl-data \
   %{buildroot}%{_datadir}/matplotlib
%if %{without bundled_fonts}
rm -rf %{buildroot}%{_datadir}/matplotlib/mpl-data/fonts
%endif

%if %{with check}
%check
# These files confuse pytest, and we want to test the installed copy.
rm -rf build*/

# We need to prime this LaTeX cache stuff, or it might fail while running tests
# in parallel.
mktexfmt latex.fmt
mktexfmt lualatex.fmt
mktexfmt pdflatex.fmt
mktexfmt xelatex.fmt
# Also prime the font cache.
%{py3_test_envvars} %{python3} -c 'import matplotlib.font_manager'

export http_proxy=http://127.0.0.1/

# This test checks for "slowness" that often fails on a heavily-loaded builder.
k="${k-}${k+ and }not test_invisible_Line_rendering"
# This test is flaky.
k="${k-}${k+ and }not test_form_widget_get_with_datetime_and_date_fields"
%ifarch %{ix86}
# This test won't work due to Xvfb not existing.
k="${k-}${k+ and }not test_cross_Qt_imports"
%endif

MPLCONFIGDIR=$PWD \
%ifnarch %{ix86}
     xvfb-run -a -s "-screen 0 640x480x24" \
%endif
         env %{pytest} -ra -n auto \
             -m 'not network' -k "${k-}" \
             --pyargs matplotlib mpl_toolkits.axes_grid1 mpl_toolkits.axisartist mpl_toolkits.mplot3d
%endif

%files -n python3-matplotlib-data
%{_datadir}/matplotlib/mpl-data/
%if %{with bundled_fonts}
%exclude %{_datadir}/matplotlib/mpl-data/fonts/
%endif

%if %{with bundled_fonts}
%files -n python3-matplotlib-data-fonts
%{_datadir}/matplotlib/mpl-data/fonts/
%endif

%files -n python3-matplotlib-doc
%doc galleries/examples
%if %{with html}
%doc doc/build/html/*
%endif

%files -n python3-matplotlib
%license LICENSE/
%doc README.md
%{python3_sitearch}/*dist-info
%{python3_sitearch}/matplotlib/
%dir %{python3_sitearch}/matplotlib/backends
%dir %{python3_sitearch}/matplotlib/backends/__pycache__
%exclude %{python3_sitearch}/matplotlib/tests/baseline_images/*
%{python3_sitearch}/mpl_toolkits/
%exclude %{python3_sitearch}/mpl_toolkits/*/tests/baseline_images/*
%{python3_sitearch}/pylab.py*
%{python3_sitearch}/__pycache__/*
%exclude %{python3_sitearch}/matplotlib/mpl-data
%if "%{backend}" == "Qt5Agg"
%exclude %{python3_sitearch}/matplotlib/backends/backend_qt5*.py
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_qt5*
%endif
%exclude %{python3_sitearch}/matplotlib/backends/backend_gtk*.py
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_gtk*

%if "%{backend}" == "TkAgg"
%exclude %{python3_sitearch}/matplotlib/backends/_backend_tk.py
%exclude %{python3_sitearch}/matplotlib/backends/backend_tk*.py
%exclude %{python3_sitearch}/matplotlib/backends/tkagg.py
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/_backend_tk.*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_tk*.*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/tkagg.*
%exclude %{python3_sitearch}/matplotlib/backends/_tkagg.*
%endif
%if "%{backend}" == "WXAgg"
%exclude %{python3_sitearch}/matplotlib/backends/backend_wx*
%exclude %{python3_sitearch}/matplotlib/backends/wx_compat.*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_wx*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/wx_compat.*
%endif

%files -n python3-matplotlib-test-data
%{python3_sitearch}/matplotlib/tests/baseline_images/
%{python3_sitearch}/mpl_toolkits/*/tests/baseline_images/


%files -n python3-matplotlib-qt5
%{python3_sitearch}/matplotlib/backends/backend_qt5.*
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_qt5.*
%{python3_sitearch}/matplotlib/backends/backend_qt5agg.*
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_qt5agg.*


# This is handled by backend_qt*.py (no number), so the package exists only for
# the dependencies.
%files -n python3-matplotlib-qt6


%files -n python3-matplotlib-gtk3
%{python3_sitearch}/matplotlib/backends/backend_gtk*.py
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_gtk*

%files -n python3-matplotlib-tk
%{python3_sitearch}/matplotlib/backends/backend_tk*.py
%{python3_sitearch}/matplotlib/backends/_backend_tk.py
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_tk*.*
%{python3_sitearch}/matplotlib/backends/__pycache__/_backend_tk.*
%{python3_sitearch}/matplotlib/backends/_tkagg.*

%files -n python3-matplotlib-wx
%{python3_sitearch}/matplotlib/backends/backend_wx*.py
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_wx*
