%bcond_without check

%{!?bash_completions_dir:%global bash_completions_dir %{_datadir}/bash-completion/completions}
%{!?fish_completions_dir:%global fish_completions_dir %{_datadir}/fish/vendor_completions.d}
%{!?zsh_completions_dir:%global zsh_completions_dir %{_datadir}/zsh/site-functions}

Name:           python-maturin
Version:        1.8.2
Release:        %mkrel 1
Summary:        Build and publish Rust crates as Python packages
Group:          Development/Python

%global pypi_version %(echo %{version} | tr -d "~")

License:        MIT OR Apache-2.0
URL:            https://github.com/PyO3/maturin
Source0:        %{pypi_source maturin %{pypi_version}}

# * disable features with missing dependencies:
#   - cross (support for cross compiling with zig / xwin)
#   - upload (support for uploading wheels to PyPI)
# * drop unused test dependencies
Patch:          0001-drop-unavailable-features-and-unused-dev-dependencie.patch

# * drop incompatible arguments from setuptools_rust cargo invocations
Patch:          0002-drop-incompatible-cargo-flags-from-setuptools_rust.patch

# * drop #!/usr/bin/env python3 shebang from maturin/__init__.py
Patch:          0003-remove-shebang-from-non-executable-__init__.py-file.patch

BuildRequires:  cargo-rpm-macros >= 24
BuildRequires:  python3-devel
BuildRequires:  rust-cbindgen0.26-devel
BuildRequires:  rust-target-lexicon0.12-devel
BuildRequires:  rust-itertools0.12-devel
BuildRequires:  rust-getrandom0.2-devel
BuildRequires:  rust-zerocopy0.7-devel

%description
Build and publish crates with pyo3, rust-cpython and cffi bindings as
well as rust binaries as python packages.

%package -n     python3-maturin
Summary:        %{summary}
Provides:       maturin = %{version}-%{release}

%description -n python3-maturin
Build and publish crates with pyo3, rust-cpython and cffi bindings as
well as rust binaries as python packages.

%prep
%autosetup -n maturin-%{pypi_version} -p1
%cargo_prep

sed -i -e '/base64/s/0\.21\.0/0.22.0/g' Cargo.toml
sed -i -e '/fs4/s/0\.12\.0/0.13.0/g' Cargo.toml

%generate_buildrequires
%pyproject_buildrequires
%cargo_generate_buildrequires -f schemars

%build
export RUSTFLAGS="%{build_rustflags}"
%pyproject_wheel

# write license summary and breakdown
%{cargo_license_summary}
%{cargo_license} > LICENSE.dependencies

%install
%pyproject_install
%pyproject_save_files maturin

# generate and install shell completions
target/rpm/maturin completions bash > maturin.bash
target/rpm/maturin completions fish > maturin.fish
target/rpm/maturin completions zsh > _maturin

install -Dpm 0644 maturin.bash -t %{buildroot}/%{bash_completions_dir}
install -Dpm 0644 maturin.fish -t %{buildroot}/%{fish_completions_dir}
install -Dpm 0644 _maturin -t %{buildroot}/%{zsh_completions_dir}

%if %{with check}
%check
# * skip a test that fails with Rust 1.74+
# * skip tests for which fixtures are not included in published sources
%cargo_test -- -- --skip build_context::test::test_macosx_deployment_target --skip build_options::test::test_find_bridge --skip metadata::test::test_implicit_readme --skip metadata::test::test_merge_metadata_from_pyproject --skip pyproject_toml::tests::test_warn_missing_maturin_version
%endif

%files -n python3-maturin -f %{pyproject_files}
%license license-apache
%license license-mit
%license LICENSE.dependencies
%doc README.md
%doc Changelog.md

%{_bindir}/maturin

%{bash_completions_dir}/maturin.bash
%{fish_completions_dir}/maturin.fish
%{zsh_completions_dir}/_maturin
