%global provider github
%global provider_tld com
%global project Calysto
%global repo metakernel
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global git0 https://%{import_path}

%global commit0 7c0ee76ae48962d5a352c72cbd9c979c9d76406f
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global date 20220912

Name:		python-metakernel
#		The python and echo subpackages have their own version
#		and release numbers - update below in each package section
#		Running rpmdev-bumpspec on this specfile will update all the
#		release tags automatically
Version:	0.30.2
Release:	%mkrel 3
%global pkgversion %{version}
%global pkgrelease %{release}
Summary:	Metakernel for Jupyter
Group:          Development/Python

License:	BSD
URL:		https://github.com/Calysto/metakernel
Source0:	https://github.com/Calysto/metakernel/archive/v%{version}/%{name}-%{version}.tar.gz

BuildArch:	noarch
BuildRequires:	python3-devel
BuildRequires:	python3-ipykernel
BuildRequires:	python3-pexpect >= 4.2
#		For testing:
BuildRequires:	python3-pytest
BuildRequires:	python3-requests
BuildRequires:	python3-ipyparallel >= 6.2.5
BuildRequires:	python3-jedi
BuildRequires:  ipyparallel >= 6.2.5
BuildRequires:	man
# needed for man sleep in test
BuildRequires:  coreutils-doc
#		For documentation
BuildRequires:	python3-sphinx
BuildRequires:	python3-sphinx-bootstrap-theme
BuildRequires:	python3-numpydoc
BuildRequires:	python3-recommonmark
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-hatchling
BuildRequires:  python3-flit-core

%description
A Jupyter/IPython kernel template which includes core magic functions
(including help, command and file path completion, parallel and
distributed processing, downloads, and much more).

%package -n python3-metakernel
Summary:	Metakernel for Jupyter
Group:          Development/Python
%{?python_provide:%python_provide python3-metakernel}
Requires:	python3-ipykernel
Requires:	python3-pexpect >= 4.2
Obsoletes:	python3-metakernel-bash < 0.19.1-24

%description -n python3-metakernel
A Jupyter/IPython kernel template which includes core magic functions
(including help, command and file path completion, parallel and
distributed processing, downloads, and much more).

%package -n python3-metakernel-tests
Summary:	Tests for python3-metakernel
Group:          Development/Python
%{?python_provide:%python_provide python3-metakernel-tests}
Requires:	python3-metakernel = %{version}-%{release}
Requires:	python3-metakernel-python
Requires:	python3-pytest
Requires:	python3-requests
Requires:	python3-ipyparallel
Requires:	python3-jedi
Requires:	man

%description -n python3-metakernel-tests
This package contains the tests of python3-metakernel.

%package doc
Summary:	Documentation for python-metakernel
BuildArch:      noarch
Group:          Documentation

%description doc
This package contains the documentation of python-metakernel.

%package -n python3-metakernel-python
Summary:	A Python kernel for Jupyter/IPython
Group:          Development/Python
%{?python_provide:%python_provide python3-metakernel-python}
Requires:	python3-metakernel = %{pkgversion}-%{pkgrelease}
Requires:	python3-jedi

%description -n python3-metakernel-python
A Python kernel for Jupyter/IPython, based on MetaKernel.

%package -n python3-metakernel-echo
Summary:	A simple echo kernel for Jupyter/IPython
Group:          Development/Python
%{?python_provide:%python_provide python3-metakernel-echo}
Requires:	python3-metakernel = %{pkgversion}-%{pkgrelease}

%description -n python3-metakernel-echo
A simple echo kernel for Jupyter/IPython, based on MetaKernel.

%prep
%autosetup -p1 -n metakernel-%{pkgversion}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

pushd metakernel_python
%pyproject_wheel
popd

pushd metakernel_echo
%pyproject_wheel
popd

#pushd docs
#PYTHONPATH=.. make html SPHINXBUILD=sphinx-build-3
#rm -f _build/html/.buildinfo
#popd

%install
%pyproject_install

pushd metakernel_python
%pyproject_install
popd

pushd metakernel_echo
%pyproject_install
popd

for f in tests/test_expect.py; do
  sed '/\/usr\/bin\/env/d' -i %{buildroot}%{python3_sitelib}/metakernel/${f}
done

PYTHONPATH=metakernel_python \
  python3 -m metakernel_python install --name python3-metakernel-python \
  --prefix %{buildroot}%{_prefix}
PYTHONPATH=metakernel_echo \
  python3 -m metakernel_echo install --name python3-metakernel-echo \
  --prefix %{buildroot}%{_prefix}

%if 0
%check
export LC_ALL=C
export LANG=C
export LANGUAGE=C
PYTHONPATH=metakernel_python ipcluster start -n=3 &
pid=$!
%if %{mageia} >= 8
# The REPLWrapTestCase.test_python test fails with readline version 8.1
# https://github.com/Calysto/metakernel/issues/228
pytest-3 -v metakernel -k 'not REPLWrapTestCase or not test_python'
%else
pytest-3 -v metakernel
%endif
ipcluster stop
wait $pid
%endif

%files -n python3-metakernel
%license LICENSE.txt
%doc README.rst
%dir %{python3_sitelib}/metakernel
%{python3_sitelib}/metakernel/*.py
%{python3_sitelib}/metakernel/__pycache__
%{python3_sitelib}/metakernel/images
%dir %{python3_sitelib}/metakernel/magics
%{python3_sitelib}/metakernel/magics/*.py
%{python3_sitelib}/metakernel/magics/*.md
%{python3_sitelib}/metakernel/magics/__pycache__
%{python3_sitelib}/metakernel/utils
%{python3_sitelib}/metakernel-*.dist-info/

%files -n python3-metakernel-tests
%{python3_sitelib}/metakernel/tests
%{python3_sitelib}/metakernel/magics/tests

%files doc
%license LICENSE.txt
#doc docs/_build/html

%files -n python3-metakernel-python
%{python3_sitelib}/metakernel_python.py
%{python3_sitelib}/__pycache__/metakernel_python.*
%{_datadir}/jupyter/kernels/python3-metakernel-python
%{python3_sitelib}/metakernel_python-*.dist-info/

%files -n python3-metakernel-echo
%{python3_sitelib}/metakernel_echo.py
%{python3_sitelib}/__pycache__/metakernel_echo.*
%{_datadir}/jupyter/kernels/python3-metakernel-echo
%{python3_sitelib}/metakernel_echo-*.dist-info/
