%define module  numpy

#(eatdirt) misses a few symbols and atlas is just lapack/blas
#optimized. Because it cannot be optimized when distributed through
#our buildserver, there is no gain in using it
%define enable_atlas 0

# disable this for bootstrapping nose and sphinx
%define enable_tests 0
#(eatdirt) something is missing here, either a python-numpydoc package
#or a Provides in python-numpy (disabled for now).
%define enable_doc 0

#uncomment next line for a release candidate or a beta
#define relc rc1

#release to bump
%define rel 4

Summary:	A fast multidimensional array facility for Python
Name:		python-%{module}
Epoch:		1
Version:	2.1.3
Release:	%mkrel %{?relc:0.%relc.}%{rel}
License:	BSD
Group:		Development/Python
Url: 		https://numpy.org
Source0:	https://github.com/numpy/numpy/releases/download/v%{version}/%{module}-%{version}%{?relc}.tar.gz
Source1:	https://numpy.org/doc/2.1/numpy-html.zip#/numpy-2.1-html.zip

%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif
BuildRequires:	lapack-devel >= 3.8.0-3
BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	gcc-gfortran >= 8.2.0-0.5
BuildRequires:	chrpath
BuildRequires:	libatomic-devel
BuildRequires:	meson
%if %enable_doc
BuildRequires:	python3dist(sphinx) >= 1.0
BuildRequires:	python3dist(sphinx-rtd-theme)
BuildRequires:	python3dist(matplotlib)
%endif
%if %enable_tests
BuildRequires:	python3dist(hypothesis)
BuildRequires:	python3dist(nose)
BuildRequires:	python3dist(pytest)
%endif
BuildRequires:	python3dist(cython)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(meson-python)


%description
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-numpy
Summary:	A fast multidimensional array facility for Python3
Group:		Development/Python
License:	BSD
%{?python_provide:%python_provide python3-numpy}

%description -n python3-numpy
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-numpy-devel
Summary:        Numpy headers for Python3
Group:          Development/Python
Requires:       python3-numpy = %{epoch}:%{version}-%{release}
Obsoletes:      python3-numeric-devel < 2.8
Provides:       python3-numeric-devel = %{epoch}:%{version}-%{release}

%description -n python3-numpy-devel
This package contains header files need to develop modules
in C and Fortran that can interact with Numpy.

%package -n python3-numpy-f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       python3-numpy = %{epoch}:%{version}-%{release}
Requires:       pkgconfig(python3)
%{?python_provide:%python_provide python3-numpy-f2py}
%{?python_provide:%python_provide python3-f2py}
Provides:       python3-f2py = %{epoch}:%{version}-%{release}
Obsoletes:      python3-f2py <= 2.45.241_1927

%description -n python3-numpy-f2py
This package includes a version of f2py that works properly with NumPy.

%package -n python3-numpy-doc
Summary:	Documentation for numpy
Group:          Documentation
Requires:	python3-numpy >= %{epoch}:%{version}-%{release}
BuildArch:	noarch

%description -n python3-numpy-doc
This package provides the complete documentation for NumPy.

%prep
%autosetup -n %{module}-%{version}%{?relc} -p1

%build
export LDFLAGS="%{build_ldflags} -lpython%{python3_version}"

%ifarch %{arm32}
%global args -C setup-args=-Dcpu-dispatch=NONE
%elifarch %{ix86}
%global args -C setup-args=-Dcpu-dispatch=SSE2
%endif

%pyproject_wheel %{?args} -C setup-args=-Dbuildtype=plain

%if %enable_doc
pushd doc
export PYTHONPATH=`dir -d ../build/lib.linux*`
%make_build html
popd
%endif

%install
mkdir docs
pushd docs
unzip %{SOURCE1}
popd

%pyproject_install
%pyproject_save_files numpy

# remove RPATH
chrpath -d %{buildroot}%{python3_sitearch}/numpy/linalg/*.so
chrpath -d %{buildroot}%{python3_sitearch}/numpy/_core/_multiarray_umath*.so

# Remove doc files that should be in %%doc:
rm -f %{buildroot}%{python3_sitearch}/%{module}/LICENSE.txt

%check
%if %enable_tests

pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{python3_sitearch}" PATH="%{buildroot}%{_bindir}:$PATH"\
    %{__python3} -m pytest -v --pyargs numpy
popd &> /dev/null
%endif



%files -n python3-numpy -f %{pyproject_files}
%license LICENSE.txt
%doc THANKS.txt
%exclude %{python3_sitearch}/%{module}/_core/include/
%{_bindir}/numpy-config

%files -n python3-numpy-f2py
%{_bindir}/f2py
%if 0
%{_bindir}/f2py3
%{_bindir}/f2py%{python3_version}
%endif
%{python3_sitearch}/%{module}/f2py

%files -n python3-numpy-devel
%{python3_sitearch}/%{module}/_core/include/

%files -n python3-numpy-doc
%doc docs/*

