%global srcname pyopencl
%global bname opencl

# It is hard to run tests
%bcond_with tests

Name:           python-%{bname}
Version:        2025.1
Release:        %mkrel 3
Summary:        Python wrapper for OpenCL
Group:          Development/Python

# https://bugzilla.redhat.com/show_bug.cgi?id=1219819#c16
# Boost (boost):
# pyopencl/cl/pyopencl-bessel-j.cl
# pyopencl/cl/pyopencl-bessel-y.cl
# pyopencl/cl/pyopencl-eval-tbl.cl
# GPLv2 (cephes):
# pyopencl/cl/pyopencl-airy.cl
# ASL 2.0 (ranluxcl), will be removed in 2018.x:
# pyopencl/cl/pyopencl-ranluxcl.cl
# ASL 2.0:
# pyopencl/scan.py
# BSD (random123):
# pyopencl/cl/pyopencl-random123/array.h
# pyopencl/cl/pyopencl-random123/openclfeatures.h
# pyopencl/cl/pyopencl-random123/philox.cl
# pyopencl/cl/pyopencl-random123/threefry.cl
# BSD:
# pyopencl/bitonic_sort.py
# pyopencl/bitonic_sort_templates.py

License:        MIT and Boost and ASL 2.0 and GPLv2 and BSD
URL:            https://mathema.tician.de/software/pyopencl
Source0:        %{pypi_source}
Patch0:         pyopencl-linking.patch

# pyopencl/cl/pyopencl-bessel-[j,y].cl and
# pyopencl/cl/pyopencl-eval-tbl.cl contain snippets taken from boost
# and cephes. pyopencl/cl/pyopencl-airy.cl contains code taken from
# cephes.
Provides:       bundled(boost-math)
Provides:       bundled(cephes) = 2.8
# pyopencl/cl/pyopencl-ranluxcl.cl contains a modified version of the
# ranluxcl library
Provides:       bundled(ranluxcl) = 1.3.1
# ./pyopencl/compyte/*
Provides:       bundled(compyte)

BuildRequires:  gcc-c++
BuildRequires:  blas-devel
BuildRequires:  boost-devel
BuildRequires:  cmake(nanobind)
BuildRequires:  cmake(OpenCLHeaders)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pybind11-devel

%if %{with tests}
BuildRequires:  pocl
%endif

%description
PyOpenCL makes it possible to access GPUs and other massively
parallel compute devices from Python. Specifically, PyOpenCL
provides Pythonic access to the OpenCL parallel computation
API in a manner similar to the sister project `PyCUDA`.

%package -n python3-%{bname}
Summary:        Python 3 wrapper for OpenCL
Group:          Development/Python
%{?python_provide:%python_provide python3-%{bname}}
%{?python_provide:%python_provide python3-%{srcname}}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-numpy-devel
BuildRequires:  python3dist(pybind11)
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(scikit-build-core)
Recommends:     python3dist(Mako)
%if %{with tests}
BuildRequires:  python3-pytest
BuildRequires:  python3-pytools >= 2017.2
BuildRequires:  python3-decorator
BuildRequires:  python3-appdirs
BuildRequires:  python3-six
BuildRequires:  python3-scipy
%endif

%description -n python3-%{bname}
PyOpenCL makes it possible to access GPUs and other massively
parallel compute devices from Python. Specifically, PyOpenCL
provides Pythonic access to the OpenCL parallel computation
API in a manner similar to the sister project `PyCUDA`.

Python 3 version of %{srcname}.

%prep
%autosetup -n %{srcname}-%{version} -p1

rm -vf examples/download-examples-from-wiki.py


# generate html docs
#sphinx-build doc/source html
# remove the sphinx-build leftovers
#rm -rf html/.{doctrees,buildinfo}

%build
%pyproject_wheel -C"cmake.build-type=RelWithDebInfo"

%install
%pyproject_install
%pyproject_save_files %{srcname}

find %{buildroot}%{python3_sitearch}/%{srcname} -name '*.so' -exec chmod 755 {} \+

%if %{with tests}
%check
pushd test/
  export PYTHONPATH=%{buildroot}%{python3_sitearch}
  find -name '*.py' -exec py.test-%{python3_version} -v {} \+
popd
%endif

%files -n python3-%{bname} -f %{pyproject_files}
%license LICENSE
%doc examples
