%define pypi_name	pyopenssl
%define pkg_name	openssl

%bcond_without doc
%bcond_without check

Name:		python-%{pkg_name}
Version:	25.0.0
Release:	%mkrel 1
Summary:	Python interface to the OpenSSL library
License:	ASL 2.0
Group:		Development/Python
Url:		https://pypi.org/project/pyOpenSSL/
Source:		%{pypi_source}
Patch2:		0001-Limit-list-of-elliptic-curves-tested-to-those-in-Fed.patch
BuildArch:	noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:	python3-devel
%if %{with check}
BuildRequires:  openssl
%endif
%if %{with doc}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
%endif

%description
pyOpenSSL is a high-level Python wrapper around a subset of OpenSSL library.

It includes:
* SSL.Connection objects, wrapping the methods of Python's portable sockets;
* callbacks written in Python;
* an extensive error-handling mechanism, mirroring OpenSSL's error codes;
* and much more.

%package -n python3-%{pkg_name}
Summary:	Python 3 wrapper module around the OpenSSL library
Group:		Development/Python
%{?python_provide:%python_provide python3-pyopenssl}
%{?python_provide:%python_provide python3-%{pkg_name}}
%{?python_provide:%python_provide python3-%{pypi_name}}
%{?python_provide:%python_provide python3-OpenSSL}

Obsoletes:      python3-OpenSSL < 23.0.0
Obsoletes:	python3-OpenSSL-doc < 23.0.0
Provides:       python3-OpenSSL = %{version}-%{release}

%description -n python3-%{pkg_name}
High-level wrapper around a subset of the OpenSSL library, includes among others
 * SSL.Connection objects, wrapping the methods of Python's portable
   sockets
 * Callbacks written in Python 3
 * Extensive error-handling mechanism, mirroring OpenSSL's error codes

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires %{?with_check:-x test}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%if %{with doc}
export PYTHONPATH=$(pwd)
sphinx-build doc html
sphinx-build -b man doc man
%endif

%install
%pyproject_install
%pyproject_save_files OpenSSL

%if %{with doc}
%__install -Dm 0644 man/pyopenssl.1 %{buildroot}%{_mandir}/man1/pyopenssl.1
%endif

%if %{with check}
%check
%pyproject_check_import
%pytest -k "not network" -k "not test_sign_verify_with_text" -k "not test_sign_verify"
%endif

%files -n python3-%{pkg_name} -f %{pyproject_files}
%if %{with doc}
%doc html
%{_mandir}/man1/pyopenssl.1*
%endif
