%global py3_incdir %(python3 -c 'import distutils.sysconfig; print(distutils.sysconfig.get_python_inc())')
%global py3_libbuilddir %(python3 -c 'import sys; import sysconfig; print("lib.{p}-cpython-{v[0]}{v[1]}".format(p=sysconfig.get_platform(), v=sys.version_info))')

%global pypi_name pillow
%global srcname   Pillow

%bcond_with docs

Name:           python-%{pypi_name}
Version:        11.1.0
Release:        %mkrel 1
Summary:        Python image processing library

Group:          Development/Python
# License: see http://www.pythonware.com/products/pil/license.htm
License:        MIT
URL:            https://python-pillow.github.io/
Source0:        https://github.com/python-pillow/Pillow/archive/%{version}/Pillow-%{version}.tar.gz

Patch0:         Pillow-fix-linking.patch
# When building docs, error occurs: ModuleNotFoundError: No module named 'PIL', it needs to be found
Patch2:         Pillow-10.2.0-allow-docs-build-without-module-installation.patch

BuildRequires:  pkgconfig(tk)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(imagequant)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  ghostscript
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  python3-devel
BuildRequires:  python3-cffi
BuildRequires:  python3-olefile
BuildRequires:  python3-pytest
# for patch2
BuildRequires:  git-core

# For EpsImagePlugin.py
Requires:       ghostscript

Provides:       python-imaging = %{version}-%{release}

%description
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

There are four subpackages: tk (tk interface), qt (PIL image wrapper for Qt),
devel (development) and doc (documentation).

%package -n python3-%{pypi_name}
Group:          Development/Python
Summary:        Python 3 image processing library
Provides:       python3-imaging = %{version}-%{release}
Provides:       python3dist(PIL) = %{version}-%{release}

%description -n python3-%{pypi_name}
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

There are four subpackages: tk (tk interface), qt (PIL image wrapper for Qt),
devel (development) and doc (documentation).

%package -n python3-%{pypi_name}-devel
Summary:        Development files for python3-%{pypi_name}
Group:          Development/C
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-devel
Requires:       libjpeg-devel
Requires:       zlib-devel

%description -n python3-%{pypi_name}-devel
Development files for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-doc
Summary:        Documentation for python3-%{pypi_name}
Group:          Documentation
Requires:       python3-%{pypi_name} = %{version}-%{release}
BuildArch:      noarch

%description -n python3-%{pypi_name}-doc
Documentation for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-tk
Summary:        Tk interface for python3-%{pypi_name}
Group:          System/Libraries
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-tkinter

%description -n python3-%{pypi_name}-tk
Tk interface for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-qt
Summary:        PIL image wrapper for Qt
Group:          System/Libraries
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-qt5

%description -n python3-%{pypi_name}-qt
PIL image wrapper for Qt.

%prep
%autosetup -p1 -n Pillow-%{version}

# drop bundled egg-info
rm -rf src/*.egg-info/

# Don't error out if sphinx warnings occur
sed -ie "s/--fail-on-warning //" docs/Makefile

%generate_buildrequires
%pyproject_buildrequires %{?with_docs:-x docs}

%build
%pyproject_wheel

%if %{with docs}
#for docs
PYTHONPATH=$PWD/build/%py3_libbuilddir:$PWD/docs make -C docs html BUILDDIR=_build SPHINXBUILD=sphinx-build-%python3_version
rm -f docs/_build/html/.buildinfo
%endif

%install
# Install Python 3 modules
install -d %{buildroot}/%{py3_incdir}/Imaging
install -m 644 src/libImaging/*.h %{buildroot}/%{py3_incdir}/Imaging
%pyproject_install


%check
# Check Python 3 modules
ln -s $PWD/Images $PWD/build/%py3_libbuilddir/Images
cp -R $PWD/Tests $PWD/build/%py3_libbuilddir/Tests
cp -a $PWD/selftest.py $PWD/build/%py3_libbuilddir/selftest.py
pushd build/%py3_libbuilddir
PYTHONPATH=$PWD %{__python3} selftest.py
popd
%pytest -v -k "not test_qt_image_qapplication"

%files -n python3-%{pypi_name}
%doc README.md CHANGES.rst
%license docs/COPYING
%{python3_sitearch}/PIL/
%{python3_sitearch}/pillow-%{version}.dist-info
# These are in subpackages
%exclude %{python3_sitearch}/PIL/_imagingtk*
%exclude %{python3_sitearch}/PIL/ImageTk*
%exclude %{python3_sitearch}/PIL/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/ImageQt*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageTk*
%exclude %{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageQt*

%files -n python3-%{pypi_name}-devel
%{py3_incdir}/Imaging/
%if %{with docs}
%doc docs/_build/html
%endif

%files -n python3-%{pypi_name}-tk
%{python3_sitearch}/PIL/_imagingtk*
%{python3_sitearch}/PIL/ImageTk*
%{python3_sitearch}/PIL/SpiderImagePlugin*
%{python3_sitearch}/PIL/__pycache__/ImageTk*
%{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*

%files -n python3-%{pypi_name}-qt
%{python3_sitearch}/PIL/ImageQt*
%{python3_sitearch}/PIL/__pycache__/ImageQt*
