%define pypi_name pyglet

Name:       python-%{pypi_name}
Version:    2.0.10
Release:    %mkrel 2
Summary:    A cross-platform windowing and multimedia library for Python
Group:      Development/Python
License:    BSD
URL:        https://pypi.org/project/pyglet/

# The upstream tarball includes some non-free files in the examples and tests,
# and a patented texture compression algorithm.
# Run the following (in rpmbuild/SOURCES) to generate the distributed tarball
# (the subcommand outputs a version number like 1.5.16):
# $ bash pyglet-get-tarball.sh $(grep Version python-pyglet.spec|cut -c10-)
# See the script for details.
Source0: %{pypi_name}-%{version}-repacked.tar.gz
Source1: pyglet-get-tarball.sh

# Use importlib instead of imp
Patch0: python-pyglet-imp.patch

# Note that unbundling pypng removes "PNGImageDecoder", which is normally
# available for advanced use cases. Instead of:
#     img = image.load(fname, decoder=PNGImageDecoder) # don't use!
# It is enough to let Pyglet choose an appropriate decoder with:
#     img = image.load(fname)
# Pyglet docs even discourage hard-coding the decoder "unless your application
# has to work around specific deficiences in an operating system decoder":
#   https://pyglet.readthedocs.io/en/latest/programming_guide/image.html?highlight=PILImageDecoder#loading-an-image
# If you do find an issue with the default decoder on Fedora, file a bug.

BuildArch: noarch

BuildRequires: pyproject-rpm-macros
BuildRequires: pkgconfig(python3)
BuildRequires: python3-setuptools

%description
This library provides an object-oriented programming interface for developing
games and other visually-rich applications with Python.
pyglet has virtually no external dependencies. For most applications and game
requirements, pyglet needs nothing else besides Python, simplifying
distribution and installation. It also handles multiple windows and
fully aware of multi-monitor setups.

pyglet might be seen as an alternative to PyGame.

%package -n python3-%{pypi_name}
Summary: A cross-platform windowing and multimedia library for Python 3
Group: Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires: python3-pillow

# The libraries are imported dynamically using ctypes, so rpm can't find them.
Requires: libmesagl
Requires: libx11
Requires: fontconfig

%description -n python3-%{pypi_name}
This library provides an object-oriented programming interface for developing
games and other visually-rich applications with Python 3.
pyglet has virtually no external dependencies. For most applications and game
requirements, pyglet needs nothing else besides Python, simplifying
distribution and installation. It also handles multiple windows and
fully aware of multi-monitor setups.

pyglet might be seen as an alternative to PyGame.



%prep
%setup -q -n %{pypi_name}-%{version}

# Remove the bundled pypng library (python-pillow provides the same functionality)
rm pyglet/image/codecs/png.py
rm pyglet/extlibs/png.py

# Get rid of hashbang lines. This is a library, it has no executable scripts.
# Also remove Windows newlines
find . -name '*.py' | xargs sed --in-place -e's|#!/usr/bin/\(env \)\?python||;s/\r//'

%build
%pyproject_wheel

%generate_buildrequires
%pyproject_buildrequires

%install
%pyproject_install
%pyproject_save_files pyglet

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.md
%doc RELEASE_NOTES

