%define pypi_name pytest

# When building pytest for the first time with new Python version
# we also don't have sphinx yet and cannot build docs.
%bcond_without docs
%bcond_without check

Name:           python-%{pypi_name}
Version:        8.3.5
Release:        %mkrel 1
Summary:        Simple powerful testing with Python
Group:          Development/Python
License:        MIT
URL:            https://pypi.org/project/pytest
Source0:        %{pypi_source}

BuildArch:      noarch
BuildRequires:  python3-devel
%if %{with docs}
BuildRequires:  python3-sphinxcontrib-inkscapeconverter
%endif

%description
py.test provides simple, yet powerful testing for Python.

%package -n python3-%{pypi_name}
Summary:        Simple powerful testing with Python 3
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Provides:       python3-test = %{version}-%{release}
Obsoletes:	%{name}-doc < %{version}-%{release}

%description -n python3-%{pypi_name}
py.test provides simple, yet powerful testing for Python 3.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# remove part not recognized
sed -i -e "s/-c broken-dep-constraints.txt//" doc/en/requirements.txt
# relax requirements not understood by urpmi
sed -i -e "s/pluggy<2,/pluggy/" pyproject.toml

%generate_buildrequires
%pyproject_buildrequires %{?with_docs:doc/en/requirements.txt} %{?with_check:-t -x tests}

%build
%pyproject_wheel

%if %{with docs}
for l in doc/* ; do
  make -C $l html PYTHONPATH=$(pwd)/src SPHINXBUILD=%{_bindir}/sphinx-build-%{python3_version}
done
for f in README CHANGELOG CONTRIBUTING ; do
  rst2html ${f}.rst > ${f}.html
done
%endif

%install
%pyproject_install
%pyproject_save_files %{pypi_name} _%{pypi_name} py

ln -snf pytest %{buildroot}%{_bindir}/pytest-3
ln -snf pytest %{buildroot}%{_bindir}/pytest-%{python3_version}
ln -snf py.test %{buildroot}%{_bindir}/py.test-3
ln -snf py.test %{buildroot}%{_bindir}/py.test-%{python3_version}

%if %{with docs}
mkdir -p _htmldocs/html
for l in doc/* ; do
  # remove hidden file
  rm ${l}/_build/html/.buildinfo
  mv ${l}/_build/html _htmldocs/html/${l##doc/}
done
%endif

# remove shebangs from all scripts
find %{buildroot}%{python3_sitelib} \
     -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' {} \;

%if %{with check}
%check
%tox
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%if %{with docs}
%doc CHANGELOG.html README.html CONTRIBUTING.html
%endif
%license LICENSE
%{_bindir}/pytest
%{_bindir}/pytest-3
%{_bindir}/pytest-%{python3_version}
%{_bindir}/py.test
%{_bindir}/py.test-3
%{_bindir}/py.test-%{python3_version}

%if %{with docs}
%doc _htmldocs/html
%endif
