%define pypi_name reportlab

Summary:	ReportLab library to create PDF documents using Python
Name:		python-reportlab
Version:	4.2.0
Release:	%mkrel 2
License:	BSD
Group:		Publishing
URL:		https://pypi.org/project/reportlab
Source0:	%{pypi_source}
BuildArch:	noarch
BuildRequires:	pkgconfig(freetype2)

%description
ReportLab is a library that lets you directly create documents in
Adobe's Portable Document Format (PDF) using the Python programming
language.

ReportLab library creates PDF based on graphics commands without
intervening steps. It's therefore extremely fast, and flexible (since
you're using a full-blown programming language).

Sample use cases are:

  * Dynamic PDF generation on the web
  * High-volume corporate reporting and database publishing
  * As embeddable print engine for other applications, including a
    'report language' so that users can customize their own reports.
  * As 'build system' for complex documents with charts, tables and text
    such as management accounts, statistical reports and scientific papers
  * from XML to PDF in one step

%package -n python3-reportlab
Summary:	ReportLab library to create PDF documents using Python 3
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-pillow
Requires:	fonts-ttf-dejavu
Requires:	python3-pillow
%{?python_provide:%python_provide python3-reportlab}

%description -n python3-reportlab
ReportLab is a library that lets you directly create documents in
Adobe's Portable Document Format (PDF) using the Python programming
language.

ReportLab library creates PDF based on graphics commands without
intervening steps. It's therefore extremely fast, and flexible (since
you're using a full-blown programming language).

%package docs
Summary:	Documentation files for %{name}
Requires:	%{name} = %{version}-%{release}
Group:		Publishing
License:	BSD

%description docs
Contains the documentation for ReportLab.

%prep
%setup -q -n reportlab-%{version}
%autopatch -p1

# clean up hashbangs from libraries
find src -name '*.py' | xargs sed -i -e '/^#!\//d'

%build
%py3_build -- --no-download-t1-files

# a bit of a horrible hack due to a chicken-and-egg problem. The docs
# require reportlab, which isn't yet installed, but is at least built.
PYTHONPATH=$(readlink -f build/lib/) \
%{__python} docs/genAll.py

%install
%py3_install -- --no-download-t1-files

# Remove bundled fonts
rm -rf %{buildroot}%{python3_sitearch}/reportlab/fonts

%files -n python3-reportlab
%license LICENSE
%doc README.txt CHANGES.md
%{python3_sitelib}/reportlab/
%{python3_sitelib}/reportlab-%{version}-py%{python3_version}.egg-info

%files docs
%doc demos tools docs/reportlab-userguide.pdf
