# reduce peak memory usage
%{?constrain_build: %constrain_build -m 4096}

%ifarch %{ix86} %{arm32}
%global rustflags_debuginfo 1
%endif

%bcond_without vendored

# replacements for git snapshot dependencies
%global lsp_types_commit    3512a9f33eadc5402cfab1b8f7340824c8ca1439
%global salsa_commit        99be5d9917c3dd88e19735a82ef6bf39ba84bd7e

%{!?bash_completions_dir:%global bash_completions_dir %{_datadir}/bash-completion/completions}
%{!?fish_completions_dir:%global fish_completions_dir %{_datadir}/fish/vendor_completions.d}
%{!?zsh_completions_dir:%global zsh_completions_dir %{_datadir}/zsh/site-functions}

Name:           python-ruff
Version:        0.9.8
Release:        %mkrel 3
Summary:        An extremely fast Python linter and code formatter, written in Rust
Group:          Development/Python
License:        MIT
URL:            https://docs.astral.sh/ruff
Source:         %{pypi_source ruff}
Source1:        https://github.com/astral-sh/lsp-types/archive/%{lsp_types_commit}/lsp-types-%{lsp_types_commit}.tar.gz
Source2:        https://github.com/salsa-rs/salsa/archive/%{salsa_commit}/salsa-%{salsa_commit}.tar.gz
Source3:        avoid-duplicate-workspace-definitions.patch

Source100:      ruff-%{version}-vendor.tar.xz

# From Fedora:
#
# * drop non-Linux dependencies (non-upstreamable), generated with:
#   "for i in $(find -name Cargo.toml) ; do rust2rpm-helper strip-foreign $i -o $i ; done"
Patch:          0001-drop-Windows-and-macOS-specific-dependencies.patch
# * replace git snapshot dependencies with path-based dependencies from
#   unpacked additional sources (non-upstreamable)
Patch:          0002-replace-git-snapshot-dependencies-with-path-dependen.patch
# * do not strip debuginfo from the built executable (non-upstreamable)
Patch:          0004-do-not-strip-debuginfo-from-built-binary-executable.patch

BuildRequires:  git-core
BuildRequires:  python3-devel
BuildRequires:  cargo-rpm-macros

%description
An extremely fast Python linter and code formatter, written in Rust.

%package -n     python3-ruff
Summary:        %{summary}
%{?python_provide:%python_provide python3-ruff}
Provides:       ruff = %{version}-%{release}
Provides:       ruff%{?_isa} = %{version}-%{release}

%description -n python3-ruff
An extremely fast Python linter and code formatter, written in Rust.

%prep
%autosetup -p1 -n ruff-%{version} %{?with_vendored:-a100} -Sgit_am
%cargo_prep %{?with_vendored:-v vendor}

# move git snapshot replacements into place
tar -xzvf %{SOURCE1}
tar -xzvf %{SOURCE2}
mv lsp-types-%{lsp_types_commit} crates/lsp-types
mv salsa-%{salsa_commit} crates/salsa

# avoid duplicate workspace definitions
pushd crates/salsa
patch -p1 < %{SOURCE3}
mv components/* ../
popd

%generate_buildrequires
%pyproject_buildrequires
%{!?with_vendored:%cargo_generate_buildrequires}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files ruff

# generate and install shell completions
target/rpm/ruff generate-shell-completion bash > ruff.bash
target/rpm/ruff generate-shell-completion fish > ruff.fish
target/rpm/ruff generate-shell-completion zsh > _ruff

install -Dpm 0644 ruff.bash -t %{buildroot}/%{bash_completions_dir}
install -Dpm 0644 ruff.fish -t %{buildroot}/%{fish_completions_dir}
install -Dpm 0644 _ruff -t %{buildroot}/%{zsh_completions_dir}

%check
%pyproject_check_import

%files -n python3-ruff -f %{pyproject_files}
%doc README.md
%{_bindir}/ruff

%{bash_completions_dir}/ruff.bash
%{fish_completions_dir}/ruff.fish
%{zsh_completions_dir}/_ruff
