%define _disable_ld_no_undefined 1

%define pypi_name		scikit-learn
%define src_name		scikit_learn

%global __provides_exclude_from ^(%{python3_sitearch})/.*\\.so$

Summary:	machine learning in Python
Name:		python-%{pypi_name}
Version:	1.6.1
Release:	%mkrel 1
License:	BSD
Group:		Development/Python
Url:		https://pypi.org/project/scikit-learn/
Source0:	%{pypi_source %{src_name}}
BuildRequires:	python3-numpy-devel >= 2
BuildRequires:	pkgconfig(python3)

%description
sklearn is a Python pypi_name that integrates classic machine learning
algorithms with the tightly-knit world of scientific Python packages
(numpy, scipy, matplotlib).

%package -n	python3-%{pypi_name}
Summary:	Python 3 pypi_names for machine learning and data mining
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n	python3-%{pypi_name}
sklearn is a Python 3 pypi_name that integrates classic machine learning
algorithms with the tightly-knit world of scientific Python packages
(numpy, scipy, matplotlib).

%prep
%autosetup -n %{src_name}-%{version} -p1

sed -i -e 's|numpy>=2|numpy|' pyproject.toml
find sklearn/metrics/_dist_metrics.pyx.tp -type f | xargs sed -i 's/cdef inline {{INPUT_DTYPE_t}} rdist/cdef {{INPUT_DTYPE_t}} rdist/g'

%generate_buildrequires
%pyproject_buildrequires -p

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files sklearn

%if %{with check}
%check
# check collection crashes in armv7hl
# https://koji.fedoraproject.org/koji/taskinfo?taskID=74494216
%ifarch armv7hl
%py3_check_import sklearn
%else
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS='-p no:cacheprovider'
pushd %{buildroot}%{python3_sitearch}
  pytest \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[True-liac-arff]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[False-liac-arff]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[True-pandas]" \
  --deselect "sklearn/datasets/tests/test_openml.py::test_fetch_openml_verify_checksum[False-pandas]" \
  --deselect "sklearn/covariance/tests/test_covariance.py" \
  --deselect "sklearn/covariance/tests/test_robust_covariance.py" \
  --deselect "sklearn/linear_model/tests/test_bayes.py::test_toy_ard_object" \
  --deselect "sklearn/linear_model/tests/test_bayes.py::test_ard_accuracy_on_easy_problem[42-10-100]" \
  --deselect "sklearn/linear_model/tests/test_bayes.py::test_ard_accuracy_on_easy_problem[42-100-10]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_estimators_dtypes]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_regressors_no_decision_function]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_methods_sample_order_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_methods_subset_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_dont_overwrite_parameters]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ARDRegression()-check_fit2d_predict1d]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[EllipticEnvelope()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[EmpiricalCovariance()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_methods_sample_order_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_methods_subset_invariance]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_dict_unchanged]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_dont_overwrite_parameters]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[FastICA()-check_fit2d_predict1d]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[KernelPCA()-check_fit2d_1sample]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[LedoitWolf()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[MinCovDet()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[OAS()-check_fit2d_1feature]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[RidgeCV()-check_fit2d_1sample]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[RidgeClassifierCV()-check_fit2d_1sample]" \
  --deselect "sklearn/tests/test_common.py::test_estimators[ShrunkCovariance()-check_fit2d_1feature]" \
  --deselect "sklearn/utils/tests/test_validation.py::test_check_is_fitted_with_attributes[list]" \
  --deselect "sklearn/utils/tests/test_validation.py::test_check_is_fitted" \
%ifarch ppc64le
  --deselect "sklearn/tests/test_calibration.py::test_calibrated_classifier_cv_zeros_sample_weights_equivalence[True-isotonic]" \
%endif
  sklearn
popd
%endif
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc examples/
%doc COPYING sklearn/svm/src/liblinear/COPYRIGHT
