# please check if atlas is enabled or not in numpy
# it's better to be in sync with numpy
# latest atlas (3.10.2) seems to not work correctly with scipy
%define enable_atlas 0

# allow pythran to be disabled in order allow bootstraping
# since pythran requires scipy
%bcond_with pythran

#(eatdirt) Requires a python-numpydoc which is currently broken
%define enable_doc 0

# disable test on build system to speed build
# but they where ok on local iurt build
%define enable_test 0

%define pypi_name	scipy

%define Werror_cflags %nil

%global _disable_ld_no_undefined 1

Summary:	Scientific tools for Python
Name:		python-%{pypi_name}
Group:		Development/Python
Version:	1.14.1
Release:	%mkrel 3
License:	BSD and Boost and Public Domain
Url:		https://pypi.org/project/scipy/
Source0:	%{pypi_source}

BuildRequires:	pyproject-rpm-macros
BuildRequires:	swig
BuildRequires:	patchelf
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif
BuildRequires:	lapack-devel
BuildRequires:	gcc-gfortran >= 4.0
BuildRequires:	pkgconfig(netcdf)
BuildRequires:	suitesparse-devel
%if %enable_doc
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(matplotlib)
BuildRequires:	python3dist(numpydoc)
%endif

BuildRequires:	pybind11-devel
BuildRequires:	python3-devel
BuildRequires:	python3-numpy-f2py
BuildRequires:	python3-numpy-devel >= 1.9.2
BuildRequires:	python3dist(pybind11) >= 2.4.0
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(cython)
BuildRequires:	python3dist(pythran)
BuildRequires:  python3dist(meson-python)

%description
SciPy is an open source library of scientific tools for Python. SciPy
supplements the popular numpy module, gathering a variety of high
level science and engineering modules together as a single
package. SciPy includes modules for graphics and plotting,
optimization, integration, special functions, signal and image
processing, genetic algorithms, ODE solvers, and others.

%package -n python3-scipy
Summary:	Scipy: Scientific Tools for Python
Group:		Development/Python
%{?python_provide:%python_provide python3-scipy}
Requires:	python3dist(numpy)
Requires:	python3-numpy-f2py

%description -n python3-scipy
Scipy is open-source software for mathematics, science, and
engineering. The core library is NumPy which provides convenient and
fast N-dimensional array manipulation. The SciPy library is built to
work with NumPy arrays, and provides many user-friendly and efficient
numerical routines such as routines for numerical integration and
optimization. Together, they run on all popular operating systems, are
quick to install, and are free of charge. NumPy and SciPy are easy to
use, but powerful enough to be depended upon by some of the world's
leading scientists and engineers.

%if %enable_doc
%package doc
Summary:	Documentation for scipy
Group:		Development/Python
BuildArch:	noarch

%description doc
This package contains documentation for Scipy
%endif

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%if %{without pythran}
# Remove pythran dependency if not explicitly required
sed -i '/pythran/d' pyproject.toml	
%else
# Relax it otherwise
sed -i 's/pythran>=0.12.0,<0.15.0/pythran>=0.12.0/' pyproject.toml	
%endif

cat > site.cfg << EOF
[amd]
library_dirs = %{_libdir}
include_dirs = %{_includedir}/suitesparse
amd_libs = amd

[umfpack]
library_dirs = %{_libdir}
include_dirs = %{_includedir}/suitesparse
umfpack_libs = umfpack
EOF

cat >> pyproject.toml << EOF

[tool.meson-python.args]
setup = ['-Dblas=blas', '-Dlapack=lapack'%{!?with_pythran:, '-Duse-pythran=false'}]
EOF

%generate_buildrequires
%pyproject_buildrequires -R

%build
# Include -fPIE into LDFLAGS to avoid build break with gfortran
LDFLAGS="${LDFLAGS} -fPIE" %pyproject_wheel

%install
%pyproject_install
%pyproject_save_files scipy

# Some files got ambiguous python shebangs, we fix them after everything else is done
%py3_shebang_fix %{buildroot}%{python3_sitearch}

# Remove doc files that should be in %%doc:
%__rm -f %{buildroot}%{python3_sitearch}/%{pypi_name}/*.txt

%if %enable_doc
pushd doc
PYTHONPATH=%{buildroot}%{python3_sitearch}:%{python3_sitearch}:%{python3_sitelib} %__make html
popd
%endif

%if %enable_test
%check
mkdir test
cd test
PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch} %{__python3} -c "import scipy; scipy.test('full')"
%endif

%files -n python3-scipy -f %{pyproject_files}
%doc LICENSE.txt

%if %enable_doc
%files doc
%doc doc/build/html/*
%endif
