%global srcname setuptools

#  WARNING  When bootstrapping, disable tests as well,
#           because tests need pip.
%bcond_with bootstrap

# Disabled for now as pytest-fixture-config is requires which is imcompatible with pytest >= 4.0.0
%bcond_with tests

%global python_wheel_name %{srcname}-%{version}-py3-none-any.whl

Summary:    Easily build and distribute Python packages
Name:       python-%{srcname}
Version:    78.1.0
Release:    %mkrel 1
License:    MIT
Group:      Development/Python
Url:        https://pypi.python.org/pypi/setuptools
Source0:    %{pypi_source %{srcname} %{version}}
Patch:      link-C-modules-with-libpython.patch

# Some test deps are optional and either not desired or not available in Fedora, thus this patch removes them.
Patch:          Remove-optional-or-unpackaged-test-deps.patch

# The `setup.py install` deprecation notice might be confusing for RPM packagers
# adjust it, but only when $RPM_BUILD_ROOT is set
Patch:          Adjust-the-setup.py-install-deprecation-message.patch

# setuptools rewrites all shebangs to "#!python" which breaks workflows
# where no external installers (usually rewriting this) are involved.
# https://github.com/pypa/setuptools/issues/4883
# - Resolution: deprecated functionality won't be fixed.
# brp-mangle-shebang script cannot mangle this and fails for many pkgs.
Patch:          Revert-Always-rewrite-a-Python-shebang-to-python.patch

BuildArch:  noarch

%description
A collection of enhancements to the Python distutils that allow
you to more easily build and distribute Python packages, especially
ones that have dependencies on other packages.

%package -n python3-%{srcname}
Summary:    Easily build and distribute Python3 packages
Group:      Development/Python

BuildRequires:  pkgconfig(python3)
%if %{with tests}
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(mock)
%endif
%if %{without bootstrap}
BuildRequires:  pyproject-rpm-macros >= 0-44
# Not to use the pre-generated egg-info, we use setuptools from previous build to generate it
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-wheel
%else
Provides:       python%{python3_pkgversion}dist(setuptools) = %{version}
Provides:	python%{python3_version}dist(setuptools) = %{version}
%endif

Provides:   python3-setuptools-devel = %{version}-%{release}
Obsoletes:  python3-setuptools-devel < 0.7

Provides:   python3-distribute = %{version}-%{release}
Obsoletes:  python3-distribute < 0.7
Conflicts:      python2-setuptools < %{version}-%{release}

Provides:   python3-pkg-resources = %{version}-%{release}
Obsoletes:  python3-pkg-resources < 59.8.0-2

%{?python_provide:%python_provide python3-%{srcname}}
%{?python_provide:%python_provide python3-pkg-resources}

%description -n python3-%{srcname}
A collection of enhancements to the Python 3 distutils that allow
you to more easily build and distribute Python 3 packages, especially
ones that have dependencies on other packages.

%if %{without bootstrap}
%package wheel
Summary:        The setuptools wheel

%description wheel
A Python wheel of setuptools to use with venv.
%endif


%prep
%autosetup -p1 -n %{srcname}-%{version}
%if %{without bootstrap}
# If we don't have setuptools installed yet, we use the pre-generated .egg-info
# See https://github.com/pypa/setuptools/pull/2543
# And https://github.com/pypa/setuptools/issues/2550
# WARNING: We cannot remove this folder since Python 3.11.1,
#          see https://github.com/pypa/setuptools/issues/3761
#rm -r %%{srcname}.egg-info
%endif

# Strip shbang
find setuptools pkg_resources -name \*.py | xargs sed -i -e '1 {/^#!\//d}'
# Remove bundled exes
rm -f setuptools/*.exe
# Don't ship these
rm -r docs/conf.py

%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires -r %{?with_tests:-x test}
%endif

%build
%if %{with bootstrap}
%py3_build
%else
%pyproject_wheel
%endif


%install
%if %{with bootstrap}
# The setup.py install command tries to import distutils
# but the distutils-precedence.pth file is not yet respected
# and Python 3.12+ no longer has distutils in the standard library.
ln -s setuptools/_distutils distutils
PYTHONPATH=$PWD:$PWD/setuptools/_vendor/ %py3_install
unlink distutils
%else
%pyproject_install
%pyproject_save_files setuptools pkg_resources _distutils_hack
%endif

# https://github.com/pypa/setuptools/issues/2709
find %{buildroot}%{python3_sitelib} -name tests -print0 | xargs -0 rm -r

%if %{without bootstrap}
sed -Ei '/\/tests\b/d' %{pyproject_files}

# Install the wheel for the python-setuptools-wheel package
mkdir -p %{buildroot}%{python_wheel_dir}
install -p %{_pyproject_wheeldir}/%{python_wheel_name} -t %{buildroot}%{python_wheel_dir}
%endif

%if %{with tests}
%check
# --ignore=pavement.py:
#   pavement.py is only used by upstream to do releases and vendoring, we don't ship it
PYTHONPATH=$(pwd) %pytest --ignore=setuptools/tests/test_integration.py --ignore=pavement.py
%endif


%files -n python3-setuptools %{?!with_bootstrap:-f %{pyproject_files}}
%license LICENSE
%doc docs/* NEWS.rst README.rst
%{python3_sitelib}/distutils-precedence.pth
%if %{with bootstrap}
%{python3_sitelib}/setuptools-%{version}-py%{python3_version}.egg-info/
%{python3_sitelib}/pkg_resources/
%{python3_sitelib}/setuptools/
%{python3_sitelib}/_distutils_hack/
%endif

%if %{without bootstrap}
%files wheel
%license LICENSE
# we own the dir for simplicity
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{python_wheel_name}
%endif
