%define pypi_name	sphinx

# disable these for bootstrapping nose and sphinx
%bcond_with check
%bcond_with doc

# some tests fails without internet, disable such
# tests by default
%bcond_with internet

Summary:	Python documentation generator
Name:		python-sphinx
Version:	8.2.3
Release:	%mkrel 1
License:	BSD
Group:		Development/Python
Url:		https://www.sphinx-doc.org
Source0:	%{pypi_source}
BuildArch:	noarch
BuildRequires:	locales-en
BuildRequires:	pyproject-rpm-macros

%description
Sphinx is a tool that facilitates the creation of beautiful
documentation for Python projects from reStructuredText sources. It
was originally created to format the new documentation for Python, but
has since been cleaned up in the hope that it will be useful in many
other projects.

%package -n python3-sphinx
Summary:	Python 3 documentation generator
Group:		Development/Python
Requires:	locales-en
Requires:	python3dist(sphinx-rtd-theme)
Provides:	sphinx-build = %{version}-%{release}
%{?python_provide:%python_provide python3-sphinx}
%{?python_provide:%python_provide python3-sphinx-locales}
Obsoletes:      python-sphinx-doc < 7.2.6-2

%description -n python3-sphinx
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires %{?with_check:-t -x test} %{?with_doc:-x docs}

%build
%pyproject_wheel

%if %{with doc}
PYTHONPATH=$PWD PYTHON=%{python3} make -C doc man html
rm -rf doc/_build/html/.buildinfo
%endif

%install
%pyproject_install

# For backwards compatibility. Remove around Mageia 10 (with care)
for i in sphinx-{apidoc,autogen,build,quickstart}; do
    ln -s %{_bindir}/$i %{buildroot}%{_bindir}/$i-%{python3_version}
    ln -s %{_bindir}/$i %{buildroot}%{_bindir}/$i-3
done

%if %{with doc}
# Man pages
for man in doc/_build/man/*.1; do
  install -Dpm644 $man %{buildroot}%{_mandir}/man1/$(basename $man)
done
%endif

# install locales to %%_datadir
pushd %{buildroot}%{python3_sitelib}/sphinx/locale/
  for i in */LC_MESSAGES; do
    lang=${i%*/LC_MESSAGES}
    # *.mo
    install -Dpm644 $i/sphinx.mo %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/sphinx.mo
    # *.js
    install -Dpm644 $i/sphinx.js %{buildroot}%{_datadir}/sphinx/locale/$lang/sphinx.js
    # remove unneeded
    rm -rf $lang/ .tx/ *.pot
  done
popd

%find_lang sphinx

# Language files; Since these are javascript, it's not immediately obvious to
# find_lang that they need to be marked with a language.
(cd %{buildroot} && find . -name 'sphinx.js') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.js$\):%lang(\2) \1\2\3:' \
  >> sphinx.lang

%if %{with check}
%check
# Currently, all linkcheck tests and test_latex_images need internet
# test_build_latex_doc needs internet to download pictures,
# but fails also with it enabled, we decided to skip it entirely
# test_autodoc_type_aliases fails with Python 3.12.4, 3.13.0b3
# skip temporarily until resolved:
# https://github.com/sphinx-doc/sphinx/issues/12430
k="not test_autodoc_type_aliases"
%if %{without internet}
k="${k} and not linkcheck and not test_latex_images and not test_build_latex_doc"
%endif

%pytest -k "${k}"
%endif

%files -n python3-sphinx -f sphinx.lang
%doc README.rst
%if %{with doc}
%doc doc/_build/html
%{_mandir}/man1/sphinx*.1*
%endif
%{_bindir}/sphinx-*
%{python3_sitelib}/sphinx/
%{python3_sitelib}/sphinx-%{version}.dist-info/
%dir %{_datadir}/sphinx/
%dir %{_datadir}/sphinx/locale/
%dir %{_datadir}/sphinx/locale/*/
