%define module		sympy

# Disable for now: https://github.com/sympy/sympy/issues/24306
%bcond_with check
%bcond_with docs

Summary:	Python library for symbolic mathematics
Name:		python-%{module}
Version:	1.13.3
Release:	%mkrel 4
License:	BSD
Group:		Development/Python
Url:		https://www.sympy.org/
Source0:	https://github.com/%{module}/%{module}/releases/download/%{version}/%{module}-%{version}.tar.gz

BuildArch:	noarch
BuildRequires:  python3-devel
BuildRequires:  python3dist(pytest)
BuildRequires:	graphviz

BuildRequires:	antlr4
BuildRequires:	python3dist(antlr4-python3-runtime)

# For docs
%if %{with docs}
BuildRequires:	python3-sphinx
BuildRequires:	python3-matplotlib
BuildRequires:	python3-sphinx-math-dollar
BuildRequires:	librsvg
BuildRequires:	imagemagick
BuildRequires:	texlive-dist
%endif
# for tests
BuildRequires:	x11-font-type1
BuildRequires:	x11-server-xvfb
BuildRequires:	locales-en

%description
SymPy is a Python library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python and does not require
any external libraries, except optionally for plotting support.

%package texmacs
Summary:	TeXmacs integration for sympy
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Requires:	texmacs

%description texmacs
This package contains a TeXmacs plugin for sympy.

%package examples
Summary:	Sympy examples
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}

%description examples
This package contains example input for sympy.

%if %{with docs}
%package doc
Summary:	Documentation for sympy
Group:		Development/Python

%description doc
man and HTML documentation for sympy.
%endif

%package -n python3-%{module}
Summary:	Python 3 library for symbolic mathematics
Group:		Development/Python
BuildRequires:	python3-mpmath
Requires:	python3-pyglet
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
SymPy is a Python 3 library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python 3 and does not require
any external libraries, except optionally for plotting support.

%prep
%autosetup -p1 -n sympy-%{version}

# Do not depend on env
for fil in $(grep -rl "^#\![[:blank:]]*%{_bindir}/env" .); do
  %py3_shebang_fix $fil
done

# Permit use of antlr4 4.13
sed -i s'/4\.11/4.13/g' sympy/parsing/autolev/_parse_autolev_antlr.py \
    sympy/parsing/latex/_parse_latex_antlr.py

%generate_buildrequires
%pyproject_buildrequires -x dev

%build
# Regenerate the ANTLR files
%{python3} setup.py antlr

# Build
%pyproject_wheel

# Build the documentation
%if %{with docs}
pushd doc
make html SPHINXOPTS=%{?_smp_mflags} PYTHON=%{python3}
make cheatsheet
popd
# leftovers
rm -rf doc/_build/html/.buildinfo
%endif

%install
%pyproject_install
%pyproject_save_files sympy isympy

# Remove extra files
rm -f %{buildroot}%{_bindir}/{,doc}test

# Install the TeXmacs integration
cp -p data/TeXmacs/bin/tm_sympy %{buildroot}%{_bindir}

# Don't let an executable script go into the documentation
chmod a-x examples/all.py

%if %{with docs}
# Install the HTML documentation
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
cp -a doc/_build/html %{buildroot}%{_docdir}/%{name}-doc
rm -fr %{buildroot}%{_docdir}/%{name}-doc/i18n
%endif

%if %{with check}
%check
# The python3 tests fail with Unicode errors without this
export LC_ALL=en_US.UTF-8
%{python3} setup.py test
%endif

%files texmacs
%doc data/TeXmacs/LICENSE
%{_bindir}/tm_sympy

%files examples
%doc examples/*

%if %{with docs}
%files doc
%docdir %{_docdir}/%{name}-doc/html
%{_docdir}/%{name}-doc/html
%endif

%files -n python3-%{module} -f %{pyproject_files}
%doc AUTHORS README.md
%license LICENSE
%{_mandir}/man1/isympy.1*
%{_bindir}/isympy
