%define pypi_name	tables

Summary: 	Hierarchical datasets in Python
Name: 	 	python-%{pypi_name}
Version: 	3.10.1
Release: 	%mkrel 2
License: 	BSD
Group: 	 	Development/Python
Url: 	 	https://pypi.org/project/tables
Source0: 	%{pypi_source}
BuildRequires:	pyproject-rpm-macros
BuildRequires:	hdf5-devel >= 1.12
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(lzo2)
BuildRequires:	pkgconfig(blosc)
BuildRequires:	pkgconfig(blosc2)

%description
PyTables is a Python package for managing hierarchical datasets
designed to efficiently and easily cope with extremely large amounts
of data. It is built on top of the HDF5 library and the NumPy package
(numarray and Numeric are also supported). PyTables features an
object-oriented interface and performance-critical extensions coded in
C (generated using Pyrex) that make it a fast yet extremely
easy-to-use tool for interactively processing and searching through
very large amounts of data. PyTables also optimizes memory and disk
resources so that data occupies much less space than with other
solutions such as relational or object-oriented databases (especially
when compression is used).

%package	doc
Group:		Development/Python
Summary:	Documentation for PyTables
BuildArch:	noarch

%description doc
The %{name}-doc package contains the documentation related to
PyTables.

%package -n python3-%{pypi_name}
Summary:        Hierarchical datasets in Python 3
Group:          Development/Python
Requires:	python3-numpy
Requires:	python3-numexpr
BuildRequires:	python3-numpy-devel
BuildRequires:	python3dist(numexpr)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(six)
BuildRequires:	python3dist(mock)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(cython)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(typing-extensions)

%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
PyTables is a Python 3 package for managing hierarchical datasets
designed to efficiently and easily cope with extremely large amounts
of data. It is built on top of the HDF5 library and the NumPy package
(numarray and Numeric are also supported). PyTables features an
object-oriented interface and performance-critical extensions coded in
C (generated using Pyrex) that make it a fast yet extremely
easy-to-use tool for interactively processing and searching through
very large amounts of data. PyTables also optimizes memory and disk
resources so that data occupies much less space than with other
solutions such as relational or object-oriented databases (especially
when compression is used).


%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Make sure we are not using anything from the bundled blosc by mistake
find c-blosc -mindepth 1 -maxdepth 1 -name hdf5 -prune -o -exec rm -r {} +

find utils -name 'pt*' | xargs sed -i '1s|^#!/usr/bin/env python|#!%{python3}|'

#generate_buildrequires
#pyproject_buildrequires

%build
export LIBS="dl m"
# Remove old c files and regenerate from cython
make distclean
%pyproject_wheel

%install
chmod -x examples/check_examples.sh
for i in utils/*; do sed -i 's|bin/env |bin/|' $i; done

%pyproject_install
%pyproject_save_files tables

%check
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir
echo "import tables; tables.test()" > bench/check_all.py
%{python3} bench/check_all.py

%files doc
%doc examples/
%doc doc/source/

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst LICENSES
%{_bindir}/pt2to3
%{_bindir}/ptdump
%{_bindir}/ptrepack
%{_bindir}/pttree

