%global pypi_name tifffile

Name:           python-%{pypi_name}
Version:        2025.3.30
Release:        %mkrel 1
Summary:        Read and write TIFF(r) files
Group:          Development/Python
License:        BSD
URL:            https://www.lfd.uci.edu/~gohlke/
Source0:        %{pypi_source}

BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(pytest)

%description
Tifffile is a Python library to:
 * store numpy arrays in TIFF (Tagged Image File Format) files, and
 * read image and metadata from TIFF-like files used in bioimaging.

%package -n python3-%{pypi_name}
Summary:        Read and write TIFF(r) files
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
Tifffile is a Python library to:
 * store numpy arrays in TIFF (Tagged Image File Format) files, and
 * read image and metadata from TIFF-like files used in bioimaging.

%prep
%autosetup -n %{pypi_name}-%{version}

sed -i -e "1d" tifffile/lsm2bin.py
sed -i 's/\r$//' README.rst

%generate_buildrequires
%pyproject_buildrequires -x tests

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS='-p no:cacheprovider'
export PYTHONPATH="${PYTHONPATH:-%{buildroot}%{python3_sitearch}:%{buildroot}%{python3_sitelib}}"
# 7 tests fail out of 1000
# these tests require network or additional packages not in Fedora
pytest-%{python3_version} -v tests \
 --deselect=tests/test_tifffile.py::test_issue_infinite_loop \
 --deselect=tests/test_tifffile.py::test_issue_jpeg_ia \
 --deselect=tests/test_tifffile.py::test_func_pformat_xml \
 --deselect=tests/test_tifffile.py::test_filehandle_seekable \
 --deselect=tests/test_tifffile.py::test_read_cfa \
 --deselect=tests/test_tifffile.py::test_read_tiles \
 --deselect=tests/test_tifffile.py::test_write_cfa \
 --deselect=tests/test_tifffile.py::test_write_volume_png \
 --deselect=tests/test_tifffile.py::test_class_omexml \
 --deselect=tests/test_tifffile.py::test_write_ome \
 --deselect=tests/test_tifffile.py::test_write_3gb \
 --deselect=tests/test_tifffile.py::test_write_bigtiff \
 --deselect=tests/test_tifffile.py::test_write_imagej_raw \
 --deselect=tests/test_tifffile.py::test_issue_trucated_tileoffsets \
 --deselect=tests/test_tifffile.py::test_write_6gb \
 --deselect=tests/test_tifffile.py::test_write_5GB_fails \
 --deselect=tests/test_tifffile.py::test_write_5GB_bigtiff
# deselect the last three because they use large amounts of memory and time

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%{_bindir}/lsm2bin
%{_bindir}/tiffcomment
%{_bindir}/tifffile
%{_bindir}/tiff2fsspec
