# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

%global pypi_name tox

Name:           python-tox
Version:        4.24.1
Release:        %mkrel 1
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python

# file toxbootstrap.py is licensed under MIT License
License:        GPLv2+ and MIT
URL:            https://pypi.org/project/tox/
Source0:        %{pypi_source}
# Remove dependency on devpi-process.
# Remove dependency on detect-test-pollution.
# Remove coverage-related dependencies.
# Adjust virtualenv environment variables to make it work with our patched virtualenv.
Patch:          fix-tests.patch
BuildArch:      noarch
BuildRequires:  python3-devel

%description
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%package -n python3-%{pypi_name}
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:	python3-py
Requires:	python3-pluggy
# python3-virtualenv is rhbz#537246
Requires:	python3-virtualenv

%description -n python3-%{pypi_name}
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Upstream updates dependencies too aggressively
# see https://github.com/tox-dev/tox/pull/2843#discussion_r1065028356
sed -ri -e 's/"(packaging|filelock|platformdirs|psutil|diff-cover|pyproject-api|pytest|pytest-mock|pytest-xdist|wheel|pluggy|distlib|cachetools)>=.*/"\1",/g' \
        -e "s/'(time-machine)>=[^;']+/'\1/" \
        -e 's/"(virtualenv)>=.*/"\1>=20",/g' \
        -e 's/"(hatchling)>=.*/"\1>=1.13",/g' \
    pyproject.toml

%generate_buildrequires
export SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
%pyproject_buildrequires

%build
export SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

# if internet connection available, run tests
%if %{with internet}
%check
%tox
%endif

%files -n python3-tox -f %{pyproject_files}
%license LICENSE
%{_bindir}/%{pypi_name}
