# what it's called on pypi
%global pypi_name trio
# what it's imported as
%global libname %{pypi_name}
# name of egg info directory
%global eggname %{pypi_name}
# package name fragment
%global pkgname %{pypi_name}

%global common_description %{expand:
The Trio project's goal is to produce a production-quality, permissively
licensed, async/await-native I/O library for Python.  Like all async libraries,
its main purpose is to help you write programs that do multiple things at the
same time with parallelized I/O.  A web spider that wants to fetch lots of
pages in parallel, a web server that needs to juggle lots of downloads and
websocket connections at the same time, a process supervisor monitoring
multiple subprocesses... that sort of thing.  Compared to other libraries, Trio
attempts to distinguish itself with an obsessive focus on usability and
correctness.  Concurrency is complicated; we try to make it easy to get things
right.}

%bcond_with  tests

Name:       python-%{pkgname}
Version:    0.28.0
Release:    %mkrel 2
Summary:    A friendly Python library for async concurrency and I/O
License:    MIT or ASL 2.0
Group:      Development/Python
URL:        https://pypi.org/project/trio/
Source0:    %{pypi_source}
BuildArch:  noarch


%description %{common_description}


%package -n python3-%{pkgname}
Summary:        %{summary}
Group:      Development/Python
BuildRequires: pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(setuptools)
%if %{with tests}
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pyopenssl)
BuildRequires:  python3dist(trustme)
BuildRequires:  python3dist(attrs)
BuildRequires:  python3dist(sortedcontainers)
BuildRequires:  python3dist(async-generator)
BuildRequires:  python3dist(idna)
BuildRequires:  python3dist(outcome)
BuildRequires:  python3dist(sniffio)
%endif
%{?python_provide:%python_provide python3-%{pkgname}}


%description -n python3-%{pkgname} %{common_description}


%prep
%autosetup -n %{pypi_name}-%{version} -p 1


%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files trio


%if %{with tests}
%check
%pytest --verbose trio/_core/tests
%endif


%files -n python3-%{pkgname} -f %{pyproject_files}
%license LICENSE LICENSE.MIT LICENSE.APACHE2
%doc README.rst

