%define pypi_name twisted

# comment out if not pre rel
#%%define prerel rc1

%global tarball_version %%(tr -d '~' <<< %{version})

Name:           python-twisted
Version:        24.11.0
Release:        %mkrel 1
Summary:        Event-based framework for internet applications
License:        MIT
Group:          Development/Python
URL:            https://www.twistedmatrix.com/
Source0:        %{pypi_source %{pypi_name} %{tarball_version}}
BuildArch:      noarch
BuildRequires:  python3-cython
BuildRequires:  pkgconfig(python3)

%description
Twisted is a framework, written in Python, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%package -n python3-twisted
Summary:        Python3 event-based framework for internet applications
Group:          Development/Python
%{?python_provide:%python_provide python3-twisted}
Recommends:     python3dist(pyopenssl)
Recommends:     python3dist(service-identity)
Recommends:     python3dist(idna)
Recommends:     python3dist(pyasn1)
Recommends:     python3dist(cryptography)
Recommends:     python3dist(pyserial)

%{?python_extras_subpkg:Recommends:  python3-twisted+tls}
%{!?python_extras_subpkg:Recommends: python3dist(service-identity) >= 18.1}

%description -n python3-twisted
Twisted is a framework, written in Python3, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%{?python_extras_subpkg:%python_extras_subpkg -n python3-twisted -i %{python3_sitelib}/*.dist-info tls}

%prep
%autosetup -n %{pypi_name}-%{tarball_version} -p1

# drop bundled egg-info
rm -rf src/*.egg-info/

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
# no-manual-page-for-binary
mkdir -p %{buildroot}%{_mandir}/man1/
for s in conch core mail; do
cp -a docs/$s/man/*.1 %{buildroot}%{_mandir}/man1/
done

%pyproject_install
# Packages that install arch-independent twisted plugins install here.
# https://bugzilla.redhat.com/show_bug.cgi?id=1252140
mkdir -p %{buildroot}%{python3_sitelib}/twisted/plugins

# Move and symlink python3 scripts
# no-manual-page-for-binary: man page is trial and twistd
mv %{buildroot}%{_bindir}/trial %{buildroot}%{_bindir}/trial-%{python3_version}
ln -s ./trial-%{python3_version} %{buildroot}%{_bindir}/trial-3
ln -s ./trial-%{python3_version} %{buildroot}%{_bindir}/trial

mv %{buildroot}%{_bindir}/twistd %{buildroot}%{_bindir}/twistd-%{python3_version}
ln -s ./twistd-%{python3_version} %{buildroot}%{_bindir}/twistd-3
ln -s ./twistd-%{python3_version} %{buildroot}%{_bindir}/twistd

%pyproject_save_files twisted
echo "%ghost %{python3_sitelib}/twisted/plugins/dropin.cache" >> %{pyproject_files}

%check
# can't get this to work within the buildroot yet due to multicast
# https://twistedmatrix.com/trac/ticket/7494
#PATH=%{buildroot}%{_bindir}:$PATH PYTHONPATH=%{buildroot}%{python3_sitelib} %{buildroot}%{_bindir}/trial twisted ||:

%files -n python3-twisted -f %{pyproject_files}
%doc NEWS.rst README.rst
%license LICENSE
%{_bindir}/trial-3*
%{_bindir}/twistd-3*
%{_bindir}/cftp
%{_bindir}/ckeygen
%{_bindir}/conch
%{_bindir}/mailmail
%{_bindir}/pyhtmlizer
%{_bindir}/tkconch
%{_bindir}/trial
%{_bindir}/twist
%{_bindir}/twistd
%{_mandir}/man1/cftp.1*
%{_mandir}/man1/ckeygen.1*
%{_mandir}/man1/conch.1*
%{_mandir}/man1/mailmail.1*
%{_mandir}/man1/pyhtmlizer.1*
%{_mandir}/man1/tkconch.1*
%{_mandir}/man1/trial.1*
%{_mandir}/man1/twistd.1*
