%define pypi_name	virtualenv
# docs need sphinx >= 3
# docs need towncrier and that is not yet available when bootstrapping Python
%bcond_with docs

Name:		python-%{pypi_name}
Version:	20.29.2
Release:	%mkrel 1
Summary:	Virtual Python Environment builder
Group:		Development/Python
License:        MIT
URL:            https://pypi.org/project/virtualenv
Source0:        %{pypi_source}

# Add /usr/share/python-wheels to extra_search_dir
Patch1:         rpm-wheels.patch

BuildArch:	noarch
BuildRequires:	python3-devel

%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(towncrier)
%endif

# RPM installed wheels
BuildRequires:	python-pip-wheel
BuildRequires:	python-setuptools-wheel
BuildRequires:	python-wheel-wheel

%description
virtualenv is a tool to create isolated Python environments.

%package -n	python3-%{pypi_name}
Summary:	Tool to create isolated Python 3 environments
Group:		Development/Python
Requires:	python3-devel
%{?python_provide:%python_provide python3-virtualenv}
Provides:	virtualenv = %{version}-%{release}

# RPM installed wheels
Requires:	python-pip-wheel
Requires:	python-setuptools-wheel
Requires:	python-wheel-wheel

%description -n python3-%{pypi_name}
virtualenv is a tool to create isolated Python 3 environments. virtualenv
is a successor to workingenv, and an extension of virtual-python. It is
written by Ian Bicking, and sponsored by the Open Planning Project. It is
licensed under an MIT-style permissive license

%if %{with docs}
%package -n     python-virtualenv-doc
Summary:    Documentation for python virtualenv
Group:		Development/Python

%description -n python-virtualenv-doc
Documentation for python virtualenv.
%endif

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Remove the wheels provided by RPM packages
rm src/virtualenv/seed/wheels/embed/pip-*
rm src/virtualenv/seed/wheels/embed/setuptools-*
rm src/virtualenv/seed/wheels/embed/wheel-*

test ! -f src/virtualenv/seed/embed/wheels/*.whl

# Replace hardcoded path from rpm-wheels.patch by %%{python_wheel_dir}
# On Fedora, this should change nothing, but when building for RHEL9+, it will
sed -i "s|/usr/share/python-wheels|%{python_wheel_dir}|" src/virtualenv/util/path/_system_wheels.py

# Allow platformdirs version 4
# Backported from release 20.24.7
# https://github.com/pypa/virtualenv/commit/55650340d9c9415bf035596266f245a8d59c6993
#sed -i "s/platformdirs<4/platformdirs<5/" pyproject.toml

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if %{with docs}
PYTHONPATH=src %{python3} setup.py build_sphinx
rm -f build/sphinx/html/.buildinfo
%endif

%install
%pyproject_install
%pyproject_save_files virtualenv

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc LICENSE
%doc README.md
%{_bindir}/virtualenv

%if %{with docs}
%files -n python-virtualenv-doc
%doc build/sphinx/*
%endif
