# Patching guideline for python :
# - no big patch with invasive change not
#     approved by upstream ( ie not coming from upstream svn )
# - small bugfix must be sent to upstream and approved if they
#     change any interface
# - all patchs should be commented ( unless for security,
#     as they are usually easy to spot )

%define docver  2.7.18
%define dirver  2.7

%define pybasever	%{dirver}

%define lib_major       %{dirver}
%define lib_name_orig   libpython
%define lib_name        %mklibname %{name} %{lib_major}
%define dev_name        %mklibname %{name} -d

%define arch_has_valgrind 1
%ifarch %arm %mips aarch64
%define arch_has_valgrind 0
%endif

%if %arch_has_valgrind
%bcond_without  valgrind
%else
%bcond_with     valgrind
%endif

%bcond_with tkinter

# Whether to use RPM build wheels from the python-{pip,setuptools}-wheel package
# Uses upstream bundled prebuilt wheels otherwise
# setuptools >= 45.0 no longer support Python 2.7, hence disabled
%bcond_with rpmwheels

# Some defines to ease files list
%define pylibdir %{_libdir}/python%{dirver}
%define dynload_dir %{pylibdir}/lib-dynload
%define site_packages %{pylibdir}/site-packages

# Some of the files below /usr/lib/pythonMAJOR.MINOR/test  (e.g. bad_coding.py)
# are deliberately invalid, leading to SyntaxError exceptions if they get
# byte-compiled.
#
# These errors are ignored by the normal python build, and aren't normally a
# problem in the buildroots since /usr/bin/python isn't present.
#
# So we disable here brp-python-bytecompile
#
%global __brp_python_bytecompile %nil

%define __python %{__python2}


Summary:        An interpreted, interactive object-oriented programming language
Name:           python
Version:        2.7.18
Release:        %mkrel 18
License:        Modified CNRI Open Source License
Group:          Development/Python
Url:            https://www.python.org/

Source0:        https://www.python.org/ftp/python/%{version}/Python-%{version}.tar.xz
Source1:        https://www.python.org/ftp/python/doc/%{docver}/python-%{docver}-docs-html.tar.bz2

Patch0:         python-2.7.14-module-linkage.patch

# Don't include /usr/local/* in search path
Patch3:         python-2.7.12-no-local-incpath.patch

# Support */lib64 convention on x86_64, sparc64, etc.
# similar patches reported upstream on http://bugs.python.org/issue1294959
Patch4:         python-lib64.patch

# add mandriva to the list of supported distribution, applied upstream
Patch10:        python-2.7.12-detect-mandriva.patch

# Backport upstream commit
# https://github.com/python/cpython/commit/3f135c073a53793ec68902f6b513934ddff47235
Patch13:	0001-bpo-44734-Fix-precision-in-turtle-tests.patch

# More precision fixes
Patch14:	0002-More-floating-point-precision-fixes-for-turtle-tests.patch

# From Fedora
# Fixup distutils/unixccompiler.py to remove standard library path from rpath
Patch15: python-2.6.4-distutils-rpath.patch

# from Fedora, fixes gettext.py parsing of Plural-Forms: header (fixes mdv bugs #49475, #44088)
# to send upstream
Patch16:        python-2.7.14-plural-fix.patch

# ffi checks for MIPS_LINUX instead of MIPS
Patch23:        python-2.7.12-mips-ffi.patch

# do not use uname -m to get the exact name on mips/arm
Patch24:        python_arch.patch

# fix https://bugs.mageia.org/show_bug.cgi?id=481
# mdv bug #62281
# patch to cope with lack of /dev/shm in iurt
Patch25:        python-2.7.14-skip-shm-test.patch

Patch130:       python-2.7.14-check-for-XML_SetHashSalt.patch

# 00189 #
# Instead of bundled wheels, use our RPM packaged wheels from
# /usr/share/python-wheels
Patch189:       00189-use-rpm-wheels.patch

# Enable loading sqlite extensions. This patch isn't needed for
# python3.spec, since Python 3 has a configuration option for this.
# rhbz#1066708
# Patch provided by John C. Peterson
# Note (05/12/2017): this patch added in rev. 666153 (21/08/2014) - but never applied up to now
Patch193:       00193-enable-loading-sqlite-extensions.patch

# (tv) make platform supports Mageia:
Patch200:       add-mga-support.patch

# Improve documentation warning against the possible zip bombs
Patch350:       CVE-2019-9674-zip-bomb.patch
# 00351 #
# Avoid infinite loop when reading specially crafted TAR files using the tarfile module
# (CVE-2019-20907).
# See: https://bugs.python.org/issue39017
Patch351:       00351-cve-2019-20907-fix-infinite-loop-in-tarfile.patch
# Fixes Python urrlib allowed an HTTP server to conduct Regular
# Expression Denial of Service (ReDoS)
Patch352:       CVE-2020-8492-urllib-ReDoS.patch
# explain that the orderness of the of the result is system-dependant in Doc/library/glob.rst
Patch353:       CVE-2019-17514.patch
# 00354 # 9e9d2c6106446ad107ca1bb6729883c76fefc6eb
# Reject control chars in HTTP method in httplib.putrequest to prevent
# HTTP header injection
#
# Backported from Python 3.5-3.10 (and adjusted for py2's single-module httplib):
# - https://bugs.python.org/issue39603
# - https://github.com/python/cpython/pull/18485 (3.10)
# - https://github.com/python/cpython/pull/21946 (3.5)
#
# Co-authored-by: AMIR <31338382+amiremohamadi@users.noreply.github.com>
Patch354:       00354-cve-2020-26116-http-request-method-crlf-injection-in-httplib.patch

# 00355 # fde656e7116767a761720970ee750ecda6774e71
# No longer call eval() on content received via HTTP in the CJK codec tests
# Backported from the python3 branches upstream: https://bugs.python.org/issue41944
# Resolves: https://bugzilla.redhat.com/show_bug.cgi?id=1889886
Patch355:       00355-CVE-2020-27619.patch

Patch366:	00366-CVE-2021-3733.patch
Patch368:	00368-CVE-2021-3737.patch
Patch372:	00372-CVE-2021-4189.patch
Patch377:	00377-CVE-2022-0391.patch

# 00382 # 65796028be4b28aaf027963d6fb2ef4c219e73dc
# Make mailcap refuse to match unsafe filenames/types/params (GH-91993)
#
# Upstream: https://github.com/python/cpython/issues/68966
#
# Tracker bug: https://bugzilla.redhat.com/show_bug.cgi?id=2075390
#
# Backported from python3.
Patch382: 00382-cve-2015-20107.patch

Patch500:       CVE-2017-18207.patch
# CVE-2021-3177: Replace snprintf with Python unicode formatting in ctypes param reprs
#
# Backport of Python3 commit 916610ef90a0d0761f08747f7b0905541f0977c7:
# https://bugs.python.org/issue42938
# https://github.com/python/cpython/pull/24239
Patch501:	CVE-2021-3177.patch
Patch502:	CVE-2021-23336-only-amp-as-query-sep.patch
Patch503:	CVE-2021-28861-double-slash-path.patch
Patch504:	CVE-2022-45061-DoS-by-IDNA-decode.patch
Patch505:	CVE-2022-48565-plistlib-XML-vulns.patch
Patch506:	CVE-2022-48566-compare_digest-more-constant.patch
Patch507:	CVE-2023-24329-blank-URL-bypass.patch
Patch508:	CVE-2023-40217-avoid-ssl-pre-close.patch
Patch509:	0001-3.9-gh-109858-Protect-zipfile-from-quoted-overlap-zi.patch

Conflicts:      tkinter < %{version}
Conflicts:      python-devel < 2.7-6
Requires:       %{lib_name} = %{version}-%{release}
BuildRequires:  blt
BuildRequires:  db5-devel
BuildRequires:  emacs-bin
BuildRequires:  git-core
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  gdbm-devel
BuildRequires:  gmp-devel
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  readline-devel
BuildRequires:  termcap-devel
%if %{with tkinter}
BuildRequires:  pkgconfig(tk)
%endif
BuildRequires:  tix
BuildRequires:  autoconf2.5
BuildRequires:  bzip2-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  emacs
%if %{with valgrind}
BuildRequires:  pkgconfig(valgrind)
%endif
%if %{with rpmwheels}
BuildRequires:  python-setuptools-wheel
BuildRequires:  python-pip-wheel
%endif
#BuildRequires:  python2
BuildRequires:	pkgconfig(libnsl)
BuildRequires:	pkgconfig(libtirpc)

# (2010/03/21, misc: interfere with test__all )
BuildConflicts: python-pyxml

Provides:       python(abi) = %dirver
Provides:	/usr/bin/python2
Provides:	/usr/bin/python%{dirver}
%rename python-ctypes
%rename python-elementtree
Obsoletes:      python-base < 2.6
Provides:       python-base = %version
Requires:       python2-rpm-macros
Provides:       python2 = %version-%{release}

# Previously, this was required for our rewheel patch to work.
# This is technically no longer needed, but we keep it recommended
# for the developer experience.
Recommends:     python2-setuptools
Recommends:     python2-pip

%if ! %{with tkinter}
Obsoletes:	tkinter < %{version}-%{release}
Obsoletes:	tkinter-apps < %{version}-%{release}
%endif

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.


%package -n     %{lib_name}
Summary:        Shared libraries for Python %{version}
Group:          System/Libraries
Requires:       %{lib_name}-stdlib = %{version}-%{release}

%description -n %{lib_name}
This packages contains Python shared object library.  Python is an
interpreted, interactive, object-oriented programming language often
compared to Tcl, Perl, Scheme or Java.

%package -n     %{lib_name}-stdlib
Summary:        Python %{version} standard library
Group:          Development/Python
%if %{with rpmwheels}
Requires:       python-setuptools-wheel
Requires:       python-pip-wheel
%else
Provides:       bundled(python2-pip) = 19.2.3
Provides:       bundled(python2-setuptools) = 41.2.0
%endif
# both main and -stdlib provides python(abi) == 2.7 so make sure main pkg is
# installed: /usr/bin/python2: bad interpreter: No such file or directory (mga#24573)
Requires:       python2 = %{version}-%{release}
Conflicts:      python < 2.7.11-10
Conflicts:      %{dev_name} < 2.7.11-10

%description -n %{lib_name}-stdlib
This package contains Python 2.7's standard library.
It is normally not used on its own, but as a dependency of Python %{version}. 


%package -n     %{lib_name}-testsuite
Summary:        Testsuite for the Python %{version} standard library
Group:          Development/Python
Conflicts:      python < 2.7.11-10
Conflicts:      %{dev_name} < 2.7.11-10
Requires:       %{lib_name}-stdlib = %{version}-%{release}
Requires:       %{lib_name} = %{version}-%{release}
%if %{with tkinter}
Recommends:     tkinter
%endif
Provides:       python2-testsuite = %{version}-%{release}

%description -n %{lib_name}-testsuite
The complete testsuite for the Python standard library.
It is normally not used on its own, but as a dependency of Python %{version}. 


%package -n     %{dev_name}
Summary:        The libraries and header files needed for Python development
Group:          Development/Python
Requires:       %{name} = %version
Requires:       %{lib_name} = %{version}-%{release}
Requires:       python-rpm-macros
Requires:       python2-rpm-macros
Provides:       %{name}-devel = %{version}-%{release}
Provides:       python2-devel = %{version}-%{release}
Provides:       %{lib_name_orig}-devel = %{version}-%{release}
Recommends:     %{lib_name}-testsuite
Recommends:     python-docs

%description -n %{dev_name}
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install %{dev_name} if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.


%package        docs
Summary:        Documentation for the Python programming language
Group:          Development/Python
Requires:       python2 = %version
Requires:       xdg-utils
BuildArch:      noarch

%description    docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%if %{with tkinter}
%package -n     tkinter
Summary:        A graphical user interface for the Python scripting language
Group:          Development/Python
Requires:       python2 = %version
Requires:       tcl tk
Provides:       python2-tkinter
Conflicts:      python < 2.7.11-10

%description -n tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.


%package -n     tkinter-apps
Summary:        Various applications written using tkinter
Group:          Development/Python
Requires:       tkinter

%description -n tkinter-apps
Various applications written using tkinter.
%endif


%prep
%setup -q -n Python-%{version}
%patch -P0 -p1
# local include
%patch -P3 -p1
# lib64
%patch -P4 -p1

# add mandriva to the list of supported distribution
%patch -P10 -p1

%patch -P13 -p1
%ifarch %ix86
%patch -P14 -p1
%endif
%patch -P15 -p1
%patch -P16 -p1
%patch -P23 -p1
%patch -P24 -p1
%patch -P25 -p1
%patch -P130 -p1
%if %{with rpmwheels}
%patch -P189 -p1
rm Lib/ensurepip/_bundled/*.whl
%endif
%patch -P193 -p1

%patch -P200 -p1
%patch -P350 -p1
# Patch 351 adds binary file for testing. We need to apply it using Git.
git apply %{PATCH351}
%patch -P352 -p1
%patch -P353 -p1
%patch -P354 -p1
%patch -P355 -p1
%patch -P366 -p1
%patch -P368 -p1
%patch -P372 -p1
%patch -P377 -p1
%patch -P382 -p1
%patch -P500 -p1
%patch -P501 -p1
%patch -P502 -p1
%patch -P503 -p1
%patch -P504 -p1
%patch -P505 -p1
%patch -P506 -p1
%patch -P507 -p1
%patch -P508 -p1
%patch -P509 -p1

# drop Autoconf version requirement
sed -i 's/^AC_PREREQ/dnl AC_PREREQ/' configure.ac

# docs
mkdir html
bzcat %{SOURCE1} | tar x  -C html
find html -type d |xargs chmod 755
find html -type f |xargs chmod 644

find . -type f -print0 | xargs -0 perl -p -i -e 's@/usr/local/bin/python@/usr/bin/python@'

cat > README.mga << EOF
Python interpreter support readline completion by default.
This is only used with the interpreter. In order to remove it,
you can :
1) unset PYTHONSTARTUP when you login
2) create a empty file \$HOME/.pythonrc.py
3) change %{_sysconfdir}/pythonrc.py
EOF

# make sur the IN.py TYPES.py and DLFCN.py are correct
# for current arch otherwise things will start failing
# in weird ways
%if 0
pushd Lib/plat-linux2/
%{__python2} ../../Tools/scripts/h2py.py -i '(u_long)' /usr/include/sys/types.h /usr/include/netinet/in.h /usr/include/dlfcn.h
popd
%endif

%build
autoreconf -fi

rm -f Modules/Setup.local
cat > Modules/Setup.local << EOF
linuxaudiodev linuxaudiodev.c
EOF

# We need -fwrapv
# https://bugs.python.org/issue34096
export OPT="%{optflags} -D_GNU_SOURCE -fPIC -fwrapv"
export CFLAGS="%{optflags} -D_GNU_SOURCE -fPIC -fwrapv"
export CXXFLAGS="%{optflags} -D_GNU_SOURCE -fPIC -fwrapv"

# to fix curses module build
# https://bugs.mageia.org/show_bug.cgi?id=5524
export CPPFLAGS="-I/usr/include/ncursesw"

autoreconf -vfi
# Remove -Wl,--no-undefined in accordance with MGA #9395 and MGA #10102:
# https://bugs.mageia.org/show_bug.cgi?id=9395
# https://bugs.mageia.org/show_bug.cgi?id=10102
%define _disable_ld_no_undefined 1

# see https://qa.mandriva.com/show_bug.cgi?id=48570
# for wide unicode support
%configure  --with-threads \
        --enable-unicode=ucs4 \
        --with-dbmliborder=gdbm \
        --enable-ipv6 \
        --enable-shared \
        --with-system-expat \
        --with-system-ffi \
%if %{with valgrind}
        --with-valgrind
%endif

# (misc) if the home is nfs mounted, rmdir fails due to delay
export TMP="/tmp" TMPDIR="/tmp"
make

%check
# (misc) if the home is nfs mounted, rmdir fails
export TMP="/tmp" TMPDIR="/tmp"

# all tests must pass
CUSTOM_TEST=""
%ifarch %arm
# don't know if it's a python issue or a toolchain issue :(
# test test_float failed -- Traceback (most recent call last):
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 665, in test_from_hex
#    self.identical(fromHex('0x0.ffffffffffffd6p-1022'), MIN-3*TINY)
#  File "/home/rtp/deb/python2.6-2.6.4/Lib/test/test_float.py", line 375, in identical
#    self.fail('%r not identical to %r' % (x, y))
# AssertionError: 2.2250738585071999e-308 not identical to 2.2250738585071984e-308
CUSTOM_TEST="$CUSTOM_TEST test_float test_cmath"
%endif

%ifarch aarch64
CUSTOM_TEST="$CUSTOM_TEST test_ctypes"
%endif

# tests failing
CUSTOM_TEST="$CUSTOM_TEST test_distutils test_ftplib test_minidom test_urllib2_localnet test_xml_etree test_xml_etree_c"

# if a test doesn't pass, it can be disabled with -x test, but this should be documented in the
# spec file, and a bug should be reported if possible ( on python side )
# (misc, 29/10/2010) "test_site" fail due to one of our patch, will fix later
# (05/12/2017) "test_tuple" fails on i586 only, no crash though
# (01/05/2018) "test_ssl" fails on BS "UnicodeEncodeError"
WITHIN_PYTHON_RPM_BUILD= make test TESTOPTS="-w -l -x test_ssl test_site test_tuple $CUSTOM_TEST"

%install
mkdir -p %{buildroot}%{_prefix}/lib/python%{dirver}

%if "%{_lib}" == "lib64"
mkdir -p %{buildroot}%{_prefix}/lib/python%{dirver}/site-packages
%endif

# fix Makefile to get rid of reference to distcc
perl -pi -e "/^CC=/ and s/distcc/gcc/" Makefile

# set the install path
echo '[install_scripts]' >setup.cfg
echo 'install_dir='"%{buildroot}/usr/bin" >>setup.cfg

# python is not GNU and does not know fsstd
mkdir -p %{buildroot}%{_mandir}
%make_install

(cd %{buildroot}%{_libdir}; ln -sf libpython%{lib_major}.so.* libpython%{lib_major}.so)

# Provide a libpython%{dirver}.so symlink in /usr/lib/puthon*/config, so that
# the shared library could be found when -L/usr/lib/python*/config is specified
(cd %{buildroot}%{_libdir}/python%{dirver}/config; ln -sf ../../libpython%{lib_major}.so .)

#"  this comment is just here because vim syntax higlighting is confused by the previous snippet of lisp

# smtpd proxy
mv -f %{buildroot}%{_bindir}/smtpd.py $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/

%if %{with tkinter}
# pynche
cat << EOF > %{buildroot}%{_bindir}/pynche
#!/bin/bash
exec %{_libdir}/python%{dirver}/site-packages/pynche/pynche
EOF
rm -f Tools/pynche/*.pyw
cp -r Tools/pynche %{buildroot}%{_libdir}/python%{dirver}/site-packages/

chmod 755 %{buildroot}%{_bindir}/pynche

ln -f Tools/pynche/README Tools/pynche/README.pynche
%endif

%if %{with valgrind}
install Misc/valgrind-python.supp -D %{buildroot}%{_libdir}/valgrind/valgrind-python.supp
%endif

%if %{with tkinter}
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-tkinter.desktop << EOF
[Desktop Entry]
Name=IDLE
Comment=IDE for Python
Exec=%{_bindir}/idle
Icon=development_environment_section
Terminal=false
Type=Application
Categories=Development;IDE;
EOF
%endif

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop << EOF
[Desktop Entry]
Name=Python documentation
Comment=Python complete reference
Exec=%{_bindir}/xdg-open %_defaultdocdir/%{name}-docs/index.html
Icon=documentation_section
Terminal=false
Type=Application
Categories=Documentation;
EOF


# fix non real scripts
chmod 644 %{buildroot}%{_libdir}/python*/test/test_{binascii,grp,htmlparser}.py*
# fix python library not stripped
chmod u+w %{buildroot}%{_libdir}/libpython%{lib_major}.so.1.0


mkdir -p %{buildroot}%{_sysconfdir}/profile.d/

cat > %{buildroot}%{_sysconfdir}/profile.d/30python2.sh << 'EOF'
if [ -f $HOME/.pythonrc.py ] ; then
        export PYTHONSTARTUP=$HOME/.pythonrc.py
else
        export PYTHONSTARTUP=/etc/pythonrc.py
fi
EOF

cat > %{buildroot}%{_sysconfdir}/profile.d/30python2.csh << 'EOF'
if ( -f ${HOME}/.pythonrc.py ) then
        setenv PYTHONSTARTUP ${HOME}/.pythonrc.py
else
        setenv PYTHONSTARTUP /etc/pythonrc.py
endif
EOF

cat > %{buildroot}%{_sysconfdir}/pythonrc.py << EOF
try:
    get_ipython()
except:
    try:
        # this add completion to python interpreter
        import readline
        import rlcompleter
        # see readline man page for this
        readline.parse_and_bind("set show-all-if-ambiguous on")
        readline.parse_and_bind("tab: complete")
    except:
        pass
# you can place a file .pythonrc.py in your home to overrides this one
# but then, this file will not be sourced
EOF

%if ! %{with tkinter}
rm -rf %{buildroot}%{_bindir}/idle
rm -rf %{buildroot}%{pylibdir}/{idlelib,lib-tk}
%endif

# Do bytecompilation with the newly installed interpreter.
# compile *.pyo
find %{buildroot}%{_libdir}/python%{pybasever} -type f -a -name "*.py" -print0 | \
    LD_LIBRARY_PATH="%{buildroot}%{dynload_dir}/:%{buildroot}%{_libdir}" \
    PYTHONPATH="%{buildroot}%{_libdir}/python%{pybasever} %{buildroot}%{_libdir}/python%{pybasever}/site-packages" \
    xargs -0 %{buildroot}%{_bindir}/python%{pybasever} -O -c 'import py_compile, sys; [py_compile.compile(f, dfile=f.partition("%{buildroot}")[2]) for f in sys.argv[1:]]' || :
# compile *.pyc
find %{buildroot}%{_libdir}/python%{pybasever} -type f -a -name "*.py" -print0 | \
    LD_LIBRARY_PATH="%{buildroot}%{dynload_dir}/:%{buildroot}%{_libdir}" \
    PYTHONPATH="%{buildroot}%{_libdir}/python%{pybasever} %{buildroot}%{_libdir}/python%{pybasever}/site-packages" \
    xargs -0 %{buildroot}%{_bindir}/python%{pybasever} -c 'import py_compile, sys; [py_compile.compile(f, dfile=f.partition("%{buildroot}")[2]) for f in sys.argv[1:]]' || :

# Fix shebangs with the newly installed interpreter.
LD_LIBRARY_PATH="%{buildroot}%{dynload_dir}/:%{buildroot}%{_libdir}" \
PYTHONPATH="%{buildroot}%{_libdir}/python%{pybasever} %{buildroot}%{_libdir}/python%{pybasever}/site-packages" \
  %{buildroot}%{_bindir}/python%{pybasever} ./Tools/scripts/pathfix.py \
    -i "%{_bindir}/python%{pybasever}" \
    %{buildroot}%{_bindir} %{buildroot}%{_libdir}/python%{pybasever} \
%if %{with tkinter}
    %{buildroot}%{_bindir}/idle \
    %{buildroot}%{_libdir}/python%{dirver}/site-packages/pynche/pynche \
%endif
    %nil

# Make python-devel multilib-ready (rhbz#192747, rhbz#139911)
mv %{buildroot}%{_includedir}/python%{pybasever}/pyconfig.h \
   %{buildroot}%{_includedir}/python%{pybasever}/pyconfig-%{__isa_bits}.h
cat > %{buildroot}%{_includedir}/python%{pybasever}/pyconfig.h << EOF
#include <bits/wordsize.h>

#if __WORDSIZE == 32
#include "pyconfig-32.h"
#elif __WORDSIZE == 64
#include "pyconfig-64.h"
#else
#error "Unknown word size"
#endif
EOF

# Make sure distutils looks at the right pyconfig.h file (rhbz#201434)
# Similar for sysconfig: sysconfig.get_config_h_filename tries to locate
# pyconfig.h so it can be parsed, and needs to do this at runtime in site.py
# when python starts up.
sed -i -e "s/'pyconfig.h'/'pyconfig-%{__isa_bits}.h'/" \
  %{buildroot}%{pylibdir}/distutils/sysconfig.py \
  %{buildroot}%{pylibdir}/sysconfig.py

# remove/rename files as python3 will be the default one
rm -rf %{buildroot}%{_bindir}/python{,-config}
rm -rf %{buildroot}%{_libdir}/pkgconfig/python.pc
rm -rf %{buildroot}%{_mandir}/man1/python.1*
for i in 2to3 pydoc; do
  mv %{buildroot}%{_bindir}/$i %{buildroot}%{_bindir}/$i-%{dirver}
done

# clean
find %{buildroot} -name "*~" -delete
rm -f %{buildroot}%{pylibdir}/LICENSE.txt

%files
%doc README.mga
%config(noreplace) %{_sysconfdir}/profile.d/30python2.*
%config(noreplace) %{_sysconfdir}/pythonrc.py

%{_bindir}/python2
%{_bindir}/python%{dirver}
%{_bindir}/pydoc-%{dirver}
%{_bindir}/2to3-%{dirver}
%{_mandir}/man1/python2*.1*

%files -n %{lib_name}-stdlib
%license LICENSE
%dir %{pylibdir}
%dir %{dynload_dir}
%{dynload_dir}/Python-%{version}-py%{dirver}.egg-info
%{dynload_dir}/_bisect.so
%{dynload_dir}/_bsddb.so
%{dynload_dir}/_codecs_cn.so
%{dynload_dir}/_codecs_hk.so
%{dynload_dir}/_codecs_iso2022.so
%{dynload_dir}/_codecs_jp.so
%{dynload_dir}/_codecs_kr.so
%{dynload_dir}/_codecs_tw.so
%{dynload_dir}/_collections.so
%{dynload_dir}/_csv.so
%{dynload_dir}/_ctypes.so
%{dynload_dir}/_curses.so
%{dynload_dir}/_curses_panel.so
%{dynload_dir}/_elementtree.so
%{dynload_dir}/_functools.so
#%%{dynload_dir}/_hashlib.so
%{dynload_dir}/_heapq.so
%{dynload_dir}/_hotshot.so
%{dynload_dir}/_io.so
%{dynload_dir}/_json.so
%{dynload_dir}/_locale.so
%{dynload_dir}/_lsprof.so
%{dynload_dir}/_md5.so
%{dynload_dir}/_multibytecodec.so
%{dynload_dir}/_multiprocessing.so
%{dynload_dir}/_random.so
%{dynload_dir}/_sha.so
%{dynload_dir}/_sha256.so
%{dynload_dir}/_sha512.so
%{dynload_dir}/_socket.so
%{dynload_dir}/_sqlite3.so
%{dynload_dir}/_ssl.so
%{dynload_dir}/_struct.so
%{dynload_dir}/array.so
%{dynload_dir}/audioop.so
%{dynload_dir}/binascii.so
%{dynload_dir}/bz2.so
%{dynload_dir}/cPickle.so
%{dynload_dir}/cStringIO.so
%{dynload_dir}/cmath.so
%{dynload_dir}/crypt.so
%{dynload_dir}/datetime.so
%{dynload_dir}/dbm.so
%ifarch %{ix86} %{arm}
%{dynload_dir}/dl.so
%endif
%{dynload_dir}/fcntl.so
%{dynload_dir}/future_builtins.so
%{dynload_dir}/gdbm.so
%{dynload_dir}/grp.so
%ifarch %{ix86} %{arm}
%{dynload_dir}/imageop.so
%endif
%{dynload_dir}/itertools.so
%{dynload_dir}/math.so
%{dynload_dir}/mmap.so
%{dynload_dir}/nis.so
%{dynload_dir}/operator.so
%{dynload_dir}/ossaudiodev.so
%{dynload_dir}/parser.so
%{dynload_dir}/pyexpat.so
%{dynload_dir}/readline.so
%{dynload_dir}/resource.so
%{dynload_dir}/select.so
%{dynload_dir}/spwd.so
%{dynload_dir}/strop.so
%{dynload_dir}/syslog.so
%{dynload_dir}/termios.so
%{dynload_dir}/time.so
%{dynload_dir}/unicodedata.so
%{dynload_dir}/zlib.so
%dir %{site_packages}
%{site_packages}/README
%{pylibdir}/*.py*
%{pylibdir}/*.doc
%{pylibdir}/wsgiref.egg-info
%dir %{pylibdir}/bsddb
%{pylibdir}/bsddb/*.py*
%{pylibdir}/compiler
%dir %{pylibdir}/ctypes
%{pylibdir}/ctypes/*.py*
%{pylibdir}/ctypes/macholib
%{pylibdir}/curses
%dir %{pylibdir}/distutils
%{pylibdir}/distutils/*.py*
%{pylibdir}/distutils/README
%{pylibdir}/distutils/command
%exclude %{pylibdir}/distutils/command/wininst-*.exe
%dir %{pylibdir}/email
%{pylibdir}/email/*.py*
%{pylibdir}/email/mime
%{pylibdir}/encodings
%{pylibdir}/hotshot
%{pylibdir}/importlib
%dir %{pylibdir}/json
%{pylibdir}/json/*.py*
%{pylibdir}/lib2to3
%exclude %{pylibdir}/lib2to3/tests
%{pylibdir}/logging
%{pylibdir}/multiprocessing
%{pylibdir}/plat-linux2
%{pylibdir}/pydoc_data
%dir %{pylibdir}/sqlite3
%{pylibdir}/sqlite3/*.py*
%dir %{pylibdir}/test
%{pylibdir}/test/test_support.py*
%{pylibdir}/test/__init__.py*
%{pylibdir}/unittest/*.py*
%{pylibdir}/wsgiref
%{pylibdir}/xml
%if "%{_lib}" == "lib64"
%dir %{_prefix}/lib/python%{dirver}
%dir %{_prefix}/lib/python%{dirver}/site-packages
%endif

# "Makefile" and the config.h file are needed by
# distutils/sysconfig.py:_init_posix(), so we include them in the libs
# package, along with their parent directories (RH bug#531901):
%dir %{_libdir}/python%{dirver}/config
%{_libdir}/python%{dirver}/config/Makefile
%dir %{_includedir}/python%{dirver}
%{_includedir}/python%{dirver}/pyconfig-%{__isa_bits}.h

%dir %{pylibdir}/ensurepip/
%{pylibdir}/ensurepip/*.py*
%if %{with rpmwheels}
%exclude %{pylibdir}/ensurepip/_bundled
%else
%dir %{pylibdir}/ensurepip/_bundled
%{pylibdir}/ensurepip/_bundled/*.whl
%endif


%files -n %{lib_name}
%{_libdir}/libpython*.so.1*


%files -n %{dev_name}
%{_libdir}/libpython*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/python%{dirver}
%{_libdir}/python%{dirver}/config/*
%{_bindir}/python%{dirver}-config
%{_bindir}/python2-config
%exclude %{_libdir}/python%{dirver}/config/Makefile
%exclude %{_includedir}/python%{dirver}/pyconfig-%{__isa_bits}.h

%if %{with valgrind}
%{_libdir}/valgrind/valgrind-python.supp
%endif


%files -n %{lib_name}-testsuite
%{pylibdir}/bsddb/test
%{pylibdir}/ctypes/test
%{pylibdir}/distutils/tests
%{pylibdir}/email/test
%{pylibdir}/json/tests
%{pylibdir}/lib2to3/tests
%{pylibdir}/sqlite3/test
%{pylibdir}/test/*
%{pylibdir}/unittest/test
# These two are shipped in the main subpackage:
%exclude %{pylibdir}/test/test_support.py*
%exclude %{pylibdir}/test/__init__.py*
%{dynload_dir}/_ctypes_test.so
%{dynload_dir}/_testcapi.so


%files docs
%doc html/*/*
%{_datadir}/applications/%{_real_vendor}-%{name}-docs.desktop

%if %{with tkinter}
%files -n tkinter
%dir %{pylibdir}/lib-tk
%{pylibdir}/lib-tk/*.py*
%{pylibdir}/lib-tk/test/
%{dynload_dir}/_tkinter.so
%{pylibdir}/idlelib
%{site_packages}/pynche


%files -n tkinter-apps
%{_bindir}/idle
%{_bindir}/pynche
%{_datadir}/applications/%{_real_vendor}-tkinter.desktop
%endif
