#
# Please do not update/rebuild/touch this package before asking first
# neoclust and/or daviddavid
# This package is part of the KDE Stack.
#

%define qt5_build 1
%define qt6_build 1

Summary:        Qt Cryptographic Architecture
Name:           qca
Version:        2.3.10
Release:        %mkrel 1
License:        LGPLv2+
Group:          System/Base
URL:            https://userbase.kde.org/QCA
Source0:        https://download.kde.org/stable/qca/%{version}/%{name}-%{version}.tar.xz
# Also generate pkgconfig file for qt6
Patch0:         qca-qt6-pkgconfig.patch

BuildRequires:  cmake
BuildRequires:  doxygen

%if %qt5_build
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Network)
%endif

%if %qt6_build
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Network)
%endif

BuildRequires:  pkgconfig(botan-3)
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(libpkcs11-helper-1)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(openssl)

%description
Qt Cryptographic Architecture.

#--------------------------------------------------------------------

%if %qt5_build

%package -n %{name}-qt5
Summary:        Qt5 Cryptographic Architecture
Group:          System/Base

%description -n %{name}-qt5
Qt5 Cryptographic Architecture.

%files -n %{name}-qt5
%{_bindir}/mozcerts-qt5
%{_bindir}/qcatool-qt5
%{_libdir}/qca-qt5/
%{_mandir}/man1/qcatool-qt5.1.*

#--------------------------------------------------------------------

%define qcaqt5_major 2
%define libqcaqt5 %mklibname %{name}-qt5_ %{qcaqt5_major}

%package -n %{libqcaqt5}
Summary:        Libraries for Qt5 Cryptographic Architecture
Group:          System/Libraries

%description -n %{libqcaqt5}
Libraries for Qt5 Cryptographic Architecture.

%files -n %{libqcaqt5}
%{_libdir}/libqca-qt5.so.%{qcaqt5_major}{,.*}

#--------------------------------------------------------------------

%define qcaqt5_devel %mklibname %{name}-qt5 -d

%package -n %{qcaqt5_devel}
Summary:        Devel stuff for %{name}-qt5
Group:          Development/KDE and Qt
Requires:       %{name}-qt5 = %{version}-%{release}
Requires:       %{libqcaqt5} = %{version}-%{release}
Provides:       %{name}-qt5-devel = %{version}-%{release}

%description -n %{qcaqt5_devel}
This package contains header files needed if you wish to build applications
based on %{name}-qt5.

%files -n %{qcaqt5_devel}
%{_includedir}/Qca-qt5/
%{_libdir}/libqca-qt5.so
%{_libdir}/cmake/Qca-qt5/
%{_libdir}/pkgconfig/qca2-qt5.pc
%{_qt5_archdatadir}/mkspecs/features/crypto.prf
%endif

#--------------------------------------------------------------------

%if %qt6_build

%package -n %{name}-qt6
Summary:        Qt6 Cryptographic Architecture
Group:          Development/KDE and Qt

Obsoletes:      qca2 < 2.3.4-2
Obsoletes:      qca2-plugin-botan < 2.3.4-2
Obsoletes:      qca2-plugin-cyrus-sasl < 2.3.4-2
Obsoletes:      qca2-plugin-gcrypt < 2.3.4-2
Obsoletes:      qca2-plugin-gnupg < 2.3.4-2
Obsoletes:      qca2-plugin-logger < 2.3.4-2
Obsoletes:      qca2-plugin-nss < 2.3.4-2
Obsoletes:      qca2-plugin-openssl < 2.3.4-2
Obsoletes:      qca2-plugin-pkcs11 < 2.3.4-2
Obsoletes:      qca2-plugin-softstore < 2.3.4-2

%description -n %{name}-qt6
Qt6 Cryptographic Architecture.

%files -n %{name}-qt6
%{_bindir}/mozcerts-qt6
%{_bindir}/qcatool-qt6
%{_libdir}/qca-qt6/
%{_mandir}/man1/qcatool-qt6.1.*

#--------------------------------------------------------------------

%define qcaqt6_major 2
%define libqcaqt6 %mklibname %{name}-qt6_ %{qcaqt6_major}

%package -n %{libqcaqt6}
Summary:        Libraries for Qt6 Cryptographic Architecture
Group:          System/Libraries

Obsoletes:      %{_lib}qca2 < 2.3.4-2

%description -n %{libqcaqt6}
Libraries for Qt6 Cryptographic Architecture.

%files -n %{libqcaqt6}
%{_libdir}/libqca-qt6.so.%{qcaqt6_major}{,.*}

#--------------------------------------------------------------------

%define qcaqt6_devel %mklibname %{name}-qt6 -d

%package -n %{qcaqt6_devel}
Summary:        Devel stuff for %{name}-qt6
Group:          Development/KDE and Qt
Requires:       %{name}-qt6 = %{version}-%{release}
Requires:       %{libqcaqt6} = %{version}-%{release}
Provides:       %{name}-qt6-devel = %{version}-%{release}

Obsoletes:      %{_lib}qca-devel < 2.3.4-2

%description -n %{qcaqt6_devel}
This package contains header files needed if you wish to build applications
based on %{name}-qt6.

%files -n %{qcaqt6_devel}
%{_includedir}/Qca-qt6/
%{_libdir}/libqca-qt6.so
%{_libdir}/cmake/Qca-qt6/
%{_libdir}/pkgconfig/qca2-qt6.pc
%endif
#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
%if %qt5_build
%define _vpath_builddir %{_target_platform}-qt5

%cmake_qt5 -DQCA_FEATURE_INSTALL_DIR:PATH=%{_qt5_archdatadir}/mkspecs/features
%cmake_build
%endif

%if %qt6_build
%define _vpath_builddir %{_target_platform}-qt6

%cmake_qt6 -DQCA_FEATURE_INSTALL_DIR:PATH=%{_qt6_archdatadir}/mkspecs/features -DBUILD_WITH_QT6=ON
%cmake_build
%endif

%install
%if %qt5_build
%define _vpath_builddir %{_target_platform}-qt5
%cmake_install
%endif

%if %qt6_build
%define _vpath_builddir %{_target_platform}-qt6
%cmake_install
%endif

%check
%if %qt5_build
%define _vpath_builddir %{_target_platform}-qt5
export CTEST_OUTPUT_ON_FAILURE=1
export PKG_CONFIG_PATH=%{buildroot}%{_libdir}/pkgconfig
# skip slow archs
%ifnarch %{arm}
test "$(pkg-config --modversion qca2-qt5)" = "%{version}"
%ctest --timeout 180
%endif
%endif

%if %qt6_build
%define _vpath_builddir %{_target_platform}-qt6
export CTEST_OUTPUT_ON_FAILURE=1
export PKG_CONFIG_PATH=%{buildroot}%{_libdir}/pkgconfig
# skip slow archs
%ifnarch %{arm}
test "$(pkg-config --modversion qca2-qt6)" = "%{version}"
%ctest --timeout 180
%endif
%endif
