# Bump this as appropriate when doing release updates, check i.e. with abi_compliance_checker
# First digit: major, bump when incompatible changes were performed
# Second digit: minor, bump when interface was extended
%define so_ver		2.0.0

# comment out when not pre-release
#define prel		beta

### Qt5 Config libs
%define major		2
%define libname_qt5	%mklibname %{name}-qt5_ %{major}
%define devname_qt5	%mklibname %{name}-qt5 -d
### Qt6 Config libs
%define major_qt6	2
%define libname_qt6	%mklibname %{name}-qt6_ %{major_qt6}
%define devname_qt6	%mklibname %{name}-qt6 -d

%define rel	2

Name:		qcustomplot
Version:	2.1.1
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	Qt widget for plotting and data visualization
Group:		Development/KDE and Qt
License:	GPLv3+
URL:		https://www.qcustomplot.com/
Source0:	https://www.qcustomplot.com/release/%{version}%{?prel:-%prel}/QCustomPlot.tar.gz
Source1:	%{name}.pro

BuildRequires:	gcc-c++
BuildRequires:	make
### Qt5 dependencies
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)

### Qt6 dependencies
BuildRequires:	pkgconfig(Qt6Core)
BuildRequires:	pkgconfig(Qt6Gui)
BuildRequires:	pkgconfig(Qt6PrintSupport)
BuildRequires:	pkgconfig(Qt6Widgets)

%description
QCustomPlot is a Qt C++ widget for plotting and data visualization.
This plotting library focuses on making good looking, publication quality 2D
plots, graphs and charts, as well as offering high performance for realtime
visualization applications.

#-----------------------------------------------------------------
### Qt5 packages

%package -n	%{libname_qt5}
Summary:	Qt5 widget for plotting and data visualization
Group:		Development/KDE and Qt

%description -n	%{libname_qt5}
QCustomPlot is a Qt C++ widget for plotting and data visualization.
This plotting library focuses on making good looking, publication quality 2D
plots, graphs and charts, as well as offering high performance for realtime
visualization applications.

This package contains the Qt5 version.

%files -n %{libname_qt5}
%doc changelog.txt
%license GPL.txt
%{_libdir}/lib%{name}-qt5.so.%{major}{,.*}

#-----------------------------------------------------------------

%package -n	%{devname_qt5}
Summary:	Development files for %{name} (Qt5)
Group:		Development/KDE and Qt
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{name}-qt5-devel = %{version}-%{release}

%description -n	%{devname_qt5}
The %{devname_qt5} package contains libraries and header files for
developing applications that use %{name} (Qt5).

%files -n %{devname_qt5}
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}-qt5.so
%{_libdir}/pkgconfig/%{name}-qt5.pc

#-----------------------------------------------------------------
### Qt6 packages

%package -n	%{libname_qt6}
Summary:	Qt6 widget for plotting and data visualization
Group:		Development/KDE and Qt

%description -n	%{libname_qt6}
QCustomPlot is a Qt C++ widget for plotting and data visualization.
This plotting library focuses on making good looking, publication quality 2D
plots, graphs and charts, as well as offering high performance for realtime
visualization applications.

This package contains the Qt6 version.

%files -n %{libname_qt6}
%doc changelog.txt
%license GPL.txt
%{_libdir}/lib%{name}-qt6.so.%{major_qt6}{,.*}

#-----------------------------------------------------------------

%package -n	%{devname_qt6}
Summary:	Development files for %{name} (Qt6)
Group:		Development/KDE and Qt
Requires:	%{libname_qt6} = %{version}-%{release}
Provides:	%{name}-qt6-devel = %{version}-%{release}

%description -n	%{devname_qt6}
The %{devname_qt6} package contains libraries and header files for
developing applications that use %{name} (Qt6).

%files -n %{devname_qt6}
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}-qt6.so
%{_libdir}/pkgconfig/%{name}-qt6.pc

#-----------------------------------------------------------------

%package	doc
Summary:	Documentation and examples for %{name}
Group:		Documentation
BuildArch:	noarch

%description	doc
The %{name}-doc package contains the documentation and examples for
%{name}.

%files doc
%doc GPL.txt
%doc documentation examples

#-----------------------------------------------------------------

%prep
%setup -qn %{name}
%autopatch -p1

cp -a %{SOURCE1} .

%build
### Qt5 Build
mkdir qt5 && pushd qt5
%qmake_qt5 SOVERSION=%{so_ver} \
           QTSUFFIX=-qt5 \
           LIBDIR=%{_libdir} ..

%make_build
popd

### Qt6 Build
mkdir qt6 && pushd qt6
%qmake_qt6 SOVERSION=%{so_ver} \
           QTSUFFIX=-qt6 \
           LIBDIR=%{_libdir} ..

%make_build
popd

%install
### Qt5 Install
%make_install -C qt5 INSTALL_ROOT=%{buildroot}
### Qt6 Install
%make_install -C qt6 INSTALL_ROOT=%{buildroot}

### Qt5 pkg-config file
install -d %{buildroot}%{_libdir}/pkgconfig/
cat > %{buildroot}%{_libdir}/pkgconfig/%{name}-qt5.pc <<EOF
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}-qt5
Description: Qt5 widget for plotting and data visualization
Version: %{version}
Cflags: -I\${includedir}
Libs: -L\${libdir} -lqcustomplot-qt5
EOF

### Qt6 pkg-config file
install -d %{buildroot}%{_libdir}/pkgconfig/
cat > %{buildroot}%{_libdir}/pkgconfig/%{name}-qt6.pc <<EOF
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}-qt6
Description: Qt6 widget for plotting and data visualization
Version: %{version}
Cflags: -I\${includedir}
Libs: -L\${libdir} -lqcustomplot-qt6
EOF
