%define major		4
%define libname_qt5	%mklibname %{name}-qt5_ %{major}
%define devname_qt5	%mklibname %{name}-qt5 -d

Name:		qhexedit2
# Remember to also update version in qhexedit2_build.patch in the setup.py hunk
Version:	0.8.9
Release:	%mkrel 7
Summary:	Binary Editor for Qt
Group:		Development/KDE and Qt
License:	LGPLv2
URL:		https://github.com/Simsys/qhexedit2
Source0:	https://github.com/Simsys/qhexedit2/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	qhexedit.desktop

# Fix build issues
Patch0:		qhexedit2_build.patch
Patch1:		sip5.patch

BuildRequires:	desktop-file-utils
BuildRequires:	gcc-c++
BuildRequires:	make
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-pyqt5-sip
BuildRequires:	python3-qt5-devel
BuildRequires:	python3-sip6
BuildRequires:	python3dist(pyqt-builder)

%description
QHexEdit is a hex editor widget written in C++ for the Qt framework.
It is a simple editor for binary data, just like QPlainTextEdit is for text
data.

%files
%doc doc/release.txt
%license src/license.txt
%{_bindir}/qhexedit
%{_datadir}/applications/qhexedit.desktop

#-----------------------------------------------------------------

%package -n	%{libname_qt5}
Summary:	Qt5 library for %{name}
Group:		Development/KDE and Qt

%description -n	%{libname_qt5}
Qt5 library for %{name}.

%files -n %{libname_qt5}
%doc doc/release.txt
%license src/license.txt
%{_libdir}/libqhexedit-qt5.so.%{major}{,.*}

#-----------------------------------------------------------------

%package -n	%{devname_qt5}
Summary:        Development files for %{name} Qt5
Group:		Development/KDE and Qt
Requires:	%{libname_qt5} = %{version}-%{release}
Provides:	%{name}-qt5-devel = %{version}-%{release}

%description -n	%{devname_qt5}
The %{devname_qt5} package contains libraries and header files for
developing applications that use %{name} Qt5.

%files -n %{devname_qt5}
%{_includedir}/%{name}/
%{_libdir}/libqhexedit-qt5.so
%{_libdir}/pkgconfig/%{name}-qt5.pc

#-----------------------------------------------------------------

%package	doc
Summary:	Documentation and examples for %{name}
Group:		Documentation
BuildArch:	noarch
Provides:	bundled(jquery)

%description	doc
The %{name}-doc package contains the documentation and examples for %{name}.

%files doc
%license src/license.txt
%doc doc/html

#-----------------------------------------------------------------

%package -n	python3-qt5-%{name}
Summary:	Python3 Qt5 bindings for %{name}
Group:		Development/Python
Requires:	%{libname_qt5} = %{version}-%{release}
%{?python_provide:%python_provide python3-qt5-%{name}}

%description -n	python3-qt5-%{name}
Python3 Qt5 bindings for %{name}.

%files -n python3-qt5-%{name}
%{python3_sitearch}/qhexedit.*.so
%{python3_sitearch}/QHexEdit-%{version}*info

#-----------------------------------------------------------------

%package -n	python3-qt5-%{name}-devel
Summary:	Development files for the %{name} Qt5 Python3 bindings
Group:		Development/Python
Requires:	python3-qt5-%{name} = %{version}-%{release}
Requires:	python3-sip6
%{?python_provide:%python_provide python3-qt5-%{name}-devel}

%description -n	python3-qt5-%{name}-devel
Development files for the %{name} Qt5 Python3 bindings.

%files -n python3-qt5-%{name}-devel
%{python3_sitearch}/PyQt5/bindings/qhexedit/

#-----------------------------------------------------------------

%prep
%autosetup -p1

# Prevent rpmlint W: doc-file-dependency /usr/share/doc/qhexedit2-doc/html/installdox /usr/bin/perl
rm -f doc/html/installdox

%build
### Build library, qt5
mkdir build-lib-qt5
pushd build-lib-qt5
LDFLAGS="%{ldflags}" \
%qmake_qt5 ../src/qhexedit.pro
%make_build
popd

### Build sip bindings, qt5, python3
sip-build --qmake=%{_qt5_bindir}/qmake --verbose --build-dir=build-python3-qt5 --no-make
%make_build -C build-python3-qt5

### Build application
mkdir build-example
pushd build-example
%qmake_qt5 ../example/qhexedit.pro
%make_build
popd

%install
# Library and headers
install -d %{buildroot}%{_includedir}/%{name}
install -m 0644 src/*.h %{buildroot}%{_includedir}/%{name}

install -d %{buildroot}%{_libdir}
chmod 0755 build-lib-qt5/*.so.*.*
cp -a build-lib-qt5/*.so* %{buildroot}%{_libdir}

### pkg-config files
install -d %{buildroot}%{_libdir}/pkgconfig/
cat > %{buildroot}%{_libdir}/pkgconfig/%{name}-qt5.pc <<EOF
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}-qt5
Description: Binary Editor for Qt5
Version: %{version}
Cflags: -I\${includedir}
Libs: -L\${libdir} -lqhexedit-qt5
EOF

### Python bindings
# Distutils does not support --build-base with install, you need to build also...
%make_install INSTALL_ROOT=%{buildroot} -C build-python3-qt5

### Application
install -Dpm 0755 build-example/qhexedit %{buildroot}%{_bindir}/qhexedit
desktop-file-install --dir=%{buildroot}%{_datadir}/applications/ %{SOURCE1}
