%define major     29
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%define snapshot 0
%if %{?snapshot}
%define date 20170730
%endif

%define rel 1

Summary:	Command-line tools and library for transforming PDF files
Name:		qpdf
Version:	11.10.1
Release:	%mkrel %{?date:0.%{date}.}%{rel}
# MIT: e.g. libqpdf/sha2.c
# upstream uses ASL 2.0 now, but he allowed other to distribute qpdf under
# old license (see README)
License:	(Artistic 2.0 or ASL 2.0) and MIT
Group:		System/Printing
URL:		https://qpdf.sourceforge.net/
%if 0%{?date}
Source0:	%{name}-%{version}+%{date}.tar.xz
%else
Source0:	https://github.com/qpdf/qpdf/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/qpdf/qpdf/releases/download/v%{version}/%{name}-%{version}-doc.zip
%endif

# make qpdf working under FIPS, downstream patch
Patch1:		qpdf-relax.patch

# uses cmake
BuildRequires:	cmake

BuildRequires:	pkgconfig(zlib)
# for gnutls crypto
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(libjpeg)
# for fix-qdf and test suite
BuildRequires:	perl
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Digest::MD5)
BuildRequires:	perl(Digest::SHA)
BuildRequires:	perl(File::Basename)
BuildRequires:  perl(File::Compare)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(FileHandle)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IO::Select)
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(strict)
# perl(Term::ANSIColor) - not needed for tests
# perl(Term::ReadKey) - not needed for tests

%description
QPDF is a command-line program that does structural, content-preserving
transformations on PDF files. It could have been called something
like pdf-to-pdf. It includes support for merging and splitting PDFs
and to manipulate the list of pages in a PDF file. It is not a PDF viewer
or a program capable of converting PDF into other formats.

%package -n	%{libname}
Summary:	QPDF library for transforming PDF files
Group:		System/Libraries

%description -n	%{libname}
QPDF is a C++ library that inspect and manipulate the structure of PDF files.
It can encrypt and linearize files, expose the internals of a PDF file,
and do many other operations useful to PDF developers.

%package -n	%{develname}
Summary:	Development files for QPDF library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}

%description -n	%{develname}
Header files and libraries necessary
for developing programs using the QPDF library.

%package	doc
Summary:	QPDF Manual
Group:		Documentation
BuildArch:	noarch

%description	doc
QPDF Manual.

%prep
%if 0%{?date}
%autosetup -p1 -n %{name}-%{version}+%{date}
%else
%autosetup -p1
%endif

# unpack zip file with manual
unzip %{SOURCE1}

%build
%cmake -DBUILD_STATIC_LIBS=0 \
       -DREQUIRE_CRYPTO_GNUTLS=1 \
       -DUSE_IMPLICIT_CRYPTO=0 \
       -DSHOW_FAILED_TEST_OUTPUT=1 \
       -DINSTALL_CMAKE_PACKAGE=0

%cmake_build

%install
%cmake_install

install -m 0644 %{name}-%{version}-doc/%{name}-manual.pdf %{buildroot}/%{_pkgdocdir}/%{name}-manual.pdf

# install bash/zsh completions
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions
install -m 0644 completions/bash/qpdf %{buildroot}%{_datadir}/bash-completion/completions/qpdf
install -m 0644 completions/zsh/_qpdf %{buildroot}%{_datadir}/zsh/site-functions/_qpdf

%check
%ctest

%files
%{_bindir}/fix-qdf
%{_bindir}/qpdf
%{_bindir}/zlib-flate
%{_mandir}/man1/*
%{_datadir}/bash-completion/completions/qpdf
%{_datadir}/zsh/site-functions/_qpdf

%files -n %{libname}
%doc README.md TODO.md ChangeLog
%license Artistic-2.0 LICENSE.txt NOTICE.md
%{_libdir}/libqpdf*.so.%{major}{,.*}

%files -n %{develname}
%doc examples/*.cc examples/*.c
%{_includedir}/qpdf/
%{_libdir}/libqpdf.so
%{_libdir}/pkgconfig/libqpdf.pc

%files doc
%{_pkgdocdir}
