%define major     15
%define libqs5    %mklibname qscintilla2_qt5_ %{major}
%define libqs5dev %mklibname qscintilla2_qt5 -d

%define libqs6    %mklibname qscintilla2_qt6_ %{major}
%define libqs6dev %mklibname qscintilla2_qt6 -d

%bcond_without	qt5
%bcond_without	qt6

Name:           qscintilla
Version:        2.14.1
Release:        %mkrel 3
Summary:        Port to Qt of Neil Hodgson's Scintilla C++ editor class
License:        GPLv2+
Group:          System/Libraries
URL:            https://riverbankcomputing.com/software/qscintilla/intro
Source0:        https://www.riverbankcomputing.com/static/Downloads/QScintilla/%{version}/QScintilla_src-%{version}.tar.gz
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  sed

# Qt5
%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  python3-qt5-devel
%endif

# Qt6
%if %{with qt6}
BuildRequires:  cmake(Qt6Designer)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  python3-qt6-devel
%endif

# Python 3
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-dbus
BuildRequires:  python3dist(sip)
BuildRequires:  python3-pyqt-builder

%description
As well as features found in standard text editing components,
QScintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

#--------------------------------------------------------------
%if %{with qt5}

%package -n     %{libqs5}
Summary:        Port to Qt5 of Neil Hodgson's Scintilla C++ editor class
Group:          System/Libraries
Requires:       qscintilla2-qt5-common >= %{version}-%{release}
Conflicts:	qscintilla2-qt5-common < 2.13.3

%description -n %{libqs5}
As well as features found in standard text editing components,
QScintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

%files -n %{libqs5}
%{_qt5_libdir}/libqscintilla2_qt5.so.%{major}{,.*}
%{_qt5_plugindir}/designer/libqscintillaplugin.so

#--------------------------------------------------------------

%package -n     %{libqs5dev}
Summary:        Libraries, include and other files to develop applications with QScintilla for Qt5
Group:          Development/KDE and Qt
Requires:       %{libqs5} = %{version}-%{release}
Provides:       %{name}-qt5-devel = %{version}-%{release}
Obsoletes:	%{_lib}qscintilla2-qt5-devel < 2.13.3

%description -n %{libqs5dev}
This packages contains the libraries, include and other files
you can use to develop applications with QScintilla.

%files -n %{libqs5dev}
%{_qt5_includedir}/*
%{_qt5_libdir}/libqscintilla2_qt5.so
%{_qt5_archdatadir}/mkspecs/features/qscintilla2.prf

#--------------------------------------------------------------

%package -n     qscintilla2-qt5-common
Summary:        Common files for %{name}-qt5
Group:          System/Libraries

%description -n qscintilla2-qt5-common
This packages contains translations and designer plugin for %{name}-qt5.

%files -n qscintilla2-qt5-common
%{_qt5_translationdir}/qscintilla*.qm

#--------------------------------------------------------------

%package -n     python3-qt5-qscintilla
Summary:        Python3 Qt5 QScintilla bindings
Group:          Development/KDE and Qt
Requires:       python3-qt5
Requires:       %{libqs5} = %{version}

%description -n python3-qt5-qscintilla
Python3 Qt5 QScintilla bindings.

%files -n python3-qt5-qscintilla
%{python3_sitearch}/PyQt5/Qsci.abi3.so
%{python3_sitearch}/PyQt5/bindings/Qsci/
%{python3_sitearch}/QScintilla-%{version}.dist-info/

#--------------------------------------------------------------

%package        doc-qt5
Summary:        QScintilla docs
Group:          Development/KDE and Qt
BuildArch:      noarch

%description    doc-qt5
QScintilla doc.

%files doc-qt5
%doc NEWS doc
%{_qt5_datadir}/qsci/api/python/*

%endif
#--------------------------------------------------------------
%if %{with qt6}

%package -n     %{libqs6}
Summary:        Port to Qt6 of Neil Hodgson's Scintilla C++ editor class
Group:          System/Libraries
Requires:       qscintilla2-qt6-common >= %{version}-%{release}

%description -n %{libqs6}
As well as features found in standard text editing components,
QScintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

%files -n %{libqs6}
%{_qt6_libdir}/libqscintilla2_qt6.so.%{major}{,.*}
%{_qt6_plugindir}/designer/libqscintillaplugin.so

#--------------------------------------------------------------

%package -n     %{libqs6dev}
Summary:        Libraries, include and other files to develop applications with QScintilla for Qt6
Group:          Development/KDE and Qt
Requires:       %{libqs6} = %{version}-%{release}
Provides:       %{name}-qt6-devel = %{version}-%{release}

%description -n %{libqs6dev}
This packages contains the libraries, include and other files
you can use to develop applications with QScintilla.

%files -n %{libqs6dev}
%{_qt6_includedir}/*
%{_qt6_libdir}/libqscintilla2_qt6.so
%{_qt6_archdatadir}/mkspecs/features/qscintilla2.prf

#--------------------------------------------------------------

%package -n     qscintilla2-qt6-common
Summary:        Common files for %{name}-qt6
Group:          System/Libraries

%description -n qscintilla2-qt6-common
This packages contains translations and designer plugin for %{name}-qt6.

%files -n qscintilla2-qt6-common
%{_qt6_translationdir}/qscintilla*.qm

#--------------------------------------------------------------

%package -n     python3-qt6-qscintilla
Summary:        Python3 Qt6 QScintilla bindings
Group:          Development/KDE and Qt
Requires:       python3-qt6
Requires:       %{libqs6} = %{version}

%description -n python3-qt6-qscintilla
Python3 Qt6 QScintilla bindings.

%files -n python3-qt6-qscintilla
%{python3_sitearch}/PyQt6/Qsci.abi3.so
%{python3_sitearch}/PyQt6/bindings/Qsci/
%{python3_sitearch}/PyQt6_QScintilla-%{version}.dist-info/

#--------------------------------------------------------------

%package        doc-qt6
Summary:        QScintilla docs
Group:          Development/KDE and Qt
BuildArch:      noarch

%description    doc-qt6
QScintilla doc.

%files doc-qt6
%doc NEWS doc
%{_qt6_datadir}/qsci/api/python/*

%endif
#--------------------------------------------------------------

%prep
%setup -qn QScintilla_src-%{version}
%autopatch -p1

%build
export QMAKEFEATURES=$PWD/src/features;

cp -a src src-qt6
%if %{with qt5}
pushd src
  %qmake_qt5 qscintilla.pro
  %make_build
popd
%endif

cp -a designer designer-qt6
%if %{with qt5}
pushd designer
  %qmake_qt5 designer.pro INCLUDEPATH+=../src LIBS+=-L../src
  %make_build
popd
%endif

cp -a Python Python-qt6
%if %{with qt5}
pushd Python
ln -s pyproject-qt5.toml pyproject.toml
LD_LIBRARY_PATH=$PWD/../src sip-build --no-make  --qmake=%{_qt5_bindir}/qmake --api-dir=%{_qt5_datadir}/qsci/api/python --verbose \
    --qsci-include-dir=../src --qsci-library-dir=../src/ --qsci-features-dir=../src/features
%make_build -C build
popd
%endif

%if %{with qt6}
pushd src-qt6
  %qmake_qt6 qscintilla.pro QMAKE_LFLAGS_RPATH=
  %make_build
popd

pushd designer-qt6
  %qmake_qt6 designer.pro QMAKE_LFLAGS_RPATH= INCLUDEPATH-=../src INCLUDEPATH+=../src-qt6 LIBS-=-L../src LIBS+=-L../src-qt6
  %make_build
popd

pushd Python-qt6
ln -s pyproject-qt6.toml pyproject.toml
LD_LIBRARY_PATH=$PWD/../src-qt6 sip-build --no-make  --qmake=%{_qt6_bindir}/qmake --qmake-setting='QMAKE_LFLAGS_RPATH=' --api-dir=%{_qt6_datadir}/qsci/api/python --verbose \
    --qsci-include-dir=../src-qt6 --qsci-library-dir=../src-qt6/ --qsci-features-dir=../src-qt6/features
%make_build -C build
popd
%endif

%install
%if %{with qt5}
%make_install -C src INSTALL_ROOT=%{buildroot}
%make_install -C designer INSTALL_ROOT=%{buildroot}
%make_install -C Python/build INSTALL_ROOT=%{buildroot}
%endif

%if %{with qt6}
%make_install -C src-qt6 INSTALL_ROOT=%{buildroot}
%make_install -C designer-qt6 INSTALL_ROOT=%{buildroot}
%make_install -C Python-qt6/build INSTALL_ROOT=%{buildroot}
%endif

# Drop Python api files
%if %{with qt5}
rm -f %{buildroot}%{_qt5_datadir}/qsci/api/python/Python*.api
%endif
%if %{with qt6}
rm -f %{buildroot}%{_qt6_datadir}/qsci/api/python/Python*.api
%endif
