# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs     0
%else
%define build_docs     1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define qttarballdir          qt3d-everywhere-opensource-src-%{qtversion}

# Library names

%define libqt3danimation      %mklibname qt%{qtmajor}3danimation %{qtmajor}
%define libqt3dcore           %mklibname qt%{qtmajor}3dcore %{qtmajor}
%define libqt3dextras         %mklibname qt%{qtmajor}3dextras %{qtmajor}
%define libqt3dinput          %mklibname qt%{qtmajor}3dinput %{qtmajor}
%define libqt3dlogic          %mklibname qt%{qtmajor}3dlogic %{qtmajor}
%define libqt3dquick          %mklibname qt%{qtmajor}3dquick %{qtmajor}
%define libqt3dquickanimation %mklibname qt%{qtmajor}3dquickanimation %{qtmajor}
%define libqt3dquickextras    %mklibname qt%{qtmajor}3dquickextras %{qtmajor}
%define libqt3dquickinput     %mklibname qt%{qtmajor}3dquickinput %{qtmajor}
%define libqt3dquickrender    %mklibname qt%{qtmajor}3dquickrender %{qtmajor}
%define libqt3dquickscene2d   %mklibname qt%{qtmajor}3dquickscene2d %{qtmajor}
%define libqt3drender         %mklibname qt%{qtmajor}3drender %{qtmajor}
%define libqt3d_d             %mklibname qt%{qtmajor}qt3d -d

Name:           qt3d5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} 3D QML bindings and C++ APIs component
# See LICENSE.GPL LICENSE.LGPL LGPL_EXCEPTION.txt, for details
# See also https://doc.qt.io/qt-5/licensing.html
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qt3d
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl

BuildRequires:  pkgconfig(Qt5Concurrent) >= %{version}
BuildRequires:  pkgconfig(Qt5Core) >= %{version}
BuildRequires:  pkgconfig(Qt5Gui) >= %{version}
BuildRequires:  pkgconfig(Qt5Network) >= %{version}
BuildRequires:  pkgconfig(Qt5OpenGL) >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{version}
BuildRequires:  pkgconfig(Qt5XmlPatterns) >= %{version}
BuildRequires:  qtimageformats5-devel >= %{version}

BuildRequires:  pkgconfig(assimp)

Requires:       qtimageformats5 >= %{version}

Provides:       qt%{qtmajor}-qt3d = %{version}-%{release}

%description
Qt%{qtmajor} 3D provides functionality for near-realtime simulation systems
with support for 2D and 3D rendering in both Qt C++ and Qt Quick applications.

%files
%license LICENSE.GPL* LICENSE.LGPL*
%{_qt5_qml}/Qt3D/
%{_qt5_qml}/QtQuick/Scene3D/
%{_qt5_qml}/QtQuick/Scene2D/
%{_qt5_plugindir}/sceneparsers/
%{_qt5_plugindir}/renderers/
%{_qt5_plugindir}/renderplugins/
%{_qt5_plugindir}/geometryloaders/

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        Qt3D%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in Qt3D%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt5_docdir}/qt3d.qch
%{_qt5_docdir}/qt3d/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqt3danimation}
Summary:        Qt%{qtmajor} 3D Animation Component Library
Group:          System/Libraries

%description -n %{libqt3danimation}
Qt%{qtmajor} 3D Animation Component Library.

%files -n %{libqt3danimation}
%{_qt5_libdir}/libQt53DAnimation.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dcore}
Summary:        Qt%{qtmajor} 3D Core Component Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqt3dcore}
Qt%{qtmajor} 3D Core Component Library.

%files -n %{libqt3dcore}
%{_qt5_libdir}/libQt53DCore.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dextras}
Summary:        Qt%{qtmajor} 3D Extras Component Library
Group:          System/Libraries

%description -n %{libqt3dextras}
Qt%{qtmajor} 3D Extras Component Library.

%files -n %{libqt3dextras}
%{_qt5_libdir}/libQt53DExtras.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dinput}
Summary:        Qt%{qtmajor} 3D Input Component Library
Group:          System/Libraries

%description -n %{libqt3dinput}
Qt%{qtmajor} 3D Input Component Library.

%files -n %{libqt3dinput}
%{_qt5_libdir}/libQt53DInput.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dlogic}
Summary:        Qt%{qtmajor} 3D Logic Component Library
Group:          System/Libraries

%description -n %{libqt3dlogic}
Qt%{qtmajor} 3D Logic Component Library.

%files -n %{libqt3dlogic}
%{_qt5_libdir}/libQt53DLogic.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dquick}
Summary:        Qt%{qtmajor} 3D Quick Component Library
Group:          System/Libraries

%description -n %{libqt3dquick}
Qt%{qtmajor} 3D Quick Component Library.

%files -n %{libqt3dquick}
%{_qt5_libdir}/libQt53DQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dquickanimation}
Summary:        Qt%{qtmajor} 3D Quick Animation Component Library
Group:          System/Libraries

%description -n %{libqt3dquickanimation}
Qt%{qtmajor} 3D Quick Animation Component Library.

%files -n %{libqt3dquickanimation}
%{_qt5_libdir}/libQt53DQuickAnimation.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dquickextras}
Summary:        Qt%{qtmajor} 3D Quick Extras Component Library
Group:          System/Libraries

%description -n %{libqt3dquickextras}
Qt%{qtmajor} 3D Quick Extras Component Library.

%files -n %{libqt3dquickextras}
%{_qt5_libdir}/libQt53DQuickExtras.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dquickinput}
Summary:        Qt%{qtmajor} 3D Quick Input Component Library
Group:          System/Libraries

%description -n %{libqt3dquickinput}
Qt%{qtmajor} 3D Quick Input Component Library.

%files -n %{libqt3dquickinput}
%{_qt5_libdir}/libQt53DQuickInput.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dquickrender}
Summary:        Qt%{qtmajor} 3D Quick Render Component Library
Group:          System/Libraries

%description -n %{libqt3dquickrender}
Qt%{qtmajor} 3D Quick Render Component Library.

%files -n %{libqt3dquickrender}
%{_qt5_libdir}/libQt53DQuickRender.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3dquickscene2d}
Summary:        Qt%{qtmajor} 3D Quick Scene2D Component Library
Group:          System/Libraries

%description -n %{libqt3dquickscene2d}
Qt%{qtmajor} 3D Quick Scene2D Component Library.

%files -n %{libqt3dquickscene2d}
%{_qt5_libdir}/libQt53DQuickScene2D.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3drender}
Summary:        Qt%{qtmajor} 3D Render Component Library
Group:          System/Libraries

%description -n %{libqt3drender}
Qt%{qtmajor} 3D Render Component Library.

%files -n %{libqt3drender}
%{_qt5_libdir}/libQt53DRender.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqt3d_d}
Summary:        Devel files needed to build apps based on Qt3D
Group:          Development/KDE and Qt
Requires:       %{libqt3danimation} = %{version}
Requires:       %{libqt3dcore} = %{version}
Requires:       %{libqt3dextras} = %{version}
Requires:       %{libqt3dinput} = %{version}
Requires:       %{libqt3dlogic} = %{version}
Requires:       %{libqt3dquick} = %{version}
Requires:       %{libqt3dquickanimation} = %{version}
Requires:       %{libqt3dquickextras} = %{version}
Requires:       %{libqt3dquickinput} = %{version}
Requires:       %{libqt3dquickrender} = %{version}
Requires:       %{libqt3dquickscene2d} = %{version}
Requires:       %{libqt3drender} = %{version}
Provides:       libqt3d5-devel = %{version}
Provides:       libqt53d-devel = %{version}
Provides:       qt3d5-devel = %{version}
Provides:       qt53d-devel = %{version}

%description -n %{libqt3d_d}
Devel files needed to build apps based on Qt 3D.

%files -n %{libqt3d_d}
%{_qt5_includedir}/Qt3DAnimation/
%{_qt5_libdir}/libQt53DAnimation.so
%{_qt5_libdir}/libQt53DAnimation.prl
%{_qt5_libdir}/cmake/Qt53DAnimation/
%{_qt5_libdir}/pkgconfig/Qt53DAnimation.pc
#
%{_qt5_includedir}/Qt3DCore/
%{_qt5_libdir}/libQt53DCore.so
%{_qt5_libdir}/libQt53DCore.prl
%{_qt5_libdir}/cmake/Qt53DCore/
%{_qt5_libdir}/pkgconfig/Qt53DCore.pc
#
%{_qt5_includedir}/Qt3DExtras/
%{_qt5_libdir}/libQt53DExtras.so
%{_qt5_libdir}/libQt53DExtras.prl
%{_qt5_libdir}/cmake/Qt53DExtras/
%{_qt5_libdir}/pkgconfig/Qt53DExtras.pc
#
%{_qt5_includedir}/Qt3DInput/
%{_qt5_libdir}/libQt53DInput.so
%{_qt5_libdir}/libQt53DInput.prl
%{_qt5_libdir}/cmake/Qt53DInput/
%{_qt5_libdir}/pkgconfig/Qt53DInput.pc
#
%{_qt5_includedir}/Qt3DLogic/
%{_qt5_libdir}/libQt53DLogic.so
%{_qt5_libdir}/libQt53DLogic.prl
%{_qt5_libdir}/cmake/Qt53DLogic/
%{_qt5_libdir}/pkgconfig/Qt53DLogic.pc
#
%{_qt5_includedir}/Qt3DQuick/
%{_qt5_libdir}/libQt53DQuick.so
%{_qt5_libdir}/libQt53DQuick.prl
%{_qt5_libdir}/cmake/Qt53DQuick/
%{_qt5_libdir}/pkgconfig/Qt53DQuick.pc
#
%{_qt5_includedir}/Qt3DQuickAnimation/
%{_qt5_libdir}/libQt53DQuickAnimation.so
%{_qt5_libdir}/libQt53DQuickAnimation.prl
%{_qt5_libdir}/cmake/Qt53DQuickAnimation/
%{_qt5_libdir}/pkgconfig/Qt53DQuickAnimation.pc
#
%{_qt5_includedir}/Qt3DQuickExtras/
%{_qt5_libdir}/libQt53DQuickExtras.so
%{_qt5_libdir}/libQt53DQuickExtras.prl
%{_qt5_libdir}/cmake/Qt53DQuickExtras/
%{_qt5_libdir}/pkgconfig/Qt53DQuickExtras.pc
#
%{_qt5_includedir}/Qt3DQuickInput/
%{_qt5_libdir}/libQt53DQuickInput.so
%{_qt5_libdir}/libQt53DQuickInput.prl
%{_qt5_libdir}/cmake/Qt53DQuickInput/
%{_qt5_libdir}/pkgconfig/Qt53DQuickInput.pc
#
%{_qt5_includedir}/Qt3DQuickRender/
%{_qt5_libdir}/libQt53DQuickRender.so
%{_qt5_libdir}/libQt53DQuickRender.prl
%{_qt5_libdir}/cmake/Qt53DQuickRender/
%{_qt5_libdir}/pkgconfig/Qt53DQuickRender.pc
#
%{_qt5_includedir}/Qt3DQuickScene2D/
%{_qt5_libdir}/libQt53DQuickScene2D.so
%{_qt5_libdir}/libQt53DQuickScene2D.prl
%{_qt5_libdir}/cmake/Qt53DQuickScene2D/
%{_qt5_libdir}/pkgconfig/Qt53DQuickScene2D.pc
#
%{_qt5_includedir}/Qt3DRender/
%{_qt5_libdir}/libQt53DRender.so
%{_qt5_libdir}/libQt53DRender.prl
%{_qt5_libdir}/cmake/Qt53DRender/
%{_qt5_libdir}/pkgconfig/Qt53DRender.pc
#
%{_qt5_bindir}/qgltf
%{_qt5_archdatadir}/mkspecs/modules/*.pri
%{_qt5_examplesdir}/qt3d/

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qt3d-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif
