# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs     0
%else
%define build_docs     1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define qttarballdir   qtcharts-everywhere-opensource-src-%{qtversion}

# Library names

%define libqtcharts    %mklibname qt%{qtmajor}charts %{qtmajor}
%define libqtcharts_d  %mklibname qt%{qtmajor}charts -d

Name:           qtcharts5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Charts component
License:        GPLv3
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

BuildRequires:  pkgconfig(Qt5Core) >= %{version}
BuildRequires:  pkgconfig(Qt5Gui) >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{version}

Provides:       qt%{qtmajor}-qtcharts = %{version}-%{release}

%description
Qt%{qtmajor} Charts module provides a set of easy to use chart components.
It uses the Qt Graphics View Framework, therefore charts can be easily
integrated to modern user interfaces. Qt Charts can be used as QWidgets,
QGraphicsWidget, or QML types. Users can easily create impressive graphs
by selecting one of the charts themes.

%files
%license LICENSE.GPL3
%{_qt5_qml}/QtCharts/

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtCharts%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtCharts%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt5_docdir}/qtcharts.qch
%{_qt5_docdir}/qtcharts/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtcharts}
Summary:        Qt%{qtmajor} Charts Component Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtcharts}
Qt%{qtmajor} Charts Component Library.

%files -n %{libqtcharts}
%{_qt5_libdir}/libQt5Charts.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtcharts_d}
Summary:        Devel files needed to build apps based on QtCharts
Group:          Development/KDE and Qt
Requires:       %{libqtcharts} = %{version}
Provides:       libqtcharts5-devel = %{version}
Provides:       libqt5charts-devel = %{version}
Provides:       qtcharts5-devel = %{version}
Provides:       qt5charts-devel = %{version}

%description -n %{libqtcharts_d}
Devel files needed to build apps based on Qt Charts.

%files -n %{libqtcharts_d}
%{_qt5_includedir}/QtCharts/
%{_qt5_libdir}/libQt5Charts.so
%{_qt5_libdir}/pkgconfig/Qt5Charts.pc
%{_qt5_libdir}/cmake/Qt5Charts/
%{_qt5_libdir}/*.prl
%{_qt5_archdatadir}/mkspecs/modules/*.pri
%{_qt5_examplesdir}/charts/

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtcharts-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif
