# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtcharts-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtcharts       %mklibname qt%{qtmajor}charts %{qtmajor}
%define libqtcharts_d     %mklibname qt%{qtmajor}charts -d

%define libqtchartsqml    %mklibname qt%{qtmajor}chartsqml %{qtmajor}
%define libqtchartsqml_d  %mklibname qt%{qtmajor}chartsqml -d

Name:           qtcharts6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Charts component
License:        GPLv3
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## Branch Patchs

## Trunk Patchs

## Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  qtbase6-devel >= %{version}
BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6QmlIntegration) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickTest) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}
# Optional
BuildRequires:  cmake(Qt6Multimedia) >= %{version}

Provides:       qt%{qtmajor}-qtcharts = %{version}-%{release}

%description
Qt%{qtmajor} Charts module provides a set of easy to use chart components.
It uses the Qt Graphics View Framework, therefore charts can be easily
integrated to modern user interfaces. Qt Charts can be used as QWidgets,
QGraphicsWidget, or QML types. Users can easily create impressive graphs
by selecting one of the charts themes.

%files
%{_qt6_qmldir}/QtCharts/
%{_qt6_archdatadir}/sbom/qtcharts-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtCharts%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtCharts%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtcharts.qch
%{_qt6_docdir}/qtcharts/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtcharts}
Summary:        Qt%{qtmajor} Charts Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtcharts}
Qt%{qtmajor} Charts Component Library.

%files -n %{libqtcharts}
%{_qt6_libdir}/libQt6Charts.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtcharts_d}
Summary:        Devel files needed to build apps based on QtCharts
Group:          Development/KDE and Qt
Requires:       %{libqtcharts} = %{version}
Provides:       libqtcharts6-devel = %{version}
Provides:       libqt6charts-devel = %{version}
Provides:       qtcharts6-devel = %{version}
Provides:       qt6charts-devel = %{version}
Provides:       qt%{qtmajor}-qtcharts-devel = %{version}-%{release}

%description -n %{libqtcharts_d}
Devel files needed to build apps based on Qt Charts.

%files -n %{libqtcharts_d}
%{_qt6_includedir}/QtCharts/
%{_qt6_libdir}/libQt6Charts.so
%{_qt6_libdir}/cmake/Qt6Charts/
%{_qt6_libdir}/libQt6Charts.prl
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_charts.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_charts_private.pri
%{_qt6_libdir}/qt6/modules/Charts.json
%{_qt6_libdir}/qt6/metatypes/qt6charts_relwithdebinfo_metatypes.json
%if %{with examples}
%{_qt6_examplesdir}/charts/
%endif
#
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtChartsTestsConfig.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake
%{_qt6_libdir}/pkgconfig/Qt6Charts.pc

#------------------------------------------------------------------------------

%package -n     %{libqtchartsqml}
Summary:        Qt%{qtmajor} Charts Qml Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtchartsqml}
Qt%{qtmajor} Charts Qml Component Library.

%files -n %{libqtchartsqml}
%{_qt6_libdir}/libQt6ChartsQml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtchartsqml_d}
Summary:        Devel files needed to build apps based on QtChartsQml
Group:          Development/KDE and Qt
Requires:       %{libqtchartsqml} = %{version}
Provides:       libqtchartsqml6-devel = %{version}
Provides:       libqt6chartsqml-devel = %{version}
Provides:       qtchartsqml6-devel = %{version}
Provides:       qt6chartsqml-devel = %{version}
Provides:       qt%{qtmajor}-qtchartsqml-devel = %{version}-%{release}

%description -n %{libqtchartsqml_d}
Devel files needed to build apps based on Qt Charts Qml.

%files -n %{libqtchartsqml_d}
%{_qt6_includedir}/QtChartsQml/
%{_qt6_libdir}/cmake/Qt6ChartsQml/
%{_qt6_libdir}/libQt6ChartsQml.prl
%{_qt6_libdir}/libQt6ChartsQml.so
%{_qt6_libdir}/qt6/metatypes/qt6chartsqml_relwithdebinfo_metatypes.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_chartsqml.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_chartsqml_private.pri
%{_qt6_libdir}/qt6/modules/ChartsQml.json
%{_qt6_libdir}/pkgconfig/Qt6ChartsQml.pc

#------------------------------------------------------------------------------

%prep
%setup -q -n qtcharts-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
