# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 2

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtconnectivity-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtbluetooth   %mklibname qt%{qtmajor}bluetooth %{qtmajor}
%define libqtbluetooth_d %mklibname qt%{qtmajor}bluetooth -d

%define libqtnfc         %mklibname qt%{qtmajor}nfc %{qtmajor}
%define libqtnfc_d       %mklibname qt%{qtmajor}nfc -d
%define libqtnfc_p_d     %mklibname qt%{qtmajor}nfc-private -d

Name:           qtconnectivity5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Connectivity component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
Patch10:        CVE-2025-23050-qtconnectivity-5.15.diff
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtconnectivity
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-sdpscanner-fix-format-strings-for-u-int64_t.patch

BuildRequires:  qtbase5-devel >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(bluez)
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

#Patch from Fedora
Patch0:        qt5-qtconnectivity-gcc11.patch

%description
Qt%{qtmajor} Connectivity component.

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtConnectivity%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtConnectivity%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtbluetooth.qch
%{_qt5_docdir}/qtbluetooth/
%{_qt5_docdir}/qtnfc.qch
%{_qt5_docdir}/qtnfc/
%endif

#------------------------------------------------------------------------------

%package -n qtbluetooth5
Summary:        Qt%{qtmajor} Bluetooth Component Library
Group:          System/Libraries
Requires:       %{libqtbluetooth} = %{version}
Provides:       qt5bluetooth = %{version}
Provides:       qt%{qtmajor}-qtbluetooth = %{version}

%description -n qtbluetooth5
Qt%{qtmajor} Component Library.

The Qt Bluetooth enables connectivity between Bluetooth enabled devices.

%files -n qtbluetooth5
%{_qt5_bindir}/sdpscanner
%{_qt5_qml}/QtBluetooth

#------------------------------------------------------------------------------

%package -n %{libqtbluetooth}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Requires:       bluez

%description -n %{libqtbluetooth}
Qt%{qtmajor} Component Library.

The Qt Bluetooth enables connectivity between Bluetooth enabled devices.

%files -n %{libqtbluetooth}
%{_qt5_libdir}/libQt5Bluetooth.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtbluetooth_d}
Summary:        Devel files needed to build apps based on QtBluetooth
Group:          Development/KDE and Qt
Requires:       %{libqtbluetooth} = %{version}
Provides:       libqtbluetooth5-devel = %{version}
Provides:       libqt5bluetooth-devel = %{version}
Provides:       qtbluetooth5-devel = %{version}
Provides:       qt5bluetooth-devel = %{version}

Provides:       libqtbluetooth5-private-devel = %{version}
Provides:       libqt5bluetooth-private-devel = %{version}
Provides:       qtbluetooth5-private-devel = %{version}
Provides:       qt5bluetooth-private-devel = %{version}

%description -n %{libqtbluetooth_d}
Devel files needed to build apps based on Qt Bluetooth.

%files -n %{libqtbluetooth_d}
%{_qt5_libdir}/libQt5Bluetooth.prl
%{_qt5_libdir}/libQt5Bluetooth.so
%{_qt5_libdir}/pkgconfig/Qt5Bluetooth.pc
%{_qt5_libdir}/cmake/Qt5Bluetooth
%{_qt5_examplesdir}/bluetooth
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_bluetooth.pri
%{_qt5_includedir}/QtBluetooth/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_bluetooth_private.pri

#------------------------------------------------------------------------------

%package -n qtnfc5
Summary:        Qt%{qtmajor} Nfc Component Library
Group:          System/Libraries
Requires:       %{libqtnfc} = %{version}
Provides:       qt5nfc = %{version}
Provides:       qt%{qtmajor}-qtnfc = %{version}

%description -n qtnfc5
Qt%{qtmajor} Component Library.

The Qt Nfc Enables connectivity between NFC enabled devices.

%files -n qtnfc5
%{_qt5_qml}/QtNfc

#------------------------------------------------------------------------------

%package -n %{libqtnfc}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries

%description -n %{libqtnfc}
Qt%{qtmajor} Component Library.

The Qt Nfc Enables connectivity between NFC enabled devices.

%files -n %{libqtnfc}
%{_qt5_libdir}/libQt5Nfc.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtnfc_d}
Summary:        Devel files needed to build apps based on QtNfc
Group:          Development/KDE and Qt
Requires:       %{libqtnfc} = %{version}
Provides:       libqtnfc5-devel = %{version}
Provides:       libqt5nfc-devel = %{version}
Provides:       qtnfc5-devel = %{version}
Provides:       qt5nfc-devel = %{version}

Provides:       libqtnfc5-private-devel = %{version}
Provides:       libqt5nfc-private-devel = %{version}
Provides:       qtnfc5-private-devel = %{version}
Provides:       qt5nfc-private-devel = %{version}

%description -n %{libqtnfc_d}
Devel files needed to build apps based on Qt Nfc.

%files -n %{libqtnfc_d}
%{_qt5_libdir}/libQt5Nfc.prl
%{_qt5_libdir}/libQt5Nfc.so
%{_qt5_libdir}/pkgconfig/Qt5Nfc.pc
%{_qt5_libdir}/cmake/Qt5Nfc/
%{_qt5_examplesdir}/nfc
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_nfc.pri
%{_qt5_includedir}/QtNfc/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_nfc_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtconnectivity-everywhere-src-%{qtversion}

%build
%qmake_qt5
%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif
