# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtconnectivity-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtbluetooth   %mklibname qt%{qtmajor}bluetooth %{qtmajor}
%define libqtbluetooth_d %mklibname qt%{qtmajor}bluetooth -d

%define libqtnfc         %mklibname qt%{qtmajor}nfc %{qtmajor}
%define libqtnfc_d       %mklibname qt%{qtmajor}nfc -d

Name:           qtconnectivity6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Connectivity component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

#Patch from Fedora

BuildRequires:  qtbase6-devel >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickControls2)
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6QmlIntegration) >= %{version}
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  ninja
BuildRequires:  qttools6

Provides:       qt%{qtmajor}-qtconnectivity = %{version}-%{release}

%description
Qt%{qtmajor} Connectivity component.

%files
%license LICENSES/GPL* LICENSES/LGPL*
%{_qt6_archdatadir}/sbom/qtconnectivity-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtConnectivity%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtConnectivity%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt6_docdir}/qtbluetooth.qch
%{_qt6_docdir}/qtbluetooth/
%{_qt6_docdir}/qtnfc.qch
%{_qt6_docdir}/qtnfc/
%endif

#------------------------------------------------------------------------------

%package -n     qtbluetooth6
Summary:        Qt%{qtmajor} Bluetooth Component Library
Group:          System/Libraries
Requires:       %{libqtbluetooth} = %{version}
Provides:       qt%{qtmajor}bluetooth = %{version}
Provides:       qt%{qtmajor}-qtbluetooth = %{version}

%description -n qtbluetooth6
Qt%{qtmajor} Bluetooth Component Library.

The Qt Bluetooth enables connectivity between Bluetooth enabled devices.

%files -n qtbluetooth6
%{_qt6_libexecdir}/sdpscanner

#------------------------------------------------------------------------------

%package -n     %{libqtbluetooth}
Summary:        Qt%{qtmajor} Bluetooth Library
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}
Requires:       bluez

%description -n %{libqtbluetooth}
Qt%{qtmajor} Bluetooth Component Library.

The Qt Bluetooth enables connectivity between Bluetooth enabled devices.

%files -n %{libqtbluetooth}
%{_qt6_libdir}/libQt6Bluetooth.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtbluetooth_d}
Summary:        Devel files needed to build apps based on QtBluetooth
Group:          Development/KDE and Qt
Requires:       %{libqtbluetooth} = %version
Provides:       libqtbluetooth6-devel = %version
Provides:       libqt6bluetooth-devel = %version
Provides:       qtbluetooth6-devel = %version
Provides:       qt6bluetooth-devel = %version

Provides:       libqtbluetooth6-private-devel = %version
Provides:       libqt6bluetooth-private-devel = %version
Provides:       qtbluetooth6-private-devel = %version
Provides:       qt6bluetooth-private-devel = %version

%description -n %{libqtbluetooth_d}
Devel files needed to build apps based on Qt Bluetooth.

%files -n %{libqtbluetooth_d}
%{_qt6_includedir}/QtBluetooth/
%{_qt6_libdir}/libQt6Bluetooth.so
%{_qt6_libdir}/cmake/Qt6Bluetooth/
%{_qt6_libdir}/libQt6Bluetooth.prl
%{_qt6_libdir}/pkgconfig/Qt6Bluetooth.pc
%{_qt6_libdir}/qt6/modules/Bluetooth.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_bluetooth.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_bluetooth_private.pri
%if %{with examples}
%{_qt6_examplesdir}/bluetooth
%endif
#
%{_qt6_libdir}/cmake/Qt6/FindBlueZ.cmake
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtConnectivityTestsConfig.cmake
%{_qt6_libdir}/qt6/metatypes/qt6bluetooth_relwithdebinfo_metatypes.json

#------------------------------------------------------------------------------

%package -n     %{libqtnfc}
Summary:        Qt%{qtmajor} Nfc Library
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}
Obsoletes:      qtnfc6 < 6.7.2-2

%description -n %{libqtnfc}
Qt%{qtmajor} Nfc Component Library.

The Qt Nfc Enables connectivity between NFC enabled devices.

%files -n %{libqtnfc}
%{_qt6_libdir}/libQt6Nfc.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtnfc_d}
Summary:        Devel files needed to build apps based on QtNfc
Group:          Development/KDE and Qt
Requires:       %{libqtnfc} = %version
Provides:       libqtnfc6-devel = %version
Provides:       libqt6nfc-devel = %version
Provides:       qtnfc6-devel = %version
Provides:       qt6nfc-devel = %version

Provides:       libqtnfc6-private-devel = %version
Provides:       libqt6nfc-private-devel = %version
Provides:       qtnfc6-private-devel = %version
Provides:       qt6nfc-private-devel = %version

%description -n %{libqtnfc_d}
Devel files needed to build apps based on Qt Nfc.

%files -n %{libqtnfc_d}
%{_qt6_includedir}/QtNfc/
%{_qt6_libdir}/libQt6Nfc.so
%{_qt6_libdir}/cmake/Qt6Nfc/
%{_qt6_libdir}/libQt6Nfc.prl
%{_qt6_libdir}/pkgconfig/Qt6Nfc.pc
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_nfc.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_nfc_private.pri
%{_qt6_libdir}/qt6/modules/Nfc.json
%{_qt6_libdir}/qt6/metatypes/qt6nfc_relwithdebinfo_metatypes.json
%if %{with examples}
%{_qt6_examplesdir}/nfc
%endif
#
%{_qt6_libdir}/cmake/Qt6/FindPCSCLITE.cmake

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtconnectivity-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
