# Build configuration

# set to '1' to do a bootstrap build
# thus disabling examples and docs as they needs pkg itself to build
%define bootstrap 0

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%if %bootstrap
%define build_docs 0
%else
%define build_docs 1
%endif
%endif

%if %bootstrap
%bcond_with examples
%else
%bcond_without examples
%endif

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtdatavis3d-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtdatavis3d   %mklibname qt%{qtmajor}datavisualization %{qtmajor}
%define libqtdatavis3dq  %mklibname qt%{qtmajor}datavisualizationqml %{qtmajor}
%define libqtdatavis3d_d %mklibname qt%{qtmajor}datavisualization -d

Name:           qtdatavis3d6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} 3D Data Visualization component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## Branch Patchs

## Trunk Patchs

## Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  cmake(Qt6Core) >= %{version}
%if %{with examples}
BuildRequires:  cmake(Qt6DataVisualization) >= %{version}
%endif
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6QmlIntegration) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickTest) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}

Provides:       qt%{qtmajor}-qtdatavis3d = %{version}-%{release}

%description
Qt%{qtmajor} 3D Data Visualization component.

%files
%{_qt6_qmldir}/QtDataVisualization/
%{_qt6_archdatadir}/sbom/qtdatavisualization-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtDataVis3D%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtDataVis3D%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtdatavis3d.qch
%{_qt6_docdir}/qtdatavis3d/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtdatavis3d}
Summary:        Qt%{qtmajor} 3D Data Visualization Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtdatavis3d}
Qt%{qtmajor} 3D Data Visualization Component Library.

%files -n %{libqtdatavis3d}
%{_qt6_libdir}/libQt6DataVisualization.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtdatavis3dq}
Summary:        Qt%{qtmajor} 3D Data Visualization Qml Library
Group:          System/Libraries
Requires:	%{name} = %{version}

%description -n %{libqtdatavis3dq}
Qt%{qtmajor} 3D Data Visualization Qml Component Library.               

%files -n %{libqtdatavis3dq} 
%{_qt6_libdir}/libQt6DataVisualizationQml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtdatavis3d_d}
Summary:        Devel files needed to build apps based on QtDataVis3D
Group:          Development/KDE and Qt
Requires:       %{libqtdatavis3d} = %{version}
Requires:       %{libqtdatavis3dq} = %{version}
Provides:       libqtdatavis3d6-devel = %{version}
Provides:       libqt6datavis3d-devel = %{version}
Provides:       qtdatavis3d6-devel = %{version}
Provides:       qt6datavis3d-devel = %{version}
Provides:       qt%{qtmajor}-qtdatavis3d-devel = %{version}-%{release}

%description -n %{libqtdatavis3d_d}
Devel files needed to build apps based on Qt DataVis3D.

%files -n %{libqtdatavis3d_d}
%{_qt6_includedir}/QtDataVisualization/
%{_qt6_includedir}/QtDataVisualizationQml/
%{_qt6_libdir}/libQt6DataVisualization.so
%{_qt6_libdir}/libQt6DataVisualizationQml.so
%{_qt6_libdir}/cmake/Qt6DataVisualization/
%{_qt6_libdir}/libQt6DataVisualization.prl
%{_qt6_libdir}/libQt6DataVisualizationQml.prl
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_datavisualization.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_datavisualization_private.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_datavisualizationqml.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_datavisualizationqml_private.pri
%{_qt6_libdir}/qt6/modules/DataVisualization.json
%{_qt6_libdir}/qt6/modules/DataVisualizationQml.json
%{_qt6_libdir}/qt6/metatypes/qt6datavisualization_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/metatypes/qt6datavisualizationqml_relwithdebinfo_metatypes.json
%if %{with examples}
%{_qt6_examplesdir}/*
%endif
#
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtDataVisualizationTestsConfig.cmake
%{_qt6_libdir}/cmake/Qt6DataVisualizationQml/
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake
%{_qt6_libdir}/pkgconfig/Qt6DataVisualization.pc
%{_qt6_libdir}/pkgconfig/Qt6DataVisualizationQml.pc

#------------------------------------------------------------------------------

%prep
%setup -q -n qtdatavis3d-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
