### Qt5 Libraries
%define lib_major_qt5 1
%define lib_name_qt5  %mklibname qt5keychain %{lib_major_qt5}
%define lib_dev_qt5   %mklibname qt5keychain -d
### Qt6 Libraries
%define lib_major_qt6 1
%define lib_name_qt6  %mklibname qt6keychain %{lib_major_qt6}
%define lib_dev_qt6   %mklibname qt6keychain -d

%bcond_without qt5
%bcond_without qt6

Name:           qtkeychain
Summary:        Platform-independent Qt API for storing passwords securely
Version:        0.14.3
Release:        %mkrel 1
License:        LGPLv2+
Group:          Graphical desktop/KDE
Url:            https://github.com/frankosterfeld/qtkeychain
Source0:        https://github.com/frankosterfeld/qtkeychain/archive/%version/%{name}-%{version}.tar.gz
### Qt5 Build dependencies
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Help)
### Qt6 Build dependencies
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Help)

BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  cmake

%description
Platform-independent Qt API for storing passwords securely.

#------------------------------------------------------------------

%if %{with qt5}
%package -n     %{lib_name_qt5}
Summary:        Platform-independent Qt5 API for storing passwords securely
Group:          System/Libraries

%description -n %{lib_name_qt5}
Platform-independent Qt5 API for storing passwords securely.

%files -n %{lib_name_qt5}
%{_libdir}/libqt5keychain.so.%{lib_major_qt5}{,.*}
%{_libdir}/libqt5keychain.so.%{version}
%{_datadir}/qt5keychain/

#------------------------------------------------------------------

%package -n     %{lib_dev_qt5}
Summary:        Development tools for programs which will use the Qt5 keychain
Group:          Development/C
Requires:       %{lib_name_qt5} = %{version}
Provides:       qt5keychain-devel = %{version}-%{release}
Provides:       libqt5keychain-devel = %{version}-%{release}

%description -n %{lib_dev_qt5}
This package contains the header files and .so libraries
for developing qt5keychain.

%files -n %{lib_dev_qt5}
%doc ChangeLog ReadMe.md
%{_includedir}/qt5keychain/
%{_libdir}/libqt5keychain.so
%{_libdir}/cmake/Qt5Keychain/
%{_qt5_archdatadir}/mkspecs/modules/qt_Qt5Keychain.pri
%endif

#------------------------------------------------------------------

%if %{with qt6}
%package -n     %{lib_name_qt6}
Summary:        Platform-independent Qt6 API for storing passwords securely
Group:          System/Libraries

%description -n %{lib_name_qt6}
Platform-independent Qt6 API for storing passwords securely.

%files -n %{lib_name_qt6}
%license COPYING
%{_libdir}/libqt6keychain.so.%{lib_major_qt6}{,.*}
%{_libdir}/libqt6keychain.so.%{version}
%{_datadir}/qt6keychain/

#------------------------------------------------------------------

%package -n     %{lib_dev_qt6}
Summary:        Development tools for programs which will use the Qt6 keychain
Group:          Development/C
Requires:       %{lib_name_qt6} = %{version}
Provides:       qt6keychain-devel = %{version}-%{release}
Provides:       libqt6keychain-devel = %{version}-%{release}

%description -n %{lib_dev_qt6}
This package contains the header files and .so libraries
for developing qt6keychain.

%files -n %{lib_dev_qt6}
%doc ChangeLog ReadMe.md
%{_includedir}/qt6keychain/
%{_libdir}/libqt6keychain.so
%{_libdir}/cmake/Qt6Keychain/
%{_qt6_archdatadir}/mkspecs/modules/*.pri
%endif

#------------------------------------------------------------------

%prep
%autosetup -p1

%build
%if %{with qt5}
%define _vpath_builddir %{_target_platform}-qt5
%cmake_qt5 \
        -DBUILD_WITH_QT6:BOOL=OFF \
        -DLIBSECRET_SUPPORT=ON \
        -DECM_MKSPECS_INSTALL_DIR=%{_qt5_archdatadir}/mkspecs/modules

%cmake_build
%endif

%if %{with qt6}
%define _vpath_builddir %{_target_platform}-qt6
%cmake_qt6 \
        -DBUILD_WITH_QT6:BOOL=ON \
        -DLIBSECRET_SUPPORT=ON \
        -DECM_MKSPECS_INSTALL_DIR=%{_qt6_archdatadir}/mkspecs/modules

%cmake_build
%endif

%install
%if %{with qt5}
%define _vpath_builddir %{_target_platform}-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir %{_target_platform}-qt6
%cmake_install
%endif
