# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtmultimedia-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqt5multimedia           %mklibname qt%{qtmajor}multimedia %{qtmajor}
%define libqt5multimedia_d         %mklibname qt%{qtmajor}multimedia -d

%define libqt5multimediawidgets    %mklibname qt%{qtmajor}multimediawidgets %{qtmajor}
%define libqt5multimediawidgets_d  %mklibname qt%{qtmajor}multimediawidgets -d

%define libqt5multimediagsttools   %mklibname qt%{qtmajor}multimediagsttools %{qtmajor}
%define libqt5multimediagsttools_d %mklibname qt%{qtmajor}multimediagsttools -d

%define libqtmultimediaquick       %mklibname qt%{qtmajor}multimediaquick %{qtmajor}
%define libqtmultimediaquick_d     %mklibname qt%{qtmajor}multimediaquick -d

Name:           qtmultimedia5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Multimedia component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtmultimedia
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Pass-explicit-GL-api-when-initializing-GStreamer-bac.patch
Patch0002:      0002-Drop-obsolete-QtOpengl-dependency.patch

BuildRequires:  qtbase5-devel = %{version}
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(openal)

BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gstreamer-bad-audio-1.0)

BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(alsa)

BuildRequires:  pkgconfig(Qt5Qml) = %{version}
BuildRequires:  pkgconfig(Qt5Quick) = %{version}

Provides:       qt%{qtmajor}-qtmultimedia = %{version}-%{release}

#Branch Patchs

#Trunk Patchs

#Patch from Mageia

#Patch from Fedora
Patch100000:    qt5-qtmultimedia-gcc11.patch

%description
Qt%{qtmajor} Multimedia component.

%files
%_qt5_plugindir/audio/*.so
%_qt5_plugindir/mediaservice/*.so
%_qt5_plugindir/playlistformats/libqtmultimedia_m3u.so
%_qt5_qml/QtAudioEngine
%_qt5_qml/QtMultimedia

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtMultimedia%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtMultimedia%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtmultimedia.qch
%{_qt5_docdir}/qtmultimedia/
%endif

#------------------------------------------------------------------------------

%package -n %{libqt5multimedia}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries

%description -n %{libqt5multimedia}
Qt%{qtmajor} Lib.

%files -n %{libqt5multimedia}
%{_qt5_libdir}/libQt5Multimedia.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqt5multimedia_d}
Summary:        Devel files needed to build apps based on QtMultimedia
Group:          Development/KDE and Qt
Requires:       %{libqt5multimedia} = %{version}
Requires:       %{name} = %{version}
Provides:       libqtmultimedia5-devel = %{version}
Provides:       libqt5multimedia-devel = %{version}
Provides:       qtmultimedia5-devel = %{version}
Provides:       qt5multimedia-devel = %{version}

Provides:       libqtmultimedia5-private-devel = %{version}
Provides:       libqt5multimedia-private-devel = %{version}
Provides:       qtmultimedia5-private-devel = %{version}
Provides:       qt5multimedia-private-devel = %{version}

%description -n %{libqt5multimedia_d}
Devel files needed to build apps based on QtMultimedia.

%files -n %{libqt5multimedia_d}
%{_qt5_libdir}/cmake/Qt5Multimedia
%{_qt5_includedir}/QtMultimedia/
%{_qt5_libdir}/libQt5Multimedia.so
%{_qt5_libdir}/libQt5Multimedia.prl
%{_qt5_libdir}/pkgconfig/Qt5Multimedia.pc
%{_qt5_examplesdir}/multimedia
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimedia.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimedia_private.pri

#------------------------------------------------------------------------------

%package -n %{libqt5multimediawidgets}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqt5multimediawidgets}
Qt%{qtmajor} Lib.

%files -n %{libqt5multimediawidgets}
%{_qt5_libdir}/libQt5MultimediaWidgets.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqt5multimediawidgets_d}
Summary:        Devel files needed to build apps based on QtMultimediaWidget
Group:          Development/KDE and Qt
Requires:       %{libqt5multimediawidgets} = %{version}
Provides:       libqtmultimediawidgets5-devel = %{version}
Provides:       libqt5multimediawidgets-devel = %{version}
Provides:       qtmultimediawidgets5-devel = %{version}
Provides:       qt5multimediawidgets-devel = %{version}

Provides:       libqtmultimediawidgets5-private-devel = %{version}
Provides:       libqt5multimediawidgets-private-devel = %{version}
Provides:       qtmultimediawidgets5-private-devel = %{version}
Provides:       qt5multimediawidgets-private-devel = %{version}

%description -n %{libqt5multimediawidgets_d}
Devel files needed to build apps based on QtMultimediaWidget.

%files -n %{libqt5multimediawidgets_d}
%{_qt5_libdir}/cmake/Qt5MultimediaWidgets
%{_qt5_includedir}/QtMultimediaWidgets/
%{_qt5_libdir}/libQt5MultimediaWidgets.so
%{_qt5_libdir}/libQt5MultimediaWidgets.prl
%{_qt5_libdir}/pkgconfig/Qt5MultimediaWidgets.pc
%{_qt5_examplesdir}/multimediawidgets
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimediawidgets.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimediawidgets_private.pri

#------------------------------------------------------------------------------

%package -n %{libqt5multimediagsttools}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries

%description -n %{libqt5multimediagsttools}
Qt%{qtmajor} Lib.

%files -n %{libqt5multimediagsttools}
%{_qt5_libdir}/libQt5MultimediaGstTools.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqt5multimediagsttools_d}
Summary:        Devel files needed to build apps based on QtMultimediaGsttools
Group:          Development/KDE and Qt
Requires:       %{libqt5multimediagsttools} = %{version}
Provides:       libqtmultimediagsttools5-devel = %{version}
Provides:       libqt5multimediagsttools-devel = %{version}
Provides:       qtmultimediagsttools5-devel = %{version}
Provides:       qt5multimediagsttools-devel = %{version}

%description -n %{libqt5multimediagsttools_d}
Devel files needed to build apps based on QtMultimediaGsttools.

%files -n %{libqt5multimediagsttools_d}
%{_qt5_includedir}/QtMultimediaGstTools/
%{_qt5_libdir}/libQt5MultimediaGstTools.prl
%{_qt5_libdir}/libQt5MultimediaGstTools.so
%{_qt5_libdir}/cmake/Qt5MultimediaGstTools/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimediagsttools_private.pri

#------------------------------------------------------------------------------

%package -n %{libqtmultimediaquick}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtmultimediaquick}
Qt%{qtmajor} Lib.

%files -n %{libqtmultimediaquick}
%{_qt5_libdir}/libQt5MultimediaQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtmultimediaquick_d}
Summary:        Devel files needed to build apps based on QtMultimediaQuick
Group:          Development/KDE and Qt
Requires:       %{libqtmultimediaquick} = %{version}
Provides:       libqtmultimediaquick5-devel = %{version}
Provides:       libqt5multimediaquick-devel = %{version}
Provides:       qt5multimediaquick-devel = %{version}
Provides:       qtmultimediaquick5-devel = %{version}

%description -n %{libqtmultimediaquick_d}
Devel files needed to build apps based on QtMultimediaQuick.

%files -n %{libqtmultimediaquick_d}
%{_qt5_libdir}/libQt5MultimediaQuick.prl
%{_qt5_libdir}/libQt5MultimediaQuick.so
%{_qt5_libdir}/cmake/Qt5MultimediaQuick/
%{_qt5_includedir}/QtMultimediaQuick/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_qtmultimediaquicktools_private.pri

#------------------------------------------------------------------------------

%prep
%setup -q -n qtmultimedia-everywhere-src-%{qtversion}
%autopatch -p1

%build
%qmake_qt5 GST_VERSION=1.0

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# .la and .a files, die, die, die.
find %{buildroot} -name '*.la' -delete

## .prl/.la file love
# nuke .prl reference(s) to %%buildroot, excessive (.la-like) libs
pushd %{buildroot}%{_qt5_libdir}
for prl_file in libQt5*.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd
