# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtopcua-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtopcua              %mklibname qt%{qtmajor}opcua %{qtmajor}
%define libqtopcua_d            %mklibname qt%{qtmajor}opcua -d

%define libqtdeclarativeopcua   %mklibname qt%{qtmajor}declarativeopcua %{qtmajor}
%define libqtdeclarativeopcua_d %mklibname qt%{qtmajor}declarativeopcua -d

Name:           qtopcua6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} OPC UA component
License:        LGPL-3.0-only OR GPL-3.0-only WITH Qt-GPL-exception-1.0
Group:          Development/KDE and Qt
Url:            https://www.qt.io
#Source0:        https://github.com/qt/qtopcua/archive/v%%{version}/qtopcua-%%{version}.tar.gz
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

## upstreamable patches

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Network) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickTest) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}

BuildRequires:  pkgconfig(openssl)
BuildRequires:  mbedtls-devel
#BuildRequires: open62541-devel

Provides:       qt%{qtmajor}-qtopcua = %{version}-%{release}

%description
Qt%{qtmajor} OPC UA (API) provides classes and functions to access
the OPC UA protocol.

%files
%license LICENSES/*
%dir %{_qt6_plugindir}/opcua/
%{_qt6_plugindir}/opcua/libopen62541_backend.so
%{_qt6_qmldir}/QtOpcUa/
%{_qt6_bindir}/qopcuaxmldatatypes2cpp
%{_qt6_archdatadir}/sbom/qtopcua-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtOpcUa%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtOpcUa%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtopcua.qch
%{_qt6_docdir}/qtopcua/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtopcua}
Summary:        Qt%{qtmajor} OpcUa Library
Group:          System/Libraries
Requires:       qt%{qtmajor}-qtopcua >= %{version}-%{release}

%description -n %{libqtopcua}
Qt%{qtmajor} OpcUa Component Library.

%files -n %{libqtopcua}
%license LICENSES/*
%{_qt6_libdir}/libQt6OpcUa.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtopcua_d}
Summary:        Devel files needed to build apps based on QtOpcUa
Group:          Development/KDE and Qt
Requires:       %{libqtopcua} = %{version}
Provides:       libqtopcua6-devel = %{version}
Provides:       libqt6opcua-devel = %{version}
Provides:       qtopcua6-devel = %{version}
Provides:       qt6opcua-devel = %{version}
Provides:       qt%{qtmajor}-qtopcua-devel = %{version}-%{release}

%description -n %{libqtopcua_d}
Devel files needed to build apps based on Qt OpcUa.

%files -n %{libqtopcua_d}
%{_qt6_includedir}/QtOpcUa/
%{_qt6_libdir}/libQt6OpcUa.so
%{_qt6_libdir}/cmake/Qt6OpcUa/
%{_qt6_libdir}/libQt6OpcUa.prl
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_opcua.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_opcua_private.pri
%{_qt6_libdir}/qt6/modules/OpcUa.json
%{_qt6_libdir}/qt6/metatypes/qt6opcua_*_metatypes.json
%{_qt6_libdir}/pkgconfig/Qt6OpcUa.pc
%if %{with examples}
%{_qt6_examplesdir}/opcua/
%endif
#
%{_qt6_libdir}/cmake/Qt6QtOpcUaTools/
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtOpcUaTestsConfig.cmake
%{_qt6_libdir}/cmake/Qt6/*.cmake

#------------------------------------------------------------------------------

%package -n     %{libqtdeclarativeopcua}
Summary:        Qt%{qtmajor} Declarative OpcUa Library
Group:          System/Libraries

%description -n %{libqtdeclarativeopcua}
Qt%{qtmajor} Declarative OpcUa Component Library.

%files -n %{libqtdeclarativeopcua}
%license LICENSES/*
%{_qt6_libdir}/libQt6DeclarativeOpcua.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtdeclarativeopcua_d}
Summary:        Devel files needed to build apps based on QtDeclarativeOpcUa
Group:          Development/KDE and Qt
Requires:       %{libqtdeclarativeopcua} = %{version}
Provides:       libqtdeclarativeopcua6-devel = %{version}
Provides:       libqt6declarativeopcua-devel = %{version}
Provides:       qtdeclarativeopcua6-devel = %{version}
Provides:       qt6declarativeopcua-devel = %{version}
Provides:       qt%{qtmajor}-qtdeclarativeopcua-devel = %{version}-%{release}

%description -n %{libqtdeclarativeopcua_d}
Devel files needed to build apps based on Qt DeclarativeOpcUa.

%files -n %{libqtdeclarativeopcua_d}
%{_qt6_includedir}/QtDeclarativeOpcua/
%{_qt6_libdir}/libQt6DeclarativeOpcua.so
%{_qt6_libdir}/cmake/Qt6DeclarativeOpcua/
%{_qt6_libdir}/libQt6DeclarativeOpcua.prl
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_declarativeopcua.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_declarativeopcua_private.pri
%{_qt6_libdir}/qt6/modules/DeclarativeOpcua.json
%{_qt6_libdir}/qt6/metatypes/qt6declarativeopcua_*_metatypes.json
%{_qt6_libdir}/pkgconfig/Qt6DeclarativeOpcua.pc
#
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/Qt6DeclarativeOpcuaplugin*.cmake

#------------------------------------------------------------------------------

%prep
%autosetup -n qtopcua-everywhere-src-%{qtversion}

%build
%cmake_qt6 \
        %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF} \
        %{!?with_examples:-DQT_INSTALL_EXAMPLES_SOURCES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
