# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs     0
%else
%define build_docs     1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define qttarballdir            qtquick3d-everywhere-opensource-src-%{qtversion}

# Library names

%define libqtquick3d            %mklibname qt%{qtmajor}quick3d %{qtmajor}
%define libqtquick3dassetimport %mklibname qt%{qtmajor}quick3dassetimport %{qtmajor}
%define libqtquick3drender      %mklibname qt%{qtmajor}quick3drender %{qtmajor}
%define libqtquick3druntime     %mklibname qt%{qtmajor}quick3druntimerender %{qtmajor}
%define libqtquick3dutils       %mklibname qt%{qtmajor}quick3dutils %{qtmajor}
%define libqtquick3d_d          %mklibname qt%{qtmajor}quick3d -d

Name:           qtquick3d5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Quick 3D bindings and C++ APIs component
# See LICENSE.GPL LICENSE.LGPL LGPL_EXCEPTION.txt, for details
# See also https://doc.qt.io/qt-5/licensing.html
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtquick3d
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Fix-build-with-system-assimp.patch

BuildRequires:  pkgconfig(Qt5Core) >= %{version}
BuildRequires:  pkgconfig(Qt5Gui) >= %{version}
BuildRequires:  pkgconfig(Qt5OpenGL) >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{version}
BuildRequires:  qtimageformats5-devel >= %{version}

BuildRequires:  pkgconfig(assimp)

Requires:       qtimageformats5 >= %{version}

Provides:       qt%{qtmajor}-qtquick3d = %{version}-%{release}

%description
Qt%{qtmajor} Quick 3D provides everything necessary build Qt Quick 3D.
Qt Quick 3D is a high level 3D API for Qt Quick. Qt Quick 3D enables
anyone to introduce 3D content into their Qt Quick applications.
Rather than requiring the end user to know advanced details of the
graphics rendering pipeline (building framegraphs and materials), it
is now possible to simply build up a 3D scene using high level primitives.
It is a new module and API for defining 3D content in Qt Quick.

%files
%doc README.md
%license LICENSE.GPL*
%{_qt5_bindir}/balsam
%{_qt5_bindir}/meshdebug
%{_qt5_qml}/QtQuick3D/
%{_qt5_plugindir}/assetimporters/

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtQuick3D%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtQuick3D%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt5_docdir}/qtquick3d.qch
%{_qt5_docdir}/qtquick3d/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtquick3d}
Summary:        Qt%{qtmajor} Quick 3D Component Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtquick3d}
Qt%{qtmajor} Quick 3D Component Library.

%files -n %{libqtquick3d}
%{_qt5_libdir}/libQt5Quick3D.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtquick3dassetimport}
Summary:        Qt%{qtmajor} Quick 3D Asset Import Component Library
Group:          System/Libraries

%description -n %{libqtquick3dassetimport}
Qt%{qtmajor} Quick 3D Asset Import Component Library.

%files -n %{libqtquick3dassetimport}
%{_qt5_libdir}/libQt5Quick3DAssetImport.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtquick3drender}
Summary:        Qt%{qtmajor} Quick 3D Render Component Library
Group:          System/Libraries

%description -n %{libqtquick3drender}
Qt%{qtmajor} Quick 3D Render Component Library.

%files -n %{libqtquick3drender}
%{_qt5_libdir}/libQt5Quick3DRender.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtquick3druntime}
Summary:        Qt%{qtmajor} Quick 3D Runtime Render Component Library
Group:          System/Libraries

%description -n %{libqtquick3druntime}
Qt%{qtmajor} Quick 3D Runtime Render Component Library.

%files -n %{libqtquick3druntime}
%{_qt5_libdir}/libQt5Quick3DRuntimeRender.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtquick3dutils}
Summary:        Qt%{qtmajor} Quick 3D Utils Component Library
Group:          System/Libraries

%description -n %{libqtquick3dutils}
Qt%{qtmajor} Quick 3D Utils Component Library.

%files -n %{libqtquick3dutils}
%{_qt5_libdir}/libQt5Quick3DUtils.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtquick3d_d}
Summary:        Devel files needed to build apps based on QtQuick3D
Group:          Development/KDE and Qt
Requires:       %{libqtquick3d} = %{version}
Requires:       %{libqtquick3dassetimport} = %{version}
Requires:       %{libqtquick3drender} = %{version}
Requires:       %{libqtquick3druntime} = %{version}
Requires:       %{libqtquick3dutils} = %{version}
Provides:       libqtquick3d5-devel = %{version}
Provides:       libqt5quick3d-devel = %{version}
Provides:       qtquick3d5-devel = %{version}
Provides:       qt5quick3d-devel = %{version}

%description -n %{libqtquick3d_d}
Devel files needed to build apps based on Qt Quick 3D.

%files -n %{libqtquick3d_d}
%{_qt5_includedir}/QtQuick3D/
%{_qt5_libdir}/libQt5Quick3D.so
%{_qt5_libdir}/libQt5Quick3D.prl
%{_qt5_libdir}/cmake/Qt5Quick3D/
%{_qt5_libdir}/pkgconfig/Qt5Quick3D.pc
#
%{_qt5_includedir}/QtQuick3DAssetImport/
%{_qt5_libdir}/libQt5Quick3DAssetImport.so
%{_qt5_libdir}/libQt5Quick3DAssetImport.prl
%{_qt5_libdir}/cmake/Qt5Quick3DAssetImport/
%{_qt5_libdir}/pkgconfig/Qt5Quick3DAssetImport.pc
#
%{_qt5_includedir}/QtQuick3DRender/
%{_qt5_libdir}/libQt5Quick3DRender.so
%{_qt5_libdir}/libQt5Quick3DRender.prl
%{_qt5_libdir}/cmake/Qt5Quick3DRender/
%{_qt5_libdir}/pkgconfig/Qt5Quick3DRender.pc
#
%{_qt5_includedir}/QtQuick3DRuntimeRender/
%{_qt5_libdir}/libQt5Quick3DRuntimeRender.so
%{_qt5_libdir}/libQt5Quick3DRuntimeRender.prl
%{_qt5_libdir}/cmake/Qt5Quick3DRuntimeRender/
%{_qt5_libdir}/pkgconfig/Qt5Quick3DRuntimeRender.pc
#
%{_qt5_includedir}/QtQuick3DUtils/
%{_qt5_libdir}/libQt5Quick3DUtils.so
%{_qt5_libdir}/libQt5Quick3DUtils.prl
%{_qt5_libdir}/cmake/Qt5Quick3DUtils/
%{_qt5_libdir}/pkgconfig/Qt5Quick3DUtils.pc
#

#
%{_qt5_archdatadir}/mkspecs/modules/*.pri
%{_qt5_examplesdir}/quick3d/

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtquick3d-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif
