# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir         qtremoteobjects-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtremoteobjects   %mklibname qt%{qtmajor}remoteobjects %{qtmajor}
%define libqtremoteobjects_d %mklibname qt%{qtmajor}remoteobjects -d

Name:           qtremoteobjects6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} RemoteObjects component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## Branch Patchs

## Trunk Patchs

## Patch from Mageia

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Network) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6QmlIntegration) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickTest) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}
BuildRequires:  ninja
BuildRequires:  qttools6
# optional
BuildRequires:  cmake(Qt6Bluetooth) >= %{version}

Provides:       qt%{qtmajor}-qtremoteobjects = %{version}-%{release}

%description
Qt%{qtmajor} Remote Objects module provides an easy to use mechanism for
sharing a QObject's API (Properties/Signals/Slots) between processes.

%files
%{_qt6_libexecdir}/repc
%{_qt6_qmldir}/QtRemoteObjects/
%{_qt6_archdatadir}/sbom/qtremoteobjects-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtRemoteObjects%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtRemoteObjects%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtremoteobjects.qch
%{_qt6_docdir}/qtremoteobjects/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtremoteobjects}
Summary:        Qt%{qtmajor} RemoteObjects Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtremoteobjects}
Qt%{qtmajor} RemoteObjects Component Library.

%files -n %{libqtremoteobjects}
%{_qt6_libdir}/libQt6RemoteObjects.so.%{qtmajor}{,.*}
%{_qt6_libdir}/libQt6RemoteObjectsQml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtremoteobjects_d}
Summary:        Devel files needed to build apps based on QtRemoteObjects
Group:          Development/KDE and Qt
Requires:       %{libqtremoteobjects} = %{version}
Provides:       libqtremoteobjects6-devel = %{version}
Provides:       libqt6remoteobjects-devel = %{version}
Provides:       qtremoteobjects6-devel = %{version}
Provides:       qt6remoteobjects-devel = %{version}

%description -n %{libqtremoteobjects_d}
Devel files needed to build apps based on Qt RemoteObjects.

%files -n %{libqtremoteobjects_d}
%{_qt6_includedir}/QtRemoteObjects/
%{_qt6_libdir}/libQt6RemoteObjects.so
%{_qt6_libdir}/cmake/Qt6RemoteObjects/
%{_qt6_libdir}/cmake/Qt6RemoteObjectsTools/
%{_qt6_libdir}/pkgconfig/Qt6RemoteObjects.pc
%{_qt6_libdir}/qt6/metatypes/qt6remoteobjects_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/RemoteObjects.json
#
%{_qt6_includedir}/QtRemoteObjectsQml/
%{_qt6_libdir}/libQt6RemoteObjectsQml.so
%{_qt6_libdir}/cmake/Qt6RemoteObjectsQml/
%{_qt6_libdir}/pkgconfig/Qt6RemoteObjectsQml.pc
%{_qt6_libdir}/qt6/metatypes/qt6remoteobjectsqml_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/RemoteObjectsQml.json
#
%{_qt6_includedir}/QtRepParser/
%{_qt6_libdir}/pkgconfig/Qt6RepParser.pc
%{_qt6_libdir}/cmake/Qt6RepParser/
%{_qt6_libdir}/qt6/modules/RepParser.json
#
%{_qt6_libdir}/*.prl
%{_qt6_archdatadir}/mkspecs/modules/*.pri
%{_qt6_archdatadir}/mkspecs/features/*.pri
%{_qt6_archdatadir}/mkspecs/features/*.prf
%if %{with examples}
%{_qt6_examplesdir}/remoteobjects/
%endif
#
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/*.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake

#------------------------------------------------------------------------------

%prep
%setup -q -n qtremoteobjects-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
