# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs   0
%else
%define build_docs   1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define qttarballdir qtscxml-everywhere-opensource-src-%{qtversion}

# Library names

%define libqtscxml   %mklibname qt%{qtmajor}scxml %{qtmajor}
%define libqtscxml_d %mklibname qt%{qtmajor}scxml -d

Name:           qtscxml5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} ScXml component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## Upstream patches:

BuildRequires:  pkgconfig(Qt5Core) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{version}

Provides:       qt%{qtmajor}-qtscxml = %{version}-%{release}

%description
The Qt SCXML module provides functionality to create state machines from
SCXML files.

This includes both dynamically creating state machines (loading the SCXML
file and instantiating states and transitions) and generating a C++ file
that has a class implementing the state machine. It also contains
functionality to support data models and executable content.

%files
%license LICENSE.GPL3-EXCEPT LICENSE.LGPL3
%{_qt5_bindir}/qscxmlc
%{_qt5_qml}/QtScxml/

#------------------------------------------------------------------------------

%if %{build_docs}
%package	doc
Summary:        QtScXml%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtScXml%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt5_docdir}/qtscxml.qch
%{_qt5_docdir}/qtscxml/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtscxml}
Summary:        Qt%{qtmajor} ScXml Component Library
Group:          System/Libraries

%description -n %{libqtscxml}
Qt%{qtmajor} ScXml Component Library.

%files -n %{libqtscxml}
%{_qt5_libdir}/libQt5Scxml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtscxml_d}
Summary:        Devel files needed to build apps based on QtScXml
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtscxml} = %{version}
Provides:       libqtscxml5-devel = %{version}
Provides:       libqt5scxml-devel = %{version}
Provides:       qtscxml5-devel = %{version}
Provides:       qt5scxml-devel = %{version}

%description -n %{libqtscxml_d}
Devel files needed to build apps based on QtScXml.

%files -n %{libqtscxml_d}
%license LICENSE.GPL3-EXCEPT LICENSE.LGPL3
%{_qt5_includedir}/QtScxml/
%{_qt5_libdir}/libQt5Scxml.so
%{_qt5_libdir}/pkgconfig/Qt5Scxml.pc
%{_qt5_libdir}/cmake/Qt5Scxml/
%{_qt5_libdir}/*.prl
%{_qt5_archdatadir}/mkspecs/modules/*.pri
%{_qt5_archdatadir}/mkspecs/features/*.prf
%{_qt5_examplesdir}/scxml/

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtscxml-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif
