# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtsensors-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtsensors     %mklibname qt%{qtmajor}sensors %{qtmajor}
%define libqtsensors_d   %mklibname qt%{qtmajor}sensors -d
%define libqtsensors_p_d %mklibname qt%{qtmajor}sensors-private -d

Name:           qtsensors5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Sensors component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
BuildRequires:  qtbase5-devel = %version
BuildRequires:  pkgconfig(Qt5Qml) = %version
BuildRequires:  pkgconfig(Qt5Quick) >= %version

Provides:       qt%{qtmajor}-qtsensors = %{version}-%{release}

#Branch Patchs

#Trunk Patchs

#Patch from Mageia

%description
The Qt Sensors API provides access to sensor hardware via QML and C++
interfaces.  The Qt Sensors API also provides a motion gesture recognition
API for devices.

%files
%{_qt5_qml}/QtSensors/
%{_qt5_plugindir}/sensorgestures/*.so
%{_qt5_plugindir}/sensors/*.so

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtSensors%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtSensors%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtsensors.qch
%{_qt5_docdir}/qtsensors/
%endif

#------------------------------------------------------------------------------

%package -n %{libqtsensors}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}

%description -n %{libqtsensors}
Qt%{qtmajor} Component Library.

The Qt Sensors API provides access to sensor hardware via QML and C++
interfaces.  The Qt Sensors API also provides a motion gesture recognition
API for devices.

%files -n %{libqtsensors}
%{_qt5_libdir}/libQt5Sensors.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtsensors_d}
Summary:        Devel files needed to build apps based on QtSensors
Group:          Development/KDE and Qt
Requires:       %{libqtsensors} = %{version}
Provides:       libqtsensors5-devel = %{version}
Provides:       libqt5sensors-devel = %{version}
Provides:       qtsensors5-devel = %{version}
Provides:       qt5sensors-devel = %{version}

Provides:       libqtsensors5-private-devel = %{version}
Provides:       libqt5sensors-private-devel = %{version}
Provides:       qtsensors5-private-devel = %{version}
Provides:       qt5sensors-private-devel = %{version}

%description -n %{libqtsensors_d}
Devel files needed to build apps based on QtSensors.

%files -n %{libqtsensors_d}
%{_qt5_libdir}/libQt5Sensors.prl
%{_qt5_libdir}/libQt5Sensors.so
%{_qt5_libdir}/pkgconfig/Qt5Sensors.pc
%{_qt5_libdir}/cmake/Qt5Sensors/
%{_qt5_examplesdir}/sensors
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_sensors.pri
%{_qt5_includedir}/QtSensors/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_sensors_private.pri

#------------------------------------------------------------------------------

%prep
%setup -q -n qtsensors-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# Fix all buildroot paths
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L%{_builddir}/\S+,,g" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L%{_builddir}/?\S+,,g" {} \;

# Don't reference builddir neither /usr(/X11R6)?/ in .pc files.
perl -pi -e '\
s@-L/usr/X11R6/%{_lib} @@g;\
s@-I/usr/X11R6/include @@g;\
s@-L/%{_builddir}\S+@@g'\
    `find . -name \*.pc`
