# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtsensors-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtsensors      %mklibname qt%{qtmajor}sensors %{qtmajor}
%define libqtsensorsquick %mklibname qt%{qtmajor}sensorsquick %{qtmajor}
%define libqtsensors_d    %mklibname qt%{qtmajor}sensors -d
%define libqtsensors_p_d  %mklibname qt%{qtmajor}sensors-private -d

Name:           qtsensors6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Sensors component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

BuildRequires:  cmake(Qt6Core) = %version
BuildRequires:  cmake(Qt6Qml) = %version
BuildRequires:  cmake(Qt6QmlIntegration) >= %version
BuildRequires:  cmake(Qt6Quick) >= %version
BuildRequires:  cmake(Qt6QuickTest) >= %version
BuildRequires:  cmake(Qt6Svg) >= %version
BuildRequires:  cmake(Qt6SvgWidgets) >= %version
%if %{with examples}
BuildRequires:  cmake(Qt6Xml) >= %version
%endif
BuildRequires:  ninja
BuildRequires:  qttools6

Provides:       qt%{qtmajor}-qtsensors = %{version}-%{release}

%description
The Qt%{qtmajor} Sensors API provides access to sensor hardware via QML and C++
interfaces.  The Qt Sensors API also provides a motion gesture recognition
API for devices.

%files
%{_qt6_qmldir}/QtSensors/
%dir %{_qt6_plugindir}/sensors/
%{_qt6_plugindir}/sensors/*.so
%{_qt6_archdatadir}/sbom/qtsensors-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtSensors%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtSensors%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt6_docdir}/qtsensors.qch
%{_qt6_docdir}/qtsensors/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtsensors}
Summary:        Qt%{qtmajor} Sensors Library
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}

%description -n %{libqtsensors}
Qt%{qtmajor} Sensors Component Library.

The Qt Sensors API provides access to sensor hardware via QML and C++
interfaces.  The Qt Sensors API also provides a motion gesture recognition
API for devices.

%files -n %{libqtsensors}
%{_qt6_libdir}/libQt6Sensors.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtsensorsquick}
Summary:        Qt%{qtmajor} Sensors Quick Library
Group:          System/Libraries
Conflicts:      %{_lib}qt6sensors-devel < 6.3.1

%description -n %{libqtsensorsquick}
Qt%{qtmajor} Sensors Quick Component Library.

The Qt Sensors API provides access to sensor hardware via QML and C++
interfaces.  The Qt Sensors API also provides a motion gesture recognition
API for devices.

%files -n %{libqtsensorsquick}
%{_qt6_libdir}/libQt6SensorsQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtsensors_d}
Summary:        Devel files needed to build apps based on QtSensors
Group:          Development/KDE and Qt
Requires:       %{libqtsensors} = %version
Requires:       %{libqtsensorsquick} = %version
Provides:       libqtsensors6-devel = %version
Provides:       libqt6sensors-devel = %version
Provides:       qtsensors6-devel = %version
Provides:       qt6sensors-devel = %version
Provides:       qtsensorsquick6-devel = %version
Provides:       qt6sensorsquick-devel = %version

Provides:       libqtsensors6-private-devel = %version
Provides:       libqt6sensors-private-devel = %version
Provides:       qtsensors6-private-devel = %version
Provides:       qt6sensors-private-devel = %version

%description -n %{libqtsensors_d}
Devel files needed to build apps based on QtSensors and QtSensors.

%files -n %{libqtsensors_d}
%{_qt6_includedir}/QtSensors/
%{_qt6_libdir}/libQt6Sensors.so
%{_qt6_libdir}/libQt6Sensors.prl
%{_qt6_libdir}/cmake/Qt6Sensors/
%{_qt6_libdir}/pkgconfig/Qt6Sensors.pc
%{_qt6_libdir}/qt6/modules/Sensors.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_sensors.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_sensors_private.pri
%{_qt6_libdir}/qt6/metatypes/qt6sensors_relwithdebinfo_metatypes.json
#
%{_qt6_includedir}/QtSensorsQuick/
%{_qt6_libdir}/libQt6SensorsQuick.so
%{_qt6_libdir}/libQt6SensorsQuick.prl
%{_qt6_libdir}/cmake/Qt6SensorsQuick/
%{_qt6_libdir}/pkgconfig/Qt6SensorsQuick.pc
%{_qt6_libdir}/qt6/modules/SensorsQuick.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_sensorsquick.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_sensorsquick_private.pri
%{_qt6_libdir}/qt6/metatypes/qt6sensorsquick_relwithdebinfo_metatypes.json
%if %{with examples}
%{_qt6_examplesdir}/sensors/
%endif
#
%{_qt6_libdir}/cmake/Qt6/*.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtSensorsTestsConfig.cmake

#------------------------------------------------------------------------------

%prep
%setup -q -n qtsensors-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif

# Fix all buildroot paths
find %{buildroot}/%{_qt6_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L%{_builddir}/\S+,,g" {} \;
find %{buildroot}/%{_qt6_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} \;
find %{buildroot}/%{_qt6_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L%{_builddir}/?\S+,,g" {} \;

# Don't reference builddir neither /usr(/X11R6)?/ in .pc files.
perl -pi -e '\
s@-L/usr/X11R6/%{_lib} @@g;\
s@-I/usr/X11R6/include @@g;\
s@-L/%{_builddir}\S+@@g'\
    `find . -name \*.pc`
