# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir     qtserialbus-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtserialbus   %mklibname qt%{qtmajor}serialbus %{qtmajor}
%define libqtserialbus_d %mklibname qt%{qtmajor}serialbus -d

Name:           qtserialbus6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} SerialBus component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Network) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}
BuildRequires:  cmake(Qt6SerialPort) >= %{version}
BuildRequires:  ninja
BuildRequires:  qttools6

Provides:       qt%{qtmajor}-qtserialbus = %{version}-%{release}

%description
Qt%{qtmajor} Serial Bus API provides classes and functions to access the
various industrial serial buses and protocols, such as CAN, ModBus,
and others.

This package contains base tools, like string, xml, and network
handling.

%files
%license LICENSES/*
%{_qt6_bindir}/canbusutil
%{_qt6_plugindir}/canbus/
%{_qt6_archdatadir}/sbom/qtserialbus-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtSerialBus%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtSerialBus%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtserialbus.qch
%{_qt6_docdir}/qtserialbus/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtserialbus}
Summary:        Qt%{qtmajor} SerialBus Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtserialbus}
Qt%{qtmajor} SerialBus Component Library.

%files -n %{libqtserialbus}
%{_qt6_libdir}/libQt6SerialBus.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtserialbus_d}
Summary:        Devel files needed to build apps based on QtSerialBus
Group:          Development/KDE and Qt
Requires:       %{libqtserialbus} = %{version}
Provides:       libqtserialbus6-devel = %{version}
Provides:       libqt6serialbus-devel = %{version}
Provides:       qtserialbus6-devel = %{version}
Provides:       qt6serialbus-devel = %{version}

%description -n %{libqtserialbus_d}
Devel files needed to build apps based on Qt SerialBus.

%files -n %{libqtserialbus_d}
%{_qt6_includedir}/QtSerialBus/
%{_qt6_libdir}/libQt6SerialBus.so
%{_qt6_libdir}/cmake/Qt6SerialBus/
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/
%{_qt6_libdir}/pkgconfig/Qt6SerialBus.pc
%{_qt6_libdir}/*.prl
%{_qt6_archdatadir}/mkspecs/modules/*.pri
%if %{with examples}
%{_qt6_examplesdir}/serialbus/
%endif
%{_qt6_libdir}/qt6/metatypes/qt6serialbus_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/SerialBus.json

#------------------------------------------------------------------------------

%prep
%setup -q -n qtserialbus-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
