# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtsvg-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtsvg   %mklibname qt%{qtmajor}svg %{qtmajor}
%define libqtsvg_d %mklibname qt%{qtmajor}svg -d

Name:           qtsvg5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Svg component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtsvg
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Avoid-buffer-overflow-in-isSupportedSvgFeature.patch
Patch0002:      0002-Support-font-size-not-in-pixels.patch
Patch0003:      0003-Fix-text-x-y-when-the-length-is-not-in-pixels.patch
Patch0004:      0004-Improve-parsing-of-r.patch
Patch0005:      0005-SVG-Image-reading-Reject-oversize-svgs-as-corrupt.patch

#Branch Patchs

#Trunk Patchs

#Patch from Mageia
#
# Security patches
# P1000 -> ...

BuildRequires:  qtbase5-devel = %version

Provides:       qt%{qtmajor}-qtsvg = %{version}-%{release}

%description
The QtSvg module provides classes for displaying and creating SVG files.

%files
%{_qt5_plugindir}/iconengines/libqsvgicon.so
%{_qt5_plugindir}/imageformats/libqsvg.so

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtSvg%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtSvg%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtsvg.qch
%{_qt5_docdir}/qtsvg/
%endif

#------------------------------------------------------------------------------

%package -n %{libqtsvg}
Summary:        Qt%{qtmajor} Svg Component Library
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}
Provides:       libqt%{qtmajor}-qtsvg = %{version}-%{release}

%description -n %{libqtsvg}
Qt%{qtmajor} Svg Component Library.

The QtSvg module provides classes for displaying and creating SVG files.

%files -n %{libqtsvg}
%{_qt5_libdir}/libQt5Svg.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtsvg_d}
Summary:        Devel files needed to build apps based on QtSvg
Group:          Development/KDE and Qt
Requires:       %{libqtsvg} = %{version}
Provides:       libqtsvg5-devel = %{version}
Provides:       libqt5svg-devel = %{version}
Provides:       qtsvg5-devel = %{version}
Provides:       qt5svg-devel = %{version}

Provides:       libqtsvg5-private-devel = %{version}
Provides:       libqt5svg-private-devel = %{version}
Provides:       qtsvg5-private-devel = %{version}
Provides:       qt5svg-private-devel = %{version}

%description -n %{libqtsvg_d}
Devel files needed to build apps based on QtSvg.

%files -n %{libqtsvg_d}
%{_qt5_libdir}/libQt5Svg.prl
%{_qt5_libdir}/libQt5Svg.so
%{_qt5_libdir}/pkgconfig/Qt5Svg.pc
%{_qt5_libdir}/cmake/Qt5Svg/
%{_qt5_libdir}/cmake/Qt5Gui/Qt5Gui_QSvgIconPlugin.cmake
%{_qt5_libdir}/cmake/Qt5Gui/Qt5Gui_QSvgPlugin.cmake
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_svg.pri
%{_qt5_includedir}/QtSvg/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_svg_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtsvg-everywhere-src-%{qtversion}

rm -frv examples

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# Fix all buildroot paths
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L%{_builddir}/\S+,,g" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L%{_builddir}/?\S+,,g" {} \;

# Don't reference builddir neither /usr(/X11R6)?/ in .pc files.
perl -pi -e '\
s@-L/usr/X11R6/%{_lib} @@g;\
s@-I/usr/X11R6/include @@g;\
s@-L/%{_builddir}\S+@@g'\
    `find . -name \*.pc`

# .la and .a files, die, die, die.
find %{buildroot} -name '*.la' -delete
