# Build configuration

# set to 1 to enable bootstrap
%define bootstrap 0

%define with_clang 1

%if ! 0%{?bootstrap}
%define build_docs 1
%else
%define build_docs 0
%endif
%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qttools-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqthelp       %mklibname qt%{qtmajor}help %{qtmajor}
%define libqthelp_d     %mklibname qt%{qtmajor}help -d

%define libqtdesigner   %mklibname qt%{qtmajor}designer %{qtmajor}
%define libqtdesigner_d %mklibname qt%{qtmajor}designer -d

%define libqtclucene    %mklibname qt%{qtmajor}clucene %{qtmajor}
%define libqtclucene_d  %mklibname qt%{qtmajor}clucene -d

Name:           qttools5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} GUI toolkit
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
Source1:        mageia-assistant-qt5.desktop
Source2:        mageia-designer-qt5.desktop
Source3:        mageia-linguist-qt5.desktop
Source4:        mageia-qdbusviewer-qt5.desktop
BuildRequires:  qtbase5-devel
%if ! 0%{?bootstrap}
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Help)
%endif
%if %with_clang
BuildRequires:  clang-devel
%endif
BuildRequires:  llvm-devel

BuildRequires:  desktop-file-utils
BuildRequires:  imagemagick
BuildRequires:  sed

%if ! 0%{?bootstrap}
Requires:       qttranslations5
%endif
Requires:       qttools5-assistant
Requires:       qttools5-qtpaths

Provides:       qt%{qtmajor}-qttools = %{version}-%{release}
Provides:       qt%{qtmajor}-linguist = %{version}-%{release}

# Link against libclang-cpp.so
# https://fedoraproject.org/wiki/Changes/Stop-Shipping-Individual-Component-Libraries-In-clang-lib-Package
Patch5:         0001-Link-against-libclang-cpp.so-instead-of-the-clang-co.patch

#Patch from Mageia

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qttools
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch101:       0001-Ensure-FileAttributeSetTable-is-filled-ordered-so-we.patch
Patch102:       0002-Drop-superfluous-network-dependency-from-assistant-h.patch
Patch103:       0003-qdoc-Ensure-the-generated-temporary-header-file-is-c.patch


%description
Qt%{qtmajor} GUI tools.

%files
%{_qt5_bindir}/lconvert*
%{_bindir}/lconvert*
%{_qt5_bindir}/linguist*
%{_bindir}/linguist*
%{_qt5_bindir}/lprodump*
%{_bindir}/lprodump*
%{_qt5_bindir}/lrelease*
%{_bindir}/lrelease*
%{_qt5_bindir}/lupdate*
%{_bindir}/lupdate*
%{_qt5_bindir}/pixeltool*
%{_bindir}/pixeltool*
%{_qt5_bindir}/qtdiag
%{_bindir}/qtdiag
%{_qt5_bindir}/qtplugininfo*
%{_bindir}/qtplugininfo*
%if ! 0%{?bootstrap}
%{_qt5_bindir}/qdistancefieldgenerator*
%{_bindir}/qdistancefieldgenerator*
%endif
%if %with_clang
%{_qt5_bindir}/qdoc
%{_bindir}/qdoc
%endif
%{_qt5_datadir}/phrasebooks
%{_bindir}/qtattributionsscanner-qt5
%{_qt5_bindir}/qtattributionsscanner*
%{_datadir}/applications/*linguist*.desktop
%{_iconsdir}/hicolor/*/apps/linguist-qt5.png
#FIXME: in the good package ?
%{_qt5_examplesdir}/linguist

#------------------------------------------------------------------------------

%package assistant
Summary:        Qt%{qtmajor} Assistant Doc Utility
Group:          Documentation
Requires:       qtbase5-database-plugin-sqlite
%if ! 0%{?bootstrap}
Requires:       qttranslations5
%endif
Provides:       qt%{qtmajor}-qttools-assistant = %{version}-%{release}

%description assistant
Qt%{qtmajor} Assistant provides a documentation Browser.

%files assistant
%{_qt5_bindir}/assistant*
%{_bindir}/assistant*
%{_qt5_bindir}/qcollectiongen*
%{_bindir}/qcollectiongen*
%{_qt5_bindir}/qhelpgen*
%{_bindir}/qhelpgen*
%{_datadir}/applications/*assistant*.desktop
%{_iconsdir}/hicolor/*/apps/assistant-qt5.png
#FIXME: in the good package ?
%{_qt5_examplesdir}/assistant

#------------------------------------------------------------------------------

%package designer
Summary:        %{name} Visual Design Tool
Group:          Development/KDE and Qt
Requires:       qttranslations5
Provides:       qt%{qtmajor}-qttools-designer = %{version}-%{release}

%description designer
The Qt Designer is a visual design tool that makes designing and
implementing user interfaces a lot easier.

%files designer
%{_qt5_bindir}/design*
%{_bindir}/design*
%{_qt5_plugindir}/designer/
%{_datadir}/applications/*designer*.desktop
%{_iconsdir}/hicolor/*/apps/designer-qt5.png

#------------------------------------------------------------------------------

%package qtdbus
Summary:        Qt%{qtmajor} Dbus Binary
Group:          Development/KDE and Qt
Requires:       qttools5-qtpaths
Provides:       qt%{qtmajor}-qttools-qtdbus = %{version}-%{release}
Provides:       qt%{qtmajor}-qttools-qdbusviewer = %{version}-%{release}
Provides:       qt%{qtmajor}-qdbusviewer = %{version}-%{release}

%description qtdbus
Qt%{qtmajor} Dbus Binary.

The QtDBus module is a Unix-only library that you can use to perform
Inter-Process Communication using the D-Bus protocol.

%files qtdbus
%{_bindir}/qdbus-qt5
%{_qt5_bindir}/qdbus
%{_qt5_bindir}/qdbus-qt5
%{_bindir}/qdbus
%{_qt5_bindir}/qdbusviewer*
%{_bindir}/qdbusviewer*
%{_datadir}/applications/*qdbusviewer*.desktop
%{_iconsdir}/hicolor/*/apps/qdbusviewer-qt5.png

#------------------------------------------------------------------------------

%package qtpaths
Summary:        Qt%{qtmajor} Paths Binary
Group:          Development/KDE and Qt
Provides:       qt%{qtmajor}-qttools-qtpaths = %{version}-%{release}

%description qtpaths
Qt%{qtmajor} Paths Binary.

%files qtpaths
%{_qt5_bindir}/qtpaths
%{_bindir}/qtpaths

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtTools%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  %{name}-assistant
Recommends:     %{name}-assistant

%description doc
Documentation for APIs and tools in QtTools%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtassistant.qch
%{_qt5_docdir}/qtassistant/
%{_qt5_docdir}/qtdesigner.qch
%{_qt5_docdir}/qtdesigner/
%if %with_clang
%{_qt5_docdir}/qdoc.qch
%{_qt5_docdir}/qdoc/
%endif
%{_qt5_docdir}/qthelp.qch
%{_qt5_docdir}/qthelp/
%{_qt5_docdir}/qtlinguist.qch
%{_qt5_docdir}/qtlinguist/
%{_qt5_docdir}/qtuitools.qch
%{_qt5_docdir}/qtuitools/
%if ! 0%{?bootstrap}
%{_qt5_docdir}/qtdistancefieldgenerator.qch
%{_qt5_docdir}/qtdistancefieldgenerator/
%endif

%endif

#------------------------------------------------------------------------------

%package -n %{libqthelp}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Provides:       qthelplib = %{version}

%description -n %{libqthelp}
Qt%{qtmajor} Component Library.

The QtHelp module provides classes for integrating online documentation
in applications.

%files -n %{libqthelp}
%{_qt5_libdir}/libQt5Help.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqthelp_d}
Summary:        Devel files needed to build apps based on QtHelp and QtLinguistTools
Group:          Development/KDE and Qt
Requires:       %{libqthelp} = %{version}
Requires:       qtbase5-common-devel = %{version}
Requires:       qttools5
Provides:       libqthelp5-devel = %{version}
Provides:       libqt5help-devel = %{version}
Provides:       qthelp5-devel = %{version}
Provides:       qt5help-devel = %{version}
Provides:       qtlinguisttools5-devel = %{version}
Provides:       qt5linguisttools-devel = %{version}
Provides:       qtdoctools5-devel = %{version}
Provides:       qt5doctools-devel = %{version}

Provides:       libqthelp5-private-devel = %{version}
Provides:       libqt5help-private-devel = %{version}
Provides:       qthelp5-private-devel = %{version}
Provides:       qt5help-private-devel = %{version}

%description -n %{libqthelp_d}
Devel files needed to build apps based on QtHelp and QtLinguistTools.

%files -n %{libqthelp_d}
%{_qt5_libdir}/libQt5Help.prl
%{_qt5_libdir}/libQt5Help.so
%{_qt5_libdir}/pkgconfig/Qt5Help.pc
%{_qt5_includedir}/QtHelp/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_help.pri
%{_qt5_examplesdir}/help/
%dir %{_qt5_libdir}/cmake/Qt5Help
%{_qt5_libdir}/cmake/Qt5Help/Qt5HelpConfig.cmake
%{_qt5_libdir}/cmake/Qt5Help/Qt5HelpConfigVersion.cmake
%{_qt5_libdir}/cmake/Qt5Help/Qt5HelpConfigExtras.cmake
#FIXME: Find a better place
%dir %{_qt5_libdir}/cmake/Qt5LinguistTools
%{_qt5_libdir}/cmake/Qt5LinguistTools/Qt5LinguistToolsConfig.cmake
%{_qt5_libdir}/cmake/Qt5LinguistTools/Qt5LinguistToolsMacros.cmake
%{_qt5_libdir}/cmake/Qt5LinguistTools/Qt5LinguistToolsConfigVersion.cmake
%dir %{_qt5_libdir}/cmake/Qt5AttributionsScannerTools
%{_qt5_libdir}/cmake/Qt5AttributionsScannerTools/Qt5AttributionsScannerToolsConfig.cmake
%{_qt5_libdir}/cmake/Qt5AttributionsScannerTools/Qt5AttributionsScannerToolsConfigVersion.cmake
%if %with_clang
%dir %{_qt5_libdir}/cmake/Qt5DocTools
%{_qt5_libdir}/cmake/Qt5DocTools/Qt5DocToolsConfig.cmake
%{_qt5_libdir}/cmake/Qt5DocTools/Qt5DocToolsConfigVersion.cmake
%endif
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_help_private.pri

#------------------------------------------------------------------------------
%if 0
%package -n %{libqtclucene}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Provides:       qtclucenelib = %{version}

%description -n %{libqtclucene}
Qt%{qtmajor} Component Library.

%files -n %{libqtclucene}
%{_qt5_libdir}/libQt5CLucene.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtclucene_d}
Summary:        Devel files needed to build apps based on QtCLucene
Group:          Development/KDE and Qt
Requires:       %{libqtclucene} = %{version}
Provides:       libqtclucene5-devel = %{version}
Provides:       libqt5clucene-devel = %{version}
Provides:       qtclucene5-devel = %{version}
Provides:       qt5clucene-devel = %{version}

Provides:       libqtclucene5-private-devel = %{version}
Provides:       libqt5clucene-private-devel = %{version}
Provides:       qtclucene5-private-devel = %{version}
Provides:       qt5clucene-private-devel = %{version}

%description -n %{libqtclucene_d}
Devel files needed to build apps based on QtCLucene.

%files -n %{libqtclucene_d}
%{_qt5_libdir}/libQt5CLucene.prl
%{_qt5_libdir}/libQt5CLucene.so
%{_qt5_includedir}/QtCLucene
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_clucene_private.pri
%endif

#------------------------------------------------------------------------------

%package -n %{libqtdesigner}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Provides:       qtdesignerlib = %{version}

%description -n %{libqtdesigner}
Qt%{qtmajor} Component Library.

The QtDesigner module provides classes that allow you to create your own
custom widget plugins for Qt Designer, and classes that enable you to
access Qt Designer's components.

%files -n %{libqtdesigner}
%{_qt5_libdir}/libQt5Designer.so.%{qtmajor}{,.*}
%{_qt5_libdir}/libQt5DesignerComponents.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtdesigner_d}
Summary:        Devel files needed to build apps based on QtDesigner
Group:          Development/KDE and Qt
Requires:       %{libqtdesigner} = %{version}
Requires:       qttools5-designer = %{version}
Provides:       libqtdesigner5-devel = %{version}
Provides:       libqt5designer-devel = %{version}
Provides:       qtdesigner5-devel = %{version}
Provides:       qt5designer-devel = %{version}

Provides:       libqtdesigner5-private-devel = %{version}
Provides:       libqt5designer-private-devel = %{version}
Provides:       qtdesigner5-private-devel = %{version}
Provides:       qt5designer-private-devel = %{version}

%description -n %{libqtdesigner_d}
Devel files needed to build apps based on QtDesigner.

%files -n %{libqtdesigner_d}
%{_qt5_libdir}/libQt5Designer.so
%{_qt5_libdir}/libQt5DesignerComponents.so
%{_qt5_libdir}/libQt5Designer.prl
%{_qt5_libdir}/libQt5DesignerComponents.prl
%{_qt5_libdir}/libQt5UiTools.prl
%{_qt5_libdir}/libQt5UiPlugin.prl
%{_qt5_libdir}/libQt5UiTools.a
%{_qt5_libdir}/pkgconfig/Qt5Designer.pc
%{_qt5_libdir}/pkgconfig/Qt5UiTools.pc
%{_qt5_libdir}/pkgconfig/Qt5UiPlugin.pc
%{_qt5_includedir}/QtDesignerComponents/
%{_qt5_includedir}/QtDesigner/
%{_qt5_includedir}/QtUiPlugin/
%{_qt5_includedir}/QtUiTools/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_designer.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_uitools.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_uiplugin.pri
%{_qt5_examplesdir}/designer
%{_qt5_examplesdir}/uitools
%{_qt5_libdir}/cmake/Qt5Designer/
%{_qt5_libdir}/cmake/Qt5UiTools/
%{_qt5_libdir}/cmake/Qt5UiPlugin/
%{_qt5_libdir}/cmake/Qt5DesignerComponents/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_designer_private.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_designercomponents_private.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_uitools_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qttools-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# Add desktop files, icons...
desktop-file-install \
  --dir=%{buildroot}%{_datadir}/applications \
  %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4}
sed -i -e 's#/usr/lib/qt5/bin#%{_qt5_bindir}#' %{buildroot}%{_datadir}/applications/*.desktop
for i in 32 48 64 128; do
	mkdir -p %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
	convert -scale ${i}x${i} src/designer/src/designer/images/designer.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/designer-qt5.png
	convert -scale ${i}x${i} src/assistant/assistant/images/assistant-128.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/assistant-qt5.png
	convert -scale ${i}x${i} src/linguist/linguist/images/icons/linguist-128-32.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/linguist-qt5.png
	convert -scale ${i}x${i} src/qdbus/qdbusviewer/images/qdbusviewer-128.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/qdbusviewer-qt5.png
done

# hardlink files to {_bindir}, add -qt5 postfix to not conflict
mkdir %{buildroot}%{_bindir}
pushd %{buildroot}%{_qt5_bindir}
for i in * ; do
  case "${i}" in
   assistant|designer|lconvert|linguist|lrelease|lupdate|pixeltool|qcollectiongenerator|qdbus|qdbusviewer|qhelpconverter|qhelpgenerator|qtplugininfo|qtattributionsscanner)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}-qt5
      ln -sv ${i} ${i}-qt5
      ;;
    *)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}
      ;;
  esac
done
popd


# Fix all buildroot paths
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L%{_builddir}/\S+,,g" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L%{_builddir}/?\S+,,g" {} \;

# Don't reference builddir neither /usr(/X11R6)?/ in .pc files.
perl -pi -e '\
s@-L/usr/X11R6/%{_lib} @@g;\
s@-I/usr/X11R6/include @@g;\
s@-L/%{_builddir}\S+@@g'\
    `find . -name \*.pc`

mkdir -p %{buildroot}%{_bindir}

pushd %{buildroot}%{_bindir}
	for i in assistant designer lconvert linguist lrelease lupdate pixeltool qcollectiongenerator qdbus qdbusviewer qhelpgenerator qtplugininfo ; do 
				ln -s %{_qt5_bindir}/$i . ;
	done
popd
