# Build configuration

# _without = enable bootstrap
# _with    = disable bootstrap
%bcond_with bootstrap

%define with_clang 1

%if ! %{with bootstrap}
%define build_docs 1
%else
%define build_docs 0
%endif
%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%endif

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qttools-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqthelp       %mklibname qt%{qtmajor}help %{qtmajor}
%define libqthelp_d     %mklibname qt%{qtmajor}help -d

%define libqtdesigner   %mklibname qt%{qtmajor}designer %{qtmajor}
%define libqtdesigner_d %mklibname qt%{qtmajor}designer -d

%define libqtuitools    %mklibname qt%{qtmajor}uitools %{qtmajor}
%define libqtuitools_d  %mklibname qt%{qtmajor}uitools -d

%define libqttools_d    %mklibname qt%{qtmajor}tools -d

%define libqtqdoc_d     %mklibname qt%{qtmajor}qdoc -d

Name:           qttools6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} GUI toolkit
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
Source1:        mageia-assistant-qt6.desktop
Source2:        mageia-designer-qt6.desktop
Source3:        mageia-linguist-qt6.desktop
Source4:        mageia-qdbusviewer-qt6.desktop

# Upstream patches

# Patch from Mageia
Patch10:        call-find_package-printsupport.patch

# Patch from Debian
Patch20:        cmake-find-zstd-before-clang.diff

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-devel
BuildRequires:  qtbase6-qtpaths
BuildRequires:  cmake(Qt6PrintSupport)

%if ! %{with bootstrap}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickWidgets) >= %{version}
BuildRequires:  cmake(litehtml)
BuildRequires:  cmake(Qt6Help) >= %{version}
%endif
%if %with_clang
BuildRequires:  clang-devel
%endif
BuildRequires:  llvm-devel
BuildRequires:  pkgconfig(cups)
BuildRequires:  pkgconfig(libzstd)

BuildRequires:  desktop-file-utils
BuildRequires:  imagemagick
BuildRequires:  sed

%if ! %{with bootstrap}
Requires:       qttranslations6
%endif
Requires:       qttools6-assistant
Requires:       qtbase6-qtpaths

Provides:       qt%{qtmajor}-qttools = %{version}-%{release}
Provides:       qt%{qtmajor}-linguist = %{version}-%{release}

%description
Qt%{qtmajor} GUI tools.

%files
%{_qt6_bindir}/lconvert*
%{_bindir}/lconvert*
%{_qt6_bindir}/linguist*
%{_bindir}/linguist*
%{_qt6_bindir}/lrelease*
%{_bindir}/lrelease*
%{_qt6_bindir}/lupdate*
%{_bindir}/lupdate*
%{_qt6_bindir}/pixeltool*
%{_bindir}/pixeltool*
%{_qt6_bindir}/qtdiag*
%{_bindir}/qtdiag*
%{_qt6_bindir}/qtplugininfo**
%{_bindir}/qtplugininfo*
%if ! %{with bootstrap}
%{_qt6_bindir}/qdoc*
%{_bindir}/qdoc*
%endif
%{_qt6_datadir}/phrasebooks
%{_datadir}/applications/*linguist*.desktop
%{_iconsdir}/hicolor/*/apps/linguist-qt6.png
%{_qt6_libexecdir}/lprodump
%{_bindir}/lprodump*
%{_qt6_libexecdir}/lrelease*
%{_qt6_libexecdir}/lupdate*
%{_qt6_libexecdir}/qtattributionsscanner
%{_bindir}/qtattributionsscanner*
%if ! %{with bootstrap}
%{_qt6_bindir}/qdistancefieldgenerator*
%{_bindir}/qdistancefieldgenerator-qt6
%endif
%{_qt6_archdatadir}/sbom/qttools-%{qtversion}.spdx

#------------------------------------------------------------------------------

%package assistant
Summary:        Qt%{qtmajor} Assistant Doc Utility
Group:          Documentation
Requires:       qtbase6-database-plugin-sqlite
%if ! %{with bootstrap}
Requires:       qttranslations6
%endif

%description assistant
Qt%{qtmajor} Assistant provides a documentation Browser.

%files assistant
%{_qt6_bindir}/assistant*
%{_bindir}/assistant*
%{_datadir}/applications/*assistant*.desktop
%{_iconsdir}/hicolor/*/apps/assistant-qt6.png
#FIXME: in the good package ?
%{_qt6_libexecdir}/qhelpgenerator*
%{_bindir}/qhelpgenerator*
%if ! %{with bootstrap}
%{_qt6_examplesdir}/assistant/

%endif

#------------------------------------------------------------------------------

%package designer
Summary:        %{name} Visual Design Tool
Group:          Development/KDE and Qt
Requires:       qttranslations6

%description designer
The Qt Designer is a visual design tool that makes designing and
implementing user interfaces a lot easier.

%files designer
%{_qt6_bindir}/design*
%{_bindir}/design*
%if ! %{with bootstrap}
%{_qt6_plugindir}/designer/*.so
%endif
%{_datadir}/applications/*designer*.desktop
%{_iconsdir}/hicolor/*/apps/designer-qt6.png

#------------------------------------------------------------------------------

%package qtdbus
Summary:        Qt%{qtmajor} Dbus Binary
Group:          Development/KDE and Qt
Requires:       qtbase%{qtmajor}-qtpaths
Provides:       qt%{qtmajor}-qttools-qtdbus = %{version}-%{release}
Provides:       qt%{qtmajor}-qttools-qdbusviewer = %{version}-%{release}
Provides:       qt%{qtmajor}-qdbusviewer = %{version}-%{release}

%description qtdbus
Qt%{qtmajor} Dbus Binary.

The QtDBus module is a Unix-only library that you can use to perform
Inter-Process Communication using the D-Bus protocol.

%files qtdbus
%{_bindir}/qdbus-qt6
%{_qt6_bindir}/qdbus
%{_qt6_bindir}/qdbus-qt6
%{_qt6_bindir}/qdbusviewer*
%{_bindir}/qdbusviewer*
%{_datadir}/applications/*qdbusviewer*.desktop
%{_iconsdir}/hicolor/*/apps/qdbusviewer-qt6.png

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtTools%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  %{name}-assistant
Recommends:     %{name}-assistant

%description doc
Documentation for APIs and tools in QtTools%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt6_docdir}/qtassistant.qch
%{_qt6_docdir}/qtassistant/
%{_qt6_docdir}/qtdesigner.qch
%{_qt6_docdir}/qtdesigner/
%if %with_clang
%{_qt6_docdir}/qdoc.qch
%{_qt6_docdir}/qdoc/
%endif
%{_qt6_docdir}/qthelp.qch
%{_qt6_docdir}/qthelp/
%{_qt6_docdir}/qtlinguist.qch
%{_qt6_docdir}/qtlinguist/
%{_qt6_docdir}/qtuitools.qch
%{_qt6_docdir}/qtuitools/
%{_qt6_docdir}/qtdistancefieldgenerator.qch
%{_qt6_docdir}/qtdistancefieldgenerator/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqthelp}
Summary:        Qt%{qtmajor} Help Library
Group:          System/Libraries
Provides:       qt6helplib = %{version}

%description -n %{libqthelp}
Qt%{qtmajor} Help Component Library.

The QtHelp module provides classes for integrating online documentation
in applications.

%files -n %{libqthelp}
%{_qt6_libdir}/libQt6Help.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqthelp_d}
Summary:        Devel files needed to build apps based on QtHelp and QtLinguistTools
Group:          Development/KDE and Qt
Requires:       %{libqthelp} = %{version}
Requires:       qtbase6-common-devel = %{version}
Requires:       qttools6
Provides:       libqthelp6-devel = %{version}
Provides:       libqt6help-devel = %{version}
Provides:       qthelp6-devel = %{version}
Provides:       qt6help-devel = %{version}
Provides:       qtlinguisttools6-devel = %{version}
Provides:       qt6linguisttools-devel = %{version}
Provides:       qtdoctools6-devel = %{version}
Provides:       qt6doctools-devel = %{version}

Provides:       libqthelp6-private-devel = %{version}
Provides:       libqt6help-private-devel = %{version}
Provides:       qthelp6-private-devel = %{version}
Provides:       qt6help-private-devel = %{version}

%description -n %{libqthelp_d}
Devel files needed to build apps based on QtHelp and Qt LinguistTools.

%files -n %{libqthelp_d}
%{_qt6_includedir}/QtHelp/
%{_qt6_libdir}/libQt6Help.so
%{_qt6_libdir}/libQt6Help.prl
%{_qt6_libdir}/cmake/Qt6Help/
#FIXME: Find a better place
%{_qt6_libdir}/cmake/Qt6Linguist/
%{_qt6_libdir}/cmake/Qt6LinguistTools/
%if %with_clang
%{_qt6_libdir}/cmake/Qt6/FindWrapLibClang.cmake
%endif
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_help.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_help_private.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_linguist.pri
%{_qt6_libdir}/qt6/modules/Help.json
%{_qt6_libdir}/qt6/modules/Linguist.json
%{_qt6_libdir}/qt6/metatypes/qt6help_relwithdebinfo_metatypes.json
%if ! %{with bootstrap}
%{_qt6_examplesdir}/help/
%{_qt6_examplesdir}/linguist/
%endif
%{_qt6_libdir}/pkgconfig/Qt6Help.pc
%{_qt6_libdir}/pkgconfig/Qt6Linguist.pc

#------------------------------------------------------------------------------

%package -n     %{libqtdesigner}
Summary:        Qt%{qtmajor} Designer Library
Group:          System/Libraries
Provides:       qt6designerlib = %{version}

%description -n %{libqtdesigner}
Qt%{qtmajor} Designer Component Library.

The QtDesigner module provides classes that allow you to create your own
custom widget plugins for Qt Designer, and classes that enable you to
access Qt Designer's components.

%files -n %{libqtdesigner}
%{_qt6_libdir}/libQt6Designer.so.%{qtmajor}{,.*}
%{_qt6_libdir}/libQt6DesignerComponents.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtdesigner_d}
Summary:        Devel files needed to build apps based on QtDesigner
Group:          Development/KDE and Qt
Requires:       %{libqtdesigner} = %{version}
Requires:       qttools6-designer = %{version}
Provides:       libqtdesigner6-devel = %{version}
Provides:       libqt6designer-devel = %{version}
Provides:       qtdesigner6-devel = %{version}
Provides:       qt6designer-devel = %{version}

Provides:       libqtdesigner6-private-devel = %{version}
Provides:       libqt6designer-private-devel = %{version}
Provides:       qtdesigner6-private-devel = %{version}
Provides:       qt6designer-private-devel = %{version}

%description -n %{libqtdesigner_d}
Devel files needed to build apps based on Qt Designer.

%files -n %{libqtdesigner_d}
%{_qt6_includedir}/QtDesigner/
%{_qt6_libdir}/libQt6Designer.so
%{_qt6_libdir}/libQt6Designer.prl
%{_qt6_libdir}/cmake/Qt6Designer/
%{_qt6_libdir}/pkgconfig/Qt6Designer.pc
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_designer.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_designer_private.pri
%{_qt6_libdir}/qt6/modules/Designer.json
%{_qt6_libdir}/qt6/metatypes/qt6designer_relwithdebinfo_metatypes.json
#
%{_qt6_includedir}/QtDesignerComponents/
%{_qt6_libdir}/libQt6DesignerComponents.so
%{_qt6_libdir}/libQt6DesignerComponents.prl
%{_qt6_libdir}/cmake/Qt6DesignerComponentsPrivate/
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_designercomponents_private.pri
%{_qt6_libdir}/qt6/modules/DesignerComponentsPrivate.json
%{_qt6_libdir}/qt6/metatypes/qt6designercomponentsprivate_relwithdebinfo_metatypes.json
%if ! %{with bootstrap}
%{_qt6_examplesdir}/designer/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtuitools}
Summary:        Qt%{qtmajor} UiTools Library
Group:          System/Libraries
Provides:       qt6uitoolslib = %{version}

%description -n %{libqtuitools}
Qt%{qtmajor} UiTools Component Library.

%files -n %{libqtuitools}
%{_qt6_libdir}/libQt6UiTools.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtuitools_d}
Summary:        Devel files needed to build apps based on QtUiTools
Group:          Development/KDE and Qt
Requires:       %{libqtuitools} = %{version}
Requires:       qttools6-designer = %{version}
Provides:       libqtuitools6-devel = %{version}
Provides:       libqt6uitools-devel = %{version}
Provides:       qtuitools6-devel = %{version}
Provides:       qt6uitools-devel = %{version}

Provides:       libqtuitools6-private-devel = %{version}
Provides:       libqt6uitools-private-devel = %{version}
Provides:       qtuitools6-private-devel = %{version}
Provides:       qt6uitools-private-devel = %{version}

%description -n %{libqtuitools_d}
Devel files needed to build apps based on Qt UiTools.

%files -n %{libqtuitools_d}
%{_qt6_includedir}/QtUiPlugin/
%{_qt6_libdir}/cmake/Qt6UiPlugin/
%{_qt6_libdir}/pkgconfig/Qt6UiPlugin.pc
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_uiplugin.pri
%{_qt6_libdir}/qt6/modules/UiPlugin.json
#
%{_qt6_includedir}/QtUiTools/
%{_qt6_libdir}/libQt6UiTools.so
%{_qt6_libdir}/libQt6UiTools.prl
%{_qt6_libdir}/cmake/Qt6UiTools/
%{_qt6_libdir}/pkgconfig/Qt6UiTools.pc
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_uitools.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_uitools_private.pri
%{_qt6_libdir}/qt6/modules/UiTools.json
%{_qt6_libdir}/qt6/metatypes/qt6uitools_relwithdebinfo_metatypes.json
%if ! %{with bootstrap}
%{_qt6_examplesdir}/uitools/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqttools_d}
Summary:        Devel files needed to build apps based on QtTools
Group:          Development/KDE and Qt
Requires:       %{libqthelp_d} = %{version}
Requires:       %{libqtdesigner_d} = %{version}
Requires:       %{libqtuitools_d} = %{version}
Provides:       libqttools6-devel = %{version}
Provides:       libqt6tools-devel = %{version}
Provides:       qttools6-devel = %{version}
Provides:       qt6tools-devel = %{version}

Provides:       libqttools6-private-devel = %{version}
Provides:       libqt6tools-private-devel = %{version}
Provides:       qttools6-private-devel = %{version}
Provides:       qt6tools-private-devel = %{version}

%description -n %{libqttools_d}
Devel files needed to build apps based on Qt Tools.

%files -n %{libqttools_d}
%{_qt6_includedir}/QtTools/
%{_qt6_libdir}/cmake/Qt6Tools/
%{_qt6_libdir}/cmake/Qt6ToolsTools/
%{_qt6_libdir}/qt6/modules/Tools.json
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_tools_private.pri
#
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtToolsTestsConfig.cmake
%if ! %with_clang
%{_qt6_libdir}/cmake/Qt6/FindWrapLibClang.cmake
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtqdoc_d}
Summary:        Devel files needed to build apps based on QtQdoc
Group:          Development/KDE and Qt
Requires:       %{libqthelp_d} = %{version}
Requires:       %{libqtdesigner_d} = %{version}
Requires:       %{libqtuitools_d} = %{version}
Provides:       libqtqdoc6-devel = %{version}
Provides:       libqt6qdoc-devel = %{version}
Provides:       qtqdoc6-devel = %{version}
Provides:       qt6qdoc-devel = %{version}

Provides:       libqtqdoc6-private-devel = %{version}
Provides:       libqt6qdoc-private-devel = %{version}
Provides:       qtqdoc6-private-devel = %{version}
Provides:       qt6qdoc-private-devel = %{version}

%description -n %{libqtqdoc_d}
Devel files needed to build apps based on Qt Qdoc.

%files -n %{libqtqdoc_d}
%{_qt6_includedir}/QtQDocCatch/
%{_qt6_includedir}/QtQDocCatchConversions/
%{_qt6_includedir}/QtQDocCatchGenerators/
#{_qt6_libdir}/cmake/Qt6QDocCatch/
%{_qt6_libdir}/cmake/Qt6QDocCatchPrivate/
%{_qt6_libdir}/cmake/Qt6QDocCatchConversionsPrivate/
%{_qt6_libdir}/cmake/Qt6QDocCatchGeneratorsPrivate/
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_qdoccatch_private.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_qdoccatchconversions_private.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_qdoccatchgenerators_private.pri
%{_qt6_libdir}/qt6/modules/QDocCatch*.json

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qttools-everywhere-src-%{qtversion}

%build
%cmake_qt6 -DCMAKE_MESSAGE_LOG_LEVEL=STATUS \
           -DQT_BUILD_EXAMPLES:BOOL=%{!?with_bootstrap:ON}%{?with_bootstrap:OFF} \
           -DQT_FEATURE_printsupport:BOOL=%{!?with_bootstrap:ON}%{?with_bootstrap:OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif

# Add desktop files, icons...
desktop-file-install \
  --dir=%{buildroot}%{_datadir}/applications \
  %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4}
sed -i -e 's#@_qt6_bindir@#%{_qt6_bindir}#' %{buildroot}%{_datadir}/applications/*.desktop
for i in 32 48 64 128; do
	mkdir -p %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
	convert -scale ${i}x${i} src/designer/src/designer/images/designer.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/designer-qt6.png
	convert -scale ${i}x${i} src/assistant/assistant/images/assistant-128.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/assistant-qt6.png
	convert -scale ${i}x${i} src/linguist/linguist/images/icons/linguist-128-32.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/linguist-qt6.png
	convert -scale ${i}x${i} src/qdbus/qdbusviewer/images/qdbusviewer-128.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/qdbusviewer-qt6.png
done

# hardlink files to {_bindir}, add -qt6 postfix to not conflict
mkdir %{buildroot}%{_bindir}
pushd %{buildroot}%{_qt6_bindir}
for i in * ; do
  case "${i}" in
   assistant|designer|lconvert|linguist|lrelease|lupdate|pixeltool|qcollectiongenerator| \
   qdbus|qdbusviewer|qhelpconverter|qtplugininfo| \
   qtpaths|qdistancefieldgenerator|qdoc|qtdiag)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}-qt6
      ln -sv ${i} ${i}-qt6
      ;;
    *)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}
      ;;
  esac
done
popd

pushd %{buildroot}%{_qt6_libexecdir}
for i in * ; do
  case "${i}" in
   lprodump|lrelease-pro|lupdate-pro|qhelpgenerator|qtattributionsscanner)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}-qt6
      ;;
  esac
done
popd

# Fix all buildroot paths
find %{buildroot}%{_qt6_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L%{_builddir}/\S+,,g" {} \;
find %{buildroot}%{_qt6_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} \;
find %{buildroot}%{_qt6_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L%{_builddir}/?\S+,,g" {} \;
