# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtvirtualkeyboard-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtvirtualkeyboard         %mklibname qt%{qtmajor}virtualkeyboard %{qtmajor}
%define libqtvirtualkeyboardsettings %mklibname qt%{qtmajor}virtualkeyboardsettings %{qtmajor}
%define libqthunspellinputmethod     %mklibname qt%{qtmajor}hunspellinputmethod %{qtmajor}
%define libqtvirtualkeyboard_d       %mklibname qt%{qtmajor}virtualkeyboard -d

Name:           qtvirtualkeyboard6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} VirtualKeyboard component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## upstream patches

## Branch Patchs

## Trunk Patchs

## Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickTest) >= %{version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{version}
BuildRequires:  cmake(Qt6Svg) >= %{version}
BuildRequires:  cmake(Qt6SvgWidgets) >= %{version}
BuildRequires:  cmake(Qt6Widgets) >= %{version}

BuildRequires:  pkgconfig(hunspell)

Provides:       qt%{qtmajor}-qtvirtualkeyboard = %{version}-%{release}

%description
The Qt Virtual Keyboard project provides an input framework and reference
keyboard frontend for Qt %{qtmajor}. Key features include:

* Customizable keyboard layouts and styles with dynamic switching.
* Predictive text input with word selection.
* Character preview and alternative character view.
* Automatic capitalization and space insertion.
* Scalability to different resolutions.
* Support for different character sets (Latin, Simplified/Traditional Chinese,
  Hindi, Japanese, Arabic, Korean, and others).
* Support for most common input languages, with possibility to easily extend
  the language support.
* Left-to-right and right-to-left input.
* Hardware key support for 2-way and 5-way navigation.
* Handwriting support, with gestures for fullscreen input.
* Audio feedback.

%files
%license LICENSES/*
%{_qt6_plugindir}/platforminputcontexts/libqtvirtualkeyboardplugin.so
%{_qt6_qmldir}/QtQuick/VirtualKeyboard/
%{_qt6_archdatadir}/sbom/qtvirtualkeyboard-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtVirtualKeyboard%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtVirtualKeyboard%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtvirtualkeyboard.qch
%{_qt6_docdir}/qtvirtualkeyboard/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtvirtualkeyboard}
Summary:        Qt%{qtmajor} Virtual Keyboard Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtvirtualkeyboard}
Qt%{qtmajor} Virtual Keyboard Component Library.

%files -n %{libqtvirtualkeyboard}
%{_qt6_libdir}/libQt6VirtualKeyboard.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtvirtualkeyboardsettings}
Summary:        Qt%{qtmajor} Virtual Keyboard Settings Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtvirtualkeyboardsettings}
Qt%{qtmajor} Virtual Keyboard Settings Component Library.

%files -n %{libqtvirtualkeyboardsettings}
%{_qt6_libdir}/libQt6VirtualKeyboardSettings.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqthunspellinputmethod}
Summary:        Qt%{qtmajor} Hunspell Input Method Library
Group:          System/Libraries

%description -n %{libqthunspellinputmethod}
Qt%{qtmajor} Hunspell Input Method Component Library.

%files -n %{libqthunspellinputmethod}
%{_qt6_libdir}/libQt6HunspellInputMethod.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtvirtualkeyboard_d}
Summary:        Devel files needed to build apps based on QtVirtualKeyboard
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtvirtualkeyboard} = %{version}
Requires:       %{libqtvirtualkeyboardsettings} = %{version}
Requires:       %{libqthunspellinputmethod} = %{version}
Provides:       libqtvirtualkeyboard6-devel = %{version}
Provides:       libqt6virtualkeyboard-devel = %{version}
Provides:       qtvirtualkeyboard6-devel = %{version}
Provides:       qt6virtualkeyboard-devel = %{version}
Provides:       qt%{qtmajor}-qtvirtualkeyboard-devel = %{version}-%{release}

%description -n %{libqtvirtualkeyboard_d}
Devel files needed to build apps based on Qt VirtualKeyboard.

%files -n %{libqtvirtualkeyboard_d}
%{_qt6_includedir}/QtVirtualKeyboard/
%{_qt6_libdir}/libQt6VirtualKeyboard.so
%{_qt6_libdir}/libQt6VirtualKeyboard.prl
%{_qt6_libdir}/cmake/Qt6VirtualKeyboard/
%{_qt6_libdir}/pkgconfig/Qt6VirtualKeyboard.pc
%{_qt6_libdir}/qt6/metatypes/qt6virtualkeyboard_relwithdebinfo_metatypes.json
%{_qt6_archdatadir}/mkspecs/modules/*.pri
%{_qt6_libdir}/qt6/modules/VirtualKeyboard.json
#
%{_qt6_includedir}/QtVirtualKeyboardSettings/
%{_qt6_libdir}/libQt6VirtualKeyboardSettings.so
%{_qt6_libdir}/libQt6VirtualKeyboardSettings.prl
%{_qt6_libdir}/cmake/Qt6VirtualKeyboardSettings/
%{_qt6_libdir}/pkgconfig/Qt6VirtualKeyboardSettings.pc
%{_qt6_libdir}/qt6/metatypes/qt6virtualkeyboardsettings_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/VirtualKeyboardSettings.json
#
%{_qt6_includedir}/QtHunspellInputMethod/
%{_qt6_libdir}/libQt6HunspellInputMethod.so
%{_qt6_libdir}/libQt6HunspellInputMethod.prl
%{_qt6_libdir}/cmake/Qt6HunspellInputMethod/
%{_qt6_libdir}/pkgconfig/Qt6HunspellInputMethod.pc
%{_qt6_libdir}/qt6/metatypes/qt6hunspellinputmethod_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/HunspellInputMethod.json

%if %{with examples}
%{_qt6_examplesdir}/virtualkeyboard/
%endif
#
%{_qt6_libdir}/cmake/Qt6/FindCerenceHwrAlphabetic.cmake
%{_qt6_libdir}/cmake/Qt6/FindCerenceHwrCjk.cmake
%{_qt6_libdir}/cmake/Qt6/FindCerenceXt9.cmake
%{_qt6_libdir}/cmake/Qt6/FindMyScript.cmake
%{_qt6_libdir}/cmake/Qt6/FindHunspell.cmake
%{_qt6_libdir}/cmake/Qt6Gui/*.cmake
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtVirtualKeyboardTestsConfig.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake
%{_qt6_libdir}/cmake/Qt6BundledOpenwnn/Qt6BundledOpenwnnDependencies.cmake
%{_qt6_libdir}/cmake/Qt6BundledPinyin/Qt6BundledPinyinDependencies.cmake
%{_qt6_libdir}/cmake/Qt6BundledTcime/Qt6BundledTcimeDependencies.cmake

#------------------------------------------------------------------------------

%prep
%autosetup -n qtvirtualkeyboard-everywhere-src-%{qtversion} -p1

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
