# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtwebchannel-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtwebchannel   %mklibname qt%{qtmajor}webchannel %{qtmajor}
%define libqtwebchannel_d %mklibname qt%{qtmajor}webchannel -d

Name:           qtwebchannel5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} WebChannel component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtwebchannel
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Handle-signals-in-the-registered-object-s-thread.patch
Patch0002:      0002-Handle-per-transport-client-idle-status.patch
Patch0003:      0003-QMetaObjectPublisher-Never-send-stale-queued-message.patch

BuildRequires:  qtbase5-devel >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}

Provides:       qt%{qtmajor}-qtwebchannel = %{version}-%{release}

#Branch Patchs

#Trunk Patchs

#Patch from Mageia

%description
The Qt WebChannel module offers Qt applications a seamless way to publish QObjects
for interaction with HTML/JavaScript clients. These clients can either be inside
local Qt WebViews or any other, potentially remote, client which supports
JavaScript, as long as a communication channel such as WebSocket is available.

Qt WebChannel uses introspection on the QObjects and sends this serialized data
to the clients. There, with the help of a small JavaScript library, an object is
created which simulates the API of the QObject. Any invokable methods, including
slots, can be called as well as properties read and written. Additionally you can
connect to signals and register JavaScript callbacks as handlers.

%files
%{_qt5_qml}/QtWebChannel/
%{_qt5_examplesdir}/webchannel/

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtWebChannel%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtWebChannel%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtwebchannel.qch
%{_qt5_docdir}/qtwebchannel/
%endif

#------------------------------------------------------------------------------

%package -n %{libqtwebchannel}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries

%description -n %{libqtwebchannel}
Qt%{qtmajor} Component Library.

%files -n %{libqtwebchannel}
%{_qt5_libdir}/libQt5WebChannel.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtwebchannel_d}
Summary:        Devel files needed to build apps based on QtWebChannel
Group:          Development/KDE and Qt
Requires:       %{libqtwebchannel} = %{version}
Provides:       libqtwebchannel5-devel = %{version}
Provides:       libqt5webchannel-devel = %{version}
Provides:       qtwebchannel5-devel = %{version}
Provides:       qt5webchannel-devel = %{version}

Provides:       libqtwebchannel-private-devel = %{version}
Provides:       libqtwebchannel5-private-devel = %{version}
Provides:       libqt5webchannel-private-devel = %{version}
Provides:       qtwebchannel-private-devel = %{version}
Provides:       qt5webchannel-private-devel = %{version}

%description -n %{libqtwebchannel_d}
Devel files needed to build apps based on QtWebChannel.

%files -n %{libqtwebchannel_d}
%{_qt5_libdir}/libQt5WebChannel.so
%{_qt5_libdir}/libQt5WebChannel.prl
%{_qt5_libdir}/pkgconfig/Qt5WebChannel.pc
%{_qt5_includedir}/QtWebChannel/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webchannel.pri
%{_qt5_libdir}/cmake/Qt5WebChannel/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_webchannel_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtwebchannel-everywhere-src-%{qtversion}

%build
%qmake_qt5
%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif
