# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtwebchannel-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtwebchannel        %mklibname qt%{qtmajor}webchannel %{qtmajor}
%define libqtwebchannel_d      %mklibname qt%{qtmajor}webchannel -d

%define libqtwebchannelquick   %mklibname qt%{qtmajor}webchannelquick %{qtmajor}
%define libqtwebchannelquick_d %mklibname qt%{qtmajor}webchannelquick -d

Name:           qtwebchannel6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} WebChannel component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

BuildRequires:  qtbase6-devel >= %version
BuildRequires:  cmake(Qt6Quick) >= %version
BuildRequires:  cmake(Qt6QuickTest) >= %version
BuildRequires:  cmake(Qt6WebSockets) >= %version
BuildRequires:  qttools6
BuildRequires:  ninja

Provides:       qt%{qtmajor}-qtwebchannel = %{version}-%{release}

# files moved in main pkg
Conflicts:      %{_lib}qt6webchannel6 < 6.4.1-2

%description
The Qt WebChannel module offers Qt applications a seamless way to publish QObjects
for interaction with HTML/JavaScript clients. These clients can either be inside
local Qt WebViews or any other, potentially remote, client which supports
JavaScript, as long as a communication channel such as WebSocket is available.

Qt WebChannel uses introspection on the QObjects and sends this serialized data
to the clients. There, with the help of a small JavaScript library, an object is
created which simulates the API of the QObject. Any invokable methods, including
slots, can be called as well as properties read and written. Additionally you can
connect to signals and register JavaScript callbacks as handlers.

%files
%{_qt6_archdatadir}/qml/QtWebChannel/
%{_qt6_archdatadir}/sbom/qtwebchannel-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtWebChannel%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtWebChannel%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtwebchannel.qch
%{_qt6_docdir}/qtwebchannel/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtwebchannel}
Summary:        Qt%{qtmajor} WebChannel Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtwebchannel}
Qt%{qtmajor} WebChannel Component Library.

%files -n %{libqtwebchannel}
%{_qt6_libdir}/libQt6WebChannel.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtwebchannel_d}
Summary:        Devel files needed to build apps based on QtWebChannel
Group:          Development/KDE and Qt
Requires:       %{libqtwebchannel} = %version
Provides:       libqtwebchannel6-devel = %version
Provides:       libqt6webchannel-devel = %version
Provides:       qtwebchannel6-devel = %version
Provides:       qt6webchannel-devel = %version

Provides:       libqtwebchannel-private-devel = %version
Provides:       libqtwebchannel6-private-devel = %version
Provides:       libqt6webchannel-private-devel = %version
Provides:       qtwebchannel-private-devel = %version
Provides:       qt6webchannel-private-devel = %version

%description -n %{libqtwebchannel_d}
Devel files needed to build apps based on Qt WebChannel.

%files -n %{libqtwebchannel_d}
%{_qt6_headerdir}/QtWebChannel/
%{_qt6_libdir}/libQt6WebChannel.so
%{_qt6_libdir}/libQt6WebChannel.prl
%{_qt6_libdir}/cmake/Qt6WebChannel/
%{_qt6_libdir}/pkgconfig/*.pc
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_webchannel.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_webchannel_private.pri
%{_qt6_libdir}/qt6/metatypes/qt6webchannel_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/WebChannel.json
%if %{with examples}
%{_qt6_examplesdir}/webchannel/
%endif
#
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtWebChannelTestsConfig.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/*.cmake

#------------------------------------------------------------------------------

%package -n     %{libqtwebchannelquick}
Summary:        Qt%{qtmajor} WebChannel Quick Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtwebchannelquick}
Qt%{qtmajor} WebChannel Quick Component Library.

%files -n %{libqtwebchannelquick}
%{_qt6_libdir}/libQt6WebChannelQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtwebchannelquick_d}
Summary:        Devel files needed to build apps based on QtWebChannelQuick
Group:          Development/KDE and Qt
Requires:       %{libqtwebchannelquick} = %version
Provides:       libqtwebchannelquick6-devel = %version
Provides:       libqt6webchannelquick-devel = %version
Provides:       qtwebchannelquick6-devel = %version
Provides:       qt6webchannelquick-devel = %version

Provides:       libqtwebchannelquick-private-devel = %version
Provides:       libqtwebchannelquick6-private-devel = %version
Provides:       libqt6webchannelquick-private-devel = %version
Provides:       qtwebchannelquick-private-devel = %version
Provides:       qt6webchannelquick-private-devel = %version

%description -n %{libqtwebchannelquick_d}
Devel files needed to build apps based on Qt WebChannelQuick.

%files -n %{libqtwebchannelquick_d}
%{_qt6_headerdir}/QtWebChannelQuick/
%{_qt6_libdir}/libQt6WebChannelQuick.so
%{_qt6_libdir}/libQt6WebChannelQuick.prl
%{_qt6_libdir}/cmake/Qt6WebChannelQuick/
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_webchannelquick.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_webchannelquick_private.pri
%{_qt6_libdir}/qt6/metatypes/qt6webchannelquick_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/WebChannelQuick.json

#------------------------------------------------------------------------------

%prep
%setup -q -n qtwebchannel-everywhere-src-%{qtversion}
#autopatch -p1

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
