# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%global docs 0
%else
%global docs 1
%endif

# NEON support on ARM (detected at runtime) - disable this if you are hitting
# FTBFS due to e.g. GCC bug https://bugzilla.redhat.com/show_bug.cgi?id=1282495
%global arm_neon 0

# the QMake CONFIG flags to force debugging information to be produced in
# release builds, and for all parts of the code
%ifarch %{arm} aarch64
# the ARM builder runs out of memory during linking with the full setting below,
# so omit debugging information for the parts upstream deems it dispensable for
# (webcore, v8base)
%global debug_config %{nil}
%else
%global debug_config force_debug_info
# webcore_debug v8base_debug
%endif

# exclude plugins (all architectures) and libv8.so (i686, it's static everywhere
# else)
%global __provides_exclude  ^lib.*plugin\\.so.*|libv8\\.so$
# exclude libv8.so (i686, it's static everywhere else)
%global __requires_exclude  ^libv8\\.so$
# exclude devel(libv8)
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libv8.*

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 18
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir        qtwebengine-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libwebengine        %mklibname qt5webengine %{qtmajor}
%define libwebenginecore    %mklibname qt5webenginecore %{qtmajor}
%define libwebenginewidgets %mklibname qt5webenginewidgets %{qtmajor}
%define libpdf              %mklibname qt5pdf %{qtmajor}
%define libpdfwidgets       %mklibname qt5pdfwidgets %{qtmajor}
%define libwebengine_d      %mklibname qt5webengine -d

# Build configuration (Part 2)

%global use_system_re2 0

%bcond_without system_ffmpeg
%bcond_without pipewire

Name:           qtwebengine5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Integrates chromium's fast moving web capabilities into Qt
Group:          Development/KDE and Qt
# See LICENSE.GPL LICENSE.LGPL LGPL_EXCEPTION.txt, for details
# See also https://qt-project.org/doc/qt-5.0/qtdoc/licensing.html
# The other licenses are from Chromium and the code it bundles
License: (LGPLv2 with exceptions or GPLv3 with exceptions) and BSD and LGPLv2+ and ASL 2.0 and IJG and MIT and GPLv2+ and ISC and OpenSSL and (MPLv1.1 or GPLv2 or LGPLv2)
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
# cleaned tarball with patent-encumbered codecs removed from the bundled FFmpeg
# ./qtwebengine-release.sh
#Source0: qtwebengine-everywhere-src-%%{version}-clean.tar.xz
# release script used above
Source1: qtwebengine-release.sh
# cleanup scripts used above
Source2: clean_qtwebengine.sh
Source3: clean_ffmpeg.sh
Source4: get_free_ffmpeg_source_files.py
# macros
Source10: macros.qt5-qtwebengine
# fix extractCFlag to also look in QMAKE_CFLAGS_RELEASE, needed to detect the
# ARM flags with our %%qmake_qt5 macro, including for the next patch
Patch2:  qtwebengine-opensource-src-5.14.1-fix-extractcflag.patch
# disable NEON vector instructions on ARM where the NEON code FTBFS due to
# GCC bug https://bugzilla.redhat.com/show_bug.cgi?id=1282495
Patch3:  qtwebengine-opensource-src-5.14.1-no-neon.patch
# use the system NSPR prtime (based on Debian patch)
# We already depend on NSPR, so it is useless to copy these functions here.
# Debian uses this just fine, and I don't see relevant modifications either.
Patch4:  qtwebengine-everywhere-src-5.15.2-system-nspr-prtime.patch
# gcc-12 FTBFS "use of deleted function"
Patch6:  chromium-angle-nullptr.patch
Patch7:  chromium-hunspell-nullptr.patch
# fix missing ARM -mfpu setting
Patch9:  qtwebengine-opensource-src-5.14.1-arm-fpu-fix.patch
# Fix/workaround FTBFS on aarch64 with newer glibc
Patch24: qtwebengine-everywhere-src-5.11.3-aarch64-new-stat.patch
# workaround FTBFS against kernel-headers-5.2.0+
Patch25: qtwebengine-SIOCGSTAMP.patch
# patch to handle futex_time64, credit Opensuse developers
Patch33: sandbox_futex_time64.patch
# fix GN flags for in built Chromium
Patch41: qtwebengine-gn_args.patch
# patch sources for ffmpeg5, credit Arch Linux developers
Patch42: qtwebengine-ffmpeg5.patch
# patch to port to pipewire 0.3, credit Opensuse developers
Patch43: qtwebengine-pipewire-0.3.patch
# Fix build with ninja 1.12
Patch44: qt5-webengine-ninja-1.12.patch
Patch50: qtwebengine-re2-2023.07.01.patch
# re2 needs absl with c++17 or higher for string_view
Patch51: qtwebengine-5.15.15-c++17.patch
# Try to get ABI compatibility between system absl (used by system re2)
# and internalized absl until we can remove the latter
Patch52: qtwebengine-system-absl-compat.patch
Patch53: qtwebengine-pdf-compile.patch
# Adapt for ffmpeg7 (from openSUSE)
Patch61: qt5-qtwebengine-ffmpeg7.patch
# Python 3.12 fix
Patch100: python3.12-imp.patch
# cherry-picked from https://github.com/chromium/chromium/commit/b3abd7e4c9467415da3a5e13d9500d2ab3abc2ec
Patch101: 0001-grit_drop-python2-compatibility.patch
# Fix build with ICU 75 (from archlinux)
Patch150: qt5-webengine-icu-75.patch

## Upstream patches:

BuildRequires:  qtbase5-devel
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5WebChannel)
BuildRequires:  pkgconfig(Qt5QuickWidgets)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Location)
BuildRequires:  pkgconfig(Qt5Positioning)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sensors)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(lcms2)
%if %{with system_ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%endif
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libwebp) >= 0.6.0
BuildRequires:  pkgconfig(libwebpdemux)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(poppler-cpp)
%if %{with pipewire}
BuildRequires:  pkgconfig(libpipewire-0.3)
%endif
%if 0%{?use_system_re2}
BuildRequires:  pkgconfig(re2)
%endif
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(vpx) >= 1.8.0
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(snappy)
BuildRequires:  nodejs-devel
BuildRequires:  git-core
BuildRequires:  gperf
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  re2c
BuildRequires:  ninja
BuildRequires:  nodejs
BuildRequires:  python3
BuildRequires:  python3-html5lib
BuildRequires:  python3-devel
# gn links statically (for now)
BuildRequires:  libstdc++-static-devel

Provides:       qt%{qtmajor}-qtwebengine = %{version}

#Branch Patchs

#Trunk Patchs

#Patch from Mageia

%description
The Qt WebEngine module provides the WebEngineView API which allows QML
applications to render regions of dynamic web content. A WebEngineView
component may share the screen with other QML components or encompass
the full screen as specified within the QML application.

It allows an application to load pages into the WebEngineView, either by
URL or with an HTML string, and navigate within session history. By
default, links to different pages load within the same WebEngineView, but
web sites may request them to be opened as a new tab, window or dialog.

%files
%{_qt5_translationdir}/qtwebengine_locales
%{_qt5_qml}/QtWebEngine/
%{_qt5_qml}/QtQuick/Pdf/
%dir %{_qt5_datadir}/resources/
%{_qt5_datadir}/resources/*.pak
%{_qt5_bindir}/qwebengine_convert_dict
%{_qt5_plugindir}/imageformats/libqpdf.so
#ifarch %%{ix86}
%if 0%{?sse2}
# shared V8 library and its SSE2 version
%{_qt5_libdir}/qtwebengine/
%endif
%{_qt5_libexecdir}/QtWebEngineProcess

#------------------------------------------------------------------------------

%if %{docs}
%package        doc
Summary:        QtWebEngine%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description    doc
Documentation for APIs and tools in QtWebEngine5 package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtwebengine.qch
%{_qt5_docdir}/qtwebengine/
%{_qt5_docdir}/qtpdf.qch
%{_qt5_docdir}/qtpdf/
%endif

#------------------------------------------------------------------------------

%package -n     %{libwebengine}
Summary:        Qt%{qtmajor} WebEngine Component Library
Group:          System/Libraries

%description -n %{libwebengine}
Qt%{qtmajor} WebEngine Component Library.

%files -n %{libwebengine}
%{_qt5_libdir}/libQt5WebEngine.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libwebenginecore}
Summary:        Qt%{qtmajor} WebEngineCore Component Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libwebenginecore}
Qt%{qtmajor} WebEngineCore Component Library.

%files -n %{libwebenginecore}
%{_qt5_libdir}/libQt5WebEngineCore.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libwebenginewidgets}
Summary:        Qt%{qtmajor} WebEngineWidgets Component Library
Group:          System/Libraries

%description -n %{libwebenginewidgets}
Qt%{qtmajor} WebEngineWidgets Component Library.

%files -n %{libwebenginewidgets}
%{_qt5_libdir}/libQt5WebEngineWidgets.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libpdf}
Summary:        Qt%{qtmajor} Pdf Component Library
Group:          System/Libraries

%description -n %{libpdf}
Qt%{qtmajor} Pdf Component Library.

%files -n %{libpdf}
%{_qt5_libdir}/libQt5Pdf.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libpdfwidgets}
Summary:        Qt%{qtmajor} PdfWidgets Component Library
Group:          System/Libraries

%description -n %{libpdfwidgets}
Qt%{qtmajor} PdfWidgets Component Library.

%files -n %{libpdfwidgets}
%{_qt5_libdir}/libQt5PdfWidgets.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libwebengine_d}
Summary:        Devel files needed to build apps based on %{name}
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libwebengine} = %{version}
Requires:       %{libwebenginecore} = %{version}
Requires:       %{libwebenginewidgets} = %{version}
Requires:       %{libpdf} = %{version}
Requires:       %{libpdfwidgets} = %{version}
Provides:       libwebengine5-devel = %{version}
Provides:       webengine5-devel = %{version}
Provides:       qtwebengine5-devel = %{version}
Provides:       qt5webengine-devel = %{version}
Provides:       qt5-qtwebengine-devel = %{version}

%description -n %{libwebengine_d}
Devel files needed to build apps based on %{name}.

%files -n %{libwebengine_d}
%{_qt5_libdir}/*.so
%{_qt5_libdir}/*.prl
%{_qt5_libdir}/pkgconfig/*.pc
%{_qt5_includedir}/QtWebEngine/
%{_qt5_includedir}/QtWebEngineCore/
%{_qt5_includedir}/QtWebEngineWidgets/
%{_qt5_includedir}/QtPdf/
%{_qt5_includedir}/QtPdfWidgets/
%{_qt5_libdir}/cmake/Qt5WebEngine/
%{_qt5_libdir}/cmake/Qt5WebEngineCore/
%{_qt5_libdir}/cmake/Qt5WebEngineWidgets/
%{_qt5_libdir}/cmake/Qt5Pdf/
%{_qt5_libdir}/cmake/Qt5PdfWidgets/
%{_qt5_libdir}/cmake/Qt5Gui/Qt5Gui_QPdfPlugin.cmake
%{_qt5_archdatadir}/mkspecs/modules/*.pri
%{_qt5_examplesdir}/webenginewidgets/
%{_qt5_examplesdir}/webengine/
%{_qt5_examplesdir}/pdfwidgets/
%{_qt5_examplesdir}/pdf/

#------------------------------------------------------------------------------

%prep
%setup -q -n %{qttarballdir}

%patch -P2 -p1 -b .fix-extractcflag
%if !0%{?arm_neon}
%patch -P3 -p1 -b .no-neon
%endif
%patch -P4 -p1 -b .system-nspr-prtime
%patch -P6 -p1 -b .angle_nullptr
%patch -P7 -p1 -b .hunspell_nullptr

## upstream patches

%patch -P9 -p1 -b .arm-fpu-fix
%patch -P24 -p1 -b .aarch64-new-stat
%patch -P25 -p1 -b .SIOCGSTAMP
%patch -P33 -p1 -b .linux-sandbox

%patch -P41 -p1 -b .gn_args
%if %{with system_ffmpeg}
%patch -P42 -p1 -b .ffmpeg5
%endif
%if %{with pipewire}
%patch -P43 -p1 -b .pipewire3
%endif
%patch -P44 -p1 -b .ninja
%if 0%{?use_system_re2}
#patch -P50 -p1 -b .re2-2023.07.01
%patch -P51 -p1 -b .system-re2
%patch -P52 -p1 -b .system-absl
%endif
%patch -P53 -p1 -b .pdf-v8
%patch -P61 -p1 -b .ffmpeg7

%patch -P100 -p1 -b .python3.12
%patch -P101 -p1 -b .drop_python2

%patch -P150 -p1 -b .icu75

# delete all "toolprefix = " lines from build/toolchain/linux/BUILD.gn, as we
# never cross-compile in native Fedora RPMs, fixes ARM and aarch64 FTBFS
sed -i -e '/toolprefix = /d' -e 's/\${toolprefix}//g' \
  src/3rdparty/chromium/build/toolchain/linux/BUILD.gn

# https://bugzilla.redhat.com/1337585
# can't just delete, but we'll overwrite with system headers to be on the safe side
%if 0%{?use_system_re2}
cp -bv /usr/include/re2/*.h src/3rdparty/chromium/third_party/re2/src/re2/

# Until we can figure out how to kill the internal absl, let's at least
# try to make it ABI compatible with the system copy (as used by re2...)
cp -f %{_includedir}/absl/base/options.h src/3rdparty/chromium/third_party/abseil-cpp/absl/base/options.h
# Chromium isn't compatible with std::optional though
sed -i -e 's,#define ABSL_OPTION_USE_STD_OPTIONAL 1,#define ABSL_OPTION_USE_STD_OPTIONAL 0,' src/3rdparty/chromium/third_party/abseil-cpp/absl/base/options.h

# webengine really really likes forcing C++14 on us...
# but we need C++17 for compatibility with system absl
find . -name "*.pro" -o -name "*.pri" |while read r; do
	echo 'QMAKE_CXXFLAGS_GNUCXX14 = -std=gnu++17' >>$r
done
%endif

# copy the Chromium license so it is installed with the appropriate name
cp -p src/3rdparty/chromium/LICENSE LICENSE.Chromium

# fix missing files for armv7hl
cp -a src/3rdparty/chromium/base/numerics/{safe_conversions_arm_impl.h,safe_math_arm_impl.h} src/3rdparty/gn/base/numerics/

# consider doing this as part of the tarball creation step instead?  rdieter
# fix/workaround
# fatal error: QtWebEngineCore/qtwebenginecoreglobal.h: No such file or directory
if [ ! -f "./include/QtWebEngineCore/qtwebenginecoreglobal.h" ]; then
 %{_qt5_bindir}/syncqt.pl -version %{version}
fi

# abort if this doesn't get created by syncqt.pl
test -f "./include/QtWebEngineCore/qtwebenginecoreglobal.h"

%build
export STRIP=strip
export NINJAFLAGS="%{__ninja_common_opts}"
export NINJA_PATH=%{__ninja}
%if 0%{?use_system_re2}
export CXXFLAGS="%{optflags} -std=gnu++17"
%endif

%{qmake_qt5} \
  %{?debug_config:CONFIG+="%{debug_config}}" \
  CONFIG+="link_pulseaudio use_gold_linker" \
  CONFIG+="use_system_libxml=true use_system_libxslt=true" \
  QMAKE_EXTRA_ARGS+="-system-webengine-icu" \
  QMAKE_EXTRA_ARGS+="-webengine-kerberos" \
  QMAKE_EXTRA_ARGS+="-feature-pdf-v8" \
  QMAKE_EXTRA_ARGS+="-webengine-python-version python3" \
  %if %{with system_ffmpeg}
  QMAKE_EXTRA_ARGS+="-system-webengine-ffmpeg" \
  QMAKE_EXTRA_ARGS+="-webengine-proprietary-codecs" \
  %endif
  %if %{with pipewire}
  QMAKE_EXTRA_ARGS+="-webengine-webrtc-pipewire" \
  %endif
  .

%make_build

%if 0%{?docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if 0%{?docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# .la and .a files, die, die, die.
find %{buildroot} -name '*.la' -delete
find %{buildroot} -name '*.a' -delete

## .prl/.la file love
# nuke .prl reference(s) to %%buildroot, excessive (.la-like) libs
pushd %{buildroot}%{_qt5_libdir}
for prl_file in libQt5*.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd

# adjust cmake dep(s) to allow for using the same Qt5 that was used to build it
# using the lesser of %%version, %%_qt5_version
%global lesser_version $(echo -e "%{version}\\n%{_qt5_version}" | sort -V | head -1)
sed -i -e "s|%{version} \${_Qt5WebEngine|%{lesser_version} \${_Qt5WebEngine|" \
  %{buildroot}%{_qt5_libdir}/cmake/Qt5WebEngine*/Qt5WebEngine*Config.cmake

%filetriggerin -- %{_datadir}/myspell
while read filename ; do
  case "$filename" in
    *.dic)
      bdicname=%{_qtwebengine_dictionaries_dir}/`basename -s .dic "$filename"`.bdic
      %{_qt5_bindir}/qwebengine_convert_dict "$filename" "$bdicname" &> /dev/null || :
      ;;
  esac
done
