# Build configuration

%global optflags %(echo %optflags | sed -e 's/-g/-g1/')

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 0
%endif

%bcond_without examples

%bcond_with clang

%if %{with clang}
%global use_clang           1
%else
%global use_clang           0
%endif

# system libvpx disabled since
# https://codereview.qt-project.org/c/qt/qtwebengine/+/454908
%global use_system_ffmpeg   1
%global use_system_libvpx   0
%global use_system_protobuf 1
%global use_system_jsoncpp  1
%global use_system_re2      1
%global use_system_libwebp  1
%global use_system_libicu   1
%global use_system_libxml   1
%global use_system_harfbuzz 1

# the QMake CONFIG flags to force debugging information to be produced in
# release builds, and for all parts of the code
%ifarch %{arm} aarch64
# the ARM builder runs out of memory during linking with the full setting below,
# so omit debugging information for the parts upstream deems it dispensable for
# (webcore, v8base)
%global debug_config %{nil}
%else
%global debug_config force_debug_info
# webcore_debug v8base_debug
%endif

# exclude plugins
%global __provides_exclude ^lib.*plugin\\.so.*$
# and designer plugins
%global __provides_exclude_from ^%{_qt6_plugindir}/.*\\.so$

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtwebengine-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libwebenginecore           %mklibname qt%{qtmajor}webenginecore %{qtmajor}
%define libwebenginequick          %mklibname qt%{qtmajor}webenginequick %{qtmajor}
%define libwebenginequickdelegates %mklibname qt%{qtmajor}webenginequickdelegates %{qtmajor}
%define libwebenginewidgets        %mklibname qt%{qtmajor}webenginewidgets %{qtmajor}
%define libpdf                     %mklibname qt%{qtmajor}pdf %{qtmajor}
%define libpdfquick                %mklibname qt%{qtmajor}pdfquick %{qtmajor}
%define libpdfwidgets              %mklibname qt%{qtmajor}pdfwidgets %{qtmajor}
%define libwebengine_d             %mklibname qt%{qtmajor}webengine -d

Name:           qtwebengine6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Integrates chromium's fast moving web capabilities into Qt
Group:          Development/KDE and Qt
# See LICENSE.GPL LICENSE.LGPL LGPL_EXCEPTION.txt, for details
# See also http://qt-project.org/doc/qt-6.0/qtdoc/licensing.html
# The other licenses are from Chromium and the code it bundles
License: (LGPLv2 with exceptions or GPLv3 with exceptions) and BSD and LGPLv2+ and ASL 2.0 and IJG and MIT and GPLv2+ and ISC and OpenSSL and (MPLv1.1 or GPLv2 or LGPLv2)
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
# macros
Source10:       macros.qt6-qtwebengine
# pulseaudio headers
Source20:       pulseaudio-12.2-headers.tar.gz

Patch2:         qtwebengine-link-pipewire.patch
## Upstream patches:

Patch11:        qtwebengine-SIOCGSTAMP.patch

Patch24:        qtwebengine-everywhere-src-5.11.3-aarch64-new-stat.patch

# Fix sandbox issue on 32-bit architectures with glibc >= 2.31 (from Debian)
Patch29:        qtwebengine-everywhere-src-5.15.5-sandbox-time64-syscalls.patch
# FTBS warning: elaborated-type-specifier for a scoped enum must not
# use the 'class' keyword
Patch50:        qtwebengine-fix-build.patch
# https://bugreports.qt.io/browse/QTBUG-129985
Patch80:        qtwebengine-fix-arm-build.patch

Patch101:       qtwebengine-rtc-dont-use-h264.patch
Patch102:       qtwebengine-chromium-90-fseal.patch

# handled by qt6-srpm-macros, which defines %%qt6_qtwebengine_arches
# FIXME use/update qt6_qtwebengine_arches
# 32-bit arches not supported (https://bugreports.qt.io/browse/QTBUG-102143)
ExclusiveArch: aarch64 x86_64

#squidf: at version check to avoid getting crazy because a module is not up-to-date...
BuildRequires: qtbase6-devel >= %{qtversion}
BuildRequires: cmake(Qt6Sensors) >= %{qtversion}
BuildRequires: cmake(Qt6Svg) >= %{qtversion}
BuildRequires: cmake(Qt6WebChannel) >= %{qtversion}
BuildRequires: cmake(Qt6Core) >= %{qtversion}
BuildRequires: cmake(Qt6Gui) >= %{qtversion}
BuildRequires: cmake(Qt6GuiTools) >= %{qtversion}
BuildRequires: cmake(Qt6Network) >= %{qtversion}
BuildRequires: cmake(Qt6OpenGL) >= %{qtversion}
BuildRequires: cmake(Qt6OpenGLWidgets) >= %{qtversion}
BuildRequires: cmake(Qt6Positioning) >= %{qtversion}
BuildRequires: cmake(Qt6PrintSupport) >= %{qtversion}
BuildRequires: cmake(Qt6Qml) >= %{qtversion}
BuildRequires: cmake(Qt6QmlModels) >= %{qtversion}
BuildRequires: cmake(Qt6QmlTools) >= %{qtversion}
BuildRequires: cmake(Qt6Quick) >= %{qtversion}
BuildRequires: cmake(Qt6QuickWidgets) >= %{qtversion}
BuildRequires: cmake(Qt6WebChannel) >= %{qtversion}
BuildRequires: cmake(Qt6WebChannelQuick) >= %{qtversion}
BuildRequires: cmake(Qt6Widgets) >= %{qtversion}
BuildRequires: cmake(Qt6WidgetsTools) >= %{qtversion}
BuildRequires: cmake(Qt6WebSockets) >= %{qtversion}
BuildRequires: cmake(Qt6) >= %{qtversion}
%if %{with examples}
BuildRequires: cmake(Qt6QuickControls2)
BuildRequires: qtsvg6
%endif
# for examples?
BuildRequires: ninja-build
BuildRequires: cmake >= 3.19
BuildRequires: bison
BuildRequires: flex
%if %{use_clang}
BuildRequires: clang
%else
BuildRequires: gcc-c++
%endif
# gn links statically (for now)
BuildRequires: libstdc++-static-devel
BuildRequires: libatomic-devel
BuildRequires: git-core
BuildRequires: gperf
BuildRequires: krb5-devel
%if %{use_system_libicu}
BuildRequires: pkgconfig(icu-io) >= 69
%endif
BuildRequires: libjpeg-devel
BuildRequires: nodejs >= 1:14.0
%if %{use_system_re2}
BuildRequires: pkgconfig(re2)
%else
Provides:      bundled(re2)
%endif
BuildRequires: snappy-devel
%ifarch %{ix86} x86_64
BuildRequires: yasm
%endif
BuildRequires: pkgconfig(dri)
BuildRequires: pkgconfig(epoxy)
BuildRequires: pkgconfig(expat)
BuildRequires: pkgconfig(gobject-2.0)
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(freetype2)
BuildRequires: pkgconfig(gl)
BuildRequires: pkgconfig(egl)
%if %{use_system_jsoncpp}
BuildRequires: pkgconfig(jsoncpp)
%endif
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(libudev)
%if %{use_system_libwebp}
BuildRequires: pkgconfig(libwebp) >= 0.6.0
%endif
%if %{use_system_libxml}
BuildRequires: pkgconfig(libxml++-3.0)
BuildRequires: pkgconfig(libxslt)
%endif
%if %{use_system_harfbuzz}
BuildRequires: pkgconfig(harfbuzz)
%endif
BuildRequires: pkgconfig(libdrm)
%if %{use_system_protobuf}
BuildRequires: pkgconfig(protobuf) >= 3.13
%endif
BuildRequires: pkgconfig(libevent)
BuildRequires: pkgconfig(poppler-cpp)
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(minizip)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(xi)
BuildRequires: pkgconfig(xcursor)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xfixes)
BuildRequires: pkgconfig(xrender)
BuildRequires: pkgconfig(xdamage)
BuildRequires: pkgconfig(xcomposite)
BuildRequires: pkgconfig(xtst)
BuildRequires: pkgconfig(xrandr)
BuildRequires: pkgconfig(xscrnsaver)
BuildRequires: pkgconfig(libcap)
BuildRequires: pkgconfig(libpulse)
BuildRequires: pkgconfig(libpipewire-0.3)
BuildRequires: pkgconfig(alsa)
BuildRequires: pkgconfig(libpci)
BuildRequires: pkgconfig(dbus-1)
BuildRequires: pkgconfig(nss)
BuildRequires: pkgconfig(lcms2)
BuildRequires: pkgconfig(xkbcommon)
BuildRequires: pkgconfig(xkbfile)
BuildRequires: pkgconfig(xshmfence)
BuildRequires: python3-html5lib

%if %{use_system_ffmpeg}
BuildRequires: pkgconfig(libavcodec)
BuildRequires: pkgconfig(libavformat)
BuildRequires: pkgconfig(libavutil)
BuildRequires: pkgconfig(opus)
%endif
BuildRequires: pkgconfig(libva)
# fesco exception to allow python2 use: https://pagure.io/fesco/issue/2208
# per https://fedoraproject.org/wiki/Changes/RetirePython2#FESCo_exceptions
# Only the interpreter is needed

%if %{use_system_libvpx}
BuildRequires: pkgconfig(vpx) >= 1.10.0
%endif
BuildRequires: pkgconfig(cups)

Provides:      qt%{qtmajor}-qtwebengine = %{version}-%{release}

# extra (non-upstream) functions needed, see
# src/3rdparty/chromium/third_party/sqlite/README.chromium for details
#BuildRequires: pkgconfig(sqlite3)

## Various bundled libraries that Chromium does not support unbundling :-(
## Only the parts actually built are listed.
## Query for candidates:
## grep third_party/ build.log | sed 's!third_party/!\nthird_party/!g' | \
## grep third_party/ | sed 's!^third_party/!!g' | sed 's!/.*$!!g' | \
## sed 's/\;.*$//g' | sed 's/ .*$//g' | sort | uniq | less
## some false positives where only shim headers are generated for some reason
## some false positives with dummy placeholder dirs (swiftshader, widevine)
## some false negatives where a header-only library is bundled (e.g. x86inc)
## Spot's chromium.spec also has a list that I checked.

# Of course, Chromium itself is bundled. It cannot be unbundled because it is
# not a library, but forked (modified) application code.
Provides: bundled(chromium) = 118.0.5993.220

# Bundled in src/3rdparty/chromium/third_party:
# Check src/3rdparty/chromium/third_party/*/README.chromium for version numbers,
# except where specified otherwise.
Provides: bundled(angle) = 2422
# Google's fork of OpenSSL
# We cannot build against NSS instead because it no longer works with NSS 3.21:
# HTTPS on, ironically, Google's sites (Google, YouTube, etc.) stops working
# completely and produces only ERR_SSL_PROTOCOL_ERROR errors:
# http://kaosx.us/phpBB3/viewtopic.php?t=1235
# https://bugs.launchpad.net/ubuntu/+source/chromium-browser/+bug/1520568
# So we have to do what Chromium now defaults to (since 47): a "chimera build",
# i.e., use the BoringSSL code and the system NSS certificates.
Provides: bundled(boringssl)
Provides: bundled(brotli)
%if !%{use_system_ffmpeg}
# see src/3rdparty/chromium/third_party/ffmpeg/Changelog for the version number
Provides: bundled(ffmpeg) = 5.1.2
%endif
Provides: bundled(hunspell) = 1.6.0
Provides: bundled(iccjpeg)
# bundled as "khronos", headers only
Provides: bundled(khronos_headers)
# bundled as "leveldatabase"
Provides: bundled(leveldb) = 1.23
# bundled as "libjingle_xmpp"
Provides: bundled(libjingle)
# see src/3rdparty/chromium/third_party/libsrtp/CHANGES for the version number
Provides: bundled(libsrtp) = 2.4.0
%if !%{use_system_libvpx}
# claims "Version: 1.6.0", but according to the fine print, this is actually a
# snapshot from master from after the 1.6.1 release
Provides: bundled(libvpx) = 1.8.2
%endif
%if !%{use_system_libwebp}
Provides: bundled(libwebp) = 1.2.0
%endif
# bundled as "libxml"
# see src/3rdparty/chromium/third_party/libxml/linux/include/libxml/xmlversion.h
Provides: bundled(libxml2) = 2.9.13
# see src/3rdparty/chromium/third_party/libxslt/linux/config.h for version
Provides: bundled(libxslt) = 1.1.34
Provides: bundled(libXNVCtrl) = 302.17
Provides: bundled(libyuv) = 1819
Provides: bundled(modp_b64)
Provides: bundled(openmax_dl) = 1.0.2
Provides: bundled(ots)
%if !%{use_system_protobuf}
# see src/3rdparty/chromium/third_party/protobuf/CHANGES.txt for the version
Provides: bundled(protobuf) = 3.13.0.1
%endif
Provides: bundled(qcms) = 4
Provides: bundled(sfntly)
Provides: bundled(skia)
# bundled as "smhasher"
Provides: bundled(SMHasher) = 0-0.1.svn147
Provides: bundled(sqlite) = 3.39.4
Provides: bundled(usrsctp)
Provides: bundled(webrtc) = 90

%ifarch %{ix86} x86_64
# bundled by ffmpeg and libvpx:
# header (for assembly) only
Provides: bundled(x86inc)
%endif

# Bundled in src/3rdparty/chromium/base/third_party:
# Check src/3rdparty/chromium/third_party/base/*/README.chromium for version
# numbers, except where specified otherwise.
Provides: bundled(dmg_fp)
Provides: bundled(dynamic_annotations) = 4384
Provides: bundled(superfasthash) = 0
Provides: bundled(symbolize)
# bundled as "valgrind", headers only
Provides: bundled(valgrind.h)
# bundled as "xdg_mime"
Provides: bundled(xdg-mime)
# bundled as "xdg_user_dirs"
Provides: bundled(xdg-user-dirs) = 0.10

# Bundled in src/3rdparty/chromium/net/third_party:
# Check src/3rdparty/chromium/third_party/net/*/README.chromium for version
# numbers, except where specified otherwise.
Provides: bundled(mozilla_security_manager) = 1.9.2

# Bundled in src/3rdparty/chromium/url/third_party:
# Check src/3rdparty/chromium/third_party/url/*/README.chromium for version
# numbers, except where specified otherwise.
# bundled as "mozilla", file renamed and modified
Provides: bundled(nsURLParsers)

# Bundled outside of third_party, apparently not considered as such by Chromium:
Provides: bundled(mojo)
# see src/3rdparty/chromium/v8/include/v8_version.h for the version number
Provides: bundled(v8) = 11.8.172.18
# bundled by v8 (src/3rdparty/chromium/v8/src/base/ieee754.cc)
# The version number is 5.3, the last version that upstream released, years ago:
# http://www.netlib.org/fdlibm/readme
Provides: bundled(fdlibm) = 5.3

%description
The Qt WebEngine module provides the WebEngineView API which allows QML
applications to render regions of dynamic web content. A WebEngineView
component may share the screen with other QML components or encompass
the full screen as specified within the QML application.

It allows an application to load pages into the WebEngineView, either by
URL or with an HTML string, and navigate within session history. By
default, links to different pages load within the same WebEngineView, but
web sites may request them to be opened as a new tab, window or dialog.

%files
%{_qt6_translationdir}/qtwebengine_locales
%{_qt6_libdir}/qt6/qml/*
%dir %{_qt6_datadir}/resources/
%{_qt6_datadir}/resources/*.pak
%{_qt6_datadir}/resources/*.bin
%{_qt6_plugindir}/imageformats/libqpdf.so
#ifarch %%{ix86}
%if 0%{?sse2}
# shared V8 library and its SSE2 version
%{_qt6_libdir}/qtwebengine/
%endif
%{_qt6_libexecdir}/QtWebEngineProcess
%{_qt6_libexecdir}/webenginedriver
%{_qt6_archdatadir}/sbom/*-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtWebEngine%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description    doc
Documentation for APIs and tools in QtWebEngine%{qtmajor} package for
use with Qt Assistant.

%files doc
%{_qt6_docdir}/qtwebengine.qch
%{_qt6_docdir}/qtwebengine/
%{_qt6_docdir}/qtpdf.qch
%{_qt6_docdir}/qtpdf/
%endif

#------------------------------------------------------------------------------

%package -n     %{libwebenginequick}
Summary:        Qt%{qtmajor} WebEngineQuick Library
Group:          System/Libraries

%description -n %{libwebenginequick}
Qt%{qtmajor} WebEngineQuick Component Library.

%files -n %{libwebenginequick}
%{_qt6_libdir}/libQt6WebEngineQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libwebenginequickdelegates}
Summary:        Qt%{qtmajor} WebEngineQuickDelegates QML Library
Group:          System/Libraries

%description -n %{libwebenginequickdelegates}
Qt%{qtmajor} WebEngineQuickDelegates QML Component Library.

%files -n %{libwebenginequickdelegates}
%{_qt6_libdir}/libQt6WebEngineQuickDelegatesQml.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libwebenginecore}
Summary:        Qt%{qtmajor} WebEngineCore Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libwebenginecore}
Qt%{qtmajor} WebEngineCore Component Library.

%files -n %{libwebenginecore}
%{_qt6_libdir}/libQt6WebEngineCore.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libwebenginewidgets}
Summary:        Qt%{qtmajor} WebEngineWidgets Library
Group:          System/Libraries

%description -n %{libwebenginewidgets}
Qt%{qtmajor} WebEngineWidgets Component Library.

%files -n %{libwebenginewidgets}
%{_qt6_libdir}/libQt6WebEngineWidgets.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libpdf}
Summary:        Qt%{qtmajor} Pdf Library
Group:          System/Libraries

%description -n %{libpdf}
Qt%{qtmajor} Pdf Component Library.

%files -n %{libpdf}
%{_qt6_libdir}/libQt6Pdf.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libpdfquick}
Summary:        Qt%{qtmajor} Pdf Quick Library
Group:          System/Libraries

%description -n %{libpdfquick}
Qt%{qtmajor} Pdf Quick Component Library.

%files -n %{libpdfquick}
%{_qt6_libdir}/libQt6PdfQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libpdfwidgets}
Summary:        Qt%{qtmajor} Pdf Widgets Library
Group:          System/Libraries

%description -n %{libpdfwidgets}
Qt%{qtmajor} Pdf Widgets Component Library.

%files -n %{libpdfwidgets}
%{_qt6_libdir}/libQt6PdfWidgets.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libwebengine_d}
Summary:        Devel files needed to build apps based on QtWebEngine
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libwebenginequick} = %{version}
Requires:       %{libwebenginequickdelegates} = %{version}
Requires:       %{libwebenginecore} = %{version}
Requires:       %{libwebenginewidgets} = %{version}
Requires:       %{libpdf} = %{version}
Requires:       %{libpdfquick} = %{version}
Requires:       %{libpdfwidgets} = %{version}
Provides:       libwebengine6-devel = %{version}
Provides:       webengine6-devel = %{version}
Provides:       qtwebengine6-devel = %{version}
Provides:       qt6webengine-devel = %{version}

%description -n %{libwebengine_d}
Devel files needed to build apps based on Qt WebEngine.

%files -n %{libwebengine_d}
%{_rpmmacrodir}/macros.qt6-qtwebengine
%ifnarch %{arm}
%{_qt6_libexecdir}/gn
%endif
%{_qt6_libexecdir}/qwebengine_convert_dict
%{_qt6_headerdir}/Qt*/
%{_qt6_libdir}/libQt6*.so
%{_qt6_libdir}/libQt6*.prl
%{_qt6_libdir}/cmake/Qt6Pdf*/
%{_qt6_libdir}/cmake/Qt6WebEngine*/
%{_qt6_mkspecsdir}/modules/*.pri
%{_qt6_libdir}/qt6/modules/*.json
%{_qt6_libdir}/qt6/metatypes/qt6*_metatypes.json
%{_qt6_libdir}/pkgconfig/*.pc
%if %{with examples}
%{_qt6_examplesdir}/pdf/
%{_qt6_examplesdir}/pdfwidgets/
%{_qt6_examplesdir}/webenginequick/
%{_qt6_examplesdir}/webenginewidgets/
%endif
%{_qt6_libdir}/cmake/Qt6/*.cmake
%{_qt6_libdir}/cmake/Qt6Gui/Qt6QPdfPlugin*.cmake
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/Qt6PdfQuickplugin*.cmake
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtWebEngineTestsConfig.cmake

#------------------------------------------------------------------------------

%prep
%setup -q -n %{qttarballdir} -a20

mv pulse src/3rdparty/chromium/


%patch -P 2 -p1 -b .link-pipewire

%patch -P 11 -p1 -b .SIOCGSTAMP

## upstream patches
%patch -P 24 -p1 -b .aarch64-new-stat
%patch -P 50 -p1 -b .fix-build
%patch -P 80 -p1 -b .fix-arm-build

%patch -P 101 -p1 -b .h264
%patch -P 102 -p1 -b .fseal

# delete all "toolprefix = " lines from build/toolchain/linux/BUILD.gn, as we
# never cross-compile in native Fedora RPMs, fixes ARM and aarch64 FTBFS
sed -i -e '/toolprefix = /d' -e 's/\${toolprefix}//g' \
  src/3rdparty/chromium/build/toolchain/linux/BUILD.gn

%if %{use_system_re2}
# http://bugzilla.redhat.com/1337585
# can't just delete, but we'll overwrite with system headers to be on the safe side
cp -bv /usr/include/re2/*.h src/3rdparty/chromium/third_party/re2/src/re2/
%endif

%if 0
#ifarch x86_64
# enable this to force -g2 on x86_64 (most arches run out of memory with -g2)
# DISABLED BECAUSE OF:
# /usr/lib/rpm/find-debuginfo.sh: line 188:  3619 Segmentation fault
# (core dumped) eu-strip --remove-comment $r $g -f "$1" "$2"
sed -i -e 's/symbol_level=1/symbol_level=2/g' src/core/config/common.pri
%endif

# copy the Chromium license so it is installed with the appropriate name
cp -p src/3rdparty/chromium/LICENSE LICENSE.Chromium

# consider doing this as part of the tarball creation step instead?  rdieter
# fix/workaround
# fatal error: QtWebEngineCore/qtwebenginecoreglobal.h: No such file or directory
#if [ ! -f "./include/QtWebEngineCore/qtwebenginecoreglobal.h" ]; then
#%%{_qt6_bindir}/syncqt.pl -version %%{version}
#fi

# abort if this doesn't get created by syncqt.pl
#test -f "./include/QtWebEngineCore/qtwebenginecoreglobal.h"

%build
# Increase open files limit
ulimit -n 4096

%if %{use_clang}
export CC=clang
export CXX=clang++
%endif

export STRIP=strip
export NINJAFLAGS="%{__ninja_common_opts}"
export NINJA_PATH=%{__ninja}

%cmake_qt6 \
  -DCMAKE_TOOLCHAIN_FILE:STRING="%{_qt6_libdir}/cmake/Qt6/qt.toolchain.cmake" \
%if %{use_clang}
  -DCMAKE_C_COMPILER=clang \
  -DCMAKE_CXX_COMPILER=clang++ \
  -DQT_CFLAGS_OPTIMIZE=-Os \
%endif
  -DFEATURE_qtpdf_build:BOOL=ON \
  -DFEATURE_webengine_developer_build:BOOL=OFF \
  -DFEATURE_webengine_embedded_build:BOOL=OFF \
  -DFEATURE_webengine_extensions:BOOL=ON \
  -DFEATURE_webengine_kerberos:BOOL=ON \
  -DFEATURE_webengine_native_spellchecker:BOOL=OFF \
  -DFEATURE_webengine_printing_and_pdf:BOOL=ON \
  -DFEATURE_webengine_webrtc:BOOL=ON \
  -DFEATURE_webengine_webrtc_pipewire:BOOL=ON \
%if %{use_system_ffmpeg}
  -DQT_FEATURE_webengine_system_ffmpeg:BOOL=ON \
  -DQT_FEATURE_webengine_proprietary_codecs:BOOL=ON \
  -DQT_FEATURE_webengine_system_opus:BOOL=ON \
%else
  -DQT_FEATURE_webengine_system_ffmpeg:BOOL=OFF \
%endif
%if %{use_system_libvpx}
  -DQT_FEATURE_webengine_system_libvpx:BOOL=ON \
%endif
%if %{use_system_libicu}
  -DQT_FEATURE_webengine_system_icu=ON \
%endif
  -DQT_FEATURE_webengine_system_minizip:BOOL=ON \
  -DQT_FEATURE_webengine_system_libevent:BOOL=ON \
%if %{use_system_re2}
  -DQT_FEATURE_webengine_system_re2:BOOL=ON \
%endif
%if %{use_system_libwebp}
  -DQT_FEATURE_webengine_system_libwebp:BOOL=ON \
%endif
%if %{use_system_libxml}
  -DQT_FEATURE_webengine_system_libxml:BOOL=ON \
%else
  -DQT_FEATURE_webengine_system_libxml:BOOL=OFF \
%endif
%if %{use_system_harfbuzz}
  -DQT_FEATURE_webengine_system_harfbuzz:BOOL=ON \
%else
  -DQT_FEATURE_webengine_system_harfbuzz:BOOL=OFF \
%endif
  %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}

%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif

# rpm macros
install -p -m644 -D %{SOURCE10} \
  %{buildroot}%{_rpmmacrodir}/macros.qt6-qtwebengine
sed -i \
  -e "s|@@NAME@@|%{name}|g" \
  -e "s|@@EPOCH@@|%{?epoch}%{!?epoch:0}|g" \
  -e "s|@@VERSION@@|%{version}|g" \
  -e "s|@@EVR@@|%{?epoch:%{epoch:}}%{version}-%{release}|g" \
  %{buildroot}%{_rpmmacrodir}/macros.qt6-qtwebengine

## .prl/.la file love
# nuke .prl reference(s) to %%buildroot, excessive (.la-like) libs
pushd %{buildroot}%{_qt6_libdir}
for prl_file in libQt6*.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd

%if %{use_system_libicu}
rm -rf %{buildroot}%{_qt6_datadir}/resources/icudtl.dat
%endif

# error: build-id found in /home/iurt/rpmbuild/BUILDROOT/qtwebengine6-6.4.1-2.mga9.arm/usr/lib/qt6/libexec/gn too small
# error: Generating build-id links failed
%ifarch %{arm}
rm -rf %{buildroot}%{_qt6_libexecdir}/gn
%endif
