# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtwebsockets-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtwebsockets   %mklibname qt%{qtmajor}websockets %{qtmajor}
%define libqtwebsockets_d %mklibname qt%{qtmajor}websockets -d

Name:           qtwebsockets5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} WebSockets component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtwebsockets
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Clear-frame-on-reconnect.patch
Patch0002:      0002-Disconnect-when-handshake-fails.patch

BuildRequires:  qtbase5-devel >= %{version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}

Provides:       qt%{qtmajor}-qtwebsockets = %{version}-%{release}

#Branch Patchs

#Trunk Patchs

#Patch from Mageia

#Patch from Fedora
Patch0:         qt5-qtwebsockets-gcc11.patch


%description
QtWebSockets is a pure Qt implementation of WebSockets - both client and
server.
It is implemented as a Qt add-on module, that can easily be embedded into
existing Qt projects. It has no other dependencies than Qt.

%files
%{_qt5_qml}/Qt/WebSockets/
%{_qt5_qml}/QtWebSockets/

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtWebSockets%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtWebSockets%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtwebsockets.qch
%{_qt5_docdir}/qtwebsockets/
%endif

#------------------------------------------------------------------------------

%package -n %{libqtwebsockets}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries

%description -n %{libqtwebsockets}
Qt%{qtmajor} Component Library.

QtWebSockets is a pure Qt implementation of WebSockets - both client and
server.

%files -n %{libqtwebsockets}
%{_qt5_libdir}/libQt5WebSockets.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtwebsockets_d}
Summary:        Devel files needed to build apps based on QtWebSockets
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtwebsockets} = %{version}
Requires:       qtbase5-common-devel = %{version}
Provides:       libqtwebsockets5-devel = %{version}
Provides:       qtwebsockets5-devel = %{version}

Provides:       libqtwebsockets5-private-devel = %{version}
Provides:       libqt5websockets-private-devel = %{version}
Provides:       qtwebsockets5-private-devel = %{version}
Provides:       qt5websockets-private-devel = %{version}
Requires:       qt5core-private-devel = %{version}

%description -n %{libqtwebsockets_d}
Devel files needed to build apps based on QtWebSockets.

%files -n %{libqtwebsockets_d}
%{_qt5_libdir}/libQt5WebSockets.prl
%{_qt5_libdir}/libQt5WebSockets.so
%{_qt5_libdir}/pkgconfig/Qt5WebSockets.pc
%{_qt5_includedir}/QtWebSockets
%{_qt5_libdir}/cmake/*
%{_qt5_archdatadir}/mkspecs/modules/*
%{_qt5_examplesdir}/*

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtwebsockets-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

install -d %{buildroot}%{_qt5_docdir}
