# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir   qtwebview-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtwebview       %mklibname qt%{qtmajor}webview %{qtmajor}
%define libqtwebviewquick  %mklibname qt%{qtmajor}webviewquick %{qtmajor}
%define libqtwebview_d     %mklibname qt%{qtmajor}webview -d

Name:           qtwebview6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} WebView component
# See LGPL_EXCEPTIONS.txt, LICENSE.GPL3, respectively, for exception details
License:        LGPLv2 with exceptions or GPLv3 with exceptions
Group:          Development/KDE and Qt
Url:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
## Branch Patchs

## Trunk Patchs

## Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6OpenGL) >= %{version}
%ifnarch %{ix86} %{arm32}
BuildRequires:  cmake(Qt6WebEngineCore) >= %{version}
BuildRequires:  cmake(Qt6WebEngineQuick) >= %{version}
%endif

Provides:       qt%{qtmajor}-qtwebview = %{version}-%{release}

%description
Qt%{qtmajor} WebView provides a way to display web content in a QML
application without necessarily including a full web browser stack
by using native APIs where it makes sense.

%files
%{_qt6_qmldir}/QtWebView
%ifnarch %{ix86} %{arm32}
%dir %{_qt6_plugindir}/webview/
%{_qt6_plugindir}/webview/libqtwebview_webengine.so
%endif
%{_qt6_archdatadir}/sbom/qtwebview-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtWebView%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtWebView%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt6_docdir}/qtwebview.qch
%{_qt6_docdir}/qtwebview/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtwebview}
Summary:        Qt%{qtmajor} WebView Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtwebview}
Qt%{qtmajor} WebView Component Library.

%files -n %{libqtwebview}
%{_qt6_libdir}/libQt6WebView.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtwebviewquick}
Summary:        Qt%{qtmajor} WebView Quick Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libqtwebviewquick}
Qt%{qtmajor} WebView Quick Component Library.

%files -n %{libqtwebviewquick}
%{_qt6_libdir}/libQt6WebViewQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtwebview_d}
Summary:        Devel files needed to build apps based on QtWebView
Group:          Development/KDE and Qt
Requires:       %{libqtwebview} = %{version}
Requires:       %{libqtwebviewquick} = %{version}
Provides:       libqtwebview%{qtmajor}-devel = %{version}
Provides:       libqt%{qtmajor}webview-devel = %{version}
Provides:       qtwebview%{qtmajor}-devel = %{version}
Provides:       qt%{qtmajor}webview-devel = %{version}

%description -n %{libqtwebview_d}
Devel files needed to build apps based on Qt WebView.

%files -n %{libqtwebview_d}
%{_qt6_includedir}/QtWebView/
%{_qt6_libdir}/libQt%{qtmajor}WebView.so
%{_qt6_libdir}/cmake/Qt%{qtmajor}WebView/
%{_qt6_libdir}/pkgconfig/Qt%{qtmajor}WebView.pc
%{_qt6_libdir}/qt6/metatypes/qt%{qtmajor}webview_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/WebView.json
#
%{_qt6_includedir}/QtWebViewQuick/
%{_qt6_libdir}/libQt%{qtmajor}WebViewQuick.so
%{_qt6_libdir}/cmake/Qt%{qtmajor}WebViewQuick/
%{_qt6_libdir}/pkgconfig/Qt%{qtmajor}WebViewQuick.pc
%{_qt6_libdir}/qt6/metatypes/qt%{qtmajor}webviewquick_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/WebViewQuick.json
#
%{_qt6_libdir}/*.prl
%{_qt6_archdatadir}/mkspecs/modules/*.pri
#
%if %{with examples}
%{_qt6_examplesdir}/webview/
%endif
#
%{_qt6_libdir}/cmake/Qt%{qtmajor}Qml/QmlPlugins/Qt%{qtmajor}qtwebviewquick*
%{_qt6_libdir}/cmake/Qt%{qtmajor}BuildInternals/StandaloneTests/QtWebViewTestsConfig.cmake

#------------------------------------------------------------------------------

%prep
%setup -q -n qtwebview-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

 %if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif
