%ifarch armv7hl %ix86
# -g causes linker to run out of memory
%global debug_package %{nil}
%endif

Summary:        The free/open-source library for quantitative finance
Name:           quantlib-swig
Version:        1.37
Release:        %mkrel 3
License:        BSD License
Group:          System/Libraries
URL:            https://www.quantlib.org/
Source0:        https://github.com/lballabio/QuantLib-SWIG/releases/download/v%{version}/QuantLib-SWIG-%{version}.tar.gz

BuildRequires:  boost-devel >= 1.34.1
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig
BuildRequires:  quantlib-devel >= %{version}
BuildRequires:  R-base

# needed for R-quantlib manual
BuildRequires:  texlive

%description
Alternative language bindings for quantlib.

%package -n r-quantlib
Summary:        R bindings for Quantlib
Group:          Sciences/Mathematics
Requires:       R-base

%description -n r-quantlib
R bindings for Quantlib.

%package -n python3-quantlib
Summary:        Python 3 bindings for Quantlib
Group:          Development/Python

%description -n python3-quantlib
Python 3 bindings for Quantlib.

%prep
%autosetup -p1 -n QuantLib-SWIG-%{version}

find -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'

%build
autoreconf --force --install
export CXXFLAGS="-O2 %{Werror_cflags} --param ggc-min-expand=20 -fPIE"
export CFLAGS="-O2 %{Werror_cflags} --param ggc-min-expand=20 -fPIE"
%configure --disable-static --prefix=%{_prefix}
# make clean to remove old swig files
make clean
pushd Python
# need to build by hand to avoid pipe which exhausts memory on i586
swig -python -c++ \
     -outdir src/QuantLib -o quantlib_wrap.cpp ../SWIG/quantlib.i
%{__cxx} -O2 -Wformat -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector \
    --param=ssp-buffer-size=4 -fasynchronous-unwind-tables  -fPIC -fwrapv \
    --param ggc-min-expand=1 --param ggc-min-heapsize=51200 -c quantlib_wrap.cpp \
    -I`python3 -c 'import distutils.sysconfig ; print(distutils.sysconfig.get_config_vars("CONFINCLUDEPY")[0])'` \
    -o quantlib_wrap.o
%{__cxx} -shared quantlib_wrap.o -L/usr/lib -L/usr/lib64 -lpython3 -lQuantLib \
-o _QuantLib`python3 -c 'import distutils.sysconfig ; print(distutils.sysconfig.get_config_vars("SO")[0])'`
%{__python3} setup.py egg_info
popd
pushd R
touch .build-stamp
swig -r -c++ -o src/QuantLib.cpp ../SWIG/quantlib.i
popd

%install
pushd Python
mkdir -p %{buildroot}%{python3_sitearch}/QuantLib
cp src/QuantLib/*.py %{buildroot}%{python3_sitearch}/QuantLib
cp src/QuantLib.egg-info/PKG-INFO \
   %{buildroot}%{python3_sitearch}/QuantLib_Python-%{version}-py`python3 -c 'import distutils.sysconfig ; print(distutils.sysconfig.get_config_vars("VERSION")[0])'`.egg-info
popd
pushd R
mkdir -p %{buildroot}%{_libdir}/R/library
echo 'PKG_CPPFLAGS=--param ggc-min-expand=20' >  src/Makevars
echo 'PKG_LIBS=-lQuantLib' >>  src/Makevars
# need to build by hand to avoid pipe which exhausts memory
%ifarch armv7hl %ix86
pushd src
%{__cxx} -I%{_libdir}/R/include -DNDEBUG --param ggc-min-expand=20  -I/usr/local/include   -fPIC -O2 -Wformat -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector --param=ssp-buffer-size=4 -fasynchronous-unwind-tables  -c QuantLib.cpp -o QuantLib.o
popd
%endif
R CMD INSTALL --library=%{buildroot}%{_libdir}/R/library .
popd
rm -rf %{buildroot}%{_docdir}

%files -n python3-quantlib
%{python3_sitearch}/QuantLib/
%{python3_sitearch}/*.egg-info

%files -n r-quantlib
%{_libdir}/R/library/QuantLib

%if 0%{?with_ruby}
%files -n ruby-quantlib
%{ruby_vendorarchdir}/QuantLibc.so
%{ruby_vendorlibdir}/QuantLib.rb
%endif
