Name:		quassel
Version:	0.14.0
Release:	%mkrel 2
Summary:	A modern cross-platform distributed (monolithic) IRC client
Group:		Networking/IRC
License:	GPLv3
URL:		https://quassel-irc.org/
Source0:	https://quassel-irc.org/pub/quassel-%{version}.tar.bz2
Source1:	networks.ini
# Systemd service file and configuration script
Source2:	quasselcore.service
Source3:	quassel.conf

BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Script)
BuildRequires:	pkgconfig(Qt5Sql)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5WebEngine)

BuildRequires:	kf5-macros
BuildRequires:	cmake(KF5ConfigWidgets)
BuildRequires:	cmake(KF5CoreAddons)
BuildRequires:	cmake(KF5Notifications)
BuildRequires:	cmake(KF5NotifyConfig)
BuildRequires:	cmake(KF5TextWidgets)
BuildRequires:	cmake(KF5WidgetsAddons)
BuildRequires:	cmake(KF5XmlGui)

BuildRequires:	pkgconfig(qca2-qt5)
BuildRequires:	pkgconfig(phonon4qt5)
BuildRequires:	pkgconfig(dbusmenu-qt5)
BuildRequires:	git
BuildRequires:	systemd
BuildRequires:	boost-devel

Requires:	quassel-common = %{version}
Provides:	plasma5-irc-client

%description
Quassel IRC is a modern, cross-platform, distributed IRC client,
meaning that one (or multiple) client(s) can attach to and detach
from a central core -- much like the popular combination of screen
and a text-based IRC client such as WeeChat, but graphical. In
addition to this unique feature, we aim to bring a pleasurable,
comfortable chatting experience to all major platforms (including
Linux®, Windows®, and MacOS X® as well as Qtopia-based cell phones
and PDAs), making communication with your peers not only convenient,
but also ubiquitous available.

%files
%{_kf5_bindir}/%{name}
%{_kf5_applicationsdir}/%{name}.desktop

#-----------------------------------------------------------------------

%package	common
Group:		Networking/IRC
Summary:	A modern cross-platform distributed IRC client - Common files
BuildArch:	noarch
Requires:	qt5-database-plugin-sqlite
Requires:	qca-qt5
Recommends:	inxi-quassel
Recommends:	qt5-database-plugin-pgsql

%description	common
A modern, cross-platform, distributed IRC client.
- This is client only, depends on a core server.

%files common
%doc AUTHORS ChangeLog README.md
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_datadir}/%{name}/
%{_kf5_knotificationsdir}/%{name}.notifyrc

#-----------------------------------------------------------------------

%package	client
Group:		Networking/IRC
Summary:	A modern cross-platform distributed IRC client - Client only
Requires:	%{name}-common = %{version}

%description	client
A modern cross-platform distributed IRC client - Client only.

%files client
%{_kf5_bindir}/quasselclient
%{_kf5_applicationsdir}/quasselclient.desktop

#-----------------------------------------------------------------------

%package	core
Group:		Networking/IRC
Summary:	A modern cross-platform distributed IRC client - Core server
Requires:	%{name}-common = %{version}

# Required for the quassel user
Requires(pre):		shadow-utils
Requires(post):		rpm-helper >= %{rpmhelper_required_version}
Requires(preun):	rpm-helper >= %{rpmhelper_required_version}
Requires(postun):	rpm-helper >= %{rpmhelper_required_version}

%description	core
A modern, cross-platform, distributed IRC client - This is quassel.
core server for clients.

%files core
%{_kf5_bindir}/quasselcore
%config(noreplace) %{_sysconfdir}/%{name}.conf
%dir %attr(-,quassel,quassel) %{_var}/lib/%{name}
%{_unitdir}/quasselcore.service

#-----------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake_kf5 \
    -DWANT_MONO=ON \
    -DWITH_KDE=ON \
    -DEMBED_DATA=OFF \
    -DUSE_QT5=ON \
    -DHAVE_SSL=ON \
    -DENABLE_SHARED=OFF
%cmake_build

%install
%cmake_install

# Our own defined networks
rm -f %{buildroot}%{_kf5_datadir}/%{name}/networks.ini
install -m 644 %{SOURCE1} %{buildroot}%{_kf5_datadir}/%{name}/

# Note that quassel tend to not update their version very often, so we are better
# off changing their inxi file version with a symbolic link to our real inxi version
# for that we have an inxi-quassel package
rm -f %{buildroot}%{_kf5_datadir}/%{name}/scripts/inxi

# Install quassel.conf for systemd file
install -Dp -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.conf

# Install systemd service file
install -Dp -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/quasselcore.service

# Home directory for quassel user
install -d -m 0750 %{buildroot}%{_var}/lib/%{name}

%pre core
%_pre_useradd %{name} /dev/null /bin/false

%post core
%_post_service quasselcore

%preun core
%_preun_service quasselcore

%postun core
%_postun_userdel %{name}
