%bcond_without	qt5
%bcond_without	qt6

Name:		quazip
Version:	1.4
Release:	%mkrel 1
Summary:	Qt/C++ wrapper for the minizip library
License:	LGPLv2+
Group:		Development/C++
URL:		https://github.com/stachenov/quazip
Source0:	https://github.com/stachenov/quazip/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libzip)
### Qt5 build dependencies
%if %{with qt5}
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5Test)
BuildRequires:	cmake(Qt5Widgets)
%endif
### Qt6 build dependencies
%if %{with qt6}
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6Widgets)
%endif

%description
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives. It uses Trolltech's Qt toolkit.

QuaZIP allows you to access files inside ZIP archives using QIODevice API,
and - yes! - that means that you can also use QTextStream, QDataStream or
whatever you would like to use on your zipped files.

QuaZIP provides complete abstraction of the ZIP/UNZIP API, for both reading
from and writing to ZIP archives.

#------------------------------------------------------------------------------
### Qt5 ###

%if %{with qt5}

%define api		1
%define quazip_major	1.4.0
%define libquazip_qt5	%mklibname %{name}%{api}-qt5_ %{quazip_major}

%package -n	%{libquazip_qt5}
Summary:	Minizip wrapper library for Qt 5.x
Group:		System/Libraries

%description -n	%{libquazip_qt5}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt5 runtime library for %{name}.

%files -n %{libquazip_qt5}
%doc NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_libdir}/lib%{name}%{api}-qt5.so.%{quazip_major}{,.*}
%{_libdir}/lib%{name}%{api}-qt5.so.%{version}

#------------------------------------------------------------------------------

%define develquazip_qt5	%mklibname %{name}%{api}-qt5 -d

%package -n	%{develquazip_qt5}
Summary:	Development files for %{name}
Group:		Development/KDE and Qt
Requires:	%{libquazip_qt5} = %{version}-%{release}
Requires:	pkgconfig(libzip)
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{name}-qt5-devel = %{version}-%{release}
Provides:	%{name}%{api}-qt5-devel = %{version}-%{release}

%description -n	%{develquazip_qt5}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt5 headers files needed to build a package against
%{name}.

%files -n %{develquazip_qt5}
%doc doc/html
%doc CONTRIBUTING.md README.md NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_includedir}/QuaZip-Qt5-%{version}/
%{_libdir}/lib%{name}%{api}-qt5.so
%{_libdir}/cmake/QuaZip-Qt5-%{version}/
%{_libdir}/pkgconfig/%{name}%{api}-qt5.pc
%endif

### End Qt5 ###

#------------------------------------------------------------------------------
### Qt6 ###

%if %{with qt6}

%define api		1
%define quazip_major	1.4.0
%define libquazip_qt6	%mklibname %{name}%{api}-qt6_ %{quazip_major}

%package -n	%{libquazip_qt6}
Summary:	Minizip wrapper library for Qt 6.x
Group:		System/Libraries

%description -n	%{libquazip_qt6}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt6 runtime library for %{name}.

%files -n %{libquazip_qt6}
%doc NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_libdir}/lib%{name}%{api}-qt6.so.%{quazip_major}{,.*}
%{_libdir}/lib%{name}%{api}-qt6.so.%{version}

#------------------------------------------------------------------------------

%define develquazip_qt6	%mklibname %{name}%{api}-qt6 -d

%package -n	%{develquazip_qt6}
Summary:	Development files for %{name}-qt6
Group:		Development/KDE and Qt
Requires:	%{libquazip_qt6} = %{version}-%{release}
Requires:	pkgconfig(libzip)
Provides:	lib%{name}-qt6-devel = %{version}-%{release}
Provides:	%{name}-qt6-devel = %{version}-%{release}
Provides:	%{name}%{api}-qt6-devel = %{version}-%{release}

%description -n	%{develquazip_qt6}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt6 headers files needed to build a package against
%{name}.

%files -n %{develquazip_qt6}
%doc doc/html
%doc CONTRIBUTING.md README.md NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_includedir}/QuaZip-Qt6-%{version}/
%{_libdir}/lib%{name}%{api}-qt6.so
%{_libdir}/cmake/QuaZip-Qt6-%{version}/
%{_libdir}/pkgconfig/%{name}%{api}-qt6.pc
%endif

### End Qt6 ###

#------------------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
### Build Qt5 ###
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_qt5 -DQUAZIP_QT_MAJOR_VERSION=5
%cmake_build
%endif

### Build Qt6 ###
%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_qt6 -DQUAZIP_QT_MAJOR_VERSION=6
%cmake_build
%endif

### Build doc ###
doxygen Doxyfile
for file in doc/html/*; do
       touch -r Doxyfile $file
done

%install
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_install
%endif
