Name:           quota
Version:        4.09
Release:        %mkrel 1
Summary:        System administration tools for monitoring users' disk usage
License:        BSD and GPLv2+
Group:          System/Configuration
URL:            https://sourceforge.net/projects/linuxquota/
Source0:        https://prdownloads.sourceforge.net/linuxquota/%{name}-%{version}.tar.gz
Source1:        quota_nld.service
Source2:        quota_nld.sysconfig
Source3:        rpc-rquotad.service
Source4:        rpc-rquotad.sysconfig
Patch1:         quota-4.03-Validate-upper-bound-of-RPC-port.patch
Patch50:        quota-tools-default-conf.patch
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  e2fsprogs-devel
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  openldap-devel
BuildRequires:  systemd
BuildRequires:  tcp_wrappers-devel
BuildRequires:  rpcgen
BuildRequires:  pkgconfig(libtirpc)
Requires:       quota-nls = %{version}-%{release}

%description
The quota package contains system administration tools for monitoring
and limiting user and or group disk usage per file system.

%package nld
Group:          System/Configuration
Summary:        quota_nld daemon
Requires:       quota-nls = %{version}-%{release}
Requires(post):     systemd
Requires(preun):    systemd

%description    nld
Daemon that listens on netlink socket and processes received quota warnings.
Note, that you have to enable the kernel support for sending quota messages
over netlink (in Filesystems->Quota menu). The daemon supports forwarding
warning messages to the system D-Bus (so that desktop manager can display
a dialog) and writing them to the terminal user has last accessed.

%package rpc
Summary:    RPC quota daemon
License:    BSD and LGPLv2+ and GPLv2 and GPLv2+
Requires:   quota-nls = %{version}-%{release}
Requires:   rpcbind
Requires:   tcp_wrappers
Requires(post):     systemd
Requires(preun):    systemd
Conflicts:  quota < 4.04-2

%description rpc
The RPC daemon allows to query and set disk quotas over network. If you run
the daemon on NFS server, you could use quota tools to manage the quotas from
NFS client.

%package        warnquota
Group:          System/Configuration
Summary:        Send e-mail to users over quota
Requires:       quota-nls = %{version}-%{release}

%description    warnquota
Utility that checks disk quota for each local file system and mails a warning
message to those users who have reached their soft limit.  It is typically run
via cron(8).

%package nls
Summary:    Gettext catalogs for disk quota tools
License:    BSD and LGPLv2+ and GPLv2 and GPLv2+
BuildArch:  noarch
Conflicts:  quota < 4.04-2

%description nls
Disk quota tools messages translated into different natural languages.

%package        devel
Group:          System/Configuration
Summary:        Development files for quota
Requires:       quota = %{version}-%{release}

%description    devel
The quota package contains system administration tools for monitoring
and limiting user and or group disk usage per file system.

This package contains development header files for implementing quotas
on remote machines.


%package        doc
Group:          Documentation
Summary:        Additional documentation for disk quotas
Requires:       quota >= %{version}-%{release}
BuildArch:      noarch

%description    doc
This package contains additional documentation for disk quotas concept in
Linux/UNIX environment.

%prep
%setup -q
%autopatch -p1

# Fix for perm bug #3053
chmod 755 ldap-scripts/setquota-ldap.pl

%build
%serverbuild

autoreconf -fi

%configure \
    --enable-bsd-behaviour \
    --enable-ext2direct \
    --enable-ldapmail \
    --enable-libwrap \
    --enable-netlink \
    --enable-nls \
    --disable-rpath \
    --enable-rpc=yes \
    --enable-rpcsetquota \
    --disable-silent-rules \
    --disable-xfs-roothack

%make_build

%install
%make_install
rm -rf %{buildroot}%{_docdir}/%{name}

install -m0644 warnquota.conf %{buildroot}%{_sysconfdir}

install -p -m644 -D %{SOURCE1} %{buildroot}%{_unitdir}/quota_nld.service
install -p -m644 -D %{SOURCE2} \
    %{buildroot}%{_sysconfdir}/sysconfig/quota_nld
install -p -m644 -D %{SOURCE3} %{buildroot}%{_unitdir}/rpc-rquotad.service
install -p -m644 -D %{SOURCE4} \
    %{buildroot}%{_sysconfdir}/sysconfig/rpc-rquotad

# we don't support XFS yet
rm -f %{buildroot}%{_sbindir}/quot
rm -f %{buildroot}%{_sbindir}/xqmstats
rm -f %{buildroot}%{_mandir}/man8/quot.*
rm -f %{buildroot}%{_mandir}/man8/xqmstats.*

%find_lang %{name}

%check
%__make check

%post nld
%_post_service quota_nld

%preun nld
%_preun_service quota_nld

%post rpc
%_post_service rpc-rquotad

%preun rpc
%_preun_service rpc-rquotad

%files
%{_bindir}/quota
%{_bindir}/quotasync
%{_sbindir}/convertquota
%{_sbindir}/edquota
%{_sbindir}/quotacheck
%{_sbindir}/quotaoff
%{_sbindir}/quotaon
%{_sbindir}/quotastats
%{_sbindir}/repquota
%{_sbindir}/setquota
%{_mandir}/man1/quota.1*
%{_mandir}/man1/quotasync.1*
%{_mandir}/man8/convertquota.8*
%{_mandir}/man8/edquota.8*
%{_mandir}/man8/quotacheck.8*
%{_mandir}/man8/quotaoff.8*
%{_mandir}/man8/quotaon.8*
%{_mandir}/man8/quotastats.8*
%{_mandir}/man8/repquota.8*
%{_mandir}/man8/setquota.8*

%files nld
%config(noreplace) %{_sysconfdir}/sysconfig/quota_nld
%{_unitdir}/quota_nld.service
%{_sbindir}/quota_nld
%{_mandir}/man8/quota_nld.8*

%files rpc
%config(noreplace) %{_sysconfdir}/sysconfig/rpc-rquotad
%{_unitdir}/rpc-rquotad.service
%{_sbindir}/rpc.rquotad
%{_mandir}/man8/rpc.rquotad.8*

%files warnquota
%config(noreplace) %{_sysconfdir}/warnquota.conf
%config(noreplace) %{_sysconfdir}/quotagrpadmins
%config(noreplace) %{_sysconfdir}/quotatab
%{_sbindir}/warnquota
%{_mandir}/man5/quotagrpadmins.5*
%{_mandir}/man5/quotatab.5*
%{_mandir}/man5/warnquota.conf.5*
%{_mandir}/man8/warnquota.8*
%doc README.ldap-support README.mailserver

%files nls -f %{name}.lang
%doc COPYING Changelog

%files devel
%dir %{_includedir}/rpcsvc
%{_includedir}/rpcsvc/*
%{_mandir}/man3/*

%files doc
%doc doc/* ldap-scripts
