# To fix paths, Racket performs direct ELF surgery during install. D'oh!
# (see collects/setup/unixstyle-install.rkt)
# That's why we end up with slightly different executables that share the same
# build ID, and this breaks debuginfo extraction.
%define debug_package %{nil}

%define		major %{version}
%define		develname %mklibname %{name} -d

Name:		racket
Version:	8.16
Release:	%mkrel 1
Summary:	Racket is a Scheme implementation
License:	LGPLv2+
Group:		Development/Other
Url:		https://www.racket-lang.org/
Source0:	https://download.racket-lang.org/installers/%{version}/%{name}-%{version}-src.tgz
Source1:	racket.png
Patch0:		racket-desktop-file.patch
# Patch1:		racket-doc.patch
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	imagemagick
# Workaround to avoid a build failure https://github.com/racket/racket/issues/4613
BuildRequires:	google-noto-sans-mono-fonts
Requires:	%{_lib}png16_16

%description
Racket is a Scheme implementation. It implements
the language as described in the Revised^5 Report on the
Algorithmic Language Scheme and adds numerous extensions.

%package -n	%{develname}
Summary:	Headers for developing programs that will use %{name}
Group:		Development/Other
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%package -n	g%{name}
Summary:	Racket graphical Scheme implementation
Group:		Development/Other
Requires:	%{name} = %{version}
Requires:	gtk+2.0

%description -n	g%{name}
GRacket is the Racket's graphical Scheme implementation. It embeds and
extends Racket with a graphical user interface (GUI) toolbox.

%package -n	dr%{name}
Summary:	Racket graphical development environment
Group:		Development/Other
Requires:	g%{name} = %{version}

%description -n	dr%{name}
DrRacket is the graphical development environment for creating
Racket and GRacket applications.

%prep
%autosetup -p0

%build
cd src
# Docs include references to BUILDROOT, disable them as RPM otherwise rejects the build.
%configure \
	--disable-docs \
	--disable-strip \
%ifnarch x86_64
	--disable-generations \
%endif
	--enable-sharezo

%make_build

%install
cd src
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
# From time to time parallel "raco setup" gets broken.
# One can uncomment the following line to enforce non-parallel mode:
export PLT_SETUP_OPTIONS="-j 1"
%make_install

# correct installation
install -d -m 755 %{buildroot}%{_datadir}
install -d -m 755 %{buildroot}%{_libdir}/%{name}

# correct perms
find %{buildroot}%{_datadir}/%{name}/collects -type d -exec chmod 755 {} \;

%multiarch_includes %{buildroot}%{_includedir}/racket/*.h

# Install desktop
mkdir -p %{buildroot}%{_datadir}/applications
install -m 0644 ../share/pkgs/drracket/drracket/drracket.desktop %{buildroot}%{_datadir}/applications/drracket.desktop

# Install icons
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -m 0644 ../share/pkgs/icons/racket-logo.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/drracket.svg

# remove references to BUILDROOT in docs
find %{buildroot} -type f | xargs sed -ri 's|%{buildroot}||g'

%files
%doc README
%{_docdir}/%{name}/
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/config.rktd
%{_datadir}/%{name}/
%{_libdir}/%{name}/
%{_bindir}/*
%{_mandir}/man1/*
%exclude %{_bindir}/gracket
%exclude %{_bindir}/drracket
%exclude %{_mandir}/man1/gracket.1*
%exclude %{_mandir}/man1/drracket.1*

%files -n %{develname}
%{_libdir}/libracketcs.a
%{_includedir}/racket/
%multiarch %{multiarch_includedir}/racket/

%files -n gracket
%{_bindir}/gracket
%{_mandir}/man1/gracket.1*

%files -n drracket
%{_bindir}/drracket
%{_mandir}/man1/drracket.1*
%{_iconsdir}/hicolor/scalable/apps/drracket.svg
%{_datadir}/applications/drracket.desktop
%{_datadir}/applications/slideshow.desktop
