%define name radeon-firmware
%define version 20240909
%define release %mkrel 2

Summary: ATI/AMD Radeon firmware files
Name:	 %{name}
Version: %{version}
Release: %{release}
# extracted from git://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git
# all files in radeon/ and amdgpu/ dirs, LICENSE.{radeon,amdgpu} and WHENCE (license for some files)
# git archive --prefix=radeon-firmware-20231111/ HEAD radeon LICENSE.radeon amdgpu LICENSE.amdgpu WHENCE | xz -T0 -9e -v > radeon-firmware-20231111.tar.xz
#
# note that it's preferable to use latest "tagged" version in the git tree, rather than a version corresponding to the latest commit.

Source0: %{name}-%{version}.tar.xz
#
# From:
# https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amdgpu/dcn_3_5_dmcub.bin?id=bcd040c21dc9b2bc7525ea09121fd137eb34183f
# https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/plain/amdgpu/dcn_3_5_1_dmcub.bin?id=bcd040c21dc9b2bc7525ea09121fd137eb34183f
# Revert to release DMCUB v0.0.227.0 
# Fixes bug https://bugs.mageia.org/show_bug.cgi?id=33655
Source10: dcn_3_5_dmcub.bin.gz
Source11: dcn_3_5_1_dmcub.bin.gz

License: Freeware
Group:	 System/Kernel and hardware
Url:	 http://ati.amd.com/
BuildArch: noarch
Obsoletes: radeon-rlc-firmware
Conflicts: kernel-firmware < 20120219-1
Conflicts: kernel-firmware-nonfree < 20120219-1

%description
Firmware files for AMD/ATI Radeon graphics cards.

This package contains all the firmware files (including RLC) for the
following Radeon series: R100, R200, R300, R400, R500, R600, R700,
Evergreen, Fusion, Northern Islands, Southern Islands, Cayman, Llano,
Trinity, Oland, Hainan, Bonaire, Kabini, Kaveri, Hawaii, Mullins.
It also have firmwares for amdgpu: Carrizo, Fiji, Stoney, Tonga, Polaris,
Vega, Raven(2), Picasso, Navi, Sienna Cichlid, Green Sardine, Arcturus,
Dimgrey Cavefish, Yellow Carp, Beige Goby.

%prep
%setup -q -n %{name}-%{version}

cat WHENCE | while read line; do
	set -e
	case "$line" in
	"Driver: "*)
		driver="${line#Driver: }"
		free=
		files=
		license=
		;;
	"File: "*)
		file="${line#File: }"
		file=$(echo $file | tr -d '"' | tr ' ' '^')
		files="$files ${file}"
		;;
	"Source: "*)
		free=1
		;;
	"License: "*|"Licence: "*)
		license="${line#Licen?e: }"
		case "$license" in
		*"Allegedly"*|*"no source visible"*)
			;;
		*"GPL"*)
			free=1
			;;
		esac
		;;
	*"Advanced Micro Devices, Inc.")
		free=1
		;;
	"Original licence information: None")
		free=
		;;
	"------"*)
		if [ -n "$free" ]; then
			for file in $files; do
				file="$(echo $file | tr '^' ' ')"
				rm -f "$file"
			done
		fi
		;;
	esac
done

%build
cp -p %{SOURCE10} %{SOURCE11} .
gzip -d dcn_3_5_dmcub.bin.gz dcn_3_5_1_dmcub.bin.gz

%install
rm -rf %{buildroot}
install -d %{buildroot}/lib/firmware/amdgpu
install -m644 amdgpu/* %{buildroot}/lib/firmware/amdgpu/
install -d %{buildroot}/lib/firmware/radeon
install -m644 radeon/* %{buildroot}/lib/firmware/radeon/
# fix for bug #33655
install -m644 dcn_3_5_dmcub.bin dcn_3_5_1_dmcub.bin %{buildroot}/lib/firmware/amdgpu/

%clean
rm -rf %{buildroot}

%files
%doc WHENCE
%license LICENSE.*
/lib/firmware/amdgpu/*.bin
/lib/firmware/radeon/*.bin
