%define _localstatedir /var/lib
%define _bindir %{_libexecdir}/%{name}/bin
%define _sysconfdir /etc/%{name}

%if %{?mgaversion:0}%{?!mgaversion:1}
%global notmga 1
%endif

%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}newgetopt.pl

# Note: most of the contents is noarch, but hpuifilter, par are c binaries

Name:		rancid
Version:	3.13
Release:	%mkrel 2
Summary:	Really Awesome New Cisco confIg Differ
Group:		Monitoring
License:	BSD-3-Clause
URL:		https://www.shrubbery.net/rancid/
Source:		https://shrubbery.net/pub/rancid/rancid-%{version}.tar.gz
Source1:	README.rancid.urpmi
Source2:	rancid-lg-httpd.conf
Patch0:		rancid-Makefile.patch
Requires:	cvs expect >= 5.40
Recommends:	subversion-tools
BuildRequires:	expect >= 5.40
Requires(pre):	%{?!notmga:rpm-helper}%{?notmga:/usr/sbin/useradd}
Requires(postun):	%{?!notmga:rpm-helper}%{?notmga:/usr/sbin/userdel}
Requires(postun): findutils perl-base

%description
RANCID monitors a router's (or more generally a device's) configuration,
including software and hardware (cards, serial numbers, etc) and uses CVS
(Concurrent Version System) or Subversion  to maintain history of changes.

RANCID does this by the very simple process summarized here:

    * login to each device in the router table (router.db),
    * run various commands to get the information that will be saved,
    * cook the output; re-format, remove oscillating or incrementing data,
    * email any differences (sample) from the previous collection to a mail
      list,
    * and finally commit those changes to the revision control system

RANCID also includes looking glass software. It is based on Ed Kern's looking
glass which was once used for http://nitrous.digex.net/, for the old-school
folks who remember it. Our version has added functions, supports Cisco,
Juniper, and Foundry and uses the login scripts that come with rancid; so it
can use telnet or ssh to connect to your devices(s).

Rancid currently supports Cisco routers, Juniper routers, Catalyst switches,
Foundry switches, Redback NASs, ADC EZT3 muxes, MRTd (and thus likely IRRd),
Alteon switches, and HP Procurve switches and a host of others.

Rancid is known to be used at: AOL, Global Crossing, MFN, NTT America,
Certainty Solutions Inc. 

%package lg
Summary:	Looking Glass CGIs for rancid
# Didn't get picked up automatically
Requires:	perl(LockFile::Simple)

%description lg
This is a looking glass based on Ed Kern's which used to be available on
http://nitrous.digex.net/.  This version supports Cisco, Juniper, and
Foundry, using rancid's [cfj]login to login (so rcmd is not necessary,
it can use telnet, ssh, or rsh), and has some additional commands
implemented.  There are a few Cisco commands where either no Juniper or
Foundry equivalent exists or we have not had time to implement yet.


%prep
%autosetup -p1

cp %{SOURCE1} README.urpmi

%build
%configure
%make_build

%install
mkdir -p %{buildroot}/%{_sysconfdir}/ %{buildroot}/%{_localstatedir}/%{name}
%make_install
perl -pi -e 's/^([^#\$])/# $1/g' %{buildroot}/%{_datadir}/%{name}/cloginrc.sample

perl -pi -e 's,^BASEDIR=%{_localstatedir},BASEDIR=%{_localstatedir}/%{name},g;s,/usr/bin\;,%{_sbindir}\;,' %{buildroot}/%{_sysconfdir}/rancid.conf

# Set up looking glass
mkdir -p %{buildroot}/%{_libexecdir}/%{name}/cgi-bin
mv %{buildroot}/%{_bindir}/lg*.cgi %{buildroot}/%{_libexecdir}/%{name}/cgi-bin
install -D -m 644 %{SOURCE2} %{buildroot}/etc/httpd/conf/sites.d/rancid-lg.conf

rm -f %{buildroot}/%{_datadir}/%{name}/{README.*,CHANGES,COPYING,FAQ,UPGRADING}

mkdir -p %{buildroot}/%{_sysconfdir}/../cron.d/
cat << EOF >> %{buildroot}/%{_sysconfdir}/../cron.d/%{name}
# Rancid cron jobs

# Run config differ hourly
1 * * * * rancid %{_libdir}/rancid/rancid-run

# Clean out config differ logs
50 23 * * * rancid /usr/bin/find /var/lib/rancid/logs -type f -mtime +2 -exec rm {} \;
EOF

%pre
%_pre_useradd %{name} %{_localstatedir}/%{name} /bin/false

%postun
%_postun_userdel %{name}

%triggerpostun -- rancid < 3.0
find %{_localstatedir}/%{name} -name 'router.db' -exec perl -p -i.rpmupgrade -e 's/:/;/g' {} \;


%files
%doc README share/README.misc README.urpmi CHANGES FAQ UPGRADING
%license COPYING
%dir %{_sysconfdir}
%config(noreplace) %{_sysconfdir}/rancid.conf
%config(noreplace) %{_sysconfdir}/rancid.types.base
%config(noreplace) %{_sysconfdir}/../cron.d/%{name}
%{_libexecdir}/%{name}/
%exclude %{_libexecdir}/%{name}/cgi-bin
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/lg.conf.sample
%exclude %{_datadir}/%{name}/lgnotes.html
%attr(750,rancid,rancid) %{_localstatedir}/%{name}
%{_mandir}/man?/*
%exclude %{_mandir}/man5/lg.conf.5*

%files lg
%doc README.lg
%{_datadir}/%{name}/lg.conf.sample
%{_datadir}/%{name}/lgnotes.html
%defattr(-,root,rancid)
%config(noreplace) %{_sysconfdir}/*.conf
%config(noreplace) /etc/httpd/conf/sites.d/rancid-lg.conf
%dir %{_libexecdir}/%{name}/cgi-bin
%{_libexecdir}/%{name}/cgi-bin/lg.cgi
%{_libexecdir}/%{name}/cgi-bin/lgform.cgi
%{_mandir}/man5/lg.conf.5*
