# There are no files that we can get debug info from
%global debug_package %{nil}

Name:		rapidjson
Version:	1.1.0
Release:	%mkrel 8
Summary:	A fast JSON parser/generator for C++
Group:		Development/C++
License:	BSD
URL:		https://rapidjson.org/
Source0:	https://github.com/Tencent/rapidjson/archive/v%{version}/%{name}-%{version}.tar.gz
#
# from git
# rediff commits to fix the following bugs:
# https://github.com/Tencent/rapidjson/issues/909
# https://github.com/Tencent/rapidjson/issues/1718
Patch1:		0001-Changed-error-code-for-invalid-special-ascii-chars-f-rediffed.patch
Patch2:		0002-Fix-905-unable-to-set-writeFlags-for-PrettyWriter-rediffed.patch
Patch3:		0003-Fixes-issue-1718-rediffed.patch
#
Patch10:	remove-Werror-cmakelist.patch
# from fc
# https://github.com/Tencent/rapidjson/pull/719
Patch11:          0001-Removed-non-compiling-assignment-operator.-Fixed-718.patch
# https://github.com/Tencent/rapidjson/pull/719
Patch12:          0002-Explicitly-disable-copy-assignment-operator.patch
# https://github.com/Tencent/rapidjson/pull/1137
Patch13:          0003-Three-way-comparison-for-CLang-10-fix-1679.patch
# https://github.com/Tencent/rapidjson/pull/1679
Patch14:          0004-Fix-recursive-operator-call-in-C-20-1846.patch
# https://github.com/Tencent/rapidjson/pull/1847
Patch15:          0005-gate-definition-of-symmetric-equality-operators-on-i.patch
# https://github.com/Tencent/rapidjson/pull/2091
Patch16:          0006-do-not-define-operator-in-C-20.patch
# Downstream-patch for gtest
Patch17:          0007-do-not-include-gtest_src_dir.patch

# from deb
Patch20:	disable-valgrind_unittest.patch
Patch21:	gcc7.patch
Patch22:	0001-Fix-Wclass-memaccess-warnings-errors.patch
Patch23:	0002-Fix-Wsign-conversion-warnings-errors.patch
Patch24:	0003-Suppress-Wformat-overflow-warning-error.patch
Patch25:	python3.patch

# Security patches
Patch100:	CVE-2024-38517.patch
#
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	gcc-c++
BuildRequires:	gtest-devel
BuildRequires:	valgrind

%description
RapidJSON is a JSON parser and generator for C++. It was inspired by RapidXml.

- RapidJSON is small but complete. It supports both SAX and DOM style API.
  The SAX parser is only a half thousand lines of code.
- RapidJSON is fast. Its performance can be comparable to strlen(). It also
  optionally supports SSE2/SSE4.2 for acceleration.
- RapidJSON is self-contained and header-only. It does not depend on external
  libraries such as BOOST. It even does not depend on STL.
- RapidJSON is memory-friendly. Each JSON value occupies exactly 16 bytes for
  most 32/64-bit machines (excluding text string). By default it uses a fast
  memory allocator, and the parser allocates memory compactly during parsing.
- RapidJSON is Unicode-friendly. It supports UTF-8, UTF-16, UTF-32 (LE & BE),
  and their detection, validation and transcoding internally. For example, you
  can read a UTF-8 file and let RapidJSON transcode the JSON strings into
  UTF-16 in the DOM. It also supports surrogates and "\u0000" (null character)

%prep
%autosetup -p1

# Convert DOS line endings to unix
for file in "license.txt" $(find ./example -type f -name '*.c*');
do
  sed -e "s/\r$//g" < ${file} > ${file}.new && \
  touch -r ${file} ${file}.new && \
  mv -f ${file}.new ${file}
done

# Remove -march=native and -Werror from compile commands
find . -type f -name CMakeLists.txt -print0 | \
  xargs -0r sed -i -e "s/-march=native/ /g" -e "s/-Werror//g"

# Update Doxyfile
for f in doc/Doxyfile*; do
  doxygen -u $f
done

%build
%cmake \
	-DGTEST_SOURCE_DIR:PATH=. \
	-DGTESTSRC_FOUND:BOOL=ON \
	-DRAPIDJSON_BUILD_CXX11:BOOL=OFF \
	-DRAPIDJSON_BUILD_TESTS:BOOL=ON \
	-DRAPIDJSON_BUILD_THIRDPARTY_GTEST:BOOL=OFF
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%doc %{_datadir}/doc/RapidJSON/
%{_includedir}/%{name}/
%{_libdir}/cmake/RapidJSON/
%{_libdir}/pkgconfig/RapidJSON.pc
