%define major     11
%define libname   %mklibname %{name}_ %{major}
%define develname %mklibname %{name} -d
%define upversion 2024-07-02

Name:           re2
Version:        20240702
Release:        %mkrel 3
Summary:        C++ fast alternative to backtracking RE engines
Group:          System/Libraries
License:        BSD
URL:            https://github.com/google/re2/
Source0:        https://github.com/google/re2/archive/%{upversion}/%{name}-%{upversion}.tar.gz
BuildRequires:  cmake
BuildRequires:  cmake(absl)
BuildRequires:  pkgconfig(benchmark)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(icu-uc)

%description
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g back references and generalized assertions).

%package -n     %{libname}
Summary:        Library for %{name}
Group:          System/Libraries

%description -n %{libname}
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g back references and generalized assertions).

%package -n     %{develname}
Summary:        C++ header files and library symbolic links for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{develname}.


%prep
%setup -q -n %{name}-%{upversion}
%autopatch -p1

%build
%cmake \
    -DBUILD_SHARED_LIBS=ON \
    -DRE2_USE_ICU=ON
%cmake_build

%install
%cmake_install

%check
%make_build shared-test

%files -n %{libname}
%doc README
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc CONTRIBUTING.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}/
