%define rpmrelease %{nil}
%define debug_package %{nil}

Name:		rear
Version:	2.9
Release:	%mkrel 1
Summary:	Relax and Recover (ReaR) is a Linux Disaster Recovery framework
Group:		Archiving/Backup
License:	GPLv3
URL:		https://relax-and-recover.org/
Source0:	https://github.com/rear/rear/archive/%{version}/%{name}-%{version}.tar.gz
# rear contains only bash scripts plus documentation so that on first glance it could be "BuildArch: noarch"
# but actually it is not "noarch" because it only works on those architectures that are explicitly supported.
# Of course the rear bash scripts can be installed on any architecture just as any binaries can be installed on any architecture.
# But the meaning of architecture dependent packages should be on what architectures they will work.
# Therefore only those architectures that are actually supported are explicitly listed.
# This avoids that rear can be "just installed" on architectures that are actually not supported (e.g. ARM or IBM z Systems):
ExclusiveArch:	%ix86 x86_64 ppc ppc64 ppc64le ia64
# Furthermore for some architectures it requires architecture dependent packages (like syslinux for x86 and x86_64)
# so that rear must be architecture dependent because ifarch conditions never match in case of "BuildArch: noarch"
# see the GitHub issue https://github.com/rear/rear/issues/629
%ifarch %ix86 x86_64
Requires:	syslinux
%endif
# In the end this should tell the user that rear is known to work only on ix86 x86_64 ppc ppc64 ppc64le ia64
# and on ix86 x86_64 syslinux is explicitly required to make the bootable ISO image
# (in addition to the default installed bootloader grub2) while on ppc ppc64 the
# default installed bootloader yaboot is also useed to make the bootable ISO image.

### Dependencies on all distributions
Requires:	binutils
Requires:	ethtool
Requires:	cdrkit-genisoimage
Requires:	gawk
Requires:	gzip
Requires:	iproute2
Requires:	iputils
Requires:	openssl
Requires:	parted
Requires:	rpcbind
Requires:	tar
Requires:	attr
Requires:	bc

### We drop LSB requirements because it pulls in too many dependencies
### The OS is hardcoded in /etc/rear/os.conf instead
#Requires:	lsb

%description
Relax and Recover (abbreviated rear) is a highly modular disaster recovery
framework for GNU/Linux based systems, but can be easily extended to other
UNIX alike systems. The disaster recovery information (and maybe the backups)
can be stored via the network, local on hard disks or USB devices, DVD/CD-R,
tape, etc. The result is also a boot-able image that is capable of booting via
PXE, DVD/CD and USB media.

Relax and Recover integrates with other backup software and provides integrated
bare metal disaster recovery abilities to the compatible backup software.


%prep
%autosetup -p1

echo -e "OS_VENDOR=%{distribution}_Linux\nOS_VERSION=%{mgaver}" >etc/rear/os.conf

%build
# No code to compile - all bash scripts - but at least run "make validate"
# that runs "bash -n" for all bash files to test if the plain syntax is o.k.
make validate

%install
%make_install

%files
%doc README* MAINTAINERS
%license COPYING
%{_sbindir}/rear
%{_datadir}/rear
%{_localstatedir}/lib/rear
%{_mandir}/man8/*
%config(noreplace) %{_sysconfdir}/rear
