%define _disable_ld_no_undefined 1

%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

Name:           recoll
Version:        1.43.0
Release:        %mkrel 1
Summary:        Desktop full text search tool with a Qt GUI
Group:          Databases
License:        GPLv2
URL:            https://www.recoll.org
Source0:        https://www.recoll.org/%{name}-%{version}.tar.gz
# FIXME use/update qt6_qtwebengine_arches
# 32-bit arches not supported (https://bugreports.qt.io/browse/QTBUG-102143)
ExclusiveArch:  aarch64 x86_64
BuildRequires:  meson
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6WebEngineWidgets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(xapian-core)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  bison-devel-static
BuildRequires:  aspell-devel
BuildRequires:  chmlib-devel

Requires:       aspell
Requires:       xapian

%description
Recoll is a personal full text search package for Linux, FreeBSD and
other Unix systems. It is based on a very strong backend (Xapian), for
which it provides an easy to use, feature-rich, administration
interface.

#------------------------------------------------------

%package -n %{name}-extra
Summary:        Recoll extra indexing packages
Group:          File tools
Recommends:     %{name} >= %{version}-%{release}
BuildArch:      noarch
Recommends:     antiword
Recommends:     aspell-en
Recommends:     catdoc
Recommends:     djvulibre
Recommends:     libwpd-tools
Recommends:     python3dist(mutagen)
Recommends:     perl-Image-ExifTool
Recommends:     poppler
Recommends:     pstotext
Recommends:     python3
Recommends:     python3dist(pylzma)
Recommends:     python3dist(rarfile)
Recommends:     texlive
Recommends:     unrar
Recommends:     unrtf
Recommends:     unzip
Recommends:     xsltproc

%description -n %{name}-extra
This package contains a list of packages' suggestions
for indexing various file types by recoll:

* antiword for MS Word files.
* catdoc for MS Excel and PowerPoint files.
* unrtf for RTF files.
* djvulibre (djvutxt djvused) for djvu files.
* libwpd-tools for Wordperfect files.
* Midi karaoke files need Python and the Midi module
* mutagen for all audio file types.
* perl-Image-ExifTool to extract tag informations:
    This is only of interest if you store personal tags
    or textual descriptions inside the image files.
* Zip archives need Python (and the standard zipfile module).
* Rar archives need Python, the rarfile Python module and the unrar utility.
* 7zip archives (needs Python and the pylzma module)
* Poppler(pdftotext) for PDF files.
* pstotext for Postscript files.
* texlive :
    detex for TeX files.
    dvips for div files.
* unzip and xsltproc for LibreOffice files.
* xsltproc for MS Open XML (docx).

#--------------------------------------------------------

%package -n python3-%{name}
Summary:        Python 3 extension module for recoll
Group:          Development/Python

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
Requires:       python3
Requires:       %{name} >= %{version}-%{release}

%description -n python3-%{name}
Recoll Python 3 programming interface, for searching and indexing.

#--------------------------------------------------------

%define major   39
%define libname %mklibname %{name} %{major}

%package -n %{libname}
Summary:        Libraries for Recoll applications
Group:          System/Libraries

%description -n %{libname}
Shared libraries required to run Recoll applications.

#--------------------------------------------------------

%define devname %mklibname %{name} -d

%package -n %{devname}
Summary:        Libraries and header files to develop Recoll enabled applications
Group:          Development/KDE and Qt
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Libraries and header files required to develop Recoll enabled
applications.

#--------------------------------------------------------

%package -n kio-%{name}
Summary:        KIO slave for %{name}
Group:          Graphical desktop/KDE

BuildRequires:  kf6-rpm-macros
BuildRequires:  cmake(KF6KIO)

Requires:       %{name} >= %{version}-%{release}
Requires:       plasma6-framework

%description -n kio-%{name}
KIO slave for %{name}. Enables to perform queries and extract
results in Konqueror and Dolphin.

#-------------------------------------------------------

%package        krunner
Summary:        KRunner support for %{name}
Group:          Graphical desktop/KDE

BuildRequires:  cmake(KF6I18n)
BuildRequires:  cmake(KF6Config)
BuildRequires:  cmake(KF6Runner)
BuildRequires:  cmake(KF6KIO)
BuildRequires:  cmake(KF6Notifications)

Requires:       %{name} >= %{version}-%{release}

%description   krunner
The recoll KRunner plugin adds Recoll search results to
KRunner output.

#-------------------------------------------------------

%package -n %{name}-full
Summary:        Full Recoll installation
Group:          Office/Utilities
BuildArch:      noarch

Recommends:     %{name} >= %{version}-%{release}
Requires:       %{name}-extra >= %{version}-%{release}
Recommends:     python3-%{name} >= %{version}-%{release}
Recommends:     kio-%{name} >= %{version}-%{release}
Recommends:     recoll-krunner >= %{version}-%{release}

%description -n %{name}-full
This packages provides the complete recoll installation:

* recoll: The main application
* recoll-extra: Recoll extra indexing packages
* python-recol: Python extension module for recoll
* kio-recoll: KDE KIO slave for recoll
* plasma-runner-recoll: KDE krunner plugin for recoll

#------------------------------------------------------

%prep
%autosetup -p1

%build
%meson -D recollq=true \
       -D systemd=true \
       -D webkit=false \
       -D webengine=true
%meson_build

%install
%meson_install

export RECOLL_LIB_DIR=%{_builddir}/%{name}-%{version}/build/

pushd kde/kioslave/kio_recoll
cp CMakeLists-KF6.txt CMakeLists.txt
%cmake -DRECOLL_PUBLIC_LIB=1 \
       -DDATA_INSTALL_DIR=%{_datadir}
%cmake_build
%cmake_install
popd

# krunner_recoll
pushd kde/krunner
cp CMakeLists-KF6.txt CMakeLists.txt
%cmake -DRECOLL_PUBLIC_LIB=1
%cmake_build
%cmake_install
popd

%py_byte_compile %{python3} %{buildroot}%{_datadir}/%{name}/filters/

# Add translations tags
(cd %{buildroot} && find . -name '*.qm') | sed -e 's|^.||' | sed -e \
    's:\(.*/translations/\)\([a-z]\+_\)\([a-zA-Z_]\+\)\(\.qm\):%lang(\3) \1\2\3\4:' \
        >> %{name}.lang

%files -f %{name}.lang
%doc README
%{_bindir}/*
%{_datadir}/applications/recoll-searchgui.desktop
%{_datadir}/pixmaps/recoll.png
%{_datadir}/%{name}/doc/
%{_datadir}/%{name}/examples/
%{_datadir}/%{name}/filters/
%{_datadir}/%{name}/images/
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_iconsdir}/hicolor/48x48/apps/recoll.png
%{_iconsdir}/hicolor/scalable/apps/recoll.svg
%{_mandir}/man1/recoll*
%{_mandir}/man5/recoll*
%{_mandir}/man1/xadump.1*
%{_metainfodir}/org.recoll.recoll.appdata.xml
%{_unitdir}/recollindex@.service
%{_userunitdir}/recollindex.service

#-------------------------------------------------------
%files -n %{name}-extra
#none

#-------------------------------------------------------
%files -n python3-%{name}
%{python3_sitearch}/recoll/
%{python3_sitearch}/recollchm/
%{python3_sitearch}/recollaspell.cpython-*-linux-gnu*.so

#-------------------------------------------------------
%files -n %{libname}
%{_libdir}/librecoll.so.%{major}
%{_libdir}/librecoll.so.%{version}

#-------------------------------------------------------
%files -n %{devname}
%{_includedir}/recoll/
%{_libdir}/librecoll.so

#-------------------------------------------------------
%files -n kio-%{name}
%dir %{_datadir}/kio_recoll
%{_kf6_plugindir}/kio/kio_recoll.so
%{_datadir}/kio_recoll/help.html
%{_datadir}/kio_recoll/welcome.html

#-------------------------------------------------------
%files krunner
%{_kf6_plugindir}/krunner/krunner_recoll.so

#-------------------------------------------------------
%files -n %{name}-full
# none
