# empty debugsourcefiles.list
%global debug_package %{nil}

%global install_prefix %{_libdir}/rocm/llvm

%define rocm_major 5
%define rocm_minor 7
%define rocm_patch 1

%define libname    %mklibname %{name} %{rocm_major}
%define devel_name %mklibname %{name} -d

Name:           rocm-hip
Version:        %{rocm_major}.%{rocm_minor}.%{rocm_patch}
Release:        %mkrel 3
Summary:        ROCm HIP Runtime
Group:          System/Libraries
Url:            https://github.com/ROCm-Developer-Tools/HIP
License:        MIT
Source0:        https://github.com/ROCm-Developer-Tools/HIPCC/archive/refs/tags/rocm-%{version}.tar.gz#/HIPCC-rocm-%{version}.tar.gz
Source1:        https://github.com/ROCm-Developer-Tools/HIP/archive/refs/tags/rocm-%{version}.tar.gz#/HIP-rocm-%{version}.tar.gz
Source2:        https://github.com/ROCm-Developer-Tools/clr/archive/refs/tags/rocm-%{version}.tar.gz#/clr-rocm-%{version}.tar.gz

#squidf: from Debian to prevent messing up included modules like math.h
#           https://github.com/ROCm/HIP/issues/2712
Patch1:         rocm-hip-5.7.1-isystem-removal.patch

#squidf: patches for clr-rocm from number 100
#squidf: Allow older GPU generations
Patch100:       rocm-hip-5.7.1-enable-gfx800.patch

BuildRequires:  cmake
BuildRequires:  cmake(libxml2)
BuildRequires:  comgr-devel(rocm) = %version
BuildRequires:  libstdc++-static-devel
BuildRequires:  mesa-common-devel
BuildRequires:  pkgconfig(opengl)
BuildRequires:  pkgconfig(numa)
BuildRequires:  python3dist(cppheaderparser)
BuildRequires:  rocm-llvm-devel = %version
BuildRequires:  rocm-runtime-devel = %version
BuildRequires:  rocminfo = %version

#Only the following architectures are supported:
# The kernel support only exists for x86_64, aarch64
# However, for aarch64 immintrin.h: error: "This header is only meant to be used on x86 and x64 architecture"
ExclusiveArch:  x86_64

Requires:       %{devel_name} = %{version}-%{release}
Requires:       rocminfo = %{version}

#conflict older packages to get the new in same transaction
Conflicts:      hip(rocm) < %{version}

%description
HIP is a C++ Runtime API and Kernel Language that allows developers to create
portable applications for AMD and NVIDIA GPUs from single source code.

%package -n %{libname}
Summary:    ROCm HIP Libraries
Group:      System/Libraries
Provides:   hip(rocm) = %{version}-%{release}

%description -n %{libname}
Libraries for AMD ROCm HIP Runtime


%package -n %{devel_name}
Summary:    ROCm HIP development package
Group:      Development/Other
Provides:   hip-devel(rocm) = %{version}-%{release}
Requires:   %{libname} = %{version}-%{release}

%description -n %{devel_name}
The AMD ROCm HIP development package.

%prep
%autosetup -N -a 1 -b 2 -n HIPCC-rocm-%{version}
mv %_builddir/clr-rocm-%{version} .
pushd clr-rocm-%{version}
%autopatch -p1 -m 100
popd
%autopatch -p1 -m 0 -M 99

%build
%cmake -Wno-dev \
    -S "." \
    -B build-hipcc

%define _vpath_builddir build-hipcc
%cmake_build


%cmake -Wno-dev \
    -S "./clr-rocm-%{version}" \
    -B build \
    -DHIP_PLATFORM=amd \
    -DHIP_COMMON_DIR="%{_builddir}/HIPCC-rocm-%{version}/HIP-rocm-%{version}" \
    -DHIPCC_BIN_DIR="%{_builddir}/HIPCC-rocm-%{version}/build-hipcc" \
    -DCLR_BUILD_HIP=ON \
    -DCLR_BUILD_OCL=OFF \
    -DROCM_PATH=%{_prefix} \
    -DCMAKE_C_COMPILER=%{install_prefix}/bin/clang \
    -DLLVM_DIR=%{install_prefix}/lib/cmake/llvm \
    -DClang_DIR=%{install_prefix}/lib/cmake/clang

%define _vpath_builddir build
%cmake_build

%install
%cmake_install

# hip installs some cmake modules incorrectly:
mkdir -p %{buildroot}%{_datadir}/cmake/Modules
pushd %{buildroot}%{_datadir}/cmake/Modules
ln -s ../../../%{_lib}/cmake/hip/* ../../../%{_lib}/cmake/hip-lang/* ../../../%{_lib}/cmake/hiprtc/* .
popd

# cleanup buildroot
mv %{buildroot}/%{_prefix}/hip/bin/.hipVersion %{buildroot}/%{_bindir}/.hipVersion
rm -rf %{buildroot}/%{_prefix}/hip

# Remove Windows scripts
rm %{buildroot}%{_bindir}/hipcc.bat
rm %{buildroot}%{_bindir}/hipconfig.bat

# No cmake install for rocclr
install -Dm644 build/rocclr/librocclr.a %{buildroot}%{_libdir}/librocclr.a

echo '%{_libdir}' > %{name}.conf
install -Dm644 %{name}.conf %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}.conf

# set env variables
cat << EOF > 40rocm-hip.sh
export DEVICE_LIB_PATH=%{_libdir}/amdgcn/bitcode
export HIP_CLANG_PATH="%{install_prefix}/bin"
export HIP_PATH="%{_prefix}"
export ROCM_PATH="%{_prefix}"
EOF

%{__mkdir_p} %{buildroot}%{_sysconfdir}/profile.d
%{__install} -m 644 40rocm-hip.sh %{buildroot}%{_sysconfdir}/profile.d/40rocm-hip.sh

%posttrans
# Apply configuration
echo "Run ldconfig"
ldconfig

%files
%doc README.md

%files -n %{libname}
%doc README.md
%license LICENSE.txt
%{_datadir}/hip/version
%exclude %{_datadir}/doc/hip/LICENSE.txt
%exclude %{_datadir}/doc/hip-asan/LICENSE.txt
%{_libdir}/.hipInfo
%{_libdir}/libamdhip64.so.%{rocm_major}{,.*}
%{_libdir}/libhiprtc.so.%{rocm_major}{,.*}
%{_libdir}/libhiprtc-builtins.so.%{rocm_major}{,.*}
%{_sysconfdir}/ld.so.conf.d/%{name}.conf

%files -n %{devel_name}
%{_bindir}/.hipVersion
%{_bindir}/hipcc
%{_bindir}/hipconfig
%{_bindir}/hipcc.pl
%{_bindir}/hipconfig.pl
%{_bindir}/hipvars.pm
%{_bindir}/hipcc_cmake_linker_helper
%{_bindir}/hipdemangleatp
%{_bindir}/roc-obj
%{_bindir}/roc-obj-extract
%{_bindir}/roc-obj-ls
%{_includedir}/hip_prof_str.h
%{_includedir}/hip{,.*}
%{_libdir}/libamdhip64.so
%{_libdir}/libhiprtc.so
%{_libdir}/libhiprtc-builtins.so
%{_libdir}/librocclr.a
%{_datadir}/cmake/Modules/*
%{_libdir}/cmake/hip{,.*}
%{_libdir}/cmake/hip-lang{,.*}
%{_libdir}/cmake/hiprtc{,.*}
%{_sysconfdir}/profile.d/40rocm-hip.sh
