%ifarch x86_64
# FOR LATER: %%global targets_to_build "X86;AMDGPU;NVPTX;AArch64;ARM;BPF;WebAssembly"
%global targets_to_build "X86;AMDGPU;NVPTX"
%endif
%ifarch aarch64
# FOR LATER %%global targets_to_build "AArch64;ARM;AMDGPU;NVPTX;BPF"
%global targets_to_build "AArch64;AMDGPU;NVPTX"
%endif

%global install_prefix %{_libdir}/rocm/llvm
%global forgeurl    https://github.com/RadeonOpenCompute/llvm-project

%define llvm_major      17
%define libname         %mklibname %{name} %{llvm_major}
%define develname       %mklibname %{name} -d

Name:           rocm-llvm
Version:        5.7.1
Release:        %mkrel 3
Summary:        Various AMD ROCm-LLVM related packages
Group:          Development/Other
Url:            https://rocm.docs.amd.com/en/latest/reference/rocmcc/rocmcc.html
License:        Apache-2.0 WITH LLVM-exception
Source0:        %{forgeurl}/archive/rocm-%{version}.tar.gz#/llvm-project-rocm-%{version}.tar.gz

Patch0:         rocm-llvm-5.7.1-detect-mageia.patch

BuildRequires:  binutils-devel
BuildRequires:  clang
BuildRequires:  cmake
BuildRequires:  glibc-devel
BuildRequires:  lld
BuildRequires:  ninja-build
BuildRequires:  python3
# for %%py3_shebang_fix
BuildRequires:	python3-devel
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(valgrind)
BuildRequires:	pkgconfig(zlib)

Requires:       %libname = %version-%release

Provides:       %{name}(major) = %llvm_major

#Only the following architectures are useful for ROCm packages:
ExclusiveArch:  x86_64 aarch64


%description
Radeon Open Compute ROCm-LLVM toolchain (llvm, clang, lld)


%package -n %develname
Summary:	Development files for ROCm-LLVM
Group:		Development/Other

Provides:	%name-devel = %version-%release
Provides:	%name-devel%{?_isa} = %version-%release
Provides:	%name-devel(major) = %llvm_major

Requires:	%libname = %version-%release
Requires:	%name = %version-%release
Requires:	%name-static%{?_isa} = %version-%release

%description -n %develname
This package contains library and header files needed to develop new native
programs that use the ROCm-LLVM infrastructure.


%package -n %libname
Summary:	ROCm-LLVM shared libraries
Group:		System/Libraries

%description -n %libname
Shared libraries for the ROmM-LLVM compiler infrastructure.


%package static
Summary:	ROCMm-LLVM static libraries
Group:		Development/Other

Provides:	%name-static%{?_isa} = %version-%release
Provides:	%name-static(major) = %llvm_major

%description static
Static libraries for the ROCm-LLVM compiler infrastructure.


%package analyzer
Summary:	A source code analysis framework for ROCm
License:	Apache-2.0 WITH LLVM-exception
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}

%description analyzer
The Clang Static Analyzer consists of both a source code analysis
framework and a standalone tool that finds bugs in C and Objective-C
programs. The standalone tool is invoked from the command-line, and is
intended to run in tandem with a build of a project or code base.


%package tools-extra
Summary:	Extra tools for ROCm clang
Group:		Development/Other
Requires:	%libname%{?_isa} = %{version}

%description tools-extra
A set of extra tools built using Clang's tooling API.


%prep
%autosetup -p1 -n llvm-project-rocm-%{version}

%py3_shebang_fix \
	llvm/tools/opt-viewer/*.py \
	clang/tools/scan-view/bin/scan-view

%build
#To build with clang. GCC is way too much memory consuming.
%set_build_flags
CC=clang; export CC
CXX=clang++; export CXX

%cmake  -G Ninja \
        -B build \
        -S "./llvm" \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_INSTALL_PREFIX=%{install_prefix} \
        -DLLVM_HOST_TRIPLE=%{_host} \
        -DLLVM_DEFAULT_TARGET_TRIPLE=%{_host} \
        -DLLVM_ENABLE_PROJECTS='llvm;clang;compiler-rt;lld' \
        -DLLVM_TARGETS_TO_BUILD=%{targets_to_build} \
        -DCLANG_DEFAULT_LINKER=lld \
        -DLLVM_USE_LINKER=lld \
        -DLLVM_INSTALL_UTILS=ON \
        -DLLVM_ENABLE_BINDINGS=OFF \
        -DLLVM_BUILD_LLVM_DYLIB=OFF \
        -DLLVM_LINK_LLVM_DYLIB=OFF \
        -DLLVM_ENABLE_ASSERTIONS=ON \
        -DOCAMLFIND=NO \
        -DLLVM_ENABLE_OCAMLDOC=OFF \
        -DLLVM_INCLUDE_BENCHMARKS=OFF \
        -DLLVM_BUILD_TESTS=OFF \
        -DLLVM_INCLUDE_TESTS=OFF \
        -DLLVM_BINUTILS_INCDIR=%{_includedir} \
        -DBUILD_SHARED_LIBS=OFF
# Static lib requires to build the ROCm stack
# https://github.com/RadeonOpenCompute/ROCm-CompilerSupport/issues/55#issuecomment-1821109039

%cmake_build

%install
%cmake_install

# Add symlink to lto plugin in the binutils plugin directory.
%{__install} -d -m 0755  %{buildroot}%{install_prefix}/lib/bfd-plugins
ln -s %{install_prefix}/lib/LLVMgold.so %{buildroot}%{install_prefix}/lib/bfd-plugins/LLVMgold.so

# Removed in Fedora and Mageia packages
rm -vf %{buildroot}%{install_prefix}/share/clang/bash-autocomplete.sh

# remove editor integrations (bbedit, sublime, emacs, vim)
rm -vf %{buildroot}%{install_prefix}/share/clang/clang-format-bbedit.applescript
rm -vf %{buildroot}%{install_prefix}/share/clang/clang-format-sublime.py

%files
%license LICENSE.TXT
%doc README.md
%{install_prefix}/bin{,.*}
%exclude %{install_prefix}/bin/llvm-config
%exclude %{install_prefix}/bin/clang-tblgen
%exclude %{install_prefix}/share/opt-viewer{,.*}

%files -n %libname
%{install_prefix}/lib/*.so.*
%{install_prefix}/lib/clang/%{llvm_major}*/include/*
%{install_prefix}/lib/clang/%{llvm_major}*/share/*.txt

%files -n %{develname}
%{install_prefix}/bin/llvm-config
%{install_prefix}/bin/clang-tblgen
%{install_prefix}/lib/clang/%{llvm_major}*/bin/hwasan_symbolize
%{install_prefix}/include/lld{,.*}
%{install_prefix}/include/llvm{,.*}
%{install_prefix}/include/llvm-c{,.*}
%{install_prefix}/include/clang{,.*}
%{install_prefix}/include/clang-c{,.*}
%{install_prefix}/lib/cmake{,.*}
%{install_prefix}/lib/bfd-plugins/LLVMgold.so
%{install_prefix}/lib/*.so
%{install_prefix}/lib/clang/%{llvm_major}*/lib/linux/libclang_rt.*.so
%{install_prefix}/lib/clang/%{llvm_major}*/lib/linux/clang_rt.*.o

%files static
%{install_prefix}/lib/*.a
%{install_prefix}/lib/clang/%{llvm_major}*/lib/linux/libclang_rt.*.a*
%{install_prefix}/lib/clang/%{llvm_major}*/lib/linux/liborc_rt*.a

%files tools-extra
%{install_prefix}/share/clang/clang-format-diff.py
%{install_prefix}/share/clang/clang-format.el
%{install_prefix}/share/clang/clang-format.py
%{install_prefix}/share/clang/clang-rename.el
%{install_prefix}/share/clang/clang-rename.py

%files analyzer
%exclude %{install_prefix}/bin/scan-view
%exclude %{install_prefix}/bin/scan-build
%exclude %{install_prefix}/bin/analyze-build
%exclude %{install_prefix}/bin/intercept-build
%exclude %{install_prefix}/bin/scan-build-py
%exclude %{install_prefix}/libexec/ccc-analyzer
%exclude %{install_prefix}/libexec/c++-analyzer
%exclude %{install_prefix}/libexec/analyze-c++
%exclude %{install_prefix}/libexec/analyze-cc
%exclude %{install_prefix}/libexec/intercept-c++
%exclude %{install_prefix}/libexec/intercept-cc
%{install_prefix}/share/scan-view{,.*}
%{install_prefix}/share/scan-build{,.*}
%{install_prefix}/lib/libear{,.*}
%{install_prefix}/lib/libscanbuild{,.*}
%{install_prefix}/share/man/man1/scan-build.1

