# Needed when building new python3 version
%bcond_with bootstrap

# hardcoded so that build from another distro keeps this name
# (mandatory to have correct package name and source name)
%define _real_vendor mageia

# fix build (debuginfo package is empty...):
%define debug_package %{nil}

# If dist tag isn't defined, define it
%if %{?dist:0}%{?!dist:1}
%define dist %{?distsuffix:%distsuffix}%{?!distsuffix:.mga}%{?distro_release:%distro_release}
%endif

# If mkrel isn't defined, define it
%if %{?mkrel:0}%{?!mkrel:1}
%define mkrel(c:) %{-c: 0.%{-c*}.}%{1}%{?dist:%dist}%{?subrel:.%subrel}
%endif

# This can be useful for backport, as rpm-4.2
# provides the emacs-spec mode
%define have_emacsmodespec 1

%{?_with_emacsspecmode: %define have_emacsmodespec 1}
%{?_without_emacsspecmode: %define have_emacsmodespec 0}

%ifarch %{ix86}
%global _host_cpu %_target_cpu
%endif
%ifarch armv7hl
%global _host_cpu armv7hl
%endif

Summary:	The %{distribution} rpm configuration and scripts
Name:		rpm-%{_real_vendor}-setup
Version:	2.83
Release:	%mkrel 4
# No patch allowed on SOURCE0
# prevent suse script to slow down build:
Patch0:		gi-find-deps.sh.diff
# (tv) "handle" golang style templates in py files in gnome-builder-42.1
# resource files, which resulted in "typelib(Adw{{end}})" deps:
Patch1:		gi-find-deps.sh2.diff
Patch11:	gi-find-deps-grep-E.patch
# fix Suse attr matching:
Patch2:		gobjectintrospection.attr.patch
Patch3:		gobjectintrospection.attr2.patch
# handle filenames with space (mga#29941)
Patch4:		gi-find-deps-handle-filenames-with-space.patch
# make sure %%perl_convert_version macro is used with perl provides and requires generation
Patch5:		use_perl_convert_version.diff
# make gi-find-deps to also work with new GIRepository 3.0
Patch6:		gi-find-deps-GIRepository3.0.patch

Source0:	%{name}-%{version}.tar.xz
Source1:	gettarball.sh
#
# UPSTREAM TO SYNC:
#
# gi-find-deps.sh is a rpm helper for Provides and Requires. Script creates typelib()-style Provides/Requires.
# (From: https://build.opensuse.org/package/show/openSUSE:Factory/gobject-introspection)
Source3:        gi-find-deps.sh
Source4:        gobjectintrospection.attr
#
# Fedora stuff:
#
# kernel modules provides/requires
# (Was from redhat-rpm-config, now: kernel-srpm-macros)
Source5:        kmod.attr
Source6:        kmod.prov
# Forge handling macros
# (From: https://src.fedoraproject.org/rpms/redhat-rpm-config/tree):
# The macros defined by these files are for things that need to be defined
# at srpm creation time when it is not feasible to require the base packages
# that would otherwise be providing the macros. other language/arch specific
# macros should not be defined here but instead in the base packages that can
# be pulled in at rpm build time, this is specific for srpm creation.
Source102:	macros.mono-srpm
Source105:	macros.valgrind-srpm
Source106:      macros.java-srpm

# ldconfig stub macros for compatibility
# (From: https://src.fedoraproject.org/rpms/redhat-rpm-config/tree):
# Other misc macros
Source150:	macros.build-constraints
Source151:	macros.dwz
Source152:	macros.fedora-misc
Source153:      macros.forge
Source155:      macros.ldconfig

Source156:	macros.vpath

# Misc helper scripts
Source404:	gpgverify

# Convenience lua functions
Source800:       common.lua
Source801:       forge.lua

# Dropped from rpm upstream,
# New upstream https://github.com/rpm-software-management/perl-rpm-packaging/
# Use script version without 'normalized version support'
Source810:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/b534fc7ca37b6e81797a1fe47a99b2b7af860b5a/scripts/perl.prov
Source811:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/b534fc7ca37b6e81797a1fe47a99b2b7af860b5a/scripts/perl.req
# These were also dropped from rpm
Source812:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/d9ba508177d0841d48af8702aeedeb3295d29611/fileattrs/perl.attr
Source813:	https://raw.githubusercontent.com/rpm-software-management/perl-rpm-packaging/d9ba508177d0841d48af8702aeedeb3295d29611/fileattrs/perllib.attr

#
# END OF UPSTREAM
#

# NO PATCH ACCEPTED: WORK in GIT!!!!
License:	GPLv2+
Group:		System/Packaging
Url:		https://www.mageia.org/
# rpm-devel provide doesn't include epoch
BuildRequires:	rpm-devel >= 4.19.91
BuildRequires:	automake

%description
The %{distribution} rpm configuration and scripts.

%package	build
Group:		System/Packaging
Summary:	The %{distribution} rpm configuration and scripts to build rpms
Requires:	rpm-build >= 1:4.19.91
Requires:	spec-helper
Requires:	multiarch-utils
# needed for script to extract pkgconfig info
Requires:	pkgconfig
Requires:	%name = %version-%release
Requires:	bash >= 4.3-24.2
# gi-find-deps uses the enhanced grep variant in order to do
# multi-line matching (for pkg.requires(..))
Requires:	pcre2-tools
# gi-find-deps makes use of 'file' to identify the types.
Requires:	file
# for product version macros
Requires:	%{_real_vendor}-release
Requires:	dwz
# to generate cmake() provides
Requires:	cmake-rpm-macros >= 1:9-8
Requires:	efi-srpm-macros
Requires:	fonts-srpm-macros
Requires:	go-srpm-macros
Requires:	lua-srpm-macros
Requires:	ocaml-srpm-macros
Requires:	perl-srpm-macros
# ↓ Provides compileall2 Python module and brp-python-bytecompile scriptlet
Requires:	python-srpm-macros >= 3.10-4
Requires:	pyproject-rpm-macros
# rust-srpm-macros v24 contains %%build_rustflags defintion
Requires:	rust-srpm-macros >= 24

# for gdb-add-index:
Requires:	gdb-headless
%if ! %{with bootstrap}
# for g-ir-dep-tool:
Requires:	gobject-introspection
# python packaging
Requires:	python3-pkg-resources
%endif
# For gi-inspect-typelib used in gi-find-deps
Requires:	glib2.0-common
Requires:	desktop-file-utils
# This is not needed in the buildsystem but desirable for local development
Recommends:	rpmlint-mageia-policy
# Provide generic name for rpm vendor configuration
Provides:	system-rpm-config = %{version}-%{release}
# Due to perl.{prov,req} move (mga#33377)
Conflicts:	rpm-build < 1:4.20.0-1

%description	build
The %{distribution} rpm configuration and scripts dedicated to build rpms.

%prep
%setup -q
install -Dp %{S:3} .
install -Dp %{S:4} .
install -Dp %{S:810} %{S:811} %{S:812} %{S:813} .

%autopatch -p1

%build
autoreconf -fi
%configure || tail -1000 config.log
%make_build

%install
%make_install

# install latest config.{guess,sub} provided by automake
for i in config.{guess,sub}; do
  install -Dpm755 %{_datadir}/automake-*/$i %{buildroot}%{_rpmconfigdir}/%{_real_vendor}/
done

# upstream deps generators:
install -D gi-find-deps.sh %{S:6} -m 0755 %{buildroot}%{_rpmconfigdir}/
install -D gobjectintrospection.attr %{S:5} -m 0644 %{buildroot}%{_rpmconfigdir}/fileattrs/

install -D perl.prov perl.req -m 0755 %{buildroot}%{_rpmconfigdir}/
install -D perl.attr perllib.attr -m 0644 %{buildroot}%{_rpmconfigdir}/fileattrs/

mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -D %{S:102} %{S:105} %{S:106} %{S:150} %{S:151} %{S:152} %{S:153} %{S:155} %{S:156} -m 0644 %{buildroot}%{_rpmconfigdir}/macros.d/

install -D %{S:404} %{buildroot}%{_rpmconfigdir}/redhat/gpgverify

mkdir -p %{buildroot}%{_rpmluadir}/fedora/{rpm,srpm}
install -D %{S:800} %{buildroot}%{_rpmluadir}/fedora
install -D %{S:801} %{buildroot}%{_rpmluadir}/fedora/srpm

%if %have_emacsmodespec
# spec mode for emacs
install -d $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/
install -m644 rpm-spec-mode.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
cat <<EOF >$RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq auto-mode-alist (cons '("\\\\.spec$" . rpm-spec-mode) auto-mode-alist))
(autoload 'rpm-spec-mode "rpm-spec-mode" "RPM spec mode (for %{distribution})." t)
EOF
%endif

%check
make test

%files
%dir %{_rpmconfigdir}/%{_real_vendor}
%{_rpmconfigdir}/%{_real_vendor}/macros
%{_rpmconfigdir}/%{_real_vendor}/rpmrc

%files build
%doc NEWS
%{_rpmconfigdir}/%{_real_vendor}/config.{guess,sub}
%{_rpmconfigdir}/%{_real_vendor}/*.{req,prov}
%{_rpmconfigdir}/%{_real_vendor}/drop-ld-no-undefined-for-shared-lib-modules-in-libtool
%{_rpmconfigdir}/%{_real_vendor}/find-provides
%{_rpmconfigdir}/%{_real_vendor}/find-requires
%{_rpmconfigdir}/%{_real_vendor}/fix-dlsearch-path-in-libtool-for-multilib
%{_rpmconfigdir}/%{_real_vendor}/fix-libtool-from-moving-options-after-libs
%{_rpmconfigdir}/%{_real_vendor}/fix-libtool-ltmain-from-overlinking
%{_rpmconfigdir}/%{_real_vendor}/force-as-needed-for-shared-lib-in-libtool
%{_rpmconfigdir}/%{_real_vendor}/perl.req-from-meta
%{_rpmconfigdir}/%{_real_vendor}/perl.recommends-from-meta
%{_rpmconfigdir}/%{_real_vendor}/platform/
%{_rpmconfigdir}/gi-find-deps.sh
%{_rpmconfigdir}/macros.d/*
%{_rpmconfigdir}/*.{prov,req}
%{_rpmluadir}/fedora/
%{_rpmconfigdir}/redhat/*
%exclude %{_rpmconfigdir}/%{_real_vendor}/rpmrc
%if %have_emacsmodespec
%{_datadir}/emacs/site-lisp/rpm-spec-mode.el
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/%{name}.el
%endif
%{_rpmconfigdir}/fileattrs/*.attr
