# WARNING: This package is synced with Fedora

%define lib64arches	x86_64 aarch64

%ifarch %lib64arches
    %define _lib lib64
%else
    %define _lib lib
%endif

%define _prefix /usr
%define _libdir %_prefix/%_lib
%define _bindir %_prefix/bin
%define _sysconfdir /etc
%define _datadir /usr/share
%define _defaultdocdir %_datadir/doc
%define _localstatedir /var
%define _infodir %_datadir/info

%if %{?mklibname:0}%{?!mklibname:1}
%define mklibname(ds)  %{_lib}%{1}%{?2:%{2}}%{?3:_%{3}}%{-s:-static}%{-d:-devel}
%endif

%if %{?distsuffix:0}%{?!distsuffix:1}
%define distsuffix .mga
%endif

%if %{?_real_vendor:0}%{?!_real_vendor:1}
%define _real_vendor mageia
%endif

%if %{?mkrel:0}%{?!mkrel:1}
%define mkrel(c:) %{-c: 0.%{-c*}.}%{1}%{?distsuffix:%distsuffix}%{?!distsuffix:.mga}%{?mageia_release:%mageia_release}%{?subrel:.%subrel}
%endif

%if %{?pyver:0}%{?!pyver:1}
%define pyver %(python -V 2>&1 | cut -f2 -d" " | cut -f1,2 -d".")
%endif

%define __find_requires %{rpmhome}/%{_real_vendor}/find-requires %{?buildroot:%{buildroot}} %{?_target_cpu:%{_target_cpu}}
%define __find_provides %{rpmhome}/%{_real_vendor}/find-provides

# run internal testsuite?
%bcond_with check
# build with plugins?
%bcond_without plugins
# build with libarchive? (needed for rpm2archive)
%bcond_without libarchive
# build with fsverity support?
%bcond_with fsverity
# build with ndb backend?
%bcond_without ndb
# build with sqlite support?
%bcond_without sqlite
# build with bdb_ro support?
%bcond_without bdb_ro
# build with sequoia crypto?
%bcond_without sequoia
%bcond_with debug

# Define directory which holds rpm config files, and some binaries actually
# NOTE: it remains */lib even on lib64 platforms as only one version
#       of rpm is supported anyway, per architecture
%define rpmhome /usr/lib/rpm

%global rpmver 4.20.1
#global snapver rc1
%global baserelease 1
%global sover 10

%global srcver %{rpmver}%{?snapver:-%{snapver}}
%global srcdir %{?snapver:testing}%{!?snapver:rpm-%(echo %{rpmver} | cut -d'.' -f1-2).x}
%global libmajor	%sover
%global librpmname      %mklibname rpm  %{libmajor}
%global librpmnamedevel %mklibname -d rpm
%global librpmsign      %mklibname rpmsign %{libmajor}
%global librpmbuild     %mklibname rpmbuild %{libmajor}

%global rpmsetup_version 2.72


Summary:	The RPM package management system
Name:		rpm
Epoch:		1
Version:	%{rpmver}
Release:	%mkrel %{?snapver:0.%{snapver}.}%{baserelease}
Group:		System/Packaging
Url:		https://rpm.org/
Source0:	http://ftp.rpm.org/releases/%{srcdir}/rpm-%{srcver}.tar.bz2
# extracted from https://pkgs.fedoraproject.org/cgit/redhat-rpm-config.git/plain/macros:
Source1:	macros.filter

Source10: rpmdb-rebuild.service

#
# Fedora patches
#

# Patches already upstream:

# Disable new user/group handling
Patch501: rpm-4.20.1-disable-sysusers.patch
Patch502: rpm-4.19.91-weak-user-group.patch

# Temporarily disable the deprecation warning for
# %%clamp_mtime_to_source_date_epoch, details here:
# https://src.fedoraproject.org/rpms/redhat-rpm-config/pull-request/298
Patch503: 0001-Revert-Add-a-deprecation-warning-for-clamp_mtime_to_.patch

# These are not yet upstream
Patch906: rpm-4.7.1-geode-i686.patch

#
# End of FC patches
# 

#
# Upstream patches not carried by FC:
#



#
# Mageia patches
#

# (tmb) stop trying to strip firmware files, they need to be intact.
Patch50:	rpm-4.20.1-dont-try-to-strip-firmware-files.patch

# In original rpm, -bb --short-circuit does not work and run all stage
# From popular request, we allow to do this
# http://qa.mandriva.com/show_bug.cgi?id=15896
Patch70:	rpm-4.18.0-bb-shortcircuit.patch

# don't conflict for doc files
# (to be able to install lib*-devel together with lib64*-devel even if they have conflicting manpages)
Patch83: rpm-4.12.0-no-doc-conflicts.patch

# Fix http://qa.mandriva.com/show_bug.cgi?id=19392
# (is this working??)
Patch84: rpm-4.15.0-rpmqv-ghost.patch

# without this patch, "#%%define foo bar" is surprisingly equivalent to "%%define foo bar"
# with this patch, "#%%define foo bar" is a fatal error
# Bug still valid => Send upstream for review.
Patch145: rpm-forbid-badly-commented-define-in-spec.patch

# (nb: see the patch for more info about this issue)
#Patch151: rpm-4.6.0-rc1-protect-against-non-robust-futex.patch

#
# Merge mageia's perl.prov improvements back into upstream:
#
# making sure automatic provides & requires for perl package are using the new
# macro %%perl_convert_version:
# (tv) FIXME: no more present, doble check that rpm-mageia-setup does it:
#Patch162: use_perl_convert_version.diff

#
# Merge mageia's find-requires.sh improvements back into upstream:
#
# (tv) output perl-base requires instead of /usr/bin/perl with internal generator:
# (ngompa) This patch can be dropped once we switch fully over to dnf
Patch170: script-perl-base.diff
# (tv) do not emit requires for /bin/sh (required by glibc) or interpreters for which
# we have custom
Patch172: script-filtering.diff
# (tv) "resolve" /bin/env foo interpreter to actual path, rather than generating
# dependencies on coreutils, should trim off ~800 dependencies more
Patch173: script-env.diff
# (tv) output pkgconfig requires instead of /usr/bin/pkgconfig with internal generator:
# (ngompa) This patch can be dropped once we switch fully over to dnf
Patch174: pkgconfig.diff
# (tv) no not emit "rtld(GNU_HASH)" requires as we've support for it since mga1:
# (saves ~5K packages' dependency in synthesis)
Patch175: no-rtld_GNU_HASH_req.diff
# (tv) replace file deps by requires on packages (when interp is installed):
# (ngompa) This patch can be dropped once we switch fully over to dnf
Patch176: script-no-file-deps.diff
# (pt) generate ELF provides for libraries, not only for executables
Patch180: elf_libs_req.diff 
# [Suse]add --assumeexec option for previous patch:
Patch181: assumeexec.diff 
# (Martin Whitaker) disable the systemd-inhibit plugin when systemd-logind is not running (mga#20016):
Patch182: systemd-inhibit-requires-logind.patch

# (tv) Commit 816c7cf3fdae5c45de02a42a2245549778e2ca80 defaults to ignoring autodeps from docfile,
# which break perl autodeps from *META*:
Patch200: dont-filter-autodeps-from-doc-by-default.patch

# (wally) Don't own /usr/share/man/$LANG/man[1-9]/ directories when '%%find_lang foo --with-man --all-name' is used
Patch201: 0001-find-lang.sh-don-t-own-directories-when-with-man-all.patch

# (wally) Fix build with gcc14
Patch202: 0001-Fix-build-with-gcc14.patch

# Various arch enabling:
Patch3003: rpm_arm_mips_isa_macros.patch

# Mageia patches that are easier to rediff on top of FC patches:
#---------------------------------------------------------------

# Partially GPL/LGPL dual-licensed and some bits with BSD
# SourceLicense: (GPLv2+ and LGPLv2+ with exceptions) and BSD 
License: GPLv2+

BuildRequires:	autoconf
BuildRequires:	pkgconfig(zlib)
BuildRequires:	bzip2-devel
BuildRequires:	pkgconfig(liblzma) >= 5
BuildRequires:	libgomp-devel
BuildRequires:	automake
BuildRequires:	cmake >= 3.18
BuildRequires:	doxygen
BuildRequires:	elfutils-devel
BuildRequires:	ed
BuildRequires:	gettext-devel
%if %{with plugins}
BuildRequires:	pkgconfig(dbus-1)
%endif
BuildRequires:	audit-libs-devel
BuildRequires:	pkgconfig(neon)
BuildRequires:	pkgconfig(popt)
BuildRequires:	magic-devel
BuildRequires:	rpm-%{_real_vendor}-setup-build %{?rpmsetup_version:>= %{rpmsetup_version}}
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libselinux)
BuildRequires:	pkgconfig(lua) >= 5.4
BuildRequires:	pkgconfig(libcap)
BuildRequires:	libacl-devel
%if %{with libarchive}
BuildRequires:	pkgconfig(libarchive)
%endif
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(libzstd)
%if %{with sqlite}
BuildRequires:	pkgconfig(sqlite3)
%endif

# Needed for re-building the documentation and man pages
# normally those are shipped in the tarball pre-build
# but need re-building if sources are patched
%if 0
BuildRequires: pandoc
BuildRequires: doxygen
%endif


%if %{with sequoia}
%global crypto sequoia
BuildRequires: rpm-sequoia-devel >= 1.4.0
%else
%global crypto openssl
BuildRequires:	pkgconfig(libssl)
%endif

# for testsuite:
BuildRequires: eatmydata

Requires:	mktemp
Requires:	setup >= 2.2.0-8
Requires:	rpm-%{_real_vendor}-setup >= 1.85
# versioned deps for upgrades (mga #24767)
Requires:	%{_lib}db5.3 >= 5.3.28-17
Requires:	update-alternatives
Requires:	%librpmname = %epoch:%version-%release
%define         git_url        http://rpm.org/git/rpm.git
Requires(pre):		rpm-helper
Requires(pre):		coreutils
Requires(postun):	rpm-helper

# Weakly depend on stuff that used to be in main rpm package
Recommends: rpm-plugin-syslog
Recommends: rpm-plugin-ima
Recommends: rpm-plugin-systemd-inhibit

# RPM used to require an %%install hack (shipped by redhat-rpm-config) in order
# to enable debuginfo.  Version 4.19.91 implements this functionality properly
# so this hack is no longer necessary and, in fact, is no longer supported.
# More details: https://github.com/rpm-software-management/rpm/issues/2204
# (tv) FIXME TODO:
Conflicts: redhat-rpm-config < 291-1

%if %{with fsverity}
#BuildRequires: fsverity-devel
%endif

%description
The RPM Package Manager (RPM) is a powerful command line driven
package management system capable of installing, uninstalling,
verifying, querying, and updating software packages.  Each software
package consists of an archive of files along with information about
the package like its version, a description, etc.

%package -n %librpmname
Summary:  Libraries for manipulating RPM packages
Group:	  System/Libraries
License: GPLv2+ and LGPLv2+ with exceptions
Provides: librpm = %version-%release
Provides: rpm-libs = %{version}-%{release}
Provides: rpm-libs%{_isa} = %{version}-%{release}

%description -n %librpmname
This package contains the RPM shared libraries.

%package   -n %librpmbuild
Summary:   Libraries for building RPM packages
Group:     System/Libraries
License: GPLv2+ and LGPLv2+ with exceptions
Obsoletes: rpm-build-libs < %{version}-%{release}
Provides: rpm-build-libs%{_isa} = %{version}-%{release}

%description -n %librpmbuild
This package contains the RPM shared libraries for building packages.

%package  -n %librpmsign
Summary:  Libraries for signing RPM packages
Group:    System/Libraries
License: GPLv2+ and LGPLv2+ with exceptions
Requires: gnupg2

%description -n %librpmsign
This package contains the RPM shared libraries for signing packages.

%package -n %librpmnamedevel
Summary:	Development files for manipulating RPM packages
Group:		Development/C
License: GPLv2+ and LGPLv2+ with exceptions
Requires:	rpm = %epoch:%{version}-%{release}
Provides:	librpm-devel = %version-%release
Provides:   	rpm-devel = %version-%release
Requires:       %librpmname = %epoch:%version-%release
Requires:       %librpmbuild = %epoch:%version-%release
Requires:       %librpmsign = %epoch:%version-%release

%description -n %librpmnamedevel
This package contains the RPM C library and header files.  These
development files will simplify the process of writing programs that
manipulate RPM packages and databases. These files are intended to
simplify the process of creating graphical package managers or any
other tools that need an intimate knowledge of RPM packages in order
to function.

This package should be installed if you want to develop programs that
will manipulate RPM packages and databases.

%package build
Summary:	Scripts and executable programs used to build packages
Group:		System/Packaging
Requires:	autoconf
Requires:	automake
# /usr/lib/rpm/check-files: line 31: diff: command not found
Requires:	diffutils
Requires:	file
Requires:	gcc-c++
# We need cputoolize & amd64-* alias to x86_64-* in config.sub
Requires:	libtool-base
Requires:	patch
Requires:	make
Requires:	elfutils >= 0.167-2
Requires:	perl(CPAN::Meta) >= 2.112.150
Requires:	perl(ExtUtils::MakeMaker) >= 6.570_700
Requires:       perl(YAML::Tiny)
Requires:	rpm = %epoch:%{version}-%{release}
Requires:	%librpmbuild = %epoch:%version
Requires:	python3-rpm-generators
Requires:	gawk
Requires:	tar unzip gzip bzip2 cpio xz
Requires:	zstd
Requires:	debugedit >= 0.3
Recommends: gdb-minimal
# Technically rpmbuild doesn't require any external configuration, but
# creating distro-compatible packages does. To make the common case
# "just work" while allowing for alternatives, depend on a virtual
# provide, typically coming from redhat-rpm-config.
Requires:	rpm-%{_real_vendor}-setup-build %{?rpmsetup_version:>= %{rpmsetup_version}}

%description build
The rpm-build package contains the scripts and executable programs
that are used to build packages using the RPM Package Manager.

%package sign
Summary: Package signing support
Group:   System/Base

%description sign
This package contains support for digitally signing RPM packages.

%package -n python3-%{name}
Summary:	Python 3 bindings for apps which will manipulate RPM packages
Group:		Development/Python
Requires:	rpm = %epoch:%{version}-%{release}
Provides:	rpm-python = %epoch:%{version}-%{release}

%description -n python3-%{name}
The python3-rpm package contains a module that permits applications
written in the Python programming language to use the interface
supplied by RPM Package Manager libraries.

This package should be installed if you want to develop Python 3
programs that will manipulate RPM packages and databases.

%package apidocs
Summary: API documentation for RPM libraries
Group:   Documentation
BuildArch: noarch

%description apidocs
This package contains API documentation for developing applications
that will manipulate RPM packages and databases.

%package cron
Summary: Create daily logs of installed packages
Group: System/Base
BuildArch: noarch
Requires: crontabs
Requires: logrotate
Requires: rpm = %{epoch}:%{version}-%{release}

%description cron
This package contains a cron job which creates daily logs of installed
packages on a system.

%if %{with plugins}
%package plugin-selinux
Summary: Rpm plugin for SELinux functionality
Group: System/Base
Requires: %{librpmname}%{?_isa} = %{epoch}:%{version}-%{release}
Requires: selinux-policy-base

%description plugin-selinux
This plugin adds support for enforcing and verifying SELinux labels
in an rpm.

%package plugin-unshare
Summary: Rpm plugin for Linux namespace isolation functionality
Requires: rpm-libs%{_isa} = %{version}-%{release}

%description plugin-unshare
%{summary}.

%package plugin-syslog
Summary: Rpm plugin for syslog functionality
Group: System/Base
Requires: %{librpmname}%{?_isa} = %{epoch}:%{version}-%{release}

%description plugin-syslog
This plugin exports RPM actions to the system log.

%package plugin-systemd-inhibit
Summary: Rpm plugin for systemd inhibit functionality
Group: System/Base
Requires: %{librpmname}%{?_isa} = %{epoch}:%{version}-%{release}

%description plugin-systemd-inhibit
This plugin blocks systemd from entering idle, sleep or shutdown while an rpm
transaction is running using the systemd-inhibit mechanism.

%package plugin-ima
Summary: Rpm plugin for IMA file signatures
Group: System/Base
Requires: %{librpmname}%{?_isa} = %{epoch}:%{version}-%{release}

%description plugin-ima
This plugin adds support for enforcing and verifying IMA file signatures
in an rpm.

%package plugin-prioreset
Summary: Rpm plugin for resetting scriptlet priorities for SysV init
Group: System/Base
Requires: %{librpmname}%{?_isa} = %{epoch}:%{version}-%{release}

%description plugin-prioreset
%{summary}.

Useful on legacy SysV init systems if you run rpm transactions with
nice/ionice priorities. Should not be used on systemd systems.

%package plugin-audit
Summary: Rpm plugin for logging audit events on package operations
Requires: rpm-libs%{_isa} = %{version}-%{release}

%description plugin-audit
%{summary}.

%if %{with fsverity}
%package plugin-fsverity
Summary: Rpm plugin for fsverity file signatures
Requires: rpm-libs%{_isa} = %{version}-%{release}

%description plugin-fsverity
%{summary}.
%endif

%package plugin-fapolicyd
Summary: Rpm plugin for fapolicyd support
Requires: rpm-libs%{_isa} = %{version}-%{release}

%description plugin-fapolicyd
%{summary}.

See https://people.redhat.com/sgrubb/fapolicyd/ for information about
the fapolicyd daemon.

%package plugin-dbus-announce
Summary: Rpm plugin for announcing transactions on the DBUS
Requires: rpm-libs%{_isa} = %{version}-%{release}

%description plugin-dbus-announce
The plugin announces basic information about rpm transactions to the
system DBUS - like packages installed or removed.  Other programs can
subscribe to the signals to get notified when packages on the system
change.

# with plugins
%endif

%prep
%autosetup -n rpm-%{srcver} -p1

# switch to sqlite db by default, including during build-time tests
%if %{with sqlite}
sed -i -e "/_db_backend/ s/ bdb/ sqlite/g" macros.in
%endif

%build
%define _disable_ld_no_undefined 1

%if %with debug
RPM_OPT_FLAGS=-g
%endif
%set_build_flags

mkdir _build
cd _build
cmake \
      -DCMAKE_INSTALL_PREFIX=%{_usr} \
      -DCMAKE_INSTALL_SHAREDSTATEDIR:PATH=%{_var}/lib \
      %{?with_bdb_ro:-DENABLE_BDB_RO=ON} \
      %{!?with_ndb:-DENABLE_NDB=OFF} \
      %{!?with_sqlite:-DENABLE_SQLITE=OFF} \
      %{!?with_plugins:-DENABLE_PLUGINS=OFF} \
      %{?with_fsverity:-DWITH_FSVERITY=ON} \
      %{?with_libimaevm:-DWITH_IMAEVM=ON} \
      %{!?with_libarchive:-DWITH_ARCHIVE=OFF} \
      %{!?with_check:-DENABLE_TESTSUITE=OFF} \
      %{!?with_sequoia:-DWITH_INTERNAL_OPENPGP=ON} \
      %{!?with_sequoia:-DWITH_OPENSSL=ON } \
      -DENABLE_CUTF8=OFF \
      -DRPM_VENDOR=%{_real_vendor} \
  ..

%make_build

%check
# We can't run the actual test-suite from %%check,
# at least check the Python module is importable:
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %py3_check_import rpm rpm.transaction

%install
cd _build
%make_install
cd ..

mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -m 644 %{SOURCE10} $RPM_BUILD_ROOT/%{_unitdir}

# Built-in replacement for systemd-sysusers(8)
install -m 755 scripts/sysusers.sh $RPM_BUILD_ROOT/%{rpmhome}

# Save list of packages through cron
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/cron.daily
install -m 755 scripts/rpm.daily ${RPM_BUILD_ROOT}%{_sysconfdir}/cron.daily/rpm

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d
install -m 644 scripts/rpm.log ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/rpm

test -d doc-copy || mkdir doc-copy
rm -rf doc-copy/*
ln -f docs/manual/* doc-copy/
rm -f doc-copy/Makefile*

mkdir -p $RPM_BUILD_ROOT/var/spool/repackage

mkdir -p %buildroot%rpmhome/macros.d
install %SOURCE1 %buildroot%rpmhome/macros.d
mkdir -p $RPM_BUILD_ROOT/var/lib/rpm
mkdir -p %buildroot%_sysconfdir/rpm
cat > %buildroot%_sysconfdir/rpm/macros <<EOF
# Put your own system macros here
# usually contains 

# Set this one according your locales
# %%_install_langs

EOF

cd _build

# init an empty database for %ghost'ing for all supported backends
for be in %{?with_ndb:ndb} %{?with_sqlite:sqlite}; do
    mkdir ${be} || :
    tools/rpmdb --rcfile rpmrc --define "_db_backend ${be}" --dbpath=${PWD}/${be} --initdb
    cp -va ${be}/. $RPM_BUILD_ROOT/var/lib/rpm/
done

# some packages invoke find-debuginfo directly, preserve compat for now
ln -s ../../bin/find-debuginfo $RPM_BUILD_ROOT/usr/lib/rpm/find-debuginfo.sh

%find_lang rpm

find $RPM_BUILD_ROOT -name "*.la"|xargs rm -f

# We don't ship those historically (save ~432kb of space):
rm -rf %buildroot/%{rpmhome}/platform/m68k-linux
rm -rf %buildroot/%{rpmhome}/platform/riscv64-linux
%ifnarch %{ix86} x86_64
rm -rf %buildroot/%{rpmhome}/platform/i*86-linux
rm -rf %buildroot/%{rpmhome}/platform/athlon-linux
rm -rf %buildroot/%{rpmhome}/platform/pentium*-linux
rm -rf %buildroot/%{rpmhome}/platform/geode-linux
%endif
%ifnarch x86_64
rm -rf %buildroot/%{rpmhome}/platform/amd64-linux
rm -rf %buildroot/%{rpmhome}/platform/ia32e-linux
rm -rf %buildroot/%{rpmhome}/platform/x86_64-linux
%endif
%ifnarch %arm aarch64
rm -rf %buildroot/%{rpmhome}/platform/arm*
rm -rf %buildroot/%{rpmhome}/platform/aarch64*
%endif
# new in 4.10.0:
rm -rf %buildroot/%{rpmhome}/platform/alpha*-linux
rm -rf %buildroot/%{rpmhome}/platform/sparc*-linux
rm -rf %buildroot/%{rpmhome}/platform/ia64*-linux
rm -rf %buildroot/%{rpmhome}/platform/m68k*-linux
rm -rf %buildroot/%{rpmhome}/platform/mips*-linux
rm -rf %buildroot/%{rpmhome}/platform/ppc*-linux
rm -rf %buildroot/%{rpmhome}/platform/s390*-linux
rm -rf %buildroot/%{rpmhome}/platform/sh*-linux

# These live in python-rpm-generators now
rm -f $RPM_BUILD_ROOT/%{rpmhome}/pythond*
rm -f $RPM_BUILD_ROOT/%{_fileattrsdir}/python*

%if %{with debugedit}
rm -f $RPM_BUILD_ROOT/%{rpmhome}/{debugedit,sepdebugcrcfix,find-debuginfo.sh}
%endif

%if %{with check}
%check
#eatmydata make -j check TESTSUITEFLAGS="-j%{_smp_build_ncpus}" || (cat tests/rpmtests.log; exit 1)
%endif

%pre
/usr/share/rpm-helper/add-user rpm $1 rpm /var/lib/rpm /bin/false

%pretrans -p <lua> -n python3-rpm
-- (tv) temp upgrade for cauldron:
path = "%{python3_sitearch}/rpm-4.18.0-py3.10.egg-info"
st = posix.stat(path)
if st and st.type == "directory" then
  os.execute("rm -rf " .. path)
end

%postun
/usr/share/rpm-helper/del-user rpm $1 rpm

# Handle rpmdb rebuild service on erasure of old to avoid ordering issues
# https://pagure.io/fesco/issue/2382
%triggerun -- rpm < 1:4.16.1.3-4
if [ -x /usr/bin/systemctl ]; then
    systemctl --no-reload preset rpmdb-rebuild ||:
fi

%posttrans
if [ -f /var/lib/rpm/Packages ]; then
    touch /var/lib/rpm/.rebuilddb
fi

%define	rpmattr		%attr(0755, rpm, rpm)

%files -f _build/rpm.lang
%license COPYING
%doc CREDITS docs/manual/[a-z]*
%doc %{_defaultdocdir}/rpm/CONTRIBUTING.md
%doc %{_defaultdocdir}/rpm/COPYING
%doc %{_defaultdocdir}/rpm/INSTALL
%doc %{_defaultdocdir}/rpm/README

%attr(0755,rpm,rpm) %{_bindir}/rpm
%attr(0755, rpm, rpm) %{_bindir}/rpm2cpio
%attr(0755, rpm, rpm) %{_bindir}/rpm2archive
%attr(0755, rpm, rpm) %{_bindir}/gendiff
%attr(0755, rpm, rpm) %{_bindir}/rpmdb
%attr(0755, rpm, rpm) %{_bindir}/rpmkeys
%attr(0755, rpm, rpm) %{_bindir}/rpmgraph
%{_bindir}/rpmquery
%{_bindir}/rpmverify
%{_bindir}/rpmsort

%dir %{_localstatedir}/spool/repackage
%dir %{rpmhome}
%dir /etc/rpm
%config(noreplace) /etc/rpm/macros
%attr(0755, rpm, rpm) %{rpmhome}/rpmdb_*
%attr(0644, rpm, rpm) %{rpmhome}/macros
%exclude %{rpmhome}/macros.d/macros.transaction*
%rpmhome/macros.d
%{rpmhome}/lua
%attr(0755, rpm, rpm) %{rpmhome}/rpm.*
%attr(0644, rpm, rpm) %{rpmhome}/rpmpopt*
%attr(0644, rpm, rpm) %{rpmhome}/rpmrc

%rpmattr	%{rpmhome}/rpm2cpio.sh
%rpmattr	%{rpmhome}/tgpg

%{_mandir}/man8/rpm.8*
%{_mandir}/man8/rpmdb.8*
%{_mandir}/man8/rpmgraph.8*
%{_mandir}/man8/rpmkeys.8*
%{_mandir}/man8/rpm2archive.8*
%{_mandir}/man8/rpm2cpio.8*
%{_mandir}/man8/rpm-misc.8*
%{_mandir}/man8/rpmsort.8*
%{_mandir}/man8/rpm-plugins.8*
%{_mandir}/man1/*.1*

%attr(0755, rpm, rpm)	%dir %_localstatedir/lib/rpm

%{_unitdir}/rpmdb-rebuild.service
%attr(0644, root, root) %ghost %config(missingok,noreplace) /var/lib/rpm/*
%attr(0644, root, root) %ghost /var/lib/rpm/.*.lock

%{rpmhome}/platform
%{rpmhome}/sysusers.sh

%dir %{rpmhome}/fileattrs

%files -n %librpmname
%{_libdir}/librpm.so.%{libmajor}{,.*}
%{_libdir}/librpmio.so.%{libmajor}{,.*}
%if %{with plugins}
%dir %{_libdir}/rpm-plugins

%files plugin-syslog
%{rpmhome}/macros.d/macros.transaction_syslog
%{_libdir}/rpm-plugins/syslog.so
%{_mandir}/man8/rpm-plugin-syslog.8*

%files plugin-selinux
%{rpmhome}/macros.d/macros.transaction_selinux
%{_libdir}/rpm-plugins/selinux.so
%{_mandir}/man8/rpm-plugin-selinux.8*

%files plugin-systemd-inhibit
%{rpmhome}/macros.d/macros.transaction_systemd_inhibit
%{_libdir}/rpm-plugins/systemd_inhibit.so
%{_mandir}/man8/rpm-plugin-systemd-inhibit.8*

%if %{with libimaevm}
%files plugin-ima
%{rpmhome}/macros.d/macros.transaction_ima
%{_libdir}/rpm-plugins/ima.so
%{_mandir}/man8/rpm-plugin-ima.8*
%endif

%if %{with fsverity}
%{rpmhome}/macros.d/macros.transaction_fsverity
%files plugin-fsverity
%{_libdir}/rpm-plugins/fsverity.so
%endif

%files plugin-fapolicyd
%{rpmhome}/macros.d/macros.transaction_fapolicyd
%{_libdir}/rpm-plugins/fapolicyd.so
%{_mandir}/man8/rpm-plugin-fapolicyd.8*

%files plugin-prioreset
%{rpmhome}/macros.d/macros.transaction_prioreset
%{_libdir}/rpm-plugins/prioreset.so
%{_mandir}/man8/rpm-plugin-prioreset.8*

%files plugin-audit
%{rpmhome}/macros.d/macros.transaction_audit
%{_libdir}/rpm-plugins/audit.so
%{_mandir}/man8/rpm-plugin-audit.8*
# with plugins

%files plugin-dbus-announce
%{rpmhome}/macros.d/macros.transaction_dbus_announce
%{_libdir}/rpm-plugins/dbus_announce.so
%{_mandir}/man8/rpm-plugin-dbus-announce.8*
%{_datadir}/dbus-1/system.d/org.rpm.conf
%endif

%files plugin-unshare
%{rpmhome}/macros.d/macros.transaction_unshare
%{_libdir}/rpm-plugins/unshare.so
%{_mandir}/man8/rpm-plugin-unshare.8*

%files -n %librpmbuild
%{_libdir}/librpmbuild.so.%{libmajor}{,.*}

%files -n %librpmsign
%{_libdir}/librpmsign.so.%{libmajor}{,.*}

%files build
%doc doc-copy/*
%rpmattr	%{_bindir}/rpmbuild
%rpmattr        %{_bindir}/rpmspec
%rpmattr        %{_bindir}/rpmlua

%{_mandir}/man8/rpmbuild.8*
%{_mandir}/man8/rpmdeps.8*
%{_mandir}/man8/rpmspec.8*
%{_mandir}/man8/rpmlua.8*

%{rpmhome}/brp-*
%{rpmhome}/check-*
%{rpmhome}/find-lang.sh
%{rpmhome}/*provides*
%{rpmhome}/*requires*
%{rpmhome}/*deps*
%{rpmhome}/*.prov
%{rpmhome}/*.req
%{rpmhome}/fileattrs/*
%{rpmhome}/find-debuginfo.sh
%{rpmhome}/rpmuncompress
%{rpmhome}/rpmdump

%files sign
%{_bindir}/rpmsign
%{_mandir}/man8/rpmsign.8*

%files -n python3-%{name}
%dir %{python3_sitearch}/rpm
%{python3_sitearch}/rpm-%{rpmver}*.egg-info
%{python3_sitearch}/rpm/__init__.py
%{python3_sitearch}/rpm/transaction.py
%{python3_sitearch}/rpm/_rpm.so
%artifact %{python3_sitearch}/rpm/__pycache__/

# Python examples
%{_defaultdocdir}/rpm/examples/*.py

%files -n %librpmnamedevel
%{_libdir}/librp*[a-z].so
%{_libdir}/pkgconfig/rpm.pc
%{_libdir}/cmake/rpm/
%{_includedir}/rpm/

%files cron
%{_sysconfdir}/cron.daily/rpm
%config(noreplace) %{_sysconfdir}/logrotate.d/rpm

%files apidocs
%license COPYING
%doc %{_defaultdocdir}/rpm/API/

