%define rspamd_user       _rspamd
%define rspamd_group      %{rspamd_user}
%define rspamd_home       %{_localstatedir}/lib/rspamd
%define rspamd_logdir     %{_localstatedir}/log/rspamd
%define rspamd_confdir    %{_sysconfdir}/rspamd
%define rspamd_pluginsdir %{_datadir}/rspamd
%define rspamd_rulesdir   %{_datadir}/rspamd/rules
%define rspamd_wwwdir     %{_datadir}/rspamd/www

Name:           rspamd
Version:        3.11.1
Release:        %mkrel 1
Summary:        Rapid spam filtering system
Group:          Networking/Mail

# BSD License (two clause)
# https://www.freebsd.org/copyright/freebsd-license.html
License:        BSD
URL:            https://rspamd.com/
Source0:        https://github.com/rspamd/rspamd/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        rspamd.tmpfile
Source2:        rspamd.logrotate
Source3:        80-rspamd.preset
Patch0:         rspamd-service-type.patch
Patch1:         rspamd-linking.patch
Patch2:         rspamd-default-ciphers.patch
Patch4:         rspamd-system-snowball.patch
BuildRequires:  cmake
BuildRequires:  ragel
BuildRequires:  systemd
BuildRequires:  icu-devel
BuildRequires:  libstemmer-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  cmake(doctest)
BuildRequires:  pkgconfig(gmime-2.6)
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libdwarf)
%ifarch x86_64
BuildRequires:  pkgconfig(libhs)
%endif
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(fann)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(libzstd)

Requires(pre):  systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires(pre):  shadow-utils
Requires:       logrotate

%description
Rspamd is a rapid, modular and lightweight spam filter. It is designed to work
with big amount of mail and can be easily extended with own filters written in
lua.

%prep
%autosetup -p1

# build with system libs
rm -rf contrib/{doctest,fmt,snowball,xxhash,zstd}

%build
%cmake \
        -DCONFDIR=%{_sysconfdir}/rspamd \
        -DMANDIR=%{_mandir} \
        -DDBDIR=%{_localstatedir}/lib/rspamd \
        -DRUNDIR=%{_rundir}/rspamd \
        -DWANT_SYSTEMD_UNITS=ON \
        -DSYSTEMDDIR=%{_unitdir} \
        -DENABLE_LUAJIT=ON \
        -DLOGDIR=%{_localstatedir}/log/rspamd \
        -DPLUGINSDIR=%{_datadir}/rspamd \
        -DLIBDIR=%{_libdir}/rspamd/ \
        -DINCLUDEDIR=%{_includedir} \
%ifarch x86_64
        -DENABLE_HYPERSCAN=ON \
%endif
        -DENABLE_JEMALLOC=ON \
        -DENABLE_PCRE2=ON \
        -DENABLE_OPTIMIZATION=ON \
        -DENABLE_STATIC=OFF \
        -DNO_SHARED=ON \
        -DDEBIAN_BUILD=1 \
        -DRSPAMD_GROUP=%{rspamd_group} \
        -DRSPAMD_USER=%{rspamd_user} \
        -DSYSTEM_DOCTEST=ON \
        -DSYSTEM_ZSTD=ON \
        -DSYSTEM_FMT=ON \
        -DSYSTEM_XXHASH=ON

%cmake_build

%install
%cmake_install

install -p -D -m 644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d %{buildroot}%{_rundir}/%{name}

install -p -D -m 0644 %{SOURCE3} %{buildroot}%{_presetdir}/80-rspamd.preset

install -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -d -p -m 0755 %{buildroot}%{rspamd_logdir}

install -d -p -m 0755 %{buildroot}%{rspamd_home}
install -p -D -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/local.d/
install -p -D -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/override.d/

%pre
%{_sbindir}/groupadd -r %{rspamd_group} 2>/dev/null || :
%{_sbindir}/useradd -g %{rspamd_group} -c "Rspamd user" -s /bin/false -r -d %{rspamd_home} %{rspamd_user} 2>/dev/null || :

%post
%_tmpfilescreate %{name}
# to allow easy upgrade from 0.8.1
chown -R %{rspamd_user}:%{rspamd_group} %{rspamd_home}
# Macro is not used as we want to do this on upgrade
#%%_post_service %%{name}
systemctl --no-reload preset %{name}.service >/dev/null 2>&1 || :
chown %{rspamd_user}:%{rspamd_group} %{rspamd_logdir}

%preun
%_preun_service %{name}

%postun
%_postun_service %{name}

%files
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%dir %ghost %attr(0755, _rspamd, _rspamd) %{_rundir}/%{name}
%ghost %attr(0660, -, -) %{_rundir}/%{name}/%{name}.pid
%{_presetdir}/80-rspamd.preset
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{rspamd_logdir}
%{_mandir}/man8/%{name}.*
%{_mandir}/man1/rspamc.*
%{_mandir}/man1/rspamadm.*
%{_bindir}/rspamd
%{_bindir}/rspamd-*
%{_bindir}/rspamd_stats
%{_bindir}/rspamc
%{_bindir}/rspamc-*
%{_bindir}/rspamadm
%{_bindir}/rspamadm-*
%config(noreplace) %{rspamd_confdir}/%{name}.conf
%config(noreplace) %{rspamd_confdir}/actions.conf
%config(noreplace) %{rspamd_confdir}/composites.conf
%config(noreplace) %{rspamd_confdir}/cgp.inc
%config(noreplace) %{rspamd_confdir}/groups.conf
%config(noreplace) %{rspamd_confdir}/metrics.conf
%config(noreplace) %{rspamd_confdir}/modules.conf
%config(noreplace) %{rspamd_confdir}/statistic.conf
%config(noreplace) %{rspamd_confdir}/settings.conf
%config(noreplace) %{rspamd_confdir}/common.conf
%config(noreplace) %{rspamd_confdir}/lang_detection.inc
%config(noreplace) %{rspamd_confdir}/logging.inc
%config(noreplace) %{rspamd_confdir}/options.inc
%config(noreplace) %{rspamd_confdir}/worker-controller.inc
%config(noreplace) %{rspamd_confdir}/worker-fuzzy.inc
%config(noreplace) %{rspamd_confdir}/worker-normal.inc
%config(noreplace) %{rspamd_confdir}/worker-proxy.inc
%config(noreplace) %{rspamd_confdir}/modules.d/*
%config(noreplace) %{rspamd_confdir}/modules.local.d/*
%config(noreplace) %{rspamd_confdir}/local.d/*
%config(noreplace) %{rspamd_confdir}/lua.local.d/*
%config(noreplace) %{rspamd_confdir}/override.d/*
%config(noreplace) %{rspamd_confdir}/scores.d/*
%global rspamd_mapsdir %{rspamd_confdir}/maps.d
%config(noreplace) %{rspamd_mapsdir}/dmarc_whitelist.inc
%config(noreplace) %{rspamd_mapsdir}/exe_clickbait.inc
%config(noreplace) %{rspamd_mapsdir}/maillist.inc
%config(noreplace) %{rspamd_mapsdir}/mid.inc
%config(noreplace) %{rspamd_mapsdir}/mime_types.inc
%config(noreplace) %{rspamd_mapsdir}/redirectors.inc
%config(noreplace) %{rspamd_mapsdir}/spf_dkim_whitelist.inc
%config(noreplace) %{rspamd_mapsdir}/surbl-whitelist.inc
%attr(-, _rspamd, _rspamd) %dir %{rspamd_home}
%dir %{rspamd_rulesdir}/controller
%dir %{rspamd_rulesdir}/regexp
%dir %{rspamd_rulesdir}
%dir %{rspamd_confdir}
%dir %{rspamd_confdir}/modules.d
%dir %{rspamd_confdir}/local.d
%dir %{rspamd_confdir}/override.d
%dir %{rspamd_confdir}/scores.d
%dir %{rspamd_pluginsdir}/languages
%dir %{rspamd_pluginsdir}/lualib
%dir %{rspamd_pluginsdir}
%dir %{rspamd_wwwdir}
%dir %{_libdir}/rspamd
%{rspamd_pluginsdir}/languages/*.json
%{rspamd_pluginsdir}/lualib/*.lua
%{rspamd_pluginsdir}/lualib/*/*.lua
%{rspamd_pluginsdir}/*.lua
%{rspamd_rulesdir}/controller/*.lua
%{rspamd_rulesdir}/regexp/*.lua
%{rspamd_rulesdir}/*.lua
%{rspamd_wwwdir}/*
%{_libdir}/rspamd/*
%{rspamd_pluginsdir}/effective_tld_names.dat
%{rspamd_pluginsdir}/languages/stop_words
