Summary: Realtime IRQ thread system tuning.
Name: rtirq
Version: 20120505
Release: %mkrel 01
License: GPL
Group: System Environment/Base         
Source0: %{name}-%{version}.tar.gz
# add configuration option for a minimum priority in rtirq script
Patch0: rtirq-minprio.patch
# sources for udev and power management additions
Source1: rtirq-udev
Source2: rtirq-udev-rules
Source3: rtirq-power
# patch to add udev options to rtirq configuration
Patch1: rtirq-udevprio.patch
# This URL is no longer available
URL: https://www.rncbc.org/jack/

BuildRoot: %{_tmppath}/%{name}-%{version}-root

Requires: /bin/sh
Requires: /usr/bin/chrt
Requires(post,preun): /sbin/chkconfig

%description
Startup scripts for tuning the real-time scheduling policy and priority
of relevant IRQ service threads, featured for a real-time-preempt enabled
kernel configuration. 

%prep
%setup -q
%patch -P 0 -p0
%patch -P 1 -p0

%build

%install
%{__rm} -rf %{buildroot}
%{__install} -D rtirq.sh   -m 0755 %{buildroot}%{_sysconfdir}/rc.d/init.d/rtirq
%{__install} -D rtirq.conf -m 0644 %{buildroot}%{_sysconfdir}/sysconfig/rtirq

# fix order of interrupts, tac was reversing the priority of the soundcards
%{__perl} -p -i -e "s/\| tac//g" %{buildroot}%{_sysconfdir}/rc.d/init.d/rtirq

# start rtirq after the alsasound startup script (starts at 87)
%{__perl} -p -i -e "s|35 81 19|35 88 19|g" %{buildroot}%{_sysconfdir}/rc.d/init.d/rtirq

# high priority is 70 instead of 90 (in Fedora 17+)
%{__perl} -p -i -e "s|RTIRQ_PRIO_HIGH=90|RTIRQ_PRIO_HIGH=70|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# low priority is 65, 5 above Jack highest priority thread
%{__perl} -p -i -e "s|RTIRQ_PRIO_LOW=51|RTIRQ_PRIO_LOW=65|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# priority decrement now 1 instead of 5, no need to leave vacant priorities
%{__perl} -p -i -e "s|RTIRQ_PRIO_DECR=5|RTIRQ_PRIO_DECR=1|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# remove usb from list of cards in configuration, this is now handled through udev rules
%{__perl} -p -i -e "s|rtc snd usb i8042|rtc snd i8042|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq
# adjust priority for udev changes, same as highest priority
%{__perl} -p -i -e "s|RTIRQ_PRIO_UDEV=85|RTIRQ_PRIO_UDEV=70|g" %{buildroot}%{_sysconfdir}/sysconfig/rtirq

# install udev and power files
%{__install} -D %{SOURCE2} -m 0644 %{buildroot}%{_sysconfdir}/udev/rules.d/95-rtirq.rules
%{__install} -D %{SOURCE1} -m 0755 %{buildroot}%{_bindir}/rtirq-udev
%{__install} -D %{SOURCE3} -m 0755 %{buildroot}%{_sysconfdir}/pm/sleep.d/05-rtirq

%post
# only run on install, not upgrade
if [ "$1" = "1" ]; then
    /sbin/chkconfig --add rtirq
#   /sbin/chkconfig rtirq on
fi
if [ -L /etc/rc.d/rc5.d/S81rtirq ] ; then
    # update startup to new priority
    /sbin/chkconfig --del rtirq
    /sbin/chkconfig --add rtirq
fi

%preun
# only run if this is the last instance to be removed
if [ "$1" = "0" ]; then
    /sbin/chkconfig rtirq off
    /sbin/chkconfig --del rtirq
fi

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/sysconfig/rtirq
%{_sysconfdir}/rc.d/init.d/rtirq
# udev and power management
%{_sysconfdir}/udev/rules.d/95-rtirq.rules
%{_sysconfdir}/pm/sleep.d/05-rtirq
%{_bindir}/rtirq-udev

