%bcond_with	dotlock

Name:           s-nail
Version:        14.9.25
Release:        %mkrel 1
Summary:        Environment for sending and receiving mail
Group:		Networking/Mail
# Everything is ISC except parts coming from the original Heirloom mailx which are BSD
License:        ISC and BSD with advertising and BSD
URL:            https://www.sdaoden.eu/code.html#s-nail
Source0:        https://www.sdaoden.eu/downloads/%{name}-%{version}.tar.xz
Source1:        https://www.sdaoden.eu/downloads/%{name}-%{version}.tar.xz.asc
# https://ftp.sdaoden.eu/steffen.asc
Source2:        steffen.asc

BuildRequires:  make
BuildRequires:  gnupg2
BuildRequires:  gcc
BuildRequires:  openssl
BuildRequires:  openssl-devel
BuildRequires:  krb5-devel
BuildRequires:  libidn2-devel
BuildRequires:  ncurses-devel

# (mga#29626)
Obsoletes:	nail < 12.4-18
Provides:	nail = %{version}-%{release}
Provides:	mailx = %{version}-%{release}

%description
S-nail provides a simple and friendly environment for sending and receiving
mail. It is intended to provide the functionality of the POSIX mailx(1)
command, but is MIME capable and optionally offers extensions for line editing,
S/MIME, SMTP and POP3, among others. S-nail divides incoming mail into its
constituent messages and allows the user to deal with them in any order. It
offers many commands and internal variables for manipulating messages and
sending mail. It provides the user simple editing capabilities to ease the
composition of outgoing messages, and increasingly powerful and reliable
non-interactive scripting capabilities.


%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'

%autosetup -p1

sed -i -e 's/\(^set emptystart\)/#\1/' nail.rc

cat <<EOF >>nail.rc

# %{_vendor}-specific defaults
set bsdcompat
set noemptystart
set prompt='& '
EOF

%build
# This must not use %%make_build
# This make command runs a single command (mk/make-config.sh)
# and if it is parallel with make >= 4.4 --sync-mutex=fnm:/tmp/...
# gets added to .obj/mk-config.mk breaking the following build.
make \
    CFLAGS="%{build_cflags}" \
    LDFLAGS="%{build_ldflags}" \
    OPT_AUTOCC=no \
    OPT_DEBUG=yes \
    OPT_NOMEMDBG=yes \
    OPT_DOTLOCK=%{?with_dotlock:yes}%{!?with_dotlock:no} \
    VAL_PREFIX=%{_prefix} \
    VAL_SYSCONFDIR=%{_sysconfdir} \
    VAL_MAIL=%{_localstatedir}/mail \
    config

%make_build build

%install
%make_install

# s-nail binary is installed with 0555 permissions, fix that
chmod 0755 %{buildroot}%{_bindir}/%{name}

# symlinks
for i in Mail mail mailx nail; do
ln -s %{name} %{buildroot}%{_bindir}/$i
ln -s %{name}.1.xz %{buildroot}%{_mandir}/man1/$i.1.xz
done

%check
make test

%files
%license COPYING
%doc NEWS README
%{_bindir}/Mail
%{_bindir}/mail
%{_bindir}/mailx
%{_bindir}/nail
%{_bindir}/%{name}
%if %{with dotlock}
%{_libexecdir}/s-nail-dotlock
%endif
%config(noreplace) %{_sysconfdir}/%{name}.rc
%{_mandir}/man1/Mail.1*
%{_mandir}/man1/mail.1*
%{_mandir}/man1/mailx.1*
%{_mandir}/man1/nail.1*
%{_mandir}/man1/%{name}.1*
