%define libname %mklibname sbuild 1.7.2
%define devname %mklibname -d sbuild

Name: schroot
Version: 1.7.2
Release: %mkrel 30
Summary: Execute commands in a chroot environment
Group: Development/Other
License: GPLv3+
URL: https://codeberg.org/shelter/reschroot
Source0: https://ftp.debian.org/debian/pool/main/s/schroot/%{name}_%{version}.orig.tar.xz
Patch0: schroot-pam.patch
Patch1: schroot-default-config-path.patch
Patch2: schroot-1.7.2-regex.patch
Patch3: schroot-1.7.2-gtest-1.7.0.patch
Patch27: schroot-po4a.patch
Patch28: 6f7166a285e1e97aea390be633591f9791b29a6d.patch
Patch29: schroot-build-with-C-17.patch
Patch30: schroot-boost1.85.patch
BuildRequires: pam-devel
BuildRequires: boost-devel
BuildRequires: pkgconfig(lockdev)
BuildRequires: gettext
BuildRequires: pkgconfig(uuid)
BuildRequires: lvm2
BuildRequires: pkgconfig(cppunit)
BuildRequires: btrfs-progs
BuildRequires: debootstrap
BuildRequires: fakeroot
BuildRequires: groff
BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: gtest-devel
BuildRequires: po4a

Recommends: lvm2
Recommends: btrfs-progs

%description
schroot allows users to execute commands or interactive shells in
different chroots.  Any number of named chroots may be created, and
access permissions given to each, including root access for normal
users, on a per-user or per-group basis.  Additionally, schroot can
switch to a different user in the chroot, using PAM for
authentication and authorisation.  
All operations are logged for security.

Several different types of chroot are supported, including normal
directories in the filesystem, and also block devices.  Sessions,
persistent chroots created on the fly from files (tar with optional
compression and zip) and LVM snapshots are also supported.

schroot supports kernel personalities, allowing the programs run
inside the chroot to have a different personality.  For example,
running 32-bit chroots on 64-bit systems, or even running binaries
from alternative operating systems such as SVR4 or Xenix.

schroot also integrates with sbuild, to allow building packages with
all supported chroot types, including session-managed chroot types
such as LVM snapshots.

schroot shares most of its options with dchroot, but offers vastly
more functionality.

%package -n dchroot
Group: Development/Other
Summary: Older tool similar to schroot

%description -n dchroot
dchroot allows users to execute commands or interactive shells in different 
chroots. Users can move between chroots as necessary. Enhanced functionality 
is available in the next generation tool called schroot.

%package -n %libname
Group: Development/Other
Summary: sbuild library for schroot and dchroot


%description -n %libname
sbuild library for schroot and dchroot

%package -n %devname
Group: Development/Other
Summary: Development files for schroot and dchroot
Requires: %libname = %version
Provides: schroot-devel

%description -n %devname
Development files for schroot and dchroot


%prep
%setup -q
%patch -P0 -p0
%patch -P1 -p0
%patch -P2 -p0
%patch -P3 -p1 -b .gtest17
%patch -P27 -p1
%patch -P28 -p1
%patch -P29 -p1
%patch -P30 -p1

# Remove -Wall
sed -i -e 's/-Wall\s\+//g' cmake/CompilerChecks.cmake

%build
%cmake  -DCMAKE_INSTALL_LOCALSTATEDIR=%{_localstatedir} \
	-DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
	-Dlvm-snapshot=ON \
	-Dbtrfs-snapshot=ON \
	-Ddchroot=ON \
	-Ddchroot-dsa=ON \
	-DBTRFS_EXECUTABLE=%{_sbindir}/btrfs \
	-DLVCREATE_EXECUTABLE=%{_sbindir}/lvcreate \
	-DLVREMOVE_EXECUTABLE=%{_sbindir}/lvremove
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_localstatedir}/lib/schroot/session
mkdir -p %{buildroot}%{_sysconfdir}/schroot/chroot.d
/sbin/ldconfig -n %{buildroot}/%{_libdir}

sed -i 's/\${GIT_RELEASE_VERSION}/%{version}/' %{buildroot}%{_libdir}/pkgconfig/sbuild.pc

%find_lang %{name}

%files -f %{name}.lang
%doc COPYING AUTHORS ChangeLog HACKING NEWS README THANKS TODO
%{_bindir}/schroot
%dir %{_sysconfdir}/schroot
%dir %{_sysconfdir}/schroot/chroot.d
%config(noreplace) %{_sysconfdir}/schroot/schroot.conf
%config(noreplace) %{_sysconfdir}/pam.d/schroot
%dir %{_sysconfdir}/schroot/setup.d
%{_sysconfdir}/bash_completion.d/schroot
%{_sysconfdir}/schroot/default/copyfiles
%{_sysconfdir}/schroot/default/fstab
%{_sysconfdir}/schroot/default/nssdatabases
%{_sysconfdir}/schroot/desktop/copyfiles
%{_sysconfdir}/schroot/desktop/fstab
%{_sysconfdir}/schroot/desktop/nssdatabases
%{_sysconfdir}/schroot/minimal/copyfiles
%{_sysconfdir}/schroot/minimal/fstab
%{_sysconfdir}/schroot/minimal/nssdatabases
%{_sysconfdir}/schroot/buildd/copyfiles
%{_sysconfdir}/schroot/buildd/fstab
%{_sysconfdir}/schroot/buildd/nssdatabases
%{_sysconfdir}/schroot/sbuild/copyfiles
%{_sysconfdir}/schroot/sbuild/fstab
%{_sysconfdir}/schroot/sbuild/nssdatabases
%{_sysconfdir}/schroot/setup.d/00check
%{_sysconfdir}/schroot/setup.d/05btrfs
%{_sysconfdir}/schroot/setup.d/05file
%{_sysconfdir}/schroot/setup.d/05lvm
%{_sysconfdir}/schroot/setup.d/05union
%{_sysconfdir}/schroot/setup.d/10mount
%{_sysconfdir}/schroot/setup.d/15binfmt
%{_sysconfdir}/schroot/setup.d/15killprocs
%{_sysconfdir}/schroot/setup.d/20copyfiles
%{_sysconfdir}/schroot/setup.d/20nssdatabases
%{_sysconfdir}/schroot/setup.d/50chrootname
%{_sysconfdir}/schroot/setup.d/70services
%{_sysconfdir}/schroot/setup.d/99check
%dir %{_libexecdir}/schroot
%{_libexecdir}/schroot/listmounts
%{_libexecdir}/schroot/mount
%dir %{_localstatedir}/lib/schroot
%{_localstatedir}/lib/schroot/session
%{_localstatedir}/lib/schroot/mount
%{_datadir}/%{name}/setup/common-config
%{_datadir}/%{name}/setup/common-data
%{_datadir}/%{name}/setup/common-functions
%{_mandir}/man1/schroot.1.*
%{_mandir}/de/man1/schroot.1.*
%{_mandir}/fr/man1/schroot.1.*
%{_mandir}/man5/schroot*.5.*
%{_mandir}/man7/schroot*.7.*
%{_mandir}/de/man5/schroot*.5.*
%{_mandir}/de/man7/schroot*.7.*
%{_mandir}/fr/man5/schroot*.5.*
%{_mandir}/fr/man7/schroot*.7.*

%files -n dchroot
%{_bindir}/dchroot*
%{_mandir}/man1/dchroot*.1.*
%{_mandir}/de/man1/dchroot*.1.*
%{_mandir}/fr/man1/dchroot*.1.*

%files -n %libname
%{_libdir}/*.so.*

%files -n %devname
%dir %{_includedir}/sbuild
%{_includedir}/sbuild/*
%{_libdir}/libsbuild.so
%{_libdir}/pkgconfig/sbuild.pc

