%define major	%(echo %{version}|cut -d. -f1,2)
%define tcltk	8.6
%define app_id	io.github.benini.%{name}

Summary:	Shane's Chess Information Database
Name:		scid
Version:	5.1.0
Release:	%mkrel 1
Group:		Games/Boards
License:	GPLv2+
URL:		https://scid.sourceforge.net/
Source0:	https://sourceforge.net/projects/scid/files/Scid/Scid%20%{major}/scid%{version}-src.zip
Source1:	%{name}.png
Patch0:		scid-5.1.0-mga-gtest.patch
Patch1:		scid-5.1.0-mga-installdir.patch

BuildRequires:	cmake
BuildRequires:	tcl-devel
BuildRequires:	tk-devel
BuildRequires:	pkgconfig(gtest)

Recommends:	nail
Recommends:	tcl-snack
Conflicts:	scidvspc

%description
Scid (Shane's Chess Information Database) is a free chess database app.

With Scid you can maintain a database of chess games, search games by
many criteria, view graphical trends, and produce printable reports on
players and openings.

You can also analyze games with the Xboard or UCI compatible chess
program, and even use Scid to study endings with endgame tablebases.

With Scid you can also play against various engines, or on the Internet.

%prep
%autosetup -p1

# Force loading of system Tk library
sed -e "/^package require Tk /i load %{_libdir}/libtk%{tcltk}.so" \
    -i tcl/start.tcl

# Add building togaII engine directly into CMakeLists.txt file
cat << EOF | sed -e "/phalanx-scid DESTINATION bin/ r /dev/stdin" -i CMakeLists.txt

# engine togaII
file(GLOB TOGAII_SRC engines/togaII1.2.1a/src/*.cpp)
add_executable(togaII \${TOGAII_SRC})
set_target_properties(togaII PROPERTIES COMPILE_FLAGS "-w")
install(TARGETS togaII DESTINATION bin)
EOF

%build
2to3 --no-diffs -w scripts
sed -i -e '1s/python$/python3/' scripts/*.py
sed -i -E -e 's/string\.(strip|lower)\((.*)\)/\2.\1()/' scripts/*.py
sed -i -E -e 's/string\.join\(([^,]*), *([^)]*)\)/\2.join(\1)/' scripts/*.py

%cmake -DGTEST=ON \
       -DSPELLCHKVALIDATE=ON
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
cp flatpak/%{app_id}.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps
mkdir -p %{buildroot}%{_metainfodir}
cp flatpak/%{app_id}.appdata.xml %{buildroot}%{_metainfodir}

# Desktop entry
desktop-file-install flatpak/%{app_id}.desktop \
    --set-key=Exec --set-value="scid %f" \
    --dir %{buildroot}%{_datadir}/applications

# Licenses:
cp engines/phalanx-scid/COPYING COPYING_phalanx
cp engines/togaII*/copying.txt COPYING_togaII
cp src/polyglot/copying.txt COPYING_polyglot

%check
build/gtest/scid_tests

%files
%license COPYING{,_phalanx,_togaII,_polyglot}
%doc ChangeLog README.md help/
%{_bindir}/*
%{_libdir}/*.so
%{_datadir}/%{name}/
%{_datadir}/applications/%{app_id}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{app_id}.svg
%{_metainfodir}/%{app_id}.appdata.xml
