%define major 4
%define libname %mklibname subid %{major}
%define devname %mklibname subid -d

# (cg) Certain binaries build in this package are no longer wanted or are now 
# provided by other packages (e.g. coreutils, util-linux or passwd)
%define unwanted chfn chsh expiry groups login passwd porttime su suauth faillog logoutd nologin chgpasswd getspnam
# (cg) Some localised man pages are provided by the man-pages package rather
# than here so kill them off
# (Question: why?? See "urpmf share.*man.*/XXXX\\." where XXXX is one of the below)
%define unwanted_i18n_mans sg shadow

Name:		shadow-utils
Epoch:		3
Version:	4.13
Release:	%mkrel 3
Summary:	Utilities for managing shadow password files and user/group accounts
License:	BSD-3-Clause AND GPL-2.0-or-later
Group:		System/Base
URL:		https://github.com/shadow-maint/shadow
Source0:	https://github.com/shadow-maint/shadow/releases/download/%{version}/shadow-%{version}.tar.xz
Source1:	shadow-utils.login.defs
Source2:	shadow-970616.useradd
Source3:	adduser.8
Source4:	pwunconv.8
Source5:	grpconv.8
Source6:	grpunconv.8
Source7:	shadow-utils.HOME_MODE.xml
Source8:	user-group-mod.pamd
Source9:	chpasswd-newusers.pamd
Source10:	chage-chfn-chsh.pamd

Patch0:		shadow-4.1.5.1-rpmsave.patch
Patch1:		shadow-4.4-avx-owl-crypt_gensalt.patch
Patch2:		shadow-4.9-manfix.patch
Patch3:		shadow-4.9-libpam-link.patch
Patch4:		shadow-4.11.1-audit-update.patch
Patch7:		shadow-utils-configure-gshadow.patch
Patch8:		shadow-4.13-CVE-2023-4641.patch

BuildRequires:	gettext-devel
BuildRequires:  automake
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(libcrypt) >= 4.1.1-2
BuildRequires:	pam_userpass-devel
BuildRequires:  selinux-devel
BuildRequires:  semanage-devel
BuildRequires:	itstool
BuildRequires:	xsltproc
Requires:	setup >= 2.7.12-2
Requires:	pam_userpass
Requires(posttrans):	sed
Provides: 	adduser, newgrp
Provides:	/usr/sbin/useradd
Provides:	/usr/sbin/groupadd
Provides:	/usr/sbin/userdel
Provides:	/usr/sbin/groupdel
Conflicts:	msec < 0.47
Conflicts:	util-linux-ng < 2.13.1-6

%description
The shadow-utils package includes the necessary programs for
converting UNIX password files to the shadow password format, plus
programs for managing user and group accounts.  The pwconv command
converts passwords to the shadow password format.  The pwunconv command
unconverts shadow passwords and generates an npasswd file (a standard
UNIX password file).  The pwck command checks the integrity of
password and shadow files.  The lastlog command prints out the last
login times for all users.  The useradd, userdel and usermod commands
are used for managing user accounts.  The groupadd, groupdel and
groupmod commands are used for managing group accounts.

%package -n	%{libname}
Summary:	A library to manage subordinate uid and gid ranges
License:	BSD and GPLv2+
Group:		System/Libraries

%description -n	%{libname}
Utility library that provides a way to manage subid ranges.

%package -n	%{devname}
Summary:	Development package for shadow-utils-subid
License:	BSD and GPLv2+
Group:		Development/C

%description -n	%{devname}
Development files for shadow-utils-subid.

%prep
%autosetup -p1 -n shadow-%{version}

cp -a %{SOURCE7} man/login.defs.d/HOME_MODE.xml

%build
libtoolize --copy --force; aclocal; autoconf; automake --add-missing
%serverbuild
CFLAGS="%{optflags} -DEXTRA_CHECK_HOME_DIR" \
%configure \
        --enable-shadowgrp \
        --enable-man \
        --with-audit \
        --with-sha-crypt \
        --with-libpam \
        --with-bcrypt \
        --with-yescrypt \
	--with-selinux \
        --without-libcrack \
        --enable-shared \
        --with-group-name-max-length=32
%make_build
# because of the extra po file added manually
make -C po update-gmo

%install
%make_install gnulocaledir=%{buildroot}%{_datadir}/locale MKINSTALLDIRS=`pwd`/mkinstalldirs

install -d -m 750 %{buildroot}%{_sysconfdir}/default
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/login.defs
install -m 0600 %{SOURCE2} %{buildroot}%{_sysconfdir}/default/useradd


ln -s useradd %{buildroot}%{_sbindir}/adduser
mkdir -p %{buildroot}%{_mandir}/man8
install -m644 %{SOURCE3} %{buildroot}%{_mandir}/man8/
install -m644 %{SOURCE4} %{buildroot}%{_mandir}/man8/
install -m644 %{SOURCE5} %{buildroot}%{_mandir}/man8/
install -m644 %{SOURCE6} %{buildroot}%{_mandir}/man8/
perl -pi -e "s/encrpted/encrypted/g" %{buildroot}%{_mandir}/man8/newusers.8

# add pam support files
rm -rf %{buildroot}/etc/pam.d/
mkdir -p %{buildroot}/etc/pam.d/
install -m 0600 %{SOURCE8} %{buildroot}/etc/pam.d/user-group-mod
install -m 0600 %{SOURCE9} %{buildroot}/etc/pam.d/chpasswd-newusers
install -m 0600 %{SOURCE10} %{buildroot}/etc/pam.d/chage-chfn-chsh

pushd %{buildroot}/etc/pam.d
    for f in chpasswd newusers; do
        ln -s chpasswd-newusers ${f}
    done
    for f in chage; do
        # chfn and chsh are built without pam support in util-linux-ng
        ln -s chage-chfn-chsh ${f}
    done
    for f in groupadd groupdel groupmod useradd userdel usermod; do
        ln -s user-group-mod ${f}
    done
popd

# (cg) Remove unwanted binaries (and their corresponding man pages)
for unwanted in %{unwanted}; do
  rm -f %{buildroot}{%{_bindir},%{_sbindir}}/$unwanted
  rm -f %{buildroot}%{_mandir}/{,{??,??_??}/}man*/$unwanted.[[:digit:]]*
done

# (cg) Remove man pages provided by the "man-pages" package...
for unwanted in %{unwanted_i18n_mans}; do
  rm -f %{buildroot}%{_mandir}/{??,??_??}/man*/$unwanted.[[:digit:]]*
done

# (cg) Find all localised man pages
find %{buildroot}%{_mandir} -depth -type d -empty -delete
%find_lang shadow
for dir in $(ls -1d %{buildroot}%{_mandir}/{??,??_??}) ; do
  dir=$(echo $dir | sed -e "s|^%{buildroot}||")
  lang=$(basename $dir)
  echo "%%lang($lang) $dir/man*/*" >> shadow.lang
done

# Remove .la and .a files created by libsubid
rm -f %{buildroot}%{_libdir}/libsubid.la
rm -f %{buildroot}%{_libdir}/libsubid.a

%triggerin -p <lua> -- %{name} <= %{version}-%{release}
shadow_lock = "/etc/shadow.lock"
st = posix.stat(shadow_lock)
if st and st.type == "regular" and st.size == 0 then
  os.remove(shadow_lock)
end

%posttrans
# remove tcb and use sha512
sed -i 's/^CRYPT_PREFIX.*/ENCRYPT_METHOD SHA512/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^USE_TCB[ \t]+yes)/#USE_TCB                 yes/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_AUTH_GROUP[ \t]+yes)/#TCB_AUTH_GROUP          yes/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_SYMLINKS[ \t]+yes)/#TCB_SYMLINKS          yes/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^USE_TCB[ \t]+no)/#USE_TCB                 no/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_AUTH_GROUP[ \t]+no)/#TCB_AUTH_GROUP          no/g' %{_sysconfdir}/login.defs
sed -i -re 's/(^TCB_SYMLINKS[ \t]+no)/#TCB_SYMLINKS          no/g' %{_sysconfdir}/login.defs

%files -f shadow.lang
%doc doc/HOWTO NEWS
%doc doc/WISHLIST doc/README.platforms
%attr(0644,root,root)	%config(noreplace) %{_sysconfdir}/login.defs
%attr(0600,root,root)	%config(noreplace) %{_sysconfdir}/default/useradd
%{_bindir}/sg
%attr(2711,root,shadow) %{_bindir}/chage
%attr(4711,root,root)   %{_bindir}/gpasswd
%attr(0711,root,root) %caps(cap_setgid=ep) %{_bindir}/newgidmap
%attr(4711,root,root)   %{_bindir}/newgrp
%attr(0711,root,root) %caps(cap_setuid=ep) %{_bindir}/newuidmap
%{_bindir}/lastlog
%{_bindir}/getsubids
%{_sbindir}/adduser
%{_sbindir}/user*
%{_sbindir}/group*
%{_sbindir}/grpck
%{_sbindir}/pwck
%{_sbindir}/*conv
%{_sbindir}/chpasswd
%{_sbindir}/newusers
%{_sbindir}/vipw
%{_sbindir}/vigr
%{_mandir}/man1/chage.1*
%{_mandir}/man1/newgidmap.1*
%{_mandir}/man1/newgrp.1*
%{_mandir}/man1/newuidmap.1*
%{_mandir}/man1/sg.1*
%{_mandir}/man1/gpasswd.1*
%{_mandir}/man1/getsubids.1*
%{_mandir}/man3/shadow.3*
%{_mandir}/man5/gshadow.5*
%{_mandir}/man5/login.defs.5*
%{_mandir}/man5/shadow.5*
%{_mandir}/man5/subgid.5*
%{_mandir}/man5/subuid.5*
%{_mandir}/man8/adduser.8*
%{_mandir}/man8/group*.8*
%{_mandir}/man8/user*.8*
%{_mandir}/man8/pwck.8*
%{_mandir}/man8/grpck.8*
%{_mandir}/man8/chpasswd.8*
%{_mandir}/man8/newusers.8*
%{_mandir}/man8/vipw.8*
%{_mandir}/man8/vigr.8*
%{_mandir}/man8/*conv.8*
%{_mandir}/man8/lastlog.8*
%attr(640,root,shadow) %config(noreplace) /etc/pam.d/chage-chfn-chsh
/etc/pam.d/chage
%attr(640,root,shadow) %config(noreplace) /etc/pam.d/chpasswd-newusers 
/etc/pam.d/chpasswd
/etc/pam.d/newusers
%attr(640,root,shadow) %config(noreplace) /etc/pam.d/user-group-mod
/etc/pam.d/useradd
/etc/pam.d/userdel
/etc/pam.d/usermod
/etc/pam.d/groupadd
/etc/pam.d/groupdel
/etc/pam.d/groupmod

%files -n %{libname}
%{_libdir}/libsubid.so.%{major}
%{_libdir}/libsubid.so.%{major}.*

%files -n %{devname}
%{_includedir}/shadow/subid.h
%{_libdir}/libsubid.so
