Name:		shared-mime-info
Version:	2.4
Release:	%mkrel 5
Summary:	Shared MIME-Info Specification
Group:		Graphical desktop/Other
#gw main is GPL, test program is LGPL
License:	GPL+ and LGPLv2+
URL:		https://www.freedesktop.org/wiki/Software/shared-mime-info
Source0:	https://gitlab.freedesktop.org/xdg/shared-mime-info/-/archive/%{version}/%{name}-%{version}.tar.gz
####
#### Fedora:
####
Source1:	mimeapps.list

# Tarball for https://gitlab.freedesktop.org/xdg/xdgmime/-/tree/179296748e92bd91bf531656632a1056307fb7b7
Source6:	https://gitlab.freedesktop.org/xdg/xdgmime/-/archive/master/xdgmime-master.tar.gz

# Mageia KDE overrides.
Source20:	plasma-mimeapps.list

# Work-around for https://bugs.freedesktop.org/show_bug.cgi?id=40354
Patch0:		0001-Remove-sub-classing-from-OO.o-mime-types.patch

Patch100:	shared-mime-info-xz.patch

BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	xmlto
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	intltool
BuildRequires:	itstool
BuildRequires:	libxml2-utils
BuildRequires:	meson
Provides:	gnome-mime-data
Conflicts:	cinnamon-desktop < 4.0.1-4
Conflicts:	mageia-kde4-config-common < 5-0.20150505.13

# Disable pkgconfig autodep
%global __requires_exclude ^/usr/bin/pkg-config$

%description
This is the freedesktop.org shared MIME info database.

Many programs and desktops use the MIME system to represent the types of
files. Frequently, it is necessary to work out the correct MIME type for
a file. This is generally done by examining the file's name or contents,
and looking up the correct MIME type in a database.

For interoperability, it is useful for different programs to use the
same database so that different programs agree on the type of a file,
and new rules for determining the type apply to all programs.

This specification attempts to unify the type-guessing systems currently
in use by GNOME, KDE and ROX. Only the name-to-type and contents-to-type
mappings are covered by this spec; other MIME type information, such as
the default handler for a particular type, or the icon to use to display
it in a file manager, are not covered since these are a matter of style.

In addition, freedesktop.org provides a shared database in this format
to avoid inconsistencies between desktops. This database has been
created by converting the existing KDE and GNOME databases to the new
format and merging them together.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 100 -p1

rmdir xdgmime
tar -xzf %{SOURCE6}
mv xdgmime-*/ xdgmime/

%build
%make_build -C xdgmime || :
# the updated mimedb is later owned as %%ghost to ensure proper file-ownership
# it also asserts it is possible to build it
%meson -Dupdate-mimedb=true
%meson_build

%install
%meson_install

find %{buildroot}%{_datadir}/mime -type d \
| sed -e "s|^%{buildroot}|%%dir |" > %{name}.files
find %{buildroot}%{_datadir}/mime -type f -not -path "*/packages/*" \
| sed -e "s|^%{buildroot}|%%ghost |" >> %{name}.files

# install mimeapps.list files
mkdir -p %{buildroot}%{_datadir}/applications
install -pm644 %{SOURCE1} %{SOURCE20} %{buildroot}%{_datadir}/applications
cp -p %{buildroot}%{_datadir}/applications/plasma-mimeapps.list %{buildroot}%{_datadir}/applications/kde-mimeapps.list

## remove bogus translation files
## translations are already in the xml file installed
rm -rf %{buildroot}%{_datadir}/locale/*

# fix x-rpm entry
sed -i 's!application/x-rpm=.*!application/x-rpm=%{_real_vendor}-gurpmi.desktop;gurpmi.desktop;!' \
	%{buildroot}%{_datadir}/applications/mimeapps.list

## Xfce starts
sed \
    -e 's,brasero,xfburn,g' \
    -e 's,evolution,exo-mail-reader,g' \
    -e 's,firefox,exo-web-browser,g' \
    -e 's,org.gnome.eog,org.xfce.ristretto,g' \
    -e 's,org.gnome.Evince,atril,g' \
    -e 's,org.gnome.FileRoller,engrampa,g' \
    -e 's,org.gnome.gedit,org.xfce.mousepad,g' \
    -e 's,org.gnome.Nautilus,exo-file-manager,g' \
    -e 's,org.gnome.Rhythmbox3,org.xfce.Parole.desktop,g' \
    -e 's,org.gnome.Totem,org.xfce.Parole.desktop,g' \
    %{buildroot}%{_datadir}/applications/mimeapps.list >> %{buildroot}%{_datadir}/applications/xfce-mimeapps.list
## Xfce ends

## Cinnamon
# $XDG_CURRENT_DESKTOP in cinnamon is X-Cinnamon
sed -e 's,\(eog.desktop\),pix.desktop;\1,g' \
    -e 's,\(org.gnome.Evince.desktop\),xreader.desktop;\1,g' \
    -e 's,\(org.gnome.gedit.desktop\),xed.desktop;\1,g' \
    -e 's,\(org.gnome.Totem.desktop\),xplayer.desktop;\1,g' \
    -e 's,org.gnome.Nautilus,nemo,g' \
    %{buildroot}%{_datadir}/applications/mimeapps.list >> %{buildroot}%{_datadir}/applications/x-cinnamon-mimeapps.list
## Cinnamon ends

%check
%meson_test

%post
/bin/touch --no-create %{_datadir}/mime/packages &>/dev/null ||:

# automatic mime database update on rpm installs/removals
%transfiletriggerin -- %{_datadir}/mime
update-mime-database -n %{_datadir}/mime &> /dev/null ||:

%transfiletriggerpostun -- %{_datadir}/mime
update-mime-database -n %{_datadir}/mime &> /dev/null ||:

%files -f %{name}.files
%doc README.md data/shared-mime-info-spec.xml NEWS
%{_bindir}/update-mime-database
%{_datadir}/applications/kde-mimeapps.list
%{_datadir}/applications/plasma-mimeapps.list
%{_datadir}/applications/mimeapps.list
%{_datadir}/applications/x-cinnamon-mimeapps.list
%{_datadir}/applications/xfce-mimeapps.list
%{_datadir}/mime/packages/freedesktop.org.xml
%{_mandir}/man1/update-mime-database.1*
%{_datadir}/pkgconfig/shared-mime-info.pc
%{_datadir}/gettext/its/shared-mime-info.its
%{_datadir}/gettext/its/shared-mime-info.loc
