%define pyname  Shiboken6

%define qttarballdir pyside-setup-everywhere-src

%define toolchain clang

Name:           shiboken6
Version:        6.8.3
Release:        %mkrel 1
License:        LGPLv2+
Summary:        Creates the PySide6 bindings source files for Qt6
Group:          Development/KDE and Qt
URL:            https://wiki.qt.io/Qt_for_Python
Source0:        https://download.qt.io/official_releases/QtForPython/pyside6/PySide6-%{version}-src/%{qttarballdir}-%{version}.tar.xz
# From opensuse
Patch0:         0001-Always-link-to-python-libraries.patch
# Upstream patches

BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6Test)

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libxml-2.0)

BuildRequires:  clang-devel
BuildRequires:  llvm-devel >= 17.0.6-6

Requires:       python3-%{name} = %{version}-%{release}

### Python 3

%description
The Shiboken6 Generator (A.K.A. shiboken) is the plugin that creates the
PySide6 bindings source files from Qt6 headers and auxiliary files
(type systems, global.h and glue files).

%files
%{_bindir}/%{name}
%{_bindir}/shiboken_tool.py

#------------------------------------------------------------------------------

%package -n     python3-%{name}
Summary:        Creates the Python3 PySide6 bindings source files for Qt6
Group:          Development/KDE and Qt

%description -n python3-%{name}
The Shiboken6 Generator (A.K.A. shiboken) is the plugin that creates the
Python3 PySide6 bindings source files from Qt6 headers and auxiliary files
(type systems, global.h and glue files).

%files -n python3-%{name}
%{python3_sitearch}/%{name}/
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info/
%{python3_sitearch}/%{name}_generator/
%{python3_sitearch}/%{name}_generator-%{version}-py%{python3_version}.egg-info/

#------------------------------------------------------------------------------

%define py3major   6.8
%define py3libname %mklibname %{name}-abi3_ %{py3major}

%package -n     %{py3libname}
Summary:        Shiboken6 Generator core library
Group:          System/Libraries

%description -n %{py3libname}
Python3 Shiboken6 Generator core library.

%files -n %{py3libname}
%{_libdir}/lib%{name}.abi3.so.%{py3major}{,.*}

#------------------------------------------------------------------------------

%define py3libname_dev %mklibname %{name} -d

%package -n     %{py3libname_dev}
Summary:        Development files for Python3 Shiboken6 Generator
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}-%{release}
Requires:       %{py3libname} = %{version}-%{release}
Requires:       python3-%{name} = %{version}-%{release}
Requires:       clang-devel
Requires:       llvm-devel
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{_lib}%{name}-python%{python3_version}-devel = %{version}-%{release}

%description -n %{py3libname_dev}
Development files for Python3 Shiboken6 Generator.

%files -n %{py3libname_dev}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.abi3.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/Shiboken6Tools/
%{_libdir}/cmake/Shiboken6/

### End of Python 3
#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{qttarballdir}-%{version}

# Fix installation dir
sed -i 's#purelib#platlib#' sources/shiboken6/cmake/ShibokenHelpers.cmake

%build
export CLANG_INSTALL_DIR="%{_prefix}"

%global _vpath_srcdir sources/shiboken6
%cmake_qt6 \
  -DBUILD_TESTS:BOOL=ON \
  -DNUMPY_INCLUDE_DIR:STRING=%{python3_sitearch}/numpy/_core/include \
  -DCMAKE_SKIP_RPATH:BOOL=ON \
  -DQFP_NO_STRIP:BOOL=ON
%cmake_build

%install
%cmake_install

#
# Generate egg-info manually and install since we're performing a cmake build.
#
# Copy CMake configuration files from the BINARY dir back to the SOURCE dir so
# setuptools can find them.
cp %{_vpath_builddir}/shibokenmodule/{*.py,*.txt} sources/shiboken6/shibokenmodule/
%{__python3} setup.py egg_info
for name in shiboken6 shiboken6_generator; do
  mkdir -p %{buildroot}%{python3_sitearch}/$name-%{version}-py%{python3_version}.egg-info
  cp -p $name.egg-info/{PKG-INFO,top_level.txt} \
        %{buildroot}%{python3_sitearch}/$name-%{version}-py%{python3_version}.egg-info/
done

# Python shebang
%py3_shebang_fix %{buildroot}%{_bindir}/*

%check
# the pyside tests need to know the path to the 'qmake' executable
export PATH=%{_qt6_bindir}:$PATH

# Needed by the shiboken tests
export LD_LIBRARY_PATH=%{buildroot}%{_qt6_libdir}:$LD_LIBRARY_PATH
# Since we need CMAKE_SKIP_RPATH to avoid having bogus RUNPATH in the shiboken libraries,
# It needs to know the path to a couple tests folders
for dir in libminimal libother libsample libsmart; do
  export LD_LIBRARY_PATH=$PWD/sources/shiboken6/tests/$dir:$LD_LIBRARY_PATH
done

pushd sources/shiboken6
%{?xvfb_command}
ctest \
  --output-on-failure \
  --force-new-ctest-process \
  --test-dir . \
  --parallel %{_smp_build_ncpus} \
  --debug \
  %{?excluded_tests:--exclude-regex "($ctest_exclude_regex)"}
popd
