%define rev     4982

%define rel     1

Name:           skychart
Version:        4.3
Release:        %mkrel -c %{rev} %{rel}
Summary:        An advanced planetarium and ephemeris software for astronomy
Group:          Sciences/Astronomy
License:        GPLv2+
URL:            https://www.ap-i.net/skychart/start
# (Fedora) Skychart contains iridflare.exe
# Since it is pre-built code and the license is not clear
# we remove it from sources.
# Download upstream tarball and invoke this script
# while in tarballs directory:
# ./generate-tarball.sh 3.10-2854
Source0:        %{name}-%{version}-%{rev}-src-nopatents.tar.xz
Source1:        generate-tarball.sh
# Source data for skychart-data-stars
Source2:        https://sourceforge.net/projects/skychart/files/4-source_data/catalog_gcvs.tgz
Source3:        https://sourceforge.net/projects/skychart/files/4-source_data/catalog_tycho2.tgz
Source4:        https://sourceforge.net/projects/skychart/files/4-source_data/catalog_wds.tgz
Source5:        https://sourceforge.net/projects/skychart/files/4-source_data/catalog_idx.tgz
# Source data for skychart-data-dso
Source6: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_leda.tgz
Source7: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_barnard.tgz
Source8: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_gcm.tgz
Source9: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_gpn.tgz
Source10: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_lbn.tgz
Source11: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_ocl.tgz
Source12: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_sh2.tgz
#Source data for gaia1
#Removed, DR3 can be directly retrived from skychart>=4.3
#not obsoleted as left-over package will still work

#base catalogs, needed at built time
Source30: https://sourceforge.net/projects/skychart/files/4-source_data/data_spicesun.tgz
Source31: https://sourceforge.net/projects/skychart/files/4-source_data/catalog_vdb.tgz


# Avoid stripping debuginfo from executables
# This is Fedora specific and not reported upstream
Patch:          skychart-4.3-nostrip.patch

# Disable wget in install script
# This is Fedora specific and not reported upstream
Patch:          skychart-wgetdata.patch

# Notify the user that artificial satellites calculation
# has been disabled in Fedora RPMs due to Fedora policies
# This is Fedora specific and not reported upstream
Patch:          skychart-4.3-satmessage.patch

# Disable software update menu item
# This feature was asked upstream specifically for Fedora
Patch:          skychart-4.3-noupdatemenu.patch

BuildRequires:  lazarus >= 1.0.8
BuildRequires:  ImageMagick
BuildRequires:  dos2unix
BuildRequires:  qt5pas-devel
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(chealpix)
Requires:       xdg-utils
Requires:       tzdata
Requires:       xplanet
Requires:       libpasastro

Recommends:       %{name}-wikidoc = %{version}-%{release}

%description
Skychart (Cartes du Ciel in french) draws sky charts, making use of
the data from many professional catalogs for stars, nebulae and
cosmological objects. In addition, the position of planets, asteroids
and comets are also computed and updated online using latest
ephemeridis parameters. Skychart allows you to prepare different sky
maps for particular observations, ranging from amator astronomy to
professional night planning. A large number of parameters help you to
choose specifically, or automatically, which catalogs to use, the
colour and the dimension of stars and nebulae, the representation of
planets, the display of labels and coordinate grids, the superposition
of pictures, the condition of visibility and more. At last, it allows
you to remotely control telescopes' mount for easy go to. Probably one
of the best astronomical software in its category.

%files
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/cat
%{_bindir}/*
%{_metainfodir}/*.catgen.metainfo.xml
%{_metainfodir}/*.skychart.metainfo.xml
%{_metainfodir}/*.varobs.metainfo.xml
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/%{name}/data/
%{_datadir}/%{name}/cat/DSoutlines
%{_datadir}/%{name}/cat/milkyway
%{_datadir}/%{name}/cat/RealSky
%{_datadir}/%{name}/cat/xhip
%{_datadir}/%{name}/cat/vdb
%{_datadir}/%{name}/doc/
%{_iconsdir}/hicolor/*/apps/*.{png,svg}
%{_datadir}/mime//packages/*.skychart.xml
%exclude %{_datadir}/%{name}/doc/wiki_doc
%exclude %{_datadir}/doc/%{name}/changelog
%exclude %{_datadir}/doc/%{name}/copyright

#-----------------------------------------------------------------

%package        wikidoc
Summary:        Wiki documentation for Skychart
License:        CC-BY-SA or GFDL
BuildArch:      noarch

%description    wikidoc
The wiki documentation of Skychart, translated into various
languages.

Skychart can do the job without this package but you'll receive an error
from the application when trying to get help.

%files          wikidoc
%{_datadir}/%{name}/doc/wiki_doc

#-----------------------------------------------------------------

%package        data-stars
Summary:        Additional star catalogs for Skychart
License:        Public Domain
BuildArch:      noarch

%description    data-stars
Additional star catalogs for Skychart. This package install all the standard
stars catalog down to magnitude 12, variable and double stars:
Tycho 2; General Catalogue of Variable Stars; Washington Double Stars.

%files          data-stars
%{_datadir}/%{name}/cat/gcvs
%{_datadir}/%{name}/cat/tycho2
%{_datadir}/%{name}/cat/wds
%{_datadir}/%{name}/cat/bsc5
%{_metainfodir}/*data_stars.metainfo.xml

#-----------------------------------------------------------------

%package        data-dso
Summary:        Additional Deep Sky Object catalogs for Skychart
License:        Public Domain
BuildArch:      noarch

%description    data-dso
Additional DSO catalogs for Skychart. This package install all the standard
nebulae catalogs: New General Catalogue; Principal Galaxies Catalogue;
Lynds Bright Nebulae; Open Cluster Data; Globular Clusters in the Milky Way;
Galactic Planetary Nebulae.

%files          data-dso
%{_datadir}/skychart/cat/leda
%{_datadir}/skychart/cat/lbn
%{_datadir}/skychart/cat/ocl
%{_datadir}/skychart/cat/gcm
%{_datadir}/skychart/cat/gpn
%{_datadir}/skychart/cat/barnard
%{_datadir}/skychart/cat/sh2
%{_datadir}/skychart/cat/openngc
%{_metainfodir}/*data_dso.metainfo.xml

#-----------------------------------------------------------------



%prep
%autosetup -p1 -n %{name}-%{version}-%{rev}-src

find skychart -type f -print0 |xargs -0 chmod 644

# Fix exotic EOL encodings
dos2unix -q -k tools/doc/html_doc/en/feature_class_fichiers/common.css
dos2unix -q -k tools/doc/html_doc/en/feature_class_fichiers/custom.css
dos2unix -q -k tools/doc/releasenotes*.txt

# Put additional catalogs files where where required for installation
cp -p %SOURCE2 ./BaseData
cp -p %SOURCE3 ./BaseData
cp -p %SOURCE4 ./BaseData
cp -p %SOURCE5 ./BaseData
cp -p %SOURCE6 ./BaseData
cp -p %SOURCE7 ./BaseData
cp -p %SOURCE8 ./BaseData
cp -p %SOURCE9 ./BaseData
cp -p %SOURCE10 ./BaseData
cp -p %SOURCE11 ./BaseData
cp -p %SOURCE12 ./BaseData

# base catalogs
cp -p %SOURCE30 ./BaseData
cp -p %SOURCE31 ./BaseData


mkdir -p {skychart/{component/lib,units},varobs/units}/arm-linux-gtk2

%build
# Not using the %%configure macro because this is not an autotools script
./configure lazarus=%{_libdir}/lazarus prefix=%{_prefix}

# not concurrency-safe
# We pass the following options to fpc compiler:
# - O2 for code optimization level
# - gw4 for generating dwarf 4 debug symbols
# - Cg to generate PIC code
%__make fpcopts="-O2 -gw4 -Cg"

%install
# Install main program
make install PREFIX=%{buildroot}%{_prefix}

# Install catalogs, translations and data files
make install install_data PREFIX=%{buildroot}%{_prefix}

# Install wiki documentation
make install install_doc PREFIX=%{buildroot}%{_prefix}

# Install additional catalogs
make install install_cat1 PREFIX=%{buildroot}%{_prefix}
make install install_cat2 PREFIX=%{buildroot}%{_prefix}

