%define shortname slic3r

Name:           %{shortname}-experimental
Version:        1.2.9
Release:        %mkrel 2
Summary:        G-code generator for 3D printers (RepRap, Makerbot, Ultimaker etc.)
License:        AGPLv3
# Images are CC-BY, code is AGPLv3
Group:          Sciences/Other
URL:            https://slic3r.org/
#The download URL is https://github.com/alexrj/Slic3r/archive/%%{version}.tar.gz, but the file
# comes down with the traditional tarball naming convention
Source0:        Slic3r-%{version}.tar.gz

# Modify Build.PL so we are able to build this on Fedora
Patch0:         %{shortname}-fdr-buildpl.patch

# Don't warn for Perl == 5.16
# Use /usr/share/slic3r as datadir
# Those two are located at the same place at the code, so the patch is merged
Patch1:         %{shortname}-1.2.9-fdr-mga-nowarn-datadir.patch
Patch2:         %{shortname}-fdr-english-locale.patch
Patch3:         %{shortname}-fdr-linker.patch
Patch6:         %{shortname}-1.2.4-fdr-mga-clipper.patch

Source1:        %{shortname}.desktop
Source2:        %{shortname}.appdata.xml

BuildRequires:  perl-devel
BuildRequires:  perl(Class::XSAccessor)
BuildRequires:  perl(Encode::Locale)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.80
BuildRequires:  perl(ExtUtils::ParseXS) >= 3.22
BuildRequires:  perl(ExtUtils::Typemap)
BuildRequires:  perl(ExtUtils::Typemaps::Default) >= 1.50.0
BuildRequires:  perl(File::Basename)
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Growl::GNTP) >= 0.15
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(List::Util)
BuildRequires:  perl(Math::ConvexHull::MonotoneChain)
BuildRequires:  perl(Math::ConvexHull) >= 1.0.4
BuildRequires:  perl(Math::Geometry::Voronoi) >= 1.3
BuildRequires:  perl(Math::PlanePath) >= 53
BuildRequires:  perl(Module::Build::WithXSpp) >= 0.14
BuildRequires:  perl(Moo) >= 1.6.0
BuildRequires:  perl(parent)
BuildRequires:  perl(Scalar::Util)
BuildRequires:  perl(Storable)
BuildRequires:  perl(SVG)
BuildRequires:  perl(Test::Harness)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Time::HiRes)
BuildRequires:  perl(Wx)
BuildRequires:  perl(XML::SAX)
BuildRequires:  perl(XML::SAX::ExpatXS)
BuildRequires:  perl(Module::Build)

BuildRequires:  admesh-devel >= 0.98.1
BuildRequires:  boost-devel
BuildRequires:  desktop-file-utils
BuildRequires:  poly2tri-devel
BuildRequires:  polyclipping-devel >= 6.2.0
BuildRequires:  ImageMagick

Requires:       perl(XML::SAX)
Requires:       perl(threads) >= %perl_convert_version 1.96
#This duplicate added, because otherwise RPM is resolving 1.92 as meeting the 1.96+ requirement
Requires:       perl-threads >= %perl_convert_version 1.96

Provides:       %{shortname} = %{version}
Conflicts:      %{shortname}-stable

%description
Slic3r is a G-code generator for 3D printers. It's compatible with RepRaps,
Makerbots, Ultimakers and many more machines.
See the project homepage at slic3r.org and the documentation on the Slic3r wiki
for more information.
This is the experimental version.  If you experience problems, please try
%{shortname}-stable instead.

%prep
%setup -qn Slic3r-%{version}

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 6 -p1

# Remove bundled admesh, clipper, poly2tri and boost
%__rm -rf xs/src/admesh
%__rm xs/src/clipper.*pp
%__rm -rf xs/src/poly2tri
%__rm -rf xs/src/boost


%build

cd xs
%__perl ./Build.PL installdirs=vendor optimize="$RPM_OPT_FLAGS"
./Build
cd -
# Building non XS part only runs test, so skip it and run it in tests

# prepare pngs in mutliple sizes
for res in 16 32 48 128 256; do
  %__mkdir_p hicolor/${res}x${res}/apps
done
cd hicolor
%{_bindir}/convert ../var/Slic3r.ico %{shortname}.png
cp %{shortname}-0.png 256x256/apps/%{shortname}.png
cp %{shortname}-1.png 128x128/apps/%{shortname}.png
cp %{shortname}-2.png 48x48/apps/%{shortname}.png
cp %{shortname}-3.png 32x32/apps/%{shortname}.png
cp %{shortname}-4.png 16x16/apps/%{shortname}.png
%__rm %{shortname}-*.png
cd -

# To avoid "iCCP: Not recognized known sRGB profile that has been edited"
cd var
%{_bindir}/find . -type f -name "*.png" -exec convert {} -strip {} \;
cd -

%install
cd xs
./Build install destdir=%{buildroot} create_packlist=0
cd -
%{_bindir}/find %{buildroot} -type f -name '*.bs' -size 0 -exec rm -f {} \;

# I see no way of installing slic3r with it's build script
# So I copy the files around manually
%__mkdir_p %{buildroot}%{_bindir}
%__mkdir_p %{buildroot}%{perl_vendorlib}
%__mkdir_p %{buildroot}%{_datadir}/%{shortname}
%__mkdir_p %{buildroot}%{_datadir}/icons
%__mkdir_p %{buildroot}%{_datadir}/appdata

cp -a %{shortname}.pl %{buildroot}%{_bindir}/%{shortname}
cp -ar lib/* %{buildroot}%{perl_vendorlib}

cp -a var/* %{buildroot}%{_datadir}/%{shortname}
cp -r hicolor %{buildroot}%{_datadir}/icons
%{_bindir}/desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}

cp %{SOURCE2} %{buildroot}%{_datadir}/appdata/%{shortname}.appdata.xml

%{_fixperms} %{buildroot}*

#make test fails, so removed

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    %{_bindir}/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
%{_bindir}/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%doc README.md
%{_bindir}/%{shortname}
%{perl_vendorlib}/Slic3r*
%{perl_vendorarch}/Slic3r*
%{perl_vendorarch}/auto/Slic3r*
%{_datadir}/icons/hicolor/*/apps/%{shortname}.png
%{_datadir}/applications/%{shortname}.desktop
%{_datadir}/appdata/%{shortname}.appdata.xml
%{_datadir}/%{shortname}

