%define         major                    42

%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d
%define         staticdevelname          %mklibname %{name} -s -d


%ifnarch %arm32 %ix86
%bcond_without  mpi
%else
%bcond_with     mpi
%endif


Summary:        A highly configurable open-source workload manager
Name:           slurm
Version:        24.11.0
Release:        %mkrel 1
License:        GPLv2+
Group:          System/Cluster

Url:            https://www.schedmd.com/index.php

Source0:        https://download.schedmd.com/slurm/%{name}-%{version}.tar.bz2
Source1:        slurm.conf
Source2:        slurmd.service
Source3:        slurmctld.service
Source4:        slurmdbd.service
Source5:        slurm-tmpfiles.conf
Source6:        slurmdbd.conf
Source7:        cgroup.conf

BuildRequires:  pkg-config
BuildRequires:  autoconf
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  man2html
BuildRequires:  hwloc
BuildRequires:  pkgconfig(hwloc)
BuildRequires:  pkgconfig(lua)
%ifnarch %arm
BuildRequires:  pkgconfig(numa)
%endif
BuildRequires:  pkgconfig(mariadb)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libfreeipmi)
BuildRequires:  pkgconfig(librrd)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(libcgroup)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  readline-devel
BuildRequires:  hdf5
BuildRequires:  hdf5-devel
BuildRequires:  yaml-devel
BuildRequires:  pam-devel
BuildRequires:  http-parser-devel
%if %{with mpi}
BuildRequires:  openpmix-devel
%endif

Requires(pre):    rpm-helper >= %{rpmhelper_required_version}
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}




%description
Slurm is a highly configurable open-source workload manager designed
specifically to satisfy the demanding needs of high performance
computing. Slurm is in widespread use at government laboratories,
universities and companies world wide and performs workload management
for over half of the top 10 systems in the TOP500. Use of optional
plugins provides the functionality needed to satisfy the needs of
demanding high performance computing centers. More complex
configurations rely upon a database for archiving accounting records,
managing resource limits by user or bank account, and supporting
sophisticated scheduling algorithms.



%package -n %{libname}
Summary:        Shared libraries for Slurm
Group:          Development/Other
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
%{summary}.



%package -n %{develname}
Summary:        Development files for Slurm
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-devel  = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
%{summary}.



%package -n %{staticdevelname}
Summary:        Static Development files for Slurm
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-static-devel  = %{version}-%{release}
Provides:       %{name}-static-devel = %{version}-%{release}

%description -n %{staticdevelname}
%{summary}.




%prep

%setup -q


%build
%configure      \
%ifarch %ix86 %arm
               --enable-deprecated \
%endif
%if %{with mpi}
                --with-pmix=%{_prefix} \
%else
                --without-pmix \
%endif		
                --without-rpath \
                --without-nvml  \
                --without-rsmi \
		--without-munge
%make_build


%install
%make_install

%{__install} -D -p -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/slurmd.service
%{__install} -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/slurmctld.service
%{__install} -D -p -m 0600 %{SOURCE4} %{buildroot}%{_unitdir}/slurmdbd.service
%{__install} -D -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/slurmdbd.conf
%{__install} -D -p -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/cgroup.conf

%{__install} -d -m 755 %{buildroot}/%{_localstatedir}/spool/slurmctld
%{__install} -d -m 755 %{buildroot}/%{_logdir}/slurm

find %{buildroot}%{_libdir} -name *.la -delete



%pre
%_pre_useradd %{name} /dev/null /bin/false
%_pre_groupadd %{name}

%post
%_tmpfilescreate %{name}
%_post_service slurmd
%_post_service slurmctld
%_post_service slurmdbd

%preun
%_preun_service slurmd
%_preun_service slurmctld
%_preun_service slurmdbd

%postun
%_postun_userdel %{name}



%files
%doc README.rst AUTHORS CONTRIBUTING.md COPYING DISCLAIMER NEWS RELEASE_NOTES
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %attr(0600,%{name},%name) %{_sysconfdir}/slurmdbd.conf
%config(noreplace) %{_sysconfdir}/cgroup.conf
%{_unitdir}/slurmd.service
%{_unitdir}/slurmctld.service
%{_unitdir}/slurmdbd.service
%{_tmpfilesdir}/%{name}.conf
%attr(-, slurm, slurm) %dir %{_localstatedir}/spool/slurmctld
%attr(-, slurm, slurm) %dir %{_logdir}/slurm

%{_sbindir}/*
%{_bindir}/*
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man8/*.8*
%{_docdir}/%{name}-%{version}

%files -n %{libname} 
%{_libdir}/libslurm.so.%{major}{,.*}
#looks like these guys are modules, not devel files
%{_libdir}/slurm/*.so

%files -n %{develname}
%{_includedir}/slurm
%{_libdir}/*.so
%{_libdir}/%{name}/src

%files -n %{staticdevelname}
%{_libdir}/*.a
%{_libdir}/%{name}/*.a
