# WARNING: This package is synchronized with Fedora!

%define major 4
%define libname %mklibname %name %major
%define libname_devel %mklibname -d %name

%global btrfs_version 3.16.2
%global util_linux_version 2.24

Name:		snapper
Version:	0.5.6
Release:	%mkrel 19
License:	GPLv2
Group:		File tools
BuildRequires:	boost-devel
BuildRequires:	gettext
BuildRequires:	libtool
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(libxslt)
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	libacl-devel
BuildRequires:	btrfs-devel >= %{btrfs_version}
BuildRequires:	pkgconfig(mount) >= %{util_linux_version}
BuildRequires:	e2fsprogs-devel

Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	diffutils
Summary:	Tool for filesystem snapshot management
URL:		http://snapper.io

Source0:	https://ftp.suse.com/pub/projects/snapper/%{name}-%{version}.tar.bz2

# Patches from Fedora
Patch0:		%{name}-remove-ext4-info-xml.patch
Patch1:		%{name}-securelibdir.patch

# Patches from upstream
Patch100:	1453b7f147e25875d10c3e66e337093603d9e27e.patch

# Mageia
Patch200:	snapper-0.5.0-pthread.patch
Patch201:	snapper-autoconf.patch
Patch202:	snapper-missing-include.patch

%description
This package contains snapper, a tool for filesystem snapshot management.

%package -n %{libname}
Summary:	Library for filesystem snapshot management
Group:		System/Libraries
Requires:	util-linux >= %{util_linux_version}
Requires:	btrfs-progs >= %{btrfs_version}

%description -n %{libname}
This package contains the snapper shared library
for filesystem snapshot management.

%package -n %{libname_devel}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Requires:	libstdc++-devel
Requires:	boost-devel
Requires:	libxml2-devel
Requires:	libmount-devel >= %{util_linux_version}
Summary:	Header files and documentation for libsnapper

%description -n %{libname_devel}
This package contains header files and documentation for developing with
snapper.

%package -n pam_%{name}
Requires:	%{name} = %version-%{release}
Requires:	pam
Summary:	PAM module for calling snapper
Group:		System/Libraries

%description -n pam_%{name}
A PAM module for calling snapper during user login and logout.

%prep
%autosetup -p1

# use libexecdir
find -type f -exec sed -i -e "s|/usr/lib/snapper|%{_libexecdir}/%{name}|g" {} ';'

%build
# NOTE: This needed for regenerating the configuration to include changes from patches
autoreconf -vfi

# NOTE: --disable-ext4 option removes support for ext4 internal snapshots since the feature
# never made it into upstream kernel
%configure --disable-silent-rules --disable-ext4 --disable-zypp
#NOTE: avoid 'unused-direct-shlib-dependency' warning in rpmlint checks
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool
%make_build

%install
%make_install
install -m644 -D data/sysconfig.snapper %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{find_lang} %{name}
rm -f %{buildroot}/%{_libdir}/*.la
rm -f %{buildroot}/%{_libdir}/security/*.la
rm -rf %{buildroot}/%{_sysconfdir}/cron.hourly
rm -rf %{buildroot}/%{_sysconfdir}/cron.daily
rm -rf %{buildroot}/%{_docdir}/%{name}/COPYING

%files -f %{name}.lang
%license COPYING
%doc AUTHORS
%{_bindir}/snapper
%{_sbindir}/mksubvolume
%{_sbindir}/snapperd
%config(noreplace) %{_sysconfdir}/logrotate.d/snapper
%{_unitdir}/%{name}-*.timer
%{_unitdir}/%{name}-*.service
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.opensuse.Snapper.conf
%{_datadir}/dbus-1/system-services/org.opensuse.Snapper.service
%{_mandir}/man8/%{name}.8*
%{_mandir}/man8/mksubvolume.8*
%{_mandir}/man8/snapperd.8*
%{_mandir}/man5/snapper-configs.5*
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/installation-helper
%{_libexecdir}/%{name}/systemd-helper

%files -n %{libname}
%license COPYING
%{_libdir}/libsnapper.so.%{major}
%{_libdir}/libsnapper.so.%{major}.*
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/configs
%dir %{_sysconfdir}/%{name}/config-templates
%config(noreplace) %{_sysconfdir}/%{name}/config-templates/default
%dir %{_sysconfdir}/%{name}/filters
%config(noreplace) %{_sysconfdir}/%{name}/filters/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}

%files -n %{libname_devel}
%doc examples/c/*.c
%doc examples/c++-lib/*.cc
%{_libdir}/libsnapper.so
%{_includedir}/%{name}

%files -n pam_%{name}
%{_libdir}/security/pam_snapper.so
%dir %{_prefix}/lib/pam_snapper
%{_prefix}/lib/pam_snapper/*.sh
%doc %{_mandir}/*/pam_snapper*.*

