Summary:	Software version of a PKCS#11 Hardware Security Module
Name:		softhsm
Version:	2.6.1
Release:	%mkrel 5
License:	BSD
Group:		System/Base
URL:		https://www.opendnssec.org/
Source:		https://www.opendnssec.org/files/source/%{name}-%{version}.tar.gz
Source1:	https://www.opendnssec.org/files/source/%{name}-%{version}.tar.gz.sig
BuildRequires:	pkgconfig(openssl)
BuildRequires:	sqlite3-tools
BuildRequires:	pkgconfig(sqlite3) >= 3.4.2
BuildRequires:	pkgconfig(cppunit)
BuildRequires:	p11-kit-devel
Requires(pre): rpm-helper
Requires(postun): rpm-helper

%description
OpenDNSSEC is providing a software implementation of a generic
cryptographic device with a PKCS#11 interface, the SoftHSM. SoftHSM is
designed to meet the requirements of OpenDNSSEC, but can also work together
with other cryptographic products because of the PKCS#11 interface.

%package	devel
Summary:	Development package of softhsm that includes the header files
Group:		Development/C
Requires:	%{name} = %{version}
Requires:	pkgconfig(openssl)
Requires:	pkgconfig(sqlite3)

%description	devel
This package contains the libsofthsm include files.

%prep
%autosetup -p1

%build
autoreconf -fi

# remove softhsm/ subdir auto-added to --libdir
sed -i 's:full_libdir/softhsm:full_libdir:g' configure

%configure \
    --libdir=%{_libdir}/pkcs11 \
    --with-openssl=%{_prefix} \
    --disable-static \
    --with-crypto-backend=openssl \
    --enable-ecc \
    --disable-eddsa \
    --disable-gost \
    --with-migrate \
    --with-objectstore-backend-db \
    --with-sqlite3=%{_prefix} \
    --enable-visibility \
    --with-p11-kit=%{_datadir}/p11-kit/modules/

%make_build

#check
#make check

%install

%make_install

install -d %{buildroot}%{_includedir}/softhsm
install -m 644 src/lib/*.h %{buildroot}%{_includedir}/softhsm

rm %{buildroot}/etc/softhsm*.conf.sample
rm -f %{buildroot}%{_libdir}//pkcs11/*.la

# leave a softlink where softhsm-1 installed its library. Programs like
# opendnssec have that filename in their configuration file.
install -d %{buildroot}/%{_libdir}/softhsm
ln -s ../pkcs11/libsofthsm2.so %{buildroot}/%{_libdir}/softhsm/libsofthsm.so
# rhbz#1272423 NSS needs it to be in the search path too
( cd  %{buildroot}/%{_libdir} ; ln -s pkcs11/libsofthsm2.so)

%pre
%_pre_useradd %{name} /var/lib/%{name} /sbin/nologin

%postun
%_postun_userdel %{name}

%files
%doc FIPS-NOTES.md LICENSE NEWS README.md
%config(noreplace) %{_sysconfdir}/softhsm2.conf
%{_bindir}/*
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/libsofthsm2.so
%{_libdir}/libsofthsm2.so
%{_libdir}/softhsm/libsofthsm.so
%attr(0664,root,root) %{_datadir}/p11-kit/modules/softhsm2.module
%attr(0770,%{name},%{name}) %dir /var/lib/%{name}
%{_mandir}/*/*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
