%define shortname	speechd

%define major		2
%define libname		%mklibname %{shortname} %{major}
%define devname		%mklibname %{shortname} -d

%define major_mod	0
%define libname_mod	%mklibname %{shortname}-module %{major_mod}

# comment out when not a pre-release
#define prel	rc4
# rel for bumping
%define rel	1

Name:		speech-dispatcher
Version:	0.12.0
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	Speech Dispatcher provides a device independent layer for speech synthesis
Group:		System/Libraries
License:	GPLv2+ and LGPLv2
URL:		https://www.freebsoft.org/speechd
Source0:	https://github.com/brailcom/speechd/releases/download/%{version}%{?prel:-%prel}/%{name}-%{version}%{?prel:-%prel}.tar.gz
Source1:	https://www.freebsoft.org/pub/projects/sound-icons/sound-icons-0.1.tar.gz
Source3:	speech-dispatcher.logrotate
Source4:	speech-dispatcher-user-pulse.example
Patch1:		0001-Remove-pyxdg-dependency.patch
Patch2:		speech-dispatcher-0.11.4-fix-picoapi-include.patch
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(ao)
BuildRequires:	pkgconfig(dotconf) >= 1.3
BuildRequires:	pkgconfig(glib-2.0) >= 2.28
BuildRequires:	pkgconfig(gmodule-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(libpulse-simple)
BuildRequires:	pkgconfig(sndfile) >= 1.0.2
BuildRequires:	pkgconfig(python3)
BuildRequires:	libltdl-devel
BuildRequires:	pkgconfig(espeak-ng)
BuildRequires:	pkgconfig(flite)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(ttspico1)
BuildRequires:	help2man
BuildRequires:	intltool
BuildRequires:	systemd
BuildRequires:	texinfo

Recommends:	%{name}-conf
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
This is the Speech Dispatcher project (speech-dispatcher). It is a part of the
Free(b)soft project, which is intended to allow blind and visually impaired
people to work with computer and Internet based on free software.

%post
%_post_service speech-dispatcherd

%preun
%_preun_service speech-dispatcherd

%files -f %{name}.lang
%doc AUTHORS NEWS README.md FAQ
%doc speech-dispatcher-user-pulse.example
%{_bindir}/spd-say
%{_bindir}/spdsend
%{_bindir}/%{name}
%{_unitdir}/speech-dispatcherd.service
%{_userunitdir}/speech-dispatcher.service
%{_userunitdir}/speech-dispatcher.socket
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/speechd.conf
%config(noreplace) %{_sysconfdir}/%{name}/clients/*.conf
%config(noreplace) %{_sysconfdir}/%{name}/modules/*.conf
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/clients
%dir %{_sysconfdir}/%{name}/modules
%{_libdir}/%{name}
%{_libdir}/%{name}-modules
%{_datadir}/sounds/%{name}
%{_infodir}/%{name}.info.*
%{_infodir}/%{name}-cs.info.*
%{_infodir}/spd-say.info.*
%{_infodir}/ssip.info.*
%{_logdir}/%{name}
%{_datadir}/%{name}
%{_mandir}/man1/spd-say.1*
%{_mandir}/man1/%{name}.1*

#--------------------------------------------------------------------------

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries
Recommends:	%{name}

%description -n	%{libname}
This package provides the shared libraries for Speech Dispatcher.

%files -n %{libname}
%doc COPYING.LGPL NEWS
%{_libdir}/libspeechd.so.%{major}{,.*}

#--------------------------------------------------------------------------

%package -n %{libname_mod}
Summary:	Shared module libraries for %{name}
Group:		System/Libraries
Recommends:	%{name}

%description -n	%{libname_mod}
This package provides the shared module libraries for Speech Dispatcher.

%files -n %{libname_mod}
%doc COPYING.LGPL NEWS
%{_libdir}/libspeechd_module.so.%{major_mod}{,.*}

#--------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_mod} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains development files for %{name}.

%files -n %{devname}
%{_includedir}/speech-dispatcher
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/%{name}.pc

#--------------------------------------------------------------------------

%package conf
Summary:	Configuration tool for Speech Dispatcher
Group:		System/Libraries
Requires:	%{name} >= %{version}

%description conf
This package contains spd-conf, a configuration tool for Speech
Dispatcher.

%files conf
%{_bindir}/spd-conf
%{python3_sitearch}/speechd_config
%{_mandir}/man1/spd-conf.1*

#--------------------------------------------------------------------------

%package -n python3-%{shortname}
Summary:	A Python library for communication with Speech Dispatcher
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n python3-%{shortname}
This package provides a Python library for communication
with Speech Dispatcher.

%files -n python3-%{shortname}
%{python3_sitearch}/speechd

#--------------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}%{?prel:-%prel}
%autopatch -p1

tar xf %{SOURCE1}
cp -p %{SOURCE4} .

%build
%configure \
	--disable-static \
	--with-baratinoo=no \
	--with-kali=no \
	--with-ibmtts=no \
	--with-voxin=no \
	--with-espeak=no \
	--with-espeak-ng \
	--with-pico \
	--with-module-bindir=%{_libdir}/speech-dispatcher-modules/
%make_build

%install
%make_install

# upstream recommend the use of sound icons with Speech Dispatcher
install -p -m 0644 sound-icons-0.1/* %{buildroot}%{_datadir}/sounds/%{name}/

# logrotate install
install -Dm 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# create the needed directory for logs
install -d -m 0755 %{buildroot}%{_logdir}/%{name}

# remove config files for modules we don't support
rm -f %{buildroot}%{_sysconfdir}/speech-dispatcher/modules/espeak.conf
rm -f %{buildroot}%{_sysconfdir}/speech-dispatcher/modules/espeak-mbrola-generic.conf

# we don't wat these
find %{buildroot} -name "*.la" -delete

%find_lang %{name}
