%define gccinstalldir	%(LC_ALL=C %__cc --print-search-dirs | grep install | %__awk '{print $2}')
%define _fmoddir	%{gccinstalldir}/finclude

%define major		2
%define libname		%mklibname symspg %{major}
%define develname	%mklibname %{name} -d

%define libname_f08	%mklibname %{name}-f08_ %{major}
%define develname_f08	%mklibname %{name}-f08 -d

%bcond_without python

Name:		spglib
Version:	2.6.0
Release:	%mkrel 1
Summary:	C library for finding and handling crystal symmetries
License:	BSD
Group:		System/Libraries
Url:		https://spglib.readthedocs.io/
Source0:	https://github.com/spglib/spglib/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		spglib-linking-python-module.patch
Patch2:		Relax_numpy_requirements.patch
BuildRequires:	ninja-build
BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(gtest)
%if %{with python}
BuildRequires:	pkgconfig(python3)
BuildRequires:	pyproject-rpm-macros
BuildRequires:	python3-numpy-devel
BuildRequires:	python3dist(numpy)
BuildRequires:	python3dist(pip)
BuildRequires:	python3dist(pytest)
BuildRequires:	python3dist(pyyaml)
BuildRequires:	python3dist(scikit-build-core)
BuildRequires:	python3dist(setuptools-scm)
%endif

%description
C library for finding and handling crystal symmetries.

#----------------------------------------------------

%package -n	%{libname}
Summary:	C library for finding and handling crystal symmetries
Group:		System/Libraries

%description -n	%{libname}
C library for finding and handling crystal symmetries.
This package contains library files for %{name}.

#----------------------------------------------------

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	libspg-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.

#----------------------------------------------------

%package -n	%{libname_f08}
Summary:	Runtime files for spglib Fortran bindings
Group:		System/Libraries
Requires:	gcc-gfortran%{_isa}

%description -n	%{libname_f08}
This package contains runtime files to run applications that were built
using spglib's Fortran bindings.

#----------------------------------------------------

%package -n	%{develname_f08}
Summary:	Development files for spglib with Fortran bindings
Group:		Development/C
Requires:	%{libname_f08} = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}
Provides:	%{name}-fortran-devel = %{version}-%{release}

%description -n	%{develname_f08}
This package contains Fortran module and header files for developing
Fortran applications that use spglib.

#----------------------------------------------------
%if %{with python}

%package -n	python3-%{name}
Summary:	Python3 library of spglib
Group:		Development/Python

%description -n	python3-%{name}
This package contains the libraries to
develop applications with spglib Python3 bindings.
%endif

#----------------------------------------------------

%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires

%build
%cmake \
    -DSPGLIB_SHARED_LIBS=ON \
    -DSPGLIB_WITH_Fortran=ON \
    -DSPGLIB_WITH_Python=OFF \
    -DSPGLIB_WITH_TESTS=ON \
    -DCMAKE_INSTALL_MODULEDIR=%{_fmoddir}
%cmake_build

%if %{with python}
%pyproject_wheel
%endif

%install
%cmake_install

%if %{with python}
%pyproject_install
%pyproject_save_files spglib

rm %{buildroot}%{python3_sitearch}/spglib/%{_lib}/libsymspg.so*
rm %{buildroot}%{python3_sitearch}/spglib/include/spglib.h

# Delete from pyproject_files as well
sed -i "/libsymspg.so/d" %{pyproject_files}
sed -i "/spglib.h/d" %{pyproject_files}
%endif

%check
#ctest
%if %{with python}
# Need to set LD_LIBRARY_PATH manually for this test
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %pytest -v
%endif

%files -n %{libname}
%doc README.md
%license COPYING
%{_libdir}/libsymspg.so.%{major}{,.*}

%files -n %{libname_f08}
%license COPYING
%{_libdir}/libspglib_f08.so.%{major}{,.*}

%files -n %{develname}
%doc ChangeLog.md README.md
%license COPYING
%{_includedir}/%{name}.h
%{_libdir}/libsymspg.so
%{_libdir}/cmake/Spglib/
%{_libdir}/pkgconfig/spglib.pc
%exclude %{_libdir}/cmake/Spglib/SpglibTargets_fortran*

%files -n %{develname_f08}
%doc ChangeLog.md README.md
%license COPYING
%{_includedir}/spglib_f08.F90
%{_libdir}/libspglib_f08.so
%{_libdir}/cmake/Spglib/SpglibTargets_fortran*
%{_fmoddir}/spglib_f08.mod
%{_libdir}/pkgconfig/spglib_f08.pc

%if %{with python}
%files -n python3-%{name} -f %{pyproject_files}
%endif
