%define	major 1
%define libname %mklibname %{name}client %{major}
%define develname %mklibname %{name}client -d

Summary:	SQL full-text search engine
Name:		sphinx
Version:	2.3.2
Release:	%mkrel -c beta 6
License:	GPLv2+
Group:		Development/Databases
URL:		https://sphinxsearch.com/
Source0:	https://%{name}search.com/files/%{name}-%{version}-beta.tar.gz
Source1:	%{name}-searchd.service
Source2:	%{name}.logrotate
Patch0:		sphinx-DESTDIR.diff
Patch1:		sphinx-mga_conf.diff
Patch2:		sphinx-libsphinxclient-version-info_fix.diff
Patch3:		sphinx-2.0.3-fix_static.patch
Patch4:		fix-libsphinxclient-build.patch
Patch5:		listen_local.patch
# https://bugs.mageia.org/show_bug.cgi?id=30076
Patch6:		06-CVE-2020-29050.patch
# docs portion of the above Debian patch re-diffed for 2.3.2 beta
Patch7:		06-CVE-2020-29050_doc1.patch

Requires(post):	systemd >= %{systemd_required_version}
Requires(pre):	rpm-helper >= %{rpmhelper_required_version}
Requires(post):	rpm-helper >= %{rpmhelper_required_version}
Requires(preun): rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}

BuildRequires:	expat-devel
BuildRequires:	libstemmer-devel
BuildRequires:	libtool
BuildRequires:	mysql-devel
BuildRequires:	postgresql-devel

%description
Sphinx is a full-text search engine, distributed under GPL version 2.
Commercial licensing is also available upon request.

Generally, it's a standalone search engine, meant to provide fast,
size-efficient and relevant full text search functions to other applications.
Sphinx was specially designed to integrate well with SQL databases and
scripting languages. Currently built-in data source drivers support fetching
data either via direct connection to MySQL, PostgreSQL, or from a pipe in a
custom XML format.

As for the name, Sphinx is an acronym which is officially decoded as 
SQL Phrase Index. Yes, I know about CMU's Sphinx project.

%package -n	%{libname}
Summary:	Shared sphinxclient library
Group:		System/Libraries

%description -n	%{libname}
This package contains the shared sphinxclient library.

%package -n	%{develname}
Summary:	Development files for the sphinxclient library
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}client-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the development files for the sphinxclient library.

%package java
Summary:	Java API for Sphinx
Group:		Development/Java
BuildRequires:	java-devel
Requires:	java-headless
Requires:	javapackages-tools

%description java
This package provides the Java API for Sphinx,
the free, open-source full-text search engine,
designed with indexing database content in mind.

%prep

%setup -q -n %{name}-%{version}-beta
%patch -P 0 -p0
%patch -P 1 -p1
%patch -P 2 -p0
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1

cp %{SOURCE1} %{name}-searchd.service
cp %{SOURCE2} %{name}.logrotate

# Fix wrong-file-end-of-line-encoding
sed -i 's/\r//' api/ruby/spec/%{name}/%{name}_test.sql
sed -i 's/\r//' api/java/mk.cmd
sed -i 's/\r//' api/ruby/spec/fixtures/keywords.php
sed -i 's/\r//' api/ruby/lib/%{name}/response.rb


%build
%serverbuild
%configure \
    --sysconfdir=%{_sysconfdir}/%{name} \
    --program-prefix="%{name}-" \
    --localstatedir=/var/lib/%{name} \
    --with-mysql \
    --with-pgsql \
    --with-libstemmer

%make_build

pushd api/libsphinxclient
autoreconf -vfi
%configure \
	--disable-static
%make_build
popd

# make the java api
%__make -C api/java

%install

install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}/var/lib/%{name}
install -d %{buildroot}/var/log/%{name}
install -d %{buildroot}%{_localstatedir}/lib/%{name}/data

%make_install
%make_install -C api/lib%{name}client

mv %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf.dist %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
mv %{buildroot}%{_sysconfdir}/%{name}/%{name}-min.conf.dist %{buildroot}%{_sysconfdir}/%{name}/%{name}-min.conf
mv %{buildroot}%{_bindir}/%{name}-searchd %{buildroot}%{_sbindir}/%{name}-searchd

install -m0644 %{name}-searchd.service %{buildroot}%{_unitdir}/%{name}-searchd.service
install -m0644 %{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-searchd

# create ghostfiles
touch %{buildroot}%{_logdir}/%{name}/%{name}-searchd.log
touch %{buildroot}%{_logdir}/%{name}/%{name}-query.log

# we don't want these
find %{buildroot} -name "*.la" -delete

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/%{name} 0755 %{name} %{name}
EOF

# install the java api
mkdir -p %{buildroot}%{_javadir}
install -m 0644 api/java/%{name}api.jar %{buildroot}%{_javadir}/%{name}.jar
ln -s %{_javadir}/%{name}.jar %{buildroot}%{_javadir}/%{name}api.jar

%pre
 %_pre_useradd %{name} %{_localstatedir}/lib/%{name} /sbin/nologin

# Check that log files are owned by sphinx and fix if necessary
 [ -e %{_logdir}/%{name}/%{name}-query.log ] && \
 [ "$(stat -c %U %{_logdir}/%{name}/%{name}-query.log)" != "%{name}" ] && \
 chown -R %{name}:%{name} %{_logdir}/%{name} ||:

%post
%create_ghostfile %{_logdir}/%{name}/%{name}-searchd.log %{name} %{name} 0644
%create_ghostfile %{_logdir}/%{name}/%{name}-query.log %{name} %{name} 0644
%_tmpfilescreate %{name}
%_post_service %{name}-searchd

%preun
%_preun_service %{name}-searchd

%postun
%_postun_userdel %{name}

%files
%doc COPYING doc/*.html doc/*.css mysqlse/gen_data.php example.sql
%{_unitdir}/%{name}-searchd.service
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/example.sql
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/%{name}-min.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-searchd
%{_tmpfilesdir}/%{name}.conf
%attr(0755,root,root) %{_bindir}/%{name}-indexer
%attr(0755,root,root) %{_bindir}/%{name}-indextool
%attr(0755,root,root) %{_bindir}/%{name}-spelldump
%attr(0755,root,root) %{_bindir}/%{name}-wordbreaker
%attr(0755,root,root) %{_sbindir}/%{name}-searchd
%attr(0755,%{name},%{name}) %dir /var/lib/%{name}
%attr(0755,%{name},%{name}) %dir %{_logdir}/%{name}
%ghost %{_logdir}/%{name}/%{name}-searchd.log
%ghost %{_logdir}/%{name}/%{name}-query.log
%{_mandir}/man1/%{name}-*
%attr(0755,%{name},%{name}) %dir %{_localstatedir}/lib/%{name}/data

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%doc api/lib%{name}client/README
%{_includedir}/%{name}client.h
%{_libdir}/*.so

%files java
%doc api/java/README COPYING
%{_javadir}/*
