# Please keep this package in sync with FC

%define dname	%{name}d

Name:		spice-vdagent
Version:	0.22.1
Release:	%mkrel 4
Summary:	Agent for Spice guests
Group:		System/X11
License:	GPLv3+
URL:            https://spice-space.org/
Source0:        https://spice-space.org/download/releases/%{name}-%{version}.tar.bz2
Source1:        https://spice-space.org/download/releases/%{name}-%{version}.tar.bz2.sig
Source2:        victortoso-E37A484F.keyring

# from git upstream (see https://gitlab.freedesktop.org/spice/linux/vd_agent)
Patch0001:	0001-Makefile.am-don-t-create-var-run-spice-vdagentd.patch
Patch0002:	0002-vdagent-Remove-watch-event-on-vdagent_display_destro.patch
Patch0003:	0003-Switch-to-spice-vdagent.service-by-default.patch

BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	spice-protocol >= 0.14.3
BuildRequires:	pkgconfig(pciaccess)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xfixes)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(udev)
BuildRequires:	pkgconfig(libdrm)
BuildRequires:	libtool
BuildRequires:  gnupg2

Requires(post):	systemd >= %{systemd_required_version}
Requires(post):	rpm-helper >= %{rpmhelper_required_version}
Requires(preun): rpm-helper >= %{rpmhelper_required_version}

Provides:	%{name}-gdm = %{version}-%{release}
Obsoletes:	%{name}-gdm <= 0.16.0-3.mga6

%description
Spice agent for Linux guests offering the following features:

Features:
* Client mouse mode (no need to grab mouse by client, no mouse lag)
  this is handled by the daemon by feeding mouse events into the kernel
  via uinput. This will only work if the active X-session is running a
  spice-vdagent process so that its resolution can be determined.
* Automatic adjustment of the X-session resolution to the client resolution
* Support of copy and paste (text and images) between the active X-session
  and the client


%prep
gpgv2 --quiet --keyring %{SOURCE2} %{SOURCE1} %{SOURCE0}
%autosetup -p1
autoreconf -fi


%build
CFLAGS="%build_cflags -Wall -Werror"
%configure --with-session-info=systemd --with-init-script=systemd
%make_build V=2

%install
%make_install V=2

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
cat > %{buildroot}%{_sysconfdir}/sysconfig/spice-vdagentd <<EOF
SPICE_VDAGENTD_EXTRA_ARGS=""
EOF

mkdir -p %{buildroot}%{_systemd_util_dir}/user-preset
cat > %{buildroot}%{_systemd_util_dir}/user-preset/91-spice-vdagent.preset <<EOF
enable spice-vdagent.service
EOF

%post
%systemd_post spice-vdagentd.service spice-vdagentd.socket

%preun
%systemd_preun spice-vdagentd.service spice-vdagentd.socket
%systemd_user_preun spice-vdagent.service
 
%postun
%systemd_postun_with_restart spice-vdagentd.service spice-vdagentd.socket

%posttrans
%systemd_user_post spice-vdagent.service
 
%files
%doc COPYING CHANGELOG.md README.md
%config(noreplace) %{_sysconfdir}/sysconfig/spice-vdagentd
%{_udevrulesdir}/70-spice-vdagentd.rules
%{_unitdir}/spice-vdagentd.service
%{_unitdir}/spice-vdagentd.socket
%{_userunitdir}/spice-vdagent.service
%{_tmpfilesdir}/spice-vdagentd.conf
%{_systemd_util_dir}/user-preset/91-spice-vdagent.preset
%{_bindir}/spice-vdagent
%{_sbindir}/spice-vdagentd
%{_sysconfdir}/xdg/autostart/spice-vdagent.desktop
# For /usr/share/gdm/autostart/LoginWindow/spice-vdagent.desktop
# We own the dir too, otherwise we must Require gdm
%{_datadir}/gdm
%{_mandir}/man1/%{name}*.1*
