# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

# (akien) No soname upstream, arbitrarily using 0 for now
# Without proper soname, the devel package would not generate the
# devel() provides that RPM relies on to pull in the proper deps
# in reverse dependencies.
%define major   0
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

%define uname   SPIRV-Tools
%define vulkansdk vulkan-sdk-1.4.304.0

%define rel	1

Name:           spirv-tools
# Check https://github.com/KhronosGroup/SPIRV-Tools/releases to see if any
# matches the SDK tag, or take the last tag before the commit hash.
Version:        2024.4
Release:        %mkrel -c rc2 %{rel}
Summary:        API and commands for processing SPIR-V modules
Group:          System/Libraries
License:        ASL 2.0
URL:            https://github.com/KhronosGroup/SPIRV-Tools
Source0:        https://github.com/KhronosGroup/SPIRV-Tools/archive/%{vulkansdk}/%{uname}-%{vulkansdk}.tar.gz

Patch0:         fix-gcc12-build.patch

Patch1:         spirv-tools-soversion.patch

# https://github.com/KhronosGroup/SPIRV-Tools/pull/3906
Patch2:         0001-CMake-FIx-pkg-config-libdir-with-absolute-CMAKE_INST.patch

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  python3-devel
BuildRequires:  spirv-headers

%description
The package includes an assembler, binary module parser,
disassembler, and validator for SPIR-V.

%package -n %{libname}
Summary:        Library files for SPIR-V tools
Group:          System/Libraries

%description -n %{libname}
Library files for SPIR-V tools.

%package -n %{devname}
Summary:        Development files for SPIR-V tools
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       spirv-headers
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for SPIR-V tools.

%prep
%autosetup -p1 -n %{uname}-%{vulkansdk}

%build
%cmake \
    -DSPIRV_TOOLS_BUILD_STATIC=OFF \
    -DSPIRV_TOOLS_SOVERSION=%{major} \
    -DSPIRV_TOOLS_VERSION=%{version} \
    -DSPIRV-Headers_SOURCE_DIR=%{_prefix} \
    -DPYTHON_EXECUTABLE=%{__python3} \
    -GNinja
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README.md CHANGES
%{_bindir}/spirv-as
%{_bindir}/spirv-cfg
%{_bindir}/spirv-dis
%{_bindir}/spirv-lesspipe.sh
%{_bindir}/spirv-link
%{_bindir}/spirv-lint
%{_bindir}/spirv-objdump
%{_bindir}/spirv-opt
%{_bindir}/spirv-reduce
%{_bindir}/spirv-val

%files -n %{libname}
%license LICENSE
%{_libdir}/lib%{uname}-{diff,link,lint,opt,reduce,shared}.so.%{major}
%{_libdir}/lib%{uname}-{diff,link,lint,opt,reduce,shared}.so.%{version}
%{_libdir}/lib%{uname}.so.%{major}
%{_libdir}/lib%{uname}.so.%{version}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/cmake/%{uname}{,-diff,-link,-lint,-opt,-reduce,-tools}/
%{_libdir}/pkgconfig/%{uname}-shared.pc
%{_libdir}/pkgconfig/%{uname}.pc
%{_libdir}/lib%{uname}-{diff,link,lint,opt,reduce,shared}.so
%{_libdir}/lib%{uname}.so
