# bcond default logic is nicely backwards...
%bcond_without tcl
%bcond_with check
%bcond_with icu

%define realname sqlite
%define realver  3490100
%define docver   3490100
%define rpmver   3.49.1

%define major           0
%define libname         %mklibname %{name}_ %{major}
%define develname       %mklibname %{name} -d
%define staticdevelname %mklibname %{name} -d -s

Summary:    C library that implements an embeddable SQL database engine
Name:       sqlite3
Version:    %{rpmver}
Release:    %mkrel 2
License:    Public Domain
Group:      System/Libraries
URL:        https://www.sqlite.org/
Source0:    https://www.sqlite.org/2025/sqlite-src-%{realver}.zip
Source1:    https://www.sqlite.org/2025/sqlite-doc-%{docver}.zip
# Support a system-wide lemon template
Patch0:     sqlite-3.43.1-lemon-system-template.patch
# Temporary workaround for failed percentile test, see patch for details
Patch2:     sqlite-3.8.0-percentile-test.patch
# Disable test date-2.2c on i686
Patch3:     sqlite-3.16-datetest-2.2c.patch
# Modify sync2.test to pass with DIRSYNC turned off
Patch4:     sqlite-3.18.0-sync2-dirsync.patch
BuildRequires:  chrpath
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(readline)
BuildRequires:  glibc-devel
# libdl patch needs
BuildRequires:  autoconf
%if %{with icu}
BuildRequires:  icu-devel
%endif
%if %{with tcl}
BuildRequires:  tcl
BuildRequires:  pkgconfig(tcl)
%{!?tcl_version: %global tcl_version 8.6}
%{!?tcl_sitearch: %global tcl_sitearch %{_libdir}/tcl%{tcl_version}}
%endif

%description
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.


%package -n %{libname}
Summary:    C library that implements an embeddable SQL database engine
Group:      System/Libraries
Provides:   sqlite-libs%{?_isa} = %{version}-%{release}

%description -n %{libname}
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains the shared libraries for %{name}


%package -n %{develname}
Summary:    Development library and header files for the %{name} library
Group:      Development/C
Requires:   %{libname} = %{version}-%{release}
Provides:   libsqlite3-devel%{?_isa} = %{version}-%{release}
Provides:   libsqlite3-devel = %{version}-%{release}
Provides:   sqlite3-devel%{?_isa} = %{version}-%{release}
Provides:   sqlite3-devel = %{version}-%{release}
Provides:   sqlite-devel%{?_isa} = %{version}-%{release}
Provides:   sqlite-devel = %{version}-%{release}

%description -n %{develname}
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains the static %{libname} library and its header
files.


%package -n %{staticdevelname}
Summary:    Static development library for the %{name} library
Group:      Development/C
Requires:   %{develname} = %{version}-%{release}
Provides:   lib%{name}-static-devel = %{version}-%{release}
Provides:   %{name}-static-devel = %{version}-%{release}

%description -n %{staticdevelname}
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains the static %{libname} library.


%package    tools
Summary:    Command line tools for managing the %{libname} library
Group:      Databases
Requires:   %{libname} = %{version}-%{release}

%description    tools
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains command line tools for managing the
%{libname} library.


%package -n lemon
Summary:    A parser generator
Group:      Databases

%description -n lemon
Lemon is an LALR(1) parser generator for C or C++. It does the same
job as bison and yacc. But lemon is not another bison or yacc
clone. It uses a different grammar syntax which is designed to reduce
the number of coding errors. Lemon also uses a more sophisticated
parsing engine that is faster than yacc and bison and which is both
reentrant and thread-safe. Furthermore, Lemon implements features
that can be used to eliminate resource leaks, making is suitable for
use in long-running programs such as graphical user interfaces or
embedded controllers.


%if %{with tcl}
%package    tcl
Summary:    Tcl module for the sqlite3 embeddable SQL database engine
Group:      Development/Other
Requires:   %{name}-tools = %{version}-%{release}
Requires:   tcl >= 1:%{tcl_version}
Provides:   tcl-sqlite3 = %{version}-%{release}

%description    tcl
This package contains the tcl modules for %{name}.
%endif


%prep
%setup -q -a1 -n %{realname}-src-%{realver}
%patch -P0 -p1 -b .lemon-system-template
%patch -P2 -p1
%ifarch %{ix86}
%patch -P3 -p1
%endif
%patch -P4 -p1

%build
export CFLAGS="%{optflags} -DSQLITE_ENABLE_COLUMN_METADATA=1 \
                           -DSQLITE_DISABLE_DIRSYNC=1 \
                           -DSQLITE_ENABLE_FTS3=3 \
                           -DSQLITE_ENABLE_RTREE=1 \
                           -DSQLITE_SECURE_DELETE=1 \
                           -DSQLITE_ENABLE_UNLOCK_NOTIFY=1 \
                           -DSQLITE_ENABLE_DBSTAT_VTAB=1 \
                           -DSQLITE_ENABLE_FTS3_PARENTHESIS=1 \
                           -DSQLITE_ENABLE_JSON1=1 \
                           -DSQLITE_ENABLE_FTS4=1 \
                           -DSQLITE_ENABLE_MATH_FUNCTIONS \
                           -DSQLITE_ENABLE_DBPAGE_VTAB \
                           -DSQLITE_ENABLE_SESSION \
                           -DSQLITE_ENABLE_PREUPDATE_HOOK \
%if %{with icu}
                           -DSQLITE_ENABLE_ICU=1 \
%endif
                           -DSQLITE_ENABLE_LOAD_EXTENSION \
                           -Wall -fno-strict-aliasing"
%if %{with icu}
export LDFLAGS="%{ldflags} $(icu-config --ldflags)"
%endif

# (ovitters) tracker mandates --enable-fts5
# (daviddavid) fossil mandates --enable-fts4
%configure %{!?with_tcl:--disable-tcl} \
           --enable-fts4 \
           --enable-fts5 \
           --enable-threadsafe \
           --enable-load-extension \
           --enable-update-limit \
           --soname=legacy \
           %{?with_tcl:TCLLIBDIR=%{tcl_sitearch}/sqlite3}

%make_build
%if %{with tcl}
%make_build tclextension
%endif

%install
%make_install

install -Dpm0644 sqlite3.1 %{buildroot}%{_mandir}/man1/sqlite3.1
install -Dpm0755 lemon %{buildroot}%{_bindir}/lemon
install -Dpm0644 tool/lempar.c %{buildroot}%{_datadir}/lemon/lempar.c

%if %{with tcl}
mkdir -p %{buildroot}%{tcl_sitearch}/sqlite3/
install -Dpm0755 ./libsqlite%{version}.so %{buildroot}%{tcl_sitearch}/sqlite3/
install -Dpm0644 ./pkgIndex.tcl %{buildroot}%{tcl_sitearch}/sqlite3/
%endif

# This is needed since rpath removal using sed won't work for tcl library for some reason
chrpath --delete %{buildroot}%{tcl_sitearch}/sqlite3/*.so
chrpath --delete %{buildroot}%{_libdir}/*.so.%{version}
chrpath --delete %{buildroot}%{_bindir}/sqlite3

%if %{with check}
%check
%__make test
%endif

%files -n %{libname}
%{_libdir}/lib*.so.%{major}
%{_libdir}/lib*.so.%{version}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files -n %{staticdevelname}
%{_libdir}/lib*.a

%files tools
%{_bindir}/sqlite3
%{_mandir}/man1/*

%files -n lemon
%{_bindir}/lemon
%{_datadir}/lemon/

%if %{with tcl}
%files tcl
%{tcl_sitearch}/sqlite3/
%endif
