%define build_test 0

# commandline overrides:
# rpm -ba|--rebuild --with 'xxx'
%{?_with_test: %{expand: %%global build_test 1}}
%{?_without_test: %{expand: %%global build_test 0}}

%define defaultmaxfiles 8192

Summary:	The Squid proxy caching server
Name:		squid
Version:	6.12
Release:	%mkrel 1
License:	GPLv2
Group:		System/Servers
URL:		https://www.squid-cache.org/
Source0:	https://www.squid-cache.org/Versions/v6/squid-%{version}.tar.xz
Source1:	https://www.squid-cache.org/Versions/v6/squid-%{version}.tar.xz.asc
Source4:	squid.logrotate
Source5:	squid.conf.authenticate
Source6:	smb.conf
Source7:	squid.conf.transparent
Source8:	rc.firewall
Source9:	ERR_CUSTOM_ACCESS_DENIED.English
Source10:	ERR_CUSTOM_ACCESS_DENIED.French
Source11: 	squid.sysconfig
Source13:	squid.pam
Source14:	squid.ifup
Source15:	squid.service
Source16:       cache_swap.sh

Patch1:		squid-config.diff
Patch2:		squid-user_group.diff
Patch11:	squid-shutdown_lifetime.diff
Patch13:	squid-errordir.diff
Patch19:	squid-6.7-configure-egrep.patch

# Change /var/run to /run
Patch302:	squid-6.7-var-run-to-run.patch

Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
BuildRequires:	bzip2
BuildRequires:	ed
BuildRequires:	libtool-devel
BuildRequires:	db-devel
BuildRequires:	pkgconfig(libsasl2)
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pam-devel
BuildRequires:	pkgconfig
BuildRequires:	libtool
BuildRequires:	krb5-devel
BuildRequires:	pkgconfig(libecap)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	samba-winbind
BuildRequires:  chrpath
%if %{build_test}
BuildRequires:	cppunit-devel
%endif
Provides:	webproxy

%description
Squid is a high-performance proxy caching server for web clients, supporting
FTP, gopher, and HTTP data objects over IPv4 or IPv6. Unlike traditional
caching software, Squid handles all requests in a single, non-blocking,
asynchronous process.

Squid keeps meta data and especially hot objects cached in RAM, caches DNS
lookups, supports non-blocking DNS lookups, and implements negative caching of
failed requests.  Squid supports SSL, extensive access controls, and full
request logging. By using the lightweight Internet Cache Protocol (ICP) and
HTTP Cache Protocol (HTCP) Squid caches can be arranged in a hierarchy or mesh
for additional bandwidth savings.

Install squid if you need a proxy caching server.

This package defaults to a maximum of %{defaultmaxfiles} filedescriptors. You
can change these values at build time by using for example:

--define 'maxfiles 4096'

The package was built to support a maximum of %{?!maxfiles:%{defaultmaxfiles}}%{?maxfiles:%{maxfiles}} filedescriptors.

You can build %{name} with some conditional build switches;

(ie. use with rpm --rebuild):
    --with[out]	test	Initiate the test suite

%package	cachemgr
Summary:	The Squid Cache Manager
Group:		System/Servers
Requires(pre): rpm-helper
Requires(pre):	apache >= 2.0.54
Requires(pre):	%{name} = %{version}
Requires:	apache >= 2.0.54
Requires:	%{name} = %{version}

%description	cachemgr
This package contains the Squid Cache Manager.

%prep
%setup -q
%patch -P1 -p1 -b .config
%patch -P2 -p0 -b .user_group
%patch -P11 -p0 -b .shutdown_lifetime
%patch -P13 -p1 -b .errordir
%patch -P19 -p1 -b .egrep
%patch -P302 -p1

find . -type d -perm 0700 -exec chmod 755 {} \;
find . -type f -perm 0555 -exec chmod 755 {} \;
find . -type f -perm 0444 -exec chmod 644 {} \;

for i in `find . -type d -name CVS`  `find . -type d -name .svn` `find . -type f -name .cvs\*` `find . -type f -name .#\*`; do
    if [ -e "$i" ]; then rm -rf $i; fi >&/dev/null
done

install -p -m 0644 %{SOURCE5} squid.conf.authenticate
install -p -m 0644 %{SOURCE6} smb.conf
install -p -m 0644 %{SOURCE7} squid.conf.transparent
install -p -m 0755 %{SOURCE8} rc.firewall

# fix conditional pam config file
install -p -m 0644 %{SOURCE13} squid.pam

perl -p -i -e "s|^SAMBAPREFIX.*|SAMBAPREFIX = /usr|" src/auth/basic/SMB/Makefile.*
grep -r "local/bin/perl" . |sed -e "s/:.*$//g" | xargs perl -p -i -e "s@local/bin/perl@bin/perl@g"

#Fix sysctl.h deprecation
perl -pi -e "s|<sys/sysctl.h>|<linux/sysctl.h>|g" src/eui/Eui48.cc

# fix paths
perl -pi -e "s|lib/squid|%{_lib}/squid|g" squid.conf.authenticate

%build
autoreconf -fi
%serverbuild

# NIS helper has been removed because of the following bug
# https://bugzilla.redhat.com/show_bug.cgi?id=1531540
%configure \
    --disable-strict-error-checking \
    --libexecdir=%{_libdir}/squid \
    --datadir=%{_datadir}/squid \
    --sysconfdir=%{_sysconfdir}/squid \
    --with-logdir='%{_localstatedir}/log/squid' \
    --disable-arch-native \
    --enable-shared=yes \
    --enable-static=no \
    --enable-xmalloc-statistics \
    --enable-carp \
    --enable-async-io \
    --enable-storeio="aufs,diskd,ufs" \
    --enable-removal-policies="heap,lru" \
    --enable-icmp \
    --enable-delay-pools \
    --disable-esi \
    --enable-icap-client \
    --enable-ecap \
    --enable-useragent-log \
    --enable-referer-log \
    --enable-wccp \
    --enable-wccpv2 \
    --disable-kill-parent-hack \
    --enable-snmp \
    --enable-cachemgr-hostname="localhost" \
    --enable-arp-acl \
    --enable-htcp \
    --enable-ssl \
    --enable-ssl-crtd \
    --enable-forw-via-db \
    --enable-follow-x-forwarded-for \
    --enable-cache-digests \
    --disable-poll \
    --enable-epoll \
    --enable-linux-netfilter \
    --disable-ident-lookups \
    %ifnarch x86_64 aarch64
    --with-large-files \
    %endif
    --enable-default-hostsfile=/etc/hosts \
    --enable-auth \
    --enable-auth-basic="DB,fake,getpwnam,LDAP,NCSA,PAM,POP3,RADIUS,SASL,SMB,SMB_LM" \
    --enable-auth-ntlm="fake,SMB_LM" \
    --enable-auth-negotiate="kerberos,wrapper" \
    --enable-auth-digest="eDirectory,file,LDAP" \
    --enable-external-acl-helpers="eDirectory_userip,file_userip,kerberos_ldap_group,LDAP_group,session,unix_group,wbinfo_group" \
    --enable-storeid-rewrite-helpers="file" \
    --with-default-user=%{name} \
    --with-pthreads \
    --with-dl \
    --with-openssl=%{_prefix} \
    --with-large-files \
    --with-swapdir=%{_localstatedir}/spool/squid \
    --with-build-environment=default \
    --enable-mit=`/usr/bin/krb5-config --prefix` \
    --with-logdir=%{_logdir}/squid \
    --enable-http-violations \
    --enable-zph-qos \
    --enable-systemd \
    --with-pidfile=%{_rundir}/%{name}.pid \
    --sysconfdir=%{_sysconfdir}/squid \
    --with-filedescriptors=%{?!maxfiles:%{defaultmaxfiles}}%{?maxfiles} \
    --with-cap \
    --with-xml2 \
    --with-ldap

# workaround to build squid v5
mkdir -p src/icmp/tests
mkdir -p tools/squidclient/tests
mkdir -p tools/tests
%make_build

%if %{build_test}
%check
make check
%endif

%install
%make_install

# remove chrpath
chrpath --delete %{buildroot}%{_libdir}/%{name}/ext_session_acl

# make some directories
install -d %{buildroot}%{_sysconfdir}/{logrotate.d,pam.d,sysconfig}
install -d %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup.d
install -d %{buildroot}%{_webconfdir}/webapps.d
install -d %{buildroot}%{_datadir}/squid/{errors,icons}
install -d %{buildroot}%{_datadir}/squid/errors/{English,French}
install -d %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{_var}/www/cgi-bin
install -d %{buildroot}%{_logdir}/squid
install -d %{buildroot}%{_var}/spool/squid
install -d %{buildroot}%{_datadir}/squid/snmp/mibs

# fix error docs location	
rm -rf %{buildroot}%{_sysconfdir}/squid/errors
pushd errors
    for i in *; do
	if [ -d $i ]; then
	    install -d %{buildroot}%{_datadir}/squid/errors/$i
	    install -p -m0644 $i/* %{buildroot}%{_datadir}/squid/errors/$i
	fi
    done
popd
ln -fs %{_datadir}/squid/errors/templates %{buildroot}%{_sysconfdir}/squid/errors

# install config
install -p -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/squid
install -p -m0644 %{SOURCE11} %{buildroot}%{_sysconfdir}/sysconfig/squid
install -p -m0755 %{SOURCE14} %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup.d/squid
install -p -m0755 %{SOURCE15} -D %{buildroot}%{_unitdir}/%{name}.service
install -p -m0755 %{SOURCE16} -D %{buildroot}%{_libexecdir}/squid/cache_swap.sh

# fix docs
cp -a src/auth/basic/SASL/basic_sasl_auth.conf .

cp -a src/acl/external/file_userip/example.conf ip_user_external_acl.example.conf
cp -a src/acl/external/LDAP_group/ChangeLog ChangeLog.ldap_group_external_acl

head -19 src/auth/basic/NCSA/basic_ncsa_auth.cc > README.NCSA_basic_auth
head -56 src/auth/basic/PAM/basic_pam_auth.cc > README.PAM_basic_auth
head -21 src/auth/basic/getpwnam/basic_getpwnam_auth.cc > README.getpwnam_basic_auth
head -32 src/auth/digest/LDAP/digest_pw_auth.cc > README.ldap_digest_auth

install -p -m 0755 src/auth/basic/SMB/basic_smb_auth.sh %{buildroot}%{_libdir}/squid
install -p -m 0755 src/auth/basic/SASL/basic_sasl_auth %{buildroot}%{_libdir}/squid

for manpage in `find -name "*.8"`; do
    install -p -m 0644 $manpage %{buildroot}%{_mandir}/man8/
done

install -p -m 0644 %{SOURCE9} %{buildroot}%{_datadir}/squid/errors/English/ERR_CUSTOM_ACCESS_DENIED
install -p -m 0644 %{SOURCE10} %{buildroot}%{_datadir}/squid/errors/French/ERR_CUSTOM_ACCESS_DENIED

install -p -m 0644 squid.pam %{buildroot}%{_sysconfdir}/pam.d/squid

# move cachemgr.cgi to a more safe location
mv %{buildroot}%{_libdir}/squid/cachemgr.cgi %{buildroot}%{_var}/www/cgi-bin/

# provide a simple apache config
cat > %{buildroot}%{_webconfdir}/webapps.d/squid-cachemgr.conf << EOF
<Location /cgi-bin/cachemgr.cgi>
    Require local granted
    ErrorDocument 403 "Access denied per /etc/httpd/conf/webapps.d/squid-cachemgr.conf"
</Location>
EOF

# some cleaning
rm -f %{buildroot}%{_libdir}/squid/no_check.pl

# nuke zero length files
find %{buildroot}%{_datadir}/squid/errors/ -type f -size 0 -exec rm -f {} \;

# install /usr/lib/tmpfiles.d/squid.conf
mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/squid.conf <<EOF
# See tmpfiles.d(5) for details
d /run/squid 0755 squid squid - -	
EOF

# Move the MIB definition to the proper place (and name)
mkdir -p %{buildroot}/usr/share/snmp/mibs
mv %{buildroot}/usr/share/squid/mib.txt %{buildroot}/usr/share/snmp/mibs/SQUID-MIB.txt

# remove unpackaged files from the buildroot
rm -f %{buildroot}/squid.httpd.tmp


%pre
%_pre_useradd squid %{_var}/spool/squid /bin/false

for i in %{_logdir}/squid %{_var}/spool/squid ; do
        if [ -d $i ] ; then
                for adir in `find $i -maxdepth 0 \! -user squid`; do
                        chown -R squid:squid $adir
                done
        fi
done

%post
%_create_ssl_certificate squid

%_post_service squid
 case "$LANG" in
  az*)
     DIR=Azerbaijani
     ;;
  bg*)
     DIR=Bulgarian
     ;;
  ca*)
     DIR=Catalan
     ;;
  cs*)
     DIR=Czech
     ;;
  da*)
     DIR=Danish
     ;;
  nl*)
     DIR=Dutch
     ;;
  en*)
     DIR=English
     ;;
  ea*)
     DIR=Estonian
     ;;
  fi*)
     DIR=Finnish
     ;;
  fr*)
     DIR=French
     ;;
  de*)
     DIR=German
     ;;
  el*)
     DIR=Greek
     ;;
  he*)
     DIR=Hebrew
     ;;
  hu*)
     DIR=Hungarian
     ;;
  it*)
     DIR=Italian
     ;;
  ja*)
     DIR=Japanese
     ;;
  kr*)
     DIR=Korean
     ;;
  lt*)
     DIR=Lithuanian
     ;;
  pl*)
     DIR=Polish
     ;;
  pt*)
     DIR=Portuguese
     ;;
  ro*)
     DIR=Romanian
     ;;
  ru*)
     DIR=Russian-koi8-r
     ;;
  sr*)
     DIR=Serbian
     ;;
  sk*)
     DIR=Slovak
     ;;
  es*)
     DIR=Spanish
     ;;
  sv*)
     DIR=Swedish
     ;;
  zh*)
     DIR=Traditional_Chinese
     ;;
  tr*)
     DIR=Turkish
     ;;
  *)
     DIR=English
     ;;
 esac

%preun
%_preun_service squid

%pretrans -p <lua>
-- Define the path to the symlink being replaced below.
path = "%{_datadir}/squid/errors/es-mx"
st = posix.stat(path)
if st and st.type == "link" then
  os.remove(path)
end

%files
%doc C* R* Q* rc.firewall *.conf* doc/*.txt
%exclude %{_sysconfdir}/squid/cachemgr.conf
%exclude %{_sysconfdir}/squid/cachemgr.conf.default
%dir %{_sysconfdir}/squid	
%attr(755,root,root) %dir %{_libdir}/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.default
%exclude %{_sysconfdir}/squid/cachemgr.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/pam.d/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/squid
%attr(0755,root,squid) %config(noreplace) %{_sysconfdir}/sysconfig/network-scripts/ifup.d/squid
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.css
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/*.documented
%{_sysconfdir}/squid/errors
%{_datadir}/squid/errors
%{_datadir}/squid/icons
%{_libdir}/squid/*
%{_libexecdir}/squid/
%{_unitdir}/%{name}.service

%{_sbindir}/*
%{_bindir}/purge
%{_bindir}/squidclient
%attr(0644,root,root) %{_mandir}/man1/*
%attr(0644,root,root) %{_mandir}/man8/basic*
%attr(0644,root,root) %{_mandir}/man8/digest_file_auth.8*
%attr(0644,root,root) %{_mandir}/man8/ext_*
%attr(0644,root,root) %{_mandir}/man8/helper-mux.8*
%attr(0644,root,root) %{_mandir}/man8/log_db_daemon.8*
%attr(0644,root,root) %{_mandir}/man8/n*
%attr(0644,root,root) %{_mandir}/man8/s*
%attr(0644,root,root) %{_mandir}/man8/u*
%attr(0755,squid,squid) %dir %{_logdir}/squid
%attr(0755,squid,squid) %dir %{_var}/spool/squid
%{_datadir}/snmp/mibs/SQUID-MIB.txt
%{_tmpfilesdir}/squid.conf

%files cachemgr
%attr(0644,root,root) %config(noreplace) %{_webconfdir}/webapps.d/squid-cachemgr.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/squid/cachemgr.conf
%attr(0755,root,squid) %{_var}/www/cgi-bin/cachemgr.cgi
%attr(0644,root,root) %{_mandir}/man8/cachemgr.cgi.8.*
