%define oname		squirrel3

%define major		0
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define ver %(echo %{version} |tr '.' '_')

Name:		squirrel
Version:	3.2
Release:	%mkrel 3
Summary:	The squirrel language
License:	zlib
Group:		Development/Other
URL:		http://squirrel-lang.org
Source0:	https://download.sourceforge.net/squirrel/%{name}_%{ver}_stable.tar.gz
# Missing from src tarball
Source1:	https://raw.githubusercontent.com/albertodemichelis/squirrel/v%{version}/squirrel-config.cmake.in
#
# Security patches
# P100 -> ...
#
# CVE-2022-30292
# https://github.com/albertodemichelis/squirrel/commit/a6413aa690e0bdfef648c68693349a7b878fe60d
Patch100:	squirrel-3.2-CVE-2022-30292.patch
BuildRequires:	cmake

%description
Squirrel is a high level imperative, object-oriented programming
language, designed to be a light-weight scripting language that
fits in the size, memory bandwidth, and real-time requirements of
applications like video games.

%package -n %{libname}
Summary:	Libraries for %{name}
Group:		System/Libraries

%description -n %{libname}
Shared library files for %name.

%package -n %{develname}
Summary:	Header files and static libraries from %{name}
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Libraries and includes files for developing programs based on %name.


%prep
%setup -qn %{oname}
%autopatch -p1

# fix file permissions
find . -type f -exec chmod a-x {} \;

# fix EOL + preserve timestamps
for f in README HISTORY COPYRIGHT
do
    perl -pi -e 's/\015$//' $f
done

# install files missing from source tarball
if ! [ -x %(basename %{SOURCE1}) ]; then
  install -Dpm 644 %{SOURCE1} .
fi

%build
%cmake -DDISABLE_STATIC=ON \
       -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_includedir}/%{name}

%cmake_build

%install
%cmake_install

#correct wrong file end of line encoding
perl -pi -e 's/\015$//' %{buildroot}/%{_includedir}/*

# Add pkgconfig file
mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat >%{buildroot}%{_libdir}/pkgconfig/squirrel.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}/squirrel

Name: %{name}
Description: squirrel library
Version: %{version}

Requires:
Libs: -L\${libdir} -lsquirrel -lsqstdlib
Cflags: -I\${includedir}
EOF

%files
%doc README HISTORY
%license COPYRIGHT
%{_bindir}/sq

%files -n %{libname}
%doc README
%license COPYRIGHT
%{_libdir}/libsqstdlib.so.%{major}{,.*}
%{_libdir}/libsquirrel.so.%{major}{,.*}

%files -n %{develname}
%doc COMPILE
%{_includedir}/%{name}/
%{_libdir}/libsqstdlib.so
%{_libdir}/libsquirrel.so
%{_libdir}/pkgconfig/*
%{_libdir}/cmake/%{name}/
