# define SSSD user
%global sssd_user     root

%global servicename   sssd
%define sssdstatedir  %{_localstatedir}/lib/sss
%define dbpath        %{sssdstatedir}/db
%global keytabdir     %{sssdstatedir}/keytabs
%define pipepath      %{sssdstatedir}/pipes
%define mcpath        %{sssdstatedir}/mc
%define pubconfpath   %{sssdstatedir}/pubconf
%global gpocachepath  %{sssdstatedir}/gpo_cache
%global secdbpath     %{sssdstatedir}/secrets
%global deskprofilepath %{sssdstatedir}/deskprofile

# we don't want to provide private python extension libs
%define __provides_exclude_from %{python3_sitearch}/.*\.so$

# Determine the location of the LDB modules directory
%global ldb_modulesdir %(pkg-config --variable=modulesdir ldb)

%define _disable_ld_no_undefined 1
%global __brp_check_rpaths %nil

Name:           sssd
Version:        2.10.2
Release:        %mkrel 3
Group:          System/Libraries
Summary:        System Security Services Daemon
License:        GPLv3+
URL:            https://github.com/SSSD/sssd/
Source0:        https://github.com/SSSD/sssd/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        sssd.conf

# Patches

### Downstream only patches ###

Patch9999: sssd-autoconf-pre-2.70.patch

BuildRequires:  pkgconfig(cmocka)
BuildRequires:  pkgconfig(popt)
BuildRequires:  pkgconfig(talloc)
BuildRequires:  pkgconfig(tevent)
BuildRequires:  pkgconfig(tdb)
BuildRequires:  pkgconfig(ldb)
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(nspr)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(krb5) >= 1.10
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libfido2)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(dhash)
BuildRequires:  pkgconfig(collection)
BuildRequires:  pkgconfig(ini_config)
BuildRequires:  pkgconfig(path_utils)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(libsemanage)
BuildRequires:  pkgconfig(gdm-pam-extensions)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  ldb-utils
BuildRequires:  openldap-devel
BuildRequires:  pam-devel
BuildRequires:  pam_wrapper
BuildRequires:  keyutils-devel
BuildRequires:  unistring-devel
BuildRequires:  cifs-utils-devel
BuildRequires:  samba-devel
BuildRequires:  smbclient-devel
BuildRequires:  samba-winbind
BuildRequires:  pkgconfig(libnfsidmap)
BuildRequires:  gettext-devel
BuildRequires:  xsltproc
BuildRequires:  libxml2
BuildRequires:  xsltproc
BuildRequires:  docbook-style-xsl
BuildRequires:  docbook-dtd44-xml
BuildRequires:  doxygen
BuildRequires:  bind-utils
BuildRequires:  http-parser-devel
BuildRequires:  gnutls
BuildRequires:  softhsm >= 2.1.0
BuildRequires:  openssl
BuildRequires:  openssh
BuildRequires:  systemtap-sdt-devel
BuildRequires:  diffstat
BuildRequires:  bc
BuildRequires:  po4a
BuildRequires:  pkgconfig(valgrind)
BuildRequires:  python3dist(setuptools)

Recommends:	sssd-ad = %{version}-%{release}
Recommends:	sssd-ipa = %{version}-%{release}
Recommends:	sssd-krb5 = %{version}-%{release}
Recommends:	sssd-ldap = %{version}-%{release}
Recommends:	sssd-proxy = %{version}-%{release}
Recommends:	sssd-dbus = %{version}-%{release}
Requires:	sssd-common = %{version}-%{release}
Requires:	python3-sssdconfig = %{version}-%{release}
Recommends:	sssd-dbus = %{version}-%{release}

%description
Provides a set of daemons to manage access to remote directories and
authentication mechanisms. It provides an NSS and PAM interface toward
the system and a pluggable backend system to connect to multiple different
account sources. It is also the basis to provide client auditing and policy
services for projects like FreeIPA.

%package common
Summary:    Common files for the SSSD
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-client = %{version}-%{release}
Requires:   libsss_sudo = %{version}-%{release}
Requires:   libsss_autofs = %{version}-%{release}
Recommends: sssd-nfs-idmap = %{version}-%{release}
Requires:   libsss_idmap = %{version}-%{release}

# libsss_simpleifp is removed starting 2.9.0
Obsoletes:  libsss_simpleifp < 2.9.0
Obsoletes:  libsss_simpleifp-devel < 2.9.0

%description common
Common files for the SSSD. The common package includes all the files needed
to run a particular back end, however, the back ends are packaged in separate
sub-packages such as sssd-ldap.

%package        client
Summary:        SSSD Client libraries for NSS and PAM
Group:          System/Libraries
License:        LGPLv3+

%description    client
Provides the libraries needed by the PAM and NSS stacks to connect to the SSSD
service.

%package -n libsss_sudo
Summary:    A library to allow communication between SUDO and SSSD
Group:      System/Libraries
License:    LGPLv3+

%description -n libsss_sudo
A utility library to allow communication between SUDO and SSSD.

%package -n libsss_autofs
Summary:    A library to allow communication between Autofs and SSSD
Group:      System/Libraries
License:    LGPLv3+

%description -n libsss_autofs
A utility library to allow communication between Autofs and SSSD.

%package        tools
Summary:        Userspace tools for use with the SSSD
Group:          System/Libraries
License:        GPLv3+
Requires:       sssd-common = %{version}-%{release}
# required by sss_obfuscate
Requires:       python3-sss = %{version}-%{release}
Requires:       python3-sssdconfig = %{version}-%{release}

%description    tools
Provides userspace tools for manipulating users, groups, and nested groups in
SSSD when using id_provider = local in /etc/sssd/sssd.conf.

Also provides several other administrative tools:
    * sss_debuglevel to change the debug level on the fly
    * sss_seed which pre-creates a user entry for use in kickstarts
    * sss_obfuscate for generating an obfuscated LDAP password
    * sssctl -- an sssd status and control utility

%package -n python3-sssdconfig
Summary:    SSSD and IPA configuration file manipulation classes and functions
Group:      System/Libraries
License:    GPLv3+
BuildArch:  noarch

%description -n python3-sssdconfig
Provides python3 files for manipulation SSSD and IPA configuration files.

%package -n python3-sss
Summary:    Python3 bindings for sssd
Group:      System/Libraries
License:    LGPLv3+
Requires:   sssd-common = %{version}-%{release}

%description -n python3-sss
Provides python3 module for manipulating users, groups, and nested groups in
SSSD when using id_provider = local in /etc/sssd/sssd.conf.

Also provides several other useful python3 bindings:
    * function for retrieving list of groups user belongs to.
    * class for obfuscation of passwords

%package -n python3-sss-murmur
Summary:    Python3 bindings for murmur hash function
Group:      System/Libraries
License:    LGPLv3+

%description -n python3-sss-murmur
Provides python3 module for calculating the murmur hash version 3.

%package ldap
Summary:    The LDAP back end of the SSSD
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}
Requires:   sssd-krb5-common = %{version}-%{release}

%description ldap
Provides the LDAP back end that the SSSD can utilize to fetch identity data
from and authenticate against an LDAP server.

%package krb5-common
Summary:    SSSD helpers needed for Kerberos and GSSAPI authentication
Group:      System/Libraries
License:    GPLv3+
Requires:   sasl-plug-gssapi
Requires:   sssd-common = %{version}-%{release}

%description krb5-common
Provides helper processes that the LDAP and Kerberos back ends can use for
Kerberos user or host authentication.

%package krb5
Summary:    The Kerberos authentication back end for the SSSD
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}
Requires:   sssd-krb5-common = %{version}-%{release}

%description krb5
Provides the Kerberos back end that the SSSD can utilize authenticate
against a Kerberos server.

%package common-pac
Summary:    Common files needed for supporting PAC processing
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}

%description common-pac
Provides common files needed by SSSD providers such as IPA and Active Directory
for handling Kerberos PACs.

%package ipa
Summary:    The IPA back end of the SSSD
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}
Requires:   sssd-krb5-common = %{version}-%{release}
Requires:   libipa_hbac = %{version}-%{release}
Requires:   bind-utils
Requires:   sssd-common-pac = %{version}-%{release}

%description ipa
Provides the IPA back end that the SSSD can utilize to fetch identity data
from and authenticate against an IPA server.

%package ad
Summary:    The AD back end of the SSSD
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}
Requires:   sssd-krb5-common = %{version}-%{release}
Requires:   sssd-common-pac = %{version}-%{release}
Requires:   bind-utils
Recommends: adcli
Recommends: sssd-winbind-idmap = %{version}-%{release}

%description ad
Provides the Active Directory back end that the SSSD can utilize to fetch
identity data from and authenticate against an Active Directory server.

%package proxy
Summary:    The proxy back end of the SSSD
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}

%description proxy
Provides the proxy back end which can be used to wrap an existing NSS and/or
PAM modules to leverage SSSD caching.

%package -n libsss_idmap
Summary:    FreeIPA Idmap library
Group:      System/Libraries
License:    LGPLv3+
Conflicts:  sssd-%{mklibname ipa_hbac 0} < 1.13.0

%description -n libsss_idmap
Utility library to convert SIDs to Unix uids and gids.

%package -n libsss_idmap-devel
Summary:    FreeIPA Idmap library
Group:      Development/C
License:    LGPLv3+
Requires:   libsss_idmap = %{version}-%{release}

%description -n libsss_idmap-devel
Utility library to SIDs to Unix uids and gids.

%package -n libipa_hbac
Summary:    FreeIPA HBAC Evaluator library
Group:      System/Libraries
License:    LGPLv3+
Conflicts:  sssd-%{mklibname ipa_hbac 0} < 1.13.0

%description -n libipa_hbac
Utility library to validate FreeIPA HBAC rules for authorization requests.

%package -n libipa_hbac-devel
Summary:    FreeIPA HBAC Evaluator library
Group:      Development/C
License:    LGPLv3+
Requires:   libipa_hbac = %{version}-%{release}

%description -n libipa_hbac-devel
Utility library to validate FreeIPA HBAC rules for authorization requests.

%package -n python3-libipa_hbac
Summary:    Python3 bindings for the FreeIPA HBAC Evaluator library
Group:      Development/Python
License:    LGPLv3+
Requires:   libipa_hbac = %{version}-%{release}

%description -n python3-libipa_hbac
The python3-libipa_hbac contains the bindings so that libipa_hbac can be
used by Python 3 applications.

%package -n libsss_nss_idmap
Summary:    Library for SID based lookups
Group:      System/Libraries
License:    LGPLv3+

%description -n libsss_nss_idmap
Utility library for SID based lookups.

%package -n libsss_nss_idmap-devel
Summary:    Library for SID based lookups
Group:      Development/C
License:    LGPLv3+
Requires:   libsss_nss_idmap = %{version}-%{release}

%description -n libsss_nss_idmap-devel
Utility library for SID based lookups.

%package -n python3-libsss_nss_idmap
Summary:    Python3 bindings for libsss_nss_idmap
Group:      Development/Python
License:    LGPLv3+
Requires:   libsss_nss_idmap = %{version}-%{release}

%description -n python3-libsss_nss_idmap
The python3-libsss_nss_idmap contains the bindings so that libsss_nss_idmap can
be used by Python 3 applications.

%package dbus
Summary:    The D-Bus responder of the SSSD
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}

%description dbus
Provides the D-Bus responder of the SSSD, called the InfoPipe, that allows
the information from the SSSD to be transmitted over the system bus.

%package winbind-idmap
Summary:    SSSD's idmap_sss Backend for Winbind
Group:      System/Libraries
License:    GPLv3+ and LGPLv3+

%description winbind-idmap
The idmap_sss module provides a way for Winbind to call SSSD to map UIDs/GIDs
and SIDs.

%package nfs-idmap
Summary:    SSSD plug-in for NFSv4 rpc.idmapd
Group:      System/Libraries
License:    GPLv3+

%description nfs-idmap
The libnfsidmap sssd module provides a way for rpc.idmapd to call SSSD to map
UIDs/GIDs to names and vice versa. It can be also used for mapping principal
(user) name to IDs(UID or GID) or to obtain groups which user are member of.

%package -n libsss_certmap
Summary:    SSSD Certificate Mapping Library
Group:      System/Libraries
License:    LGPLv3+
Conflicts:  sssd-common < %{version}-%{release}

%description -n libsss_certmap
Library to map certificates to users based on rules.

%package -n libsss_certmap-devel
Summary:    SSSD Certificate Mapping Library
Group: 	    Development/C
License:    LGPLv3+
Requires:   libsss_certmap = %{version}-%{release}

%description -n libsss_certmap-devel
Library to map certificates to users based on rules.

%package kcm
Summary:    An implementation of a Kerberos KCM server
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}

%description kcm
An implementation of a Kerberos KCM server. Use this package if you want to
use the KCM: Kerberos credentials cache.

%package passkey
Summary:    SSSD helpers and plugins needed for authentication with passkey token
Group:      System/Libraries
License:    GPLv3+
Requires:   sssd-common = %{version}-%{release}

%description passkey
This package provides helper processes and Kerberos plugins that are
required to enable authentication with passkey token.

%prep
# Update timestamps on the files touched by a patch, to avoid non-equal
# .pyc/.pyo files across the multilib peers within a build, where "Level"
# is the patch prefix option (e.g. -p1)
# Taken from specfile for python-simplejson
UpdateTimestamps() {
  Level=$1
  PatchFile=$2

  # Locate the affected files:
  for f in $(diffstat $Level -l $PatchFile); do
    # Set the files to have the same timestamp as that of the patch:
    touch -r $PatchFile $f
  done
}

%setup -q

for p in %patches ; do
    %__patch -p1 -i $p
    UpdateTimestamps -p1 $p
done

%build
autoreconf -ivf
%configure \
    --runstatedir=%{_rundir} \
    --with-test-dir=/dev/shm \
    --with-ldb-lib-dir=%{ldb_modulesdir} \
    --with-db-path=%{dbpath} \
    --with-mcache-path=%{mcpath} \
    --with-pipe-path=%{pipepath} \
    --with-pubconf-path=%{pubconfpath} \
    --with-sssd-user=%{sssd_user} \
    --with-gpo-cache-path=%{gpocachepath} \
    --with-init-dir=%{_initrddir} \
    --with-krb5-rcache-dir=%{_localstatedir}/cache/krb5rcache \
    --enable-nsslibdir=/%{_libdir} \
    --enable-pammoddir=/%{_libdir}/security \
    --enable-nfsidmaplibdir=%{_libdir}/libnfsidmap \
    --disable-static \
    --disable-rpath \
    --with-initscript=systemd \
    --with-syslog=journald \
    --with-files-provider \
    --with-passkey \
    --enable-sss-default-nss-plugin \
    --enable-gss-spnego-for-zero-maxssf \
    --enable-systemtap \
    --without-python2-bindings \
    --without-oidc-child \
    --with-ssh-known-hosts-proxy \
    --with-allow-remote-domain-local-groups \
    --disable-polkit-rules-path
#    --with-smb-idmap-interface-version=6 \

%make_build all docs runstatedir=%{_rundir}

%py3_shebang_fix src/tools/sss_obfuscate

%install
rm -rf %{buildroot}/%{_lib}
ln -sf %{buildroot}/usr/%{_lib} %{buildroot}/%{_lib}

%make_install

# Prepare language files
%find_lang sssd

# Copy default logrotate file
install -D -m 644 src/examples/logrotate \
    %{buildroot}%{_sysconfdir}/logrotate.d/sssd

# Make sure SSSD is able to run on read-only root
install -D -m 644 src/examples/rwtab %{buildroot}%{_sysconfdir}/rwtab.d/sssd

# Kerberos KCM credential cache by default
mkdir -p %{buildroot}%{_sysconfdir}/krb5.conf.d
cp %{buildroot}%{_datadir}/sssd-kcm/kcm_default_ccache \
   %{buildroot}%{_sysconfdir}/krb5.conf.d/kcm_default_ccache

# Enable krb5 passkey plugins by default (when sssd-passkey package is installed)
cp %{buildroot}%{_datadir}/sssd/krb5-snippets/sssd_enable_passkey \
   %{buildroot}%{_sysconfdir}/krb5.conf.d/sssd_enable_passkey

# Create directory for cifs-idmap alternative
# Otherwise this directory could not be owned by sssd-client
mkdir -p %{buildroot}/%{_sysconfdir}/cifs-utils

# tmpfiles.d config
install -D -m 0644 contrib/sssd-tmpfiles.conf %{buildroot}%{_tmpfilesdir}/%{name}.conf

# Remove .la files created by libtool
find %{buildroot} -name "*.la" -delete

# Suppress developer-only documentation
rm -rf %{buildroot}%{_docdir}/%{name}

# Older versions of rpmbuild can only handle one -f option
# So we need to append to the sssd*.lang file
for file in `find %{buildroot}%{python3_sitelib} -maxdepth 1 -name "*.egg-info" 2> /dev/null`
do
    echo %{python3_sitelib}/`basename $file` >> python3_sssdconfig.lang
done

touch sssd.lang
for subpackage in sssd_ldap sssd_krb5 sssd_ipa sssd_ad sssd_proxy sssd_tools \
                  sssd_client sssd_dbus sssd_nfs_idmap sssd_winbind_idmap \
                  libsss_certmap sssd_kcm
do
    touch $subpackage.lang
done

for man in `find %{buildroot}%{_mandir}/??/man?/ -type f | sed -e "s#%{buildroot}%{_mandir}/##"`; do
    lang=`echo $man | cut -c 1-2`
    case `basename $man` in
        sss_cache*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd.lang
            ;;
        sss_ssh*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd.lang
            ;;
        sss_rpcidmapd*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_nfs_idmap.lang
            ;;
        sss_*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_tools.lang
            ;;
        sssctl*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_tools.lang
            ;;
        sssd_krb5_*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_client.lang
            ;;
        pam_sss*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_client.lang
            ;;
        sssd-ldap*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_ldap.lang
            ;;
        sssd-krb5*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_krb5.lang
            ;;
        sssd-ipa*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_ipa.lang
            ;;
        sssd-ad*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_ad.lang
            ;;
        sssd-proxy*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_proxy.lang
            ;;
        sssd-ifp*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_dbus.lang
            ;;
        sssd-kcm*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_kcm.lang
            ;;
        idmap_sss*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_winbind_idmap.lang
            ;;
        sss-certmap*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> libsss_certmap.lang
            ;;
        *)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd.lang
            ;;
    esac
done

# Print these to the rpmbuild log
echo "sssd.lang:"
cat sssd.lang

echo "python3_sssdconfig.lang:"
cat python3_sssdconfig.lang

for subpackage in sssd_ldap sssd_krb5 sssd_ipa sssd_ad sssd_proxy sssd_tools \
                  sssd_client sssd_dbus sssd_nfs_idmap sssd_winbind_idmap \
                  libsss_certmap sssd_kcm
do
    echo "$subpackage.lang:"
    cat $subpackage.lang
done

rm -f %{buildroot}/%{_lib}

%check
%if 0
#export PYTHON3_LIBS='-lpython%%{python3_version} -ldl'
export CK_TIMEOUT_MULTIPLIER=10
%__make check VERBOSE=yes
unset CK_TIMEOUT_MULTIPLIER
%endif

%post common
%_tmpfilescreate %{name}
%_post_service %{name}

%preun common
%_preun_service %{name}

%files
%license COPYING

%files common -f sssd.lang
%license COPYING
%doc src/examples/sssd-example.conf
%{_sbindir}/sssd
%{_unitdir}/sssd.service
%{_unitdir}/sssd-autofs.socket
%{_unitdir}/sssd-autofs.service
%{_unitdir}/sssd-nss.socket
%{_unitdir}/sssd-nss.service
%{_unitdir}/sssd-pac.socket
%{_unitdir}/sssd-pac.service
%{_unitdir}/sssd-pam.socket
%{_unitdir}/sssd-pam.service
%{_unitdir}/sssd-ssh.socket
%{_unitdir}/sssd-ssh.service
%{_unitdir}/sssd-sudo.socket
%{_unitdir}/sssd-sudo.service
%{_tmpfilesdir}/%{name}.conf

%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/sssd_be
%{_libexecdir}/%{name}/sssd_nss
%{_libexecdir}/%{name}/sssd_pam
%{_libexecdir}/%{name}/sssd_autofs
%{_libexecdir}/%{name}/sssd_ssh
%{_libexecdir}/%{name}/sssd_sudo
%{_libexecdir}/%{name}/p11_child
%{_libexecdir}/%{servicename}/sssd_check_socket_activated_responders
%{_libexecdir}/%{name}/sss_analyze

%dir %{_libdir}/%{name}
# The files provider is intentionally packaged in -common
%{_libdir}/%{name}/libsss_files.so
%{_libdir}/%{name}/libsss_simple.so

#Internal shared libraries
%{_libdir}/%{name}/libsss_child.so
%{_libdir}/%{name}/libsss_crypt.so
%{_libdir}/%{name}/libsss_cert.so
%{_libdir}/%{name}/libsss_debug.so
%{_libdir}/%{name}/libsss_krb5_common.so
%{_libdir}/%{name}/libsss_ldap_common.so
%{_libdir}/%{name}/libsss_util.so
%{_libdir}/%{name}/libifp_iface.so
%{_libdir}/%{name}/libifp_iface_sync.so
%{_libdir}/%{name}/libsss_iface.so
%{_libdir}/%{name}/libsss_iface_sync.so
%{_libdir}/%{name}/libsss_sbus.so
%{_libdir}/%{name}/libsss_sbus_sync.so

%{ldb_modulesdir}/memberof.so
%{_bindir}/sss_ssh_authorizedkeys
%{_bindir}/sss_ssh_knownhosts
%{_bindir}/sss_ssh_knownhostsproxy
%{_sbindir}/sss_cache
%{_libexecdir}/%{servicename}/sss_signal

%dir %{sssdstatedir}
%dir %{_localstatedir}/cache/krb5rcache
%attr(700,root,root) %dir %{dbpath}
%attr(755,root,root) %dir %{mcpath}
%attr(700,root,root) %dir %{secdbpath}
%attr(751,root,root) %dir %{deskprofilepath}
%ghost %attr(0644,root,root) %verify(not md5 size mtime) %{mcpath}/passwd
%ghost %attr(0644,root,root) %verify(not md5 size mtime) %{mcpath}/group
%ghost %attr(0644,root,root) %verify(not md5 size mtime) %{mcpath}/initgroups
%attr(755,root,root) %dir %{pipepath}
%attr(755,root,root) %dir %{pipepath}/private
%attr(755,root,root) %dir %{pubconfpath}
%attr(755,root,root) %dir %{gpocachepath}
%attr(750,root,root) %dir %{_var}/log/%{name}
%attr(700,root,root) %dir %{_sysconfdir}/sssd
%attr(711,root,root) %dir %{_sysconfdir}/sssd/conf.d
%attr(711,root,root) %dir %{_sysconfdir}/sssd/pki
%ghost %attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sssd/sssd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/sssd
%config(noreplace) %{_sysconfdir}/rwtab.d/sssd
%dir %{_datadir}/sssd
%{_sysconfdir}/pam.d/sssd-shadowutils
%dir %{_libdir}/%{name}/conf
%{_libdir}/%{name}/conf/sssd.conf

%{_datadir}/sssd/cfg_rules.ini
%{_datadir}/sssd/sssd.api.conf
%{_datadir}/sssd/sssd.api.d
%{_mandir}/man1/sss_ssh_authorizedkeys.1*
%{_mandir}/man1/sss_ssh_knownhosts.1*
%{_mandir}/man1/sss_ssh_knownhostsproxy.1*
%{_mandir}/man5/sssd.conf.5*
%{_mandir}/man5/sssd-files.5*
%{_mandir}/man5/sssd-simple.5*
%{_mandir}/man5/sssd-sudo.5*
%{_mandir}/man5/sssd-session-recording.5*
%{_mandir}/man8/sssd.8*
%{_mandir}/man8/sss_cache.8*
%dir %{_datadir}/sssd/systemtap
%{_datadir}/sssd/systemtap/id_perf.stp
%{_datadir}/sssd/systemtap/nested_group_perf.stp
%{_datadir}/sssd/systemtap/dp_request.stp
%{_datadir}/sssd/systemtap/ldap_perf.stp
%dir %{_datadir}/systemtap
%dir %{_datadir}/systemtap/tapset
%{_datadir}/systemtap/tapset/sssd.stp
%{_datadir}/systemtap/tapset/sssd_functions.stp
%{_mandir}/man5/sssd-systemtap.5*
%dir %{_datadir}/sssd/krb5-snippets
%{_datadir}/sssd/krb5-snippets/enable_sssd_conf_dir
%{_datadir}/sssd/krb5-snippets/sssd_enable_idp

%files ldap -f sssd_ldap.lang
%license COPYING
%{_libdir}/%{name}/libsss_ldap.so
%{_mandir}/man5/sssd-ldap.5*
%{_mandir}/man5/sssd-ldap-attributes.5*

%files krb5-common
%license COPYING
%attr(755,root,root) %dir %{pubconfpath}/krb5.include.d
%{_libexecdir}/%{servicename}/ldap_child
%{_libexecdir}/%{servicename}/krb5_child

%files krb5 -f sssd_krb5.lang
%license COPYING
%{_libdir}/%{name}/libsss_krb5.so
%{_mandir}/man5/sssd-krb5.5*

%files common-pac
%license COPYING
%{_libexecdir}/%{servicename}/sssd_pac

%files ipa -f sssd_ipa.lang
%license COPYING
%attr(700,root,root) %dir %{keytabdir}
%{_libdir}/%{name}/libsss_ipa.so
%{_libexecdir}/%{servicename}/selinux_child
%{_mandir}/man5/sssd-ipa.5*

%files ad -f sssd_ad.lang
%license COPYING
%{_libdir}/%{name}/libsss_ad.so
%{_libexecdir}/%{servicename}/gpo_child
%{_mandir}/man5/sssd-ad.5*

%files proxy
%license COPYING
%{_libexecdir}/%{servicename}/proxy_child
%{_libdir}/%{name}/libsss_proxy.so

%files dbus -f sssd_dbus.lang
%license COPYING
%{_libexecdir}/%{servicename}/sssd_ifp
%{_mandir}/man5/sssd-ifp.5*
%{_unitdir}/sssd-ifp.service
# InfoPipe DBus plumbing
%{_datadir}/dbus-1/system.d/org.freedesktop.sssd.infopipe.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.sssd.infopipe.service

%files client -f sssd_client.lang
%license src/sss_client/COPYING src/sss_client/COPYING.LESSER
/%{_libdir}/libnss_sss.so.2
/%{_libdir}/security/pam_sss.so
/%{_libdir}/security/pam_sss_gss.so
%{_libdir}/krb5/plugins/libkrb5/sssd_krb5_locator_plugin.so
%{_libdir}/krb5/plugins/authdata/sssd_pac_plugin.so
%dir %{_libdir}/cifs-utils
%{_libdir}/cifs-utils/cifs_idmap_sss.so
%dir %{_sysconfdir}/cifs-utils
%ghost %{_sysconfdir}/cifs-utils/idmap-plugin
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/modules
%{_libdir}/%{name}/modules/sssd_krb5_localauth_plugin.so
%{_libdir}/%{name}/modules/sssd_krb5_idp_plugin.so
%{_mandir}/man8/pam_sss.8*
%{_mandir}/man8/pam_sss_gss.8*
%{_mandir}/man8/sssd_krb5_locator_plugin.8*
%{_mandir}/man8/sssd_krb5_localauth_plugin.8*

%files -n libsss_sudo
%license src/sss_client/COPYING
%{_libdir}/libsss_sudo.so*

%files -n libsss_autofs
%license src/sss_client/COPYING src/sss_client/COPYING.LESSER
%dir %{_libdir}/%{name}/modules
%{_libdir}/%{name}/modules/libsss_autofs.so

%files tools -f sssd_tools.lang
%license COPYING
%{_sbindir}/sss_obfuscate
%{_sbindir}/sss_override
%{_sbindir}/sss_debuglevel
%{_sbindir}/sss_seed
%{_sbindir}/sssctl
%{_mandir}/man8/sss_obfuscate.8*
%{_mandir}/man8/sss_override.8*
%{_mandir}/man8/sss_debuglevel.8*
%{_mandir}/man8/sss_seed.8*
%{_mandir}/man8/sssctl.8*

%files -n python3-sssdconfig -f python3_sssdconfig.lang
%dir %{python3_sitelib}/SSSDConfig
%{python3_sitelib}/SSSDConfig/*.py*
%dir %{python3_sitelib}/SSSDConfig/__pycache__
%{python3_sitelib}/SSSDConfig/__pycache__/*.py*
%dir %{python3_sitelib}/sssd
%{python3_sitelib}/sssd/*.py*
%dir %{python3_sitelib}/sssd/__pycache__
%{python3_sitelib}/sssd/__pycache__/*.py*
%dir %{python3_sitelib}/sssd/modules
%{python3_sitelib}/sssd/modules/*.py*
%dir %{python3_sitelib}/sssd/modules/__pycache__
%{python3_sitelib}/sssd/modules/__pycache__/*.py*

%files -n python3-sss
%{python3_sitearch}/pysss.so

%files -n python3-sss-murmur
%{python3_sitearch}/pysss_murmur.so

%files -n libsss_idmap
%license src/sss_client/COPYING src/sss_client/COPYING.LESSER
%{_libdir}/libsss_idmap.so.*

%files -n libsss_idmap-devel
%doc idmap_doc/html
%{_includedir}/sss_idmap.h
%{_libdir}/libsss_idmap.so
%{_libdir}/pkgconfig/sss_idmap.pc

%files -n libipa_hbac
%license src/sss_client/COPYING src/sss_client/COPYING.LESSER
%{_libdir}/libipa_hbac.so.*

%files -n libipa_hbac-devel
%doc hbac_doc/html
%{_includedir}/ipa_hbac.h
%{_libdir}/libipa_hbac.so
%{_libdir}/pkgconfig/ipa_hbac.pc

%files -n libsss_nss_idmap
%license src/sss_client/COPYING src/sss_client/COPYING.LESSER
%{_libdir}/libsss_nss_idmap.so.*

%files -n libsss_nss_idmap-devel
%doc nss_idmap_doc/html
%{_includedir}/sss_nss_idmap.h
%{_libdir}/libsss_nss_idmap.so
%{_libdir}/pkgconfig/sss_nss_idmap.pc

%files -n python3-libsss_nss_idmap
%{python3_sitearch}/pysss_nss_idmap.so

%files -n python3-libipa_hbac
%{python3_sitearch}/pyhbac.so

%files winbind-idmap -f sssd_winbind_idmap.lang
%dir %{_libdir}/samba/idmap
%{_libdir}/samba/idmap/sss.so
%{_mandir}/man8/idmap_sss.8*

%files nfs-idmap -f sssd_nfs_idmap.lang
%{_mandir}/man5/sss_rpcidmapd.5*
%{_libdir}/libnfsidmap/sss.so

%files -n libsss_certmap -f libsss_certmap.lang
%license src/sss_client/COPYING src/sss_client/COPYING.LESSER
%{_libdir}/libsss_certmap.so.*
%{_mandir}/man5/sss-certmap.5*

%files -n libsss_certmap-devel
%doc certmap_doc/html
%{_includedir}/sss_certmap.h
%{_libdir}/libsss_certmap.so
%{_libdir}/pkgconfig/sss_certmap.pc

%files kcm -f sssd_kcm.lang
%{_libexecdir}/%{servicename}/sssd_kcm
%config(noreplace) %{_sysconfdir}/krb5.conf.d/kcm_default_ccache
%dir %{_datadir}/sssd-kcm
%{_datadir}/sssd-kcm/kcm_default_ccache
%{_unitdir}/sssd-kcm.socket
%{_unitdir}/sssd-kcm.service
%{_mandir}/man8/sssd-kcm.8*

%files passkey
%attr(755,%{sssd_user},%{sssd_user}) %{_libexecdir}/%{name}/passkey_child
%{_libdir}/%{name}/modules/sssd_krb5_passkey_plugin.so
%{_datadir}/sssd/krb5-snippets/sssd_enable_passkey
%config(noreplace) %{_sysconfdir}/krb5.conf.d/sssd_enable_passkey
