Summary:	Throttleable lightweight httpd server
Name:		sthttpd
Version:	2.27.0
Release:	%mkrel 6
License:	BSD
Group:		System/Servers
URL:		http://opensource.dyc.edu/sthttpd
Source0:	ftp://opensource.dyc.edu/pub/sthttpd/sthttpd-%{version}.tar.gz
Source1:	ftp://opensource.dyc.edu/pub/sthttpd/sthttpd-%{version}.tar.gz.asc
Source2:	thttpd.service
Source3:	thttpd.conf
Source4:	thttpd.logrotate
Source5:	thttpd.sysconfig
Source6:	thttpd-index.html
# http://jonas.fearmuffs.net/software/thttpd/thttpd-2.25b+impan-pl5.diff.gz
Patch0:		sthttpd-2.26.4+impan-pl5.diff
# https://www.ogris.de/thttpd/thttpd-2.25b.access.patch.diff
Patch1:		sthttpd-2.26.4-htaccess.diff
# http://rekl.yi.org/thttpd/pub/patch-thttpd-2.25b-re1
Patch2:		sthttpd-2.26.4-re1.diff
Patch3:		sthttpd-2.27.0-no_funky_crap.diff
Patch4:		sthttpd-fix-building-with-gcc14.patch
Requires(post): rpm-helper
Requires(preun): rpm-helper
Provides:	webserver
BuildRequires:	pkgconfig(zlib)

%description
This is a fork of Jef Poskanzer's popular thttpd server, which you can read
about on his acme.com page. When the gentoo ebuild was abandoned in March 2012,
I decided to take a look at this package. Since upstream considered this
project "done" and was not accepting any new patches, and since the Gentoo tree
had a backlog of patches going back to 2006, I decided let it get tree cleaned.
However, the masses revolted! So, I decided the only sensible thing was to fork
the code and create an avenue for people who wanted to continue patching the
code. My major contribution to the fork was to revamp the build system and
modernize it. That was an almost total rewrite. However, the codebase remains
essentially the same, plus the dozen or so Gentoo patches that we'd collected
along the way.

%prep

%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1

# tag the default index.html page
cp %{SOURCE6} index.html
perl -pi -e "s|_NAME_-_VERSION_|%{name}-%{version}|g" index.html

echo "# put some css in here for directory listings" > dirlist.css 
echo "# put some css in here for custom error messages" > error.css
echo "<b>This directory contains 'el cheapo' style web links.</b>" > .description

# Convert man pages to UTF8
for man in docs/*.8 docs/*.1; do
    iconv -f iso8859-1 -t utf-8 -o tmp ${man}
    mv -f tmp ${man}
done

%build
# due to P2
export LIBS="-lz"

export CFLAGS="%{optflags} -UHAVE_SIGSET"

%configure

%make_build \
    prefix=%{_prefix} \
    BINDIR=%{_sbindir} \
    MANDIR=%{_mandir} \
    WEBDIR=/var/lib/thttpd \
    WEBGROUP=thttpd \
    CGIBINDIR=/var/lib/thttpd/cgi-bin

%install

# make some directories
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sysconfdir}/{sysconfig,logrotate.d}
install -d %{buildroot}/var/lib/thttpd/{cgi-bin,errors,styles,links}
install -d %{buildroot}/var/log/thttpd
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_mandir}/man{1,8}

%make_install WEBDIR=/var/lib/thttpd

install -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/
install -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/thttpd.conf
install -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/thttpd
install -m0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/thttpd

install -m0644 index.html %{buildroot}/var/lib/thttpd/
install -m0644 dirlist.css %{buildroot}/var/lib/thttpd/styles/
install -m0644 error.css %{buildroot}/var/lib/thttpd/styles/
install -m0644 .description %{buildroot}/var/lib/thttpd/links/

# el-cheapo softlinks
pushd %{buildroot}/var/lib/thttpd/links
    ln -snf "http://opensource.dyc.edu/pub/sthttpd/sthttpd-%{version}.tar.gz" sthttpd-%{version}.tar.gz
popd

# don't ship this one
rm -f %{buildroot}/var/lib/thttpd/cgi-bin/printenv

# rename this one
mv %{buildroot}%{_sbindir}/htpasswd %{buildroot}%{_sbindir}/th_htpasswd

%pre
%_pre_useradd thttpd /var/lib/thttpd /bin/nologin

%post
%_post_service thttpd

%preun
%_preun_service thttpd

%postun
%_postun_userdel thttpd

%files
%doc README TODO
%{_unitdir}/thttpd.service
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/thttpd.conf
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/logrotate.d/thttpd
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/thttpd
%config(noreplace) %attr(0644,root,root) /var/lib/thttpd/styles/*.css
%config(noreplace) %attr(0644,root,root) /var/lib/thttpd/index.html
%attr(2755,thttpd,thttpd) %{_sbindir}/makeweb
%attr(0755,root,root) %{_sbindir}/th_htpasswd
%attr(0755,root,root) %{_sbindir}/syslogtocern
%attr(0755,root,root) %{_sbindir}/thttpd
%attr(0755,thttpd,thttpd) %dir /var/lib/thttpd
%attr(0755,thttpd,thttpd) %dir /var/lib/thttpd/cgi-bin
%attr(0755,thttpd,thttpd) %dir /var/log/thttpd
%attr(0755,root,root) /var/lib/thttpd/cgi-bin/phf
%attr(0755,root,root) /var/lib/thttpd/cgi-bin/redirect
%attr(0755,root,root) /var/lib/thttpd/cgi-bin/ssi
%attr(0644,root,root) %{_mandir}/man*/*
%attr(0644,thttpd,thttpd) /var/lib/thttpd/links/.description
%attr(0644,thttpd,thttpd) /var/lib/thttpd/links/*

