# Do not generate provides for private libraries
%global __provides_exclude_from ^%{_libdir}/stunnel/.*$

Summary:	Program that wraps normal socket connections with SSL/TLS
Name:		stunnel
Version:	5.69
Release:	%mkrel 1
License:	GPLv2+
Group:		System/Servers
URL:		https://www.stunnel.org/
Source0:	https://www.stunnel.org/downloads/%{name}-%{version}.tar.gz
Source1:	https://www.stunnel.org/downloads/%{name}-%{version}.tar.gz.asc
Source2:	stunnel.service
Source3:	stunnel.tmpfiles
	
# Apply patch stunnel-5.61-systemd-service.patch
Patch1:   stunnel-5.61-systemd-service.patch
# Apply patch stunnel-5.56-system-ciphers.patch
Patch3:   stunnel-5.69-system-ciphers.patch
# Apply patch stunnel-5.56-coverity.patch
Patch4:   stunnel-5.56-coverity.patch
# Apply patch stunnel-5.61-default-tls-version.patch
Patch5:   stunnel-5.69-default-tls-version.patch
# Apply patch stunnel-5.56-curves-doc-update.patch
Patch6:   stunnel-5.56-curves-doc-update.patch
# Limit curves defaults in FIPS mode
Patch8:   stunnel-5.62-disabled-curves.patch
BuildRequires:	pkgconfig(openssl) >= 0.9.5
Requires(post):	openssl
BuildRequires: netcat-traditional
BuildRequires: python3
BuildRequires: openssl

%description
The stunnel program is designed to work as SSL encryption wrapper between 
remote clients and local (inetd-startable) or remote servers. The concept is 
that having non-SSL aware daemons running on your system you can easily set 
them up to communicate with clients over secure SSL channels.

stunnel can be used to add SSL functionality to commonly used inetd daemons 
like POP-2, POP-3, and IMAP servers, to standalone daemons like NNTP, SMTP 
and HTTP, and in tunneling PPP over network sockets without changes to the 
source code.

%prep
%autosetup -S gendiff -p1

%build
%configure \
    --with-ssl=%{_prefix} \
    --disable-static \
    --enable-shared \
    --with-bashcompdir=%{buildroot}%{_datadir}/bash-completion/completions \
--disable-libwrap \
    --enable-fips \
    --enable-ipv6
    
%make_build pkglibdir=%{_libdir}

%install
# (oe) hack... don't generate the pem file, and stunnel.conf
install -d %{buildroot}%{_sysconfdir}/%{name}
touch %{buildroot}%{_sysconfdir}/%{name}/stunnel.pem

%makeinstall docdir=`pwd`/doc-to-install pkglibdir=%{buildroot}%{_libdir}

install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/stunnel.service

install -D -m 644 %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/stunnel.conf

mv %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf-sample \
    %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf

perl -pi \
    -e 's|chroot = .*|chroot = /run/stunnel|;' \
    -e 's|cert = .*|cert = /etc/pki/tls/certs/stunnel.pem|;' \
    -e 's|;key = .*|key = /etc/pki/tls/private/stunnel.pem|;' \
    -e 's|;pid = .*|pid = /run/stunnel/stunnel.pid|;' \
    -e 's|options = NO_SSLv2|options = NO_SSLv2\noptions = NO_SSLv3|;' \
    %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf

# Move the translated man pages to the right subdirectories, and strip off the
# language suffixes.
for lang in pl ; do
    mkdir -p %{buildroot}%{_mandir}/${lang}/man8
    mv %{buildroot}%{_mandir}/man8/*.${lang}.8* %{buildroot}%{_mandir}/${lang}/man8/
    rename ".${lang}" "" %{buildroot}%{_mandir}/${lang}/man8/*
done

# cleanup
rm -f ./doc-to-install/INSTALL.W32 ./doc-to-install/COPYRIGHT.GPL
rm -f %{buildroot}%{_sysconfdir}/%{name}/stunnel.pem
rm -f %{buildroot}%{_libdir}/libstunnel.la

%check
if ! make test; then
	for i in tests/logs/*.log; do
		echo "$i":
		cat "$i"
	done
	exit 1
fi

%post
%_tmpfilescreate %{name}
%_create_ssl_certificate stunnel

%files
%doc doc-to-install/*
%{_bindir}/stunnel
%{_bindir}/stunnel3
%{_mandir}/man8/stunnel.8.*
%lang(pl) %{_mandir}/pl/man8/stunnel.8*
%config(noreplace) %{_sysconfdir}/%{name}/stunnel.conf
%{_unitdir}/stunnel.service
%{_prefix}/lib/tmpfiles.d/stunnel.conf
%{_libdir}/libstunnel.so
%{_datadir}/bash-completion/completions/%{name}.bash
