%global         _legacy_common_support 1

%global	        sum               Nonlinear, differential and algebraic equation solvers

%define         majornum          7
%define         libname           %mklibname %{name} %{majornum}
%define         develname         %mklibname %{name} -d

%define         arkmajor          6
%define         cvmajor           7
%define         cvsmajor          7
%define         idasmajor         6
%define         idamajor          7
%define         kinmajor          7
%define         nvecmajor         7
%define         sunmatmajor       5
%define         sunlinmajor       5
%define         sunnonlinmajor    4

%define         gccinstalldir     %(LC_ALL=C gcc --print-search-dirs | grep install | awk '{print $2}')
%define         fincludedir       %{gccinstalldir}finclude

# On 32 bits arches, integer are defaulted to 32 bits (integer(4))),
# but the fortran interfaces seems to have been hardcoded as
# integer(8). Currently, the build will fail on all 32 bits arches.
# bug reported upstream: https://github.com/LLNL/sundials/issues/468
#ifnarch #arm32 #ix86
%bcond_without	fortran
#else
#bcond_with	fortran
#endif



%ifnarch %arm32 %ix86
%bcond_without  mpi
%else
%bcond_with     mpi
%endif

Name:           sundials
Version:        7.1.1
Release:        %mkrel 3
Summary:        %{sum}
License:        BSD
Group:          Sciences/Computer science

URL:            https://computing.llnl.gov/projects/sundials
Source0:        https://github.com/LLNL/sundials/releases/download/v%{version}/sundials-%{version}.tar.gz

BuildRequires:  cmake
%if %{with fortran}
BuildRequires:  gcc-gfortran
%endif
%ifarch %{ix86} x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel
BuildRequires:  lapack-devel
BuildRequires:  blas-devel
BuildRequires:  suitesparse-devel
%if %{with mpi}
BuildRequires:  pkgconfig(ompi)
%endif

Requires:       %{libname} = %{version}-%{release}

%description
SUNDIALS is an award-winning SUite of Nonlinear and
DIfferential/ALgebraic equation Solvers implemented with the goal of
providing robust time integrators and nonlinear solvers that can
easily be incorporated into existing simulation codes. The primary
design goals are to require minimal information from the user, allow
users to easily supply their own data structures underneath the
packages, and allow for easy incorporation of user-supplied linear
solvers and preconditioners. The main numerical operations performed
in these codes are operations on data vectors, and the codes have been
written in terms of interfaces to these vector operations. The codes
also come with default vector structures with pre-defined operation
implementations for serial, shared-memory parallel (openMP and
PThreads), and distributed memory parallel (MPI) environments in case
a user prefers not to supply their own structures. In addition, all
parallelism is contained within specific vector operations (norms, dot
products, etc.). No other operations within the solvers require
knowledge of parallelism.



%package -n %{libname}
Summary:        The SUNDIALS libraries
Group:          System/Libraries

%description -n %{libname}
%{sum}.


%package -n %{develname}
Summary:        Development files for the SUNDIALS libraries
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       sundials-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
%{sum}.


%prep
%setup -q
%autopatch -p1

%build
%cmake \
          -DBUILD_STATIC_LIBS:BOOL=OFF \
          -DCMAKE_INSTALL_LIBSUFFIX="%{_lib}" \
          -DCMAKE_INSTALL_LIBDIR="%{_libdir}" \
%if %{with fortran}
          -DBUILD_FORTRAN77_INTERFACE:BOOL=OFF \
	  -DBUILD_FORTRAN_MODULE_INTERFACE:BOOL=ON \
          -DFortran_INSTALL_MODDIR:PATH=%{fincludedir} \
%endif
          -DENABLE_LAPACK:BOOL=ON \
          -DENABLE_BLAS:BOOL=ON \
%ifnarch  %arm32 %ix86
	  -DENABLE_KLU:BOOL=ON \
          -DKLU_INCLUDE_DIR:PATH=%{_includedir}/suitesparse \
          -DKLU_LIBRARY_DIR:PATH=%{_libdir} \
%else
	  -DENABLE_KLU:BOOL=OFF \
%endif	  
%if %{with mpi}
    	  -DENABLE_MPI:BOOL=ON \
%endif	   
          -DENABLE_OPENMP:BOOL=ON \
          -DENABLE_PTHREADS:BOOL=ON \
          -DEXAMPLES_INSTALL_PATH=%{_datadir}/%{name}/examples \
          -DCMAKE_SKIP_RPATH:BOOL=YES \
	  -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES
	  
%cmake_build

%install
%cmake_install

# remove static files
find %{buildroot} -name "*.a" -delete

%__rm %{buildroot}%{_includedir}/sundials/LICENSE

%files
%doc LICENSE README.md
%{_datadir}/sundials


%files -n %{libname}
%{_libdir}/libsundials_core.so.%{majornum}{,.*}
%{_libdir}/libsundials_arkode.so.%{arkmajor}{,.*}
%{_libdir}/libsundials_cvode.so.%{cvmajor}{,.*}
%{_libdir}/libsundials_cvodes.so.%{cvsmajor}{,.*}
%if %{with fortran}
%{_libdir}/libsundials_farkode_mod.so.%{arkmajor}{,.*}
%{_libdir}/libsundials_fcvode_mod.so.%{cvmajor}{,.*}
%{_libdir}/libsundials_fcvodes_mod.so.%{cvsmajor}{,.*}
%{_libdir}/libsundials_fida_mod.so.%{idamajor}{,.*}
%{_libdir}/libsundials_fidas_mod.so.%{idasmajor}{,.*}
%{_libdir}/libsundials_fkinsol_mod.so.%{kinmajor}{,.*}
%{_libdir}/libsundials_fnvec*.so.%{nvecmajor}{,.*}
%{_libdir}/libsundials_fsunlin*.so.%{sunlinmajor}{,.*}
%{_libdir}/libsundials_fsunmat*.so.%{sunmatmajor}{,.*}
%{_libdir}/libsundials_fsunnonlin*.so.%{sunnonlinmajor}{,.*}
%endif
%{_libdir}/libsundials_ida.so.%{idamajor}{,.*}
%{_libdir}/libsundials_idas.so.%{idasmajor}{,.*}
%{_libdir}/libsundials_kinsol.so.%{kinmajor}{,.*}
%{_libdir}/libsundials_nvec*.so.%{nvecmajor}{,.*}
%{_libdir}/libsundials_sunlin*.so.%{sunlinmajor}{,.*}
%{_libdir}/libsundials_sunmat*.so.%{sunmatmajor}{,.*}
%{_libdir}/libsundials_sunnonlin*.so.%{sunnonlinmajor}{,.*}

%files -n %{develname}
%{_includedir}/*/*.h
%{_includedir}/*/*.hpp
%{_includedir}/sundials/NOTICE
%{_includedir}/sundials/priv/*.h
%{_libdir}/libsundials_*.so
%{_libdir}/cmake/sundials/*.cmake
%if %{with fortran}
%{fincludedir}/*.mod
%endif
