# Whether we should verify tarball signature with GPGv2.
%global verify_tarball_signature %{nil}

# The source directory.
%global source_directory 5.3-development

Summary:       Tool for creating supermin appliances
Name:          supermin
Version:       5.3.3
Release:       %mkrel 2
License:       GPLv2+
Group:         Development/Tools
URL:           https://people.redhat.com/~rjones/supermin/
Source0:       https://download.libguestfs.org/supermin/%{source_directory}/%{name}-%{version}.tar.gz
Source1:       https://download.libguestfs.org/supermin/%{source_directory}/%{name}-%{version}.tar.gz.sig
# Keyring used to verify tarball signature.
Source2:       libguestfs.keyring

Patch0:        urpmi-debug.patch

BuildRequires: gcc
BuildRequires: make
BuildRequires: autoconf, automake
BuildRequires: perl
BuildRequires: rpm
BuildRequires: rpm-devel
BuildRequires: dnf
BuildRequires: dnf-plugins-core
BuildRequires: e2fsprogs
BuildRequires: e2fsprogs-devel
BuildRequires: findutils
BuildRequires: glibc-static-devel
BuildRequires: ocaml
BuildRequires: ocaml-findlib-devel
# man page
BuildRequires: perl-doc

# (ngompa): These are urpmi-specific dependencies
BuildRequires: fakeroot
BuildRequires: urpmi

# These are required only to run the tests.  We could patch out the
# tests to not require these packages.
BuildRequires: augeas hivex kernel tar

# This only includes the dependencies needed at runtime, ie.  supermin
# --build.  For supermin --prepare, dependencies like dnf are placed
# in the -devel subpackage.
Requires:      rpm
Requires:      util-linux-ng
Requires:      cpio
Requires:      tar
# RHBZ#771310
Requires:      e2fsprogs >= 1.42

# (ngompa): These are urpmi-specific dependencies
Requires:      fakeroot
Requires:      urpmi

# For automatic RPM dependency generation.
# See: https://rpm-software-management.github.io/rpm/manual/dependency_generators.html
Source3:       supermin.attr
Source4:       supermin-find-requires


%description
Supermin is a tool for building supermin appliances.  These are tiny
appliances (similar to virtual machines), usually around 100KB in
size, which get fully instantiated on-the-fly in a fraction of a
second when you need to boot one of them.

Note that if you want to run 'supermin --prepare' you will need the
extra dependencies provided by %{name}-devel.

%package devel
Summary:       Development tools for %{name}
Requires:      %{name}%{?_isa} = %{version}-%{release}
Requires:      rpm-build

# Dependencies needed for supermin --prepare
Requires:      urpmi
#Requires:      dnf
Requires:      dnf-plugins-core
Requires:      findutils


%description devel
%{name}-devel contains development tools for %{name}.

It contains extra dependencies needed for 'supermin --prepare' to
work, as well as tools for automatic RPM dependency generation from
supermin appliances.


%prep
%if 0%{verify_tarball_signature}
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%endif
%autosetup -p1

%build
autoreconf -fi
%configure --disable-network-tests
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0644 %{SOURCE3} %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0755 %{SOURCE4} %{buildroot}%{_rpmconfigdir}/

%check

# Disable failing test for now
# Fedora seems to have it passing since f21 but their package is very
# different, and for example uses dietlibc
%ifarch %{arm}
export SKIP_TEST_EXECSTACK=1
%endif

make check || {
     cat tests/test-suite.log
     exit 1
}

%files
%license COPYING
%doc README examples/build-basic-vm.sh
%{_bindir}/supermin
%{_mandir}/man1/supermin.1*

%files devel
%{_rpmconfigdir}/fileattrs/supermin.attr
%{_rpmconfigdir}/supermin-find-requires
