%define uname   SuperTuxKart

# Comment out when not a pre-release
#define prerel  rc1

%define rel     4

Summary:        3D kart racing game
Name:           supertuxkart
Version:        1.4
Release:        %mkrel %{?prerel:0.%{prerel}.}%{rel}
Group:          Games/Arcade
License:        GPLv2+
URL:            https://supertuxkart.net
Source0:        https://github.com/supertuxkart/stk-code/releases/download/%{version}%{?prelrel:-%{prerel}}/%{uname}-%{version}%{?prerel:-%{prerel}}-src.tar.xz
Patch0:         supertuxkart-1.3-fix-desktop-file.patch
Patch1:         0001-Fix-missing-rotation-when-lto-is-used.patch
# https://github.com/supertuxkart/stk-code/issues/4834
Patch2:         0001-Fix-crash-bug#4834.patch
Patch3:         stk-gcc13.patch

BuildRequires:  cmake
BuildRequires:  angelscript-devel
BuildRequires:  libgomp-devel
BuildRequires:  mcpp-devel
BuildRequires:  squish-devel
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(shaderc)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  wiiuse-devel
Requires:       %{name}-data >= %{version}

# STK uses an ancient, modified version of bullet, and can't build against
# system bullet.
Provides:       bundled(bullet) = 2.79
# Bundled enet is modified to add IPv6 support, which is lacking in the
# unmaintained upstream enet.
# We could build against system enet, but then we can't support IPv6.
Provides:       bundled(libenet) = 1.3.14

Provides:       bundled(sheenbidi) = 13.0.0
Provides:       bundled(libtinygettext) = 0.1.0

%description
SuperTuxKart is a free 3D kart racing game. The aim is to make the game fun
more than to make it realistic. You can play with up to 4 friends on one PC,
racing against each other or just try to beat the computer (a network
multiplayer feature is planned).

You can do a single race against other karts, compete in one of several
Grand Prix, try to beat the high score in time trials on your own,
play battle mode against your friends, and more!

%package data
Summary:        Data files for the SuperTuxKart game
Group:          Games/Arcade
BuildArch:      noarch

%description data
This package contains data files for SuperTuxKart.

%prep
%autosetup -p1 -n %{uname}-%{version}%{?prerel:-%{prerel}}-src

rm -rf lib/{angelscript,libsquish,mcpp,wiiuse}

%build
%cmake -DSTK_INSTALL_BINARY_DIR=%{_gamesbindir} \
       -DSTK_INSTALL_DATA_DIR=%{_gamesdatadir}/%{name} \
       -DBUILD_SHARED_LIBS=OFF \
       -DBUILD_RECORDER=OFF \
       -DUSE_SYSTEM_ENET=OFF \
       -DUSE_SYSTEM_ANGELSCRIPT=ON \
       -DUSE_SYSTEM_SQUISH=ON \
       -DUSE_SYSTEM_WIIUSE=ON

%cmake_build

%install
%cmake_install

# Already in hicolor
rm -rf %{buildroot}%{_datadir}/pixmaps

%files
%doc CHANGELOG.md README.md
%{_gamesbindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_metainfodir}/%{name}.appdata.xml
%{_iconsdir}/hicolor/*/apps/%{name}.png

%files data
%{_gamesdatadir}/%{name}/
