%define major		2
%define libname		%mklibname htp %{major}
%define libname_devel	%mklibname htp -d

Summary: 	Intrusion Detection System
Name: 		suricata
Version: 	7.0.10
Release: 	%mkrel 1
License: 	GPLv2+
Group: 		Security
URL: 		https://suricata.io/
Source0: 	https://www.openinfosecfoundation.org/download/%{name}-%{version}.tar.gz
Source1:	https://www.openinfosecfoundation.org/download/%{name}-%{version}.tar.gz.sig
Source3:	suricata.sysconfig
Source4:	suricata.logrotate
Source5:	suricata-tmpfiles.conf
# Irrelevant docs are getting installed, drop them
Patch1: suricata-2.0.9-docs.patch
# Suricata service file needs some options supplied
Patch2: suricata-4.1.1-service.patch
# The default path needs to be fixed up to where Fedora keeps it
Patch4: suricata-5.0.4-geolite-path-fixup.patch
# The log path has an extra '/' at the end
Patch5: suricata-6.0.3-log-path-fixup.patch
BuildRequires:	pkgconfig(yaml-0.1)
BuildRequires:	pkgconfig(libnfnetlink)
BuildRequires:	pkgconfig(libnetfilter_log)
BuildRequires:	pkgconfig(libnetfilter_queue)
BuildRequires:	net2-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pcap-devel
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(libcap-ng)
BuildRequires:	magic-devel
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(nspr)
BuildRequires:	pkgconfig(nss)
BuildRequires:	pkgconfig(libmaxminddb)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(lua)
BuildRequires:	pkgconfig(hiredis)
BuildRequires:	pkgconfig(libevent)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	rust
BuildRequires:	cargo
BuildRequires:	python3-yaml
%ifarch x86_64
BuildRequires:	pkgconfig(libhs)
BuildRequires:	clang
BuildRequires:	llvm
BuildRequires:	pkgconfig(libbpf)
%endif
Requires:	python3-yaml

%description
The Suricata Engine is an Open Source Next Generation Intrusion
Detection and Prevention Engine. This engine is not intended to
just replace or emulate the existing tools in the industry, but
will bring new ideas and technologies to the field. This new Engine
supports Multi-threading, Automatic Protocol Detection (IP, TCP,
UDP, ICMP, HTTP, TLS, FTP and SMB! ), Gzip Decompression, Fast IP
Matching and coming soon hardware acceleration on CUDA and OpenCL
GPU cards.

%package	-n 	%{libname}
Summary:        HTP library
Group:          Networking/Other

%description 	-n	%{libname}
none for the moment.

%package	-n	%{libname_devel}
Summary:        HTP library developement
Group:          Networking/Other
Provides:	htp-devel = %{version}-%{release}

%description 	-n	%{libname_devel}
none for the moment.
These are devel files.

%prep
%autosetup -p1

sed -i 's/(datadir)/(sysconfdir)/' etc/Makefile.am
%ifarch x86_64
sed -i 's/-D__KERNEL__/-D__KERNEL__ -D__x86_64__/' ebpf/Makefile.am
%endif

find rust/ -name '*.rs' -type f -perm /111 -exec chmod -v -x '{}' '+'

# clear executable bit on lib.rs, this is rust file and should not be marked executable
chmod -x rust/vendor/alloc-no-stdlib/src/lib.rs

%build
autoreconf -fi
export CPPFLAGS=-I..
%configure \
    --disable-static \
    --enable-gccprotect \
    --enable-pie \
    --disable-gccmarch-native \
    --disable-coccinelle \
    --enable-nfqueue \
    --enable-nflog \
    --enable-af-packet \
    --enable-jansson \
    --enable-geoip \
    --enable-lua \
    --enable-hiredis \
    --disable-prelude \
    --enable-rust \
%ifarch x86_64
    --enable-ebpf-build \
    --enable-ebpf \
%endif
    --enable-python

%make_build

%install
%make_install

# Setup etc directory
install -d -m 755 %{buildroot}%{_sysconfdir}/suricata
install -m 644 suricata.yaml %{buildroot}%{_sysconfdir}/suricata
install -m 644 *.config %{buildroot}%{_sysconfdir}/%{name}
install -m 644 etc/*.config %{buildroot}%{_sysconfdir}/%{name}

install -d -m 755 %{buildroot}%{_sysconfdir}/suricata/rules
install -m 644 rules/*.rules %{buildroot}%{_sysconfdir}/%{name}/rules

install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/suricata

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 etc/%{name}.service %{buildroot}%{_unitdir}/%{name}.service

install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 etc/%{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# Make logging directory
install -d -m 755 %{buildroot}%{_var}/log/suricata

# drop .la file
rm -f %{buildroot}%{_libdir}/libhtp.la
rm -f %{buildroot}%{_libdir}/libhtp.a
rm -fr %{buildroot}%{_docdir}/%{name}

# Setup suricata-update data directory
install -d -m 755 %{buildroot}%{_var}/lib/%{name}

# Setup tmpdirs
install -d -m 755 %{buildroot}%{_tmpfilesdir}
install -m 644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf

cp suricata-update/README.rst doc/suricata-update-README.rst

%py3_shebang_fix %{buildroot}%{_prefix}/lib/suricata/python/suricata/sc/suricatasc.py

%check
make check

%pre
%_pre_useradd suricata %{_var}/log/suricata /sbin/nologin

%post
%_post_service suricata

%preun
%_preun_service suricata

%files
%doc doc/Basic_Setup.txt doc/suricata-update-README.rst
%doc doc/Setting_up_IPSinline_for_Linux.txt
%doc COPYING
%{_bindir}/suricata
%{_bindir}/suricatasc
%{_bindir}/suricatactl
%{_bindir}/suricata-update
%{_datadir}/suricata
%attr(755,suricata,suricata) %dir %{_var}/log/suricata
%attr(755,suricata,suricata) %dir %{_var}/lib/%{name}
%dir %{_sysconfdir}/suricata
%dir %{_sysconfdir}/suricata/rules
%{_unitdir}/suricata.service
%config(noreplace) %{_tmpfilesdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/suricata/suricata.yaml
%config(noreplace) %{_sysconfdir}/%{name}/*.config
%config(noreplace) %{_sysconfdir}/%{name}/rules/*.rules
%config(noreplace) %{_sysconfdir}/sysconfig/suricata
%config(noreplace) %{_sysconfdir}/logrotate.d/suricata
%{_prefix}/lib/suricata
%{_mandir}/man1/suricata.1*
%{_mandir}/man1/suricatactl-filestore.1*
%{_mandir}/man1/suricatactl.1*
%{_mandir}/man1/suricatasc.1*

%files -n %{libname}
%{_libdir}/libhtp.so.%{major}{,.*}

%files -n %{libname_devel}
%{_includedir}/htp/
%{_libdir}/libhtp.so
%{_libdir}/pkgconfig/htp.pc

