%global major   0
%define libname %mklibname wtpm_libtpms %major
%define devname %mklibname wtpm_libtpms -d

%bcond_without gnutls

Group:          Emulators
Summary:        TPM Emulator
Name:           swtpm
Version:        0.10.0
Release:        %mkrel 1
License:        BSD-3-Clause
Url:            https://github.com/stefanberger/swtpm
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  git-core
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  libtool
BuildRequires:  libtpms-devel >= 0.6.0
BuildRequires:  expect
BuildRequires:  net-tools
BuildRequires:  openssl-devel
BuildRequires:  socat
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-cryptography
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-twisted
BuildRequires:  trousers >= 0.3.9
BuildRequires:  softhsm
%if %{with gnutls}
BuildRequires:  gnutls >= 3.1.0
BuildRequires:  gnutls-devel
BuildRequires:  pkgconfig(libtasn1)
BuildRequires:  libtasn1-tools
%endif
BuildRequires:  gcc
BuildRequires:  libseccomp-devel
BuildRequires:  tpm2-pkcs11 tpm2-pkcs11-tools tpm2-tools tpm2-abrmd-devel
BuildRequires:  pkgconfig(json-glib-1.0)

Requires:       %{libname} = %{version}-%{release}

%description
TPM emulator built on libtpms providing TPM functionality for QEMU VMs.

%package        -n %libname
Summary:        Private libraries for swtpm TPM emulators
License:        BSD-3-Clause

%description    -n %libname
A private library with callback functions for libtpms based swtpm TPM emulator.

%package        -n %devname
Summary:        Include files for the TPM emulator's CUSE interface for usage by clients
License:        BSD-3-Clause
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description    -n %devname
Include files for the TPM emulator's CUSE interface.

%package        tools
Summary:        Tools for the TPM emulator
License:        BSD-3-Clause
Requires:       swtpm = %{version}-%{release}
# trousers: for tss account
Requires:       trousers >= 0.3.9 bash gnutls python3 python3-cryptography

%description    tools
Tools for the TPM emulator from the swtpm package.

%package        tools-pkcs11
Summary:        Tools for creating a local CA based on a TPM pkcs11 device
License:        BSD-3-Clause
Requires:       swtpm-tools = %{version}-%{release}
Requires:       tpm2-pkcs11 tpm2-pkcs11-tools tpm2-tools tpm2-abrmd
Requires:       expect gnutls trousers >= 0.3.9

%description   tools-pkcs11
Tools for creating a local CA based on a pkcs11 device.

%package        tests
Summary:        Installed swtpm tests
Requires:       swtpm-tools-pkcs11 = %{version}-%{release}

%description    tests
Installed swtpm tests.

%prep
%autosetup -S git -n %{name}-%{version} -p1

%build

NOCONFIGURE=1 ./autogen.sh
%configure \
%if %{with gnutls}
        --with-gnutls \
%endif
        --without-cuse

%make_build

%ifnarch %{ix86}
%check
make check VERBOSE=1
%endif

%install
%make_install
rm -f %{buildroot}%{_libdir}/%{name}/*.{a,la,so}

%files
%license LICENSE
%doc README
%{_bindir}/swtpm
%{_mandir}/man8/swtpm.8*

%files -n %libname
%license LICENSE
%doc README

%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libswtpm_libtpms.so.%{major}{,.*}

%files -n %devname
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_mandir}/man3/swtpm_ioctls.3*

%files tools
%doc README
%{_bindir}/swtpm_bios
%if %{with gnutls}
%{_bindir}/swtpm_cert
%endif
%{_bindir}/swtpm_setup
%{_bindir}/swtpm_ioctl
%{_bindir}/swtpm_localca
%{_mandir}/man5/swtpm-localca.conf.5*
%{_mandir}/man5/swtpm-localca.options.5*
%{_mandir}/man5/swtpm_setup.conf.5*
%{_mandir}/man8/swtpm_bios.8*
%{_mandir}/man8/swtpm_cert.8*
%{_mandir}/man8/swtpm_ioctl.8*
%{_mandir}/man8/swtpm-localca.8*
%{_mandir}/man8/swtpm_localca.8*
%{_mandir}/man8/swtpm_setup.8*
%config(noreplace) %{_sysconfdir}/swtpm_setup.conf
%config(noreplace) %{_sysconfdir}/swtpm-localca.options
%config(noreplace) %{_sysconfdir}/swtpm-localca.conf
%dir %{_datadir}/swtpm
%{_datadir}/swtpm/swtpm-localca
%{_datadir}/swtpm/swtpm-create-user-config-files
%attr( 750, tss, root) %{_localstatedir}/lib/swtpm-localca

%files tools-pkcs11
%{_mandir}/man8/swtpm-create-tpmca.8*
%{_datadir}/swtpm/swtpm-create-tpmca

%files tests
%{_libexecdir}/installed-tests/swtpm/
