%global __provides_exclude perl\\(.*\\)
%global __requires_exclude perl\\((Sympa.*|Archive|Auth|Bounce|Bulk|Commands|Conf|Config_XML|Datasource|Family|Fetch|Language|Ldap|List|Lock|Log|Marc.*|Message|PlainDigest|Robot|SDM|SharedDocument|Scenario|SQLSource|Task|Upgrade|WebAgent|admin|confdef|mail|report|tools|tt2|wwslib)\\)
%global __requires_exclude %{?__requires_exclude}|^perl\\((cookielib|sympasoap|time_utils)\\)

Name:		sympa
Version:	6.2.76
Release:	%mkrel 2
Summary:	Electronic mailing list manager
License:	GPL
Group:		System/Servers
URL:		https://www.sympa.community/
Source0:	https://github.com/sympa-community/sympa/releases/download/%{version}/sympa-%{version}.tar.gz
Source1:	README.update.urpmi
Source6:	sympa.tmpfiles
Requires:	openssl >= 0.9.5a
Requires:	mhonarc >= 2.4.5
Requires:   mail-server
Requires:   sympa-database
Requires:   perl-Unicode-UTF8
Recommends: perl-Mail-DKIM
Requires(pre):	    rpm-helper
Requires(post):     rpm-helper >= 0.20.0
Requires(post):     mail-server
Requires(preun):    rpm-helper
Requires(preun):    mail-server
Requires(postun):   rpm-helper >= 0.16
BuildRequires:      rpm-helper >= 0.20.0
BuildRequires:      rpm-mageia-setup
BuildRequires:	    pkgconfig(openssl)
BuildRequires:	    perl-Class-Singleton
BuildRequires:	    perl-DateTime
BuildRequires:	    perl-DBI
BuildRequires:	    perl-File-Copy-Recursive
BuildRequires:	    perl-HTML-Parser
BuildRequires:	    perl-MailTools
BuildRequires:	    perl-MIME-EncWords
BuildRequires:	    perl-Unicode-LineBreak
BuildRequires:	    perl-Unicode-UTF8
BuildRequires:	    perl-URI
BuildRequires:	    perl-libintl-perl
BuildRequires:	    gettext-devel

%description
Sympa is an open source mailing list manager. It provides advanced features with a rich and secure web interface.

%package www
Summary:	Web interface for Sympa
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	webserver
Recommends:   apache-mod_fastcgi
Recommends:   perl(CGI::Fast)
Recommends:   perl(FCGI)
Requires(post):     rpm-helper >= 0.20.0
Requires(postun):   rpm-helper >= 0.16

%description www
This package contains the web interface for %{name}.

%package mysql
Summary:    MySQL database support for Sympa
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
Requires:   perl-DBD-mysql

%description mysql
This package ensures the necessary dependencies are in place for Sympa to
work with MySQL / MariaDB databases. It does not require a MySQL / MariaDB
server to be installed, as you may well wish to use a remote database
server.

%package postgresql
Summary:    PostgreSQL database support for Sympa
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
Requires:   perl-DBD-Pg

%description postgresql
This package ensures the necessary dependencies are in place for Sympa to
work with a PostgreSQL database. It does not require the PostgreSQL server
package to be installed, as you may well wish to use a remote database
server.

%prep
%autosetup -p1

%build
%serverbuild
autoreconf -i
%configure \
    --enable-fhs \
    --libexecdir=%{_sbindir} \
    --sysconfdir=%{_sysconfdir}/sympa \
    --with-unitsdir=%{_unitdir} \
    --with-confdir=%{_sysconfdir}/sympa \
    --with-aliases_file=%{_localstatedir}/lib/sympa/aliases \
    --with-newaliases_arg=-oA/var/lib/sympa/aliases
%make_build

%install
%make_install HOST=localhost

rm -f %{buildroot}%{_sysconfdir}/sympa/data_structure.version

perl -pi -e 's|/var/run|/run|' \
    %{buildroot}%{_sysconfdir}/sympa/sympa.conf \
    %{buildroot}%{_unitdir}/*.service

rm -f %{buildroot}%{_sysconfdir}/sympa/rc.d/init.d/sympa
install -D -m 644 %{SOURCE6} %{buildroot}%{_prefix}/lib/tmpfiles.d/sympa.conf

install -d -m 755 %{buildroot}%{_unitdir}/sympa.service.d

cat > %{buildroot}%{_unitdir}/sympa.service.d/mysql.conf <<EOF
[Unit]
After=mysqld.service
EOF

cat > %{buildroot}%{_unitdir}/sympa.service.d/postgresql.conf <<EOF
[Unit]
After=postgresql.service
EOF

# apache conf
install -d -m 755 %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/sympa.conf <<EOF
Alias /static-sympa %{_localstatedir}/lib/sympa/static_content
Alias /sympa %{_libdir}/sympa/cgi

<Directory %{_localstatedir}/lib/sympa/static_content>
    Require all granted
</Directory>

<Directory %{_libdir}/sympa/cgi>
    Options ExecCGI
    # fallback handler if mod_fcgid is not installed
    <IfModule !mod_fcgid.c>
        AddHandler cgi-script .fcgi
    </IfModule>
    DirectoryIndex wwsympa-wrapper.fcgi
    Require all granted
</Directory>
EOF

# no need for perl modules man pages
rm -rf %{buildroot}%{_mandir}/man3

# Install remaining documentation manually
install -m 644 AUTHORS.md COPYING NEWS.md README.md %{buildroot}%{_docdir}/%{name}
install -D -m 644 %{SOURCE1} README.update.urpmi

# don't install  bundled certs
rm -f %{buildroot}%{_datadir}/sympa/ca-bundle.crt

# not the place for documentation
rm -f %{buildroot}%{_sysconfdir}/sympa/README

# drop sendmail stuff
rm -rf %{buildroot}%{_sysconfdir}/sympa/smrsh

%find_lang sympa
%find_lang web_help
cat web_help.lang >> sympa.lang

%pre
%_pre_useradd sympa %{_localstatedir}/lib/sympa /bin/false

%post
%_post_service sympa

if [ $1 = 1 ]; then
  # installation

  # sympa configuration
  hostname=`hostname`

  perl -pi \
    -e "s|^domain(\s+).*|domain\$1$hostname|;" \
    -e "s|^listmaster(\s+).*|listmaster\$1listmaster\@$hostname|;" \
    -e "s|^wwsympa_url(\s+).*|wwsympa_url\$1http://$hostname/sympa|;" \
    -e "s|^syslog(\s+).*|syslog\$1mail|;" \
    %{_sysconfdir}/sympa/sympa.conf

  # Initial aliase file creation
  cat >> %{_localstatedir}/lib/sympa/aliases <<EOF
listmaster:	"|%{_sbindir}/queue listmaster"
sympa:		"|%{_sbindir}/queue sympa"
bounce+*:	"|%{_sbindir}/bouncequeue sympa"
sympa-request:	listmaster@$hostname
sympa-owner:	listmaster@$hostname
EOF
  chown sympa.sympa %{_localstatedir}/lib/sympa/aliases

  # mta-specific aliases inclusion procedure
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database`
    maps=`/usr/sbin/postconf -h alias_maps`
    postconf -e \
        "alias_database = $database, hash:%{_localstatedir}/lib/sympa/aliases" \
        "alias_maps = $maps, hash:%{_localstatedir}/lib/sympa/aliases"
  else
    cat >> %{_sysconfdir}/aliases <<EOF
:include:	%{_localstatedir}/lib/sympa/aliases
EOF
  fi
  # masqmail don't have this command
  [ -x /usr/bin/newaliases ] && /usr/bin/newaliases
else
  # find aliases file
  aliases=`awk '/sendmail_aliases/ {print $2}' %{_sysconfdir}/sympa/sympa.conf`
  if [ -z "$aliases" ]; then
    aliases=%{_sysconfdir}/aliases
  fi
  # correct pathes
  sed -i \
      -e 's|%{_bindir}/queue|%{_sbindir}/queue|' \
      -e 's|%{_bindir}/bouncequeue|%{_sbindir}/bouncequeue|' \
      $aliases
  # regenerate aliases
  /usr/bin/newaliases
fi

%preun
%_preun_service sympa

if [ $1 = 0 ]; then
  # uninstallation

  # remove aliases
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    maps=`/usr/sbin/postconf -h alias_maps | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    postconf -e \
      "alias_database = $database" \
      "alias_maps = $maps"
  else
    sed -i -e '/:include:   %{_localstatedir}/lib/sympa/aliases/d' \
      %{_sysconfdir}/aliases
  fi
  /usr/bin/newaliases
fi

%postun
%_postun_userdel sympa

%files -f sympa.lang
%{_docdir}/%{name}
%doc README.update.urpmi

# variable directories
%attr(-,sympa,sympa) %{_localstatedir}/lib/sympa
%attr(-,sympa,sympa) %{_localstatedir}/spool/sympa

# config files
%dir %{_sysconfdir}/sympa
%config(noreplace) %attr(640,root,sympa) %{_sysconfdir}/sympa/sympa.conf

%{_unitdir}/sympa.service
%{_unitdir}/sympa-outgoing.service
%{_unitdir}/sympa-archive.service
%{_unitdir}/sympa-bounce.service
%{_unitdir}/sympa-task.service
%{_prefix}/lib/tmpfiles.d/sympa.conf

# binaries
%attr(-,sympa,sympa) %{_sbindir}/queue
%attr(-,sympa,sympa) %{_sbindir}/bouncequeue
%attr(-,sympa,sympa) %{_sbindir}/familyqueue
%attr(-,sympa,sympa) %{_sbindir}/sympa_newaliases.pl
%attr(-,root,sympa) %{_sbindir}/sympa_newaliases-wrapper
%{_sbindir}/sympa
%{_sbindir}/sympa.pl
%{_sbindir}/sympa_msg.pl
%{_sbindir}/sympa_automatic.pl
%{_sbindir}/alias_manager.pl
%{_sbindir}/archived.pl
%{_sbindir}/bounced.pl
%{_sbindir}/bulk.pl
%{_sbindir}/task_manager.pl

# other
%{_datadir}/sympa
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_mandir}/man5/*

%files www
%dir %{_libdir}/sympa
%dir %{_libdir}/sympa/cgi
%{_libdir}/sympa/cgi/wwsympa.fcgi
%{_libdir}/sympa/cgi/sympa_soap_server.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/sympa_soap_server-wrapper.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/wwsympa-wrapper.fcgi
%config(noreplace) %{_webappconfdir}/sympa.conf

%files mysql
%{_unitdir}/sympa.service.d/mysql.conf

%files postgresql
%{_unitdir}/sympa.service.d/postgresql.conf
