%define oname	sysdig

Name:		%{oname}
# versioning taken from https://github.com/draios/sysdig/releases
Version:	0.27.1
Release:	%mkrel 16
Summary:	Open Source Linux Troubleshooting
Group:		Monitoring
License:	GPLv2
URL:		http://www.sysdig.org
Source0:	https://github.com/draios/%{oname}/archive/%{version}/%{name}-%{version}.tar.gz
# bundled dependency for base64 encoder/decoder
Source1:	http://download.draios.com/dependencies/libb64-1.2.src.zip
Patch0:		sysdig-0.24.2-luajit-2.1.patch
Patch1:		sysdig-0.27.1-str-fmt.patch
Patch2:		fix-arm64-ftbfs.patch
Patch3:		0.27.1-grpc-absl-sync.patch
Patch4:		sysdig-0.27.1-set-c++17.patch
Patch5:		sysdig-0.27.1-linux-macro.patch
Patch6:		sysdig-0.27.1-stdint.patch
Patch7:		sysdig-0.27.1-gpr-lib.patch
BuildRequires:	cmake
BuildRequires:	jq-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(grpc)
BuildRequires:	pkgconfig(gtest)
BuildRequires:	pkgconfig(libcares)
BuildConflicts:	pkgconfig(lua)
BuildRequires:	pkgconfig(luajit)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libelf)
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(tbb)
# the kernel module is only required for live tracing, not for analysing traces
Recommends:	dkms-%{oname} = %{version}-%{release}

%description
Sysdig is open source, system-level exploration: capture system state and
activity from a running Linux instance, then save, filter and analyze.
Think of it as strace + tcpdump + lsof + awesome sauce.
With a little Lua cherry on top.

Sysdig instruments your physical and virtual machines at the OS level
by installing into the Linux kernel and capturing system calls and other
OS events. Then, using sysdig's command line interface, you can filter and 
decode these events in order to extract useful information. Sysdig can be used
to inspect systems live in real-time, or to generate trace files that can be
analyzed at a later stage.


%package -n dkms-%{oname}
Summary:	Kernel module required for live tracing, built via dkms
Group:		System/Kernel and hardware
Provides:	kmod(%{oname}.ko) = %{version}
Requires(pre):	dkms
Requires(post):	dkms
BuildArch:	noarch

%description -n dkms-%{oname}
Sysdig is open source, system-level exploration: capture system state and
activity from a running Linux instance, then save, filter and analyze.
Think of it as strace + tcpdump + lsof + awesome sauce.
With a little Lua cherry on top.

Sysdig instruments your physical and virtual machines at the OS level
by installing into the Linux kernel and capturing system calls and other
OS events. Then, using sysdig's command line interface, you can filter and 
decode these events in order to extract useful information. Sysdig can be used
to inspect systems live in real-time, or to generate trace files that can be
analyzed at a later stage.

This package uses DKMS to automatically build the %{oname} kernel module.

%prep
%setup -qn %{oname}-%{version}
%autopatch -p1

install -D %{SOURCE1} %{_arch}/b64-prefix/src/libb64-1.2.src.zip

%build
#** RUNNING CMAKE FROM THE BASE SYSDIG DIRECTORY WILL NOT WORK **#
%global _vpath_srcdir ..
%global _vpath_builddir .
mkdir -p %{_arch} && cd %{_arch}

export CXXFLAGS="%{build_cxxflags} -Wno-deprecated-declarations"

# disable driver build, handled in -dkms subpackage, also disable build of bundled libraries
%cmake -DBUILD_DRIVER=OFF \
       -DUSE_BUNDLED_B64=ON \
       -DUSE_BUNDLED_CURL=OFF \
       -DUSE_BUNDLED_DEPS=OFF \
       -DUSE_BUNDLED_JSONCPP=OFF \
       -DUSE_BUNDLED_LUAJIT=OFF \
       -DUSE_BUNDLED_ZLIB=OFF \
       -DUSE_BUNDLED_NCURSES=OFF \
       -DUSE_BUNDLED_OPENSSL=OFF \
       -DUSE_BUNDLED_JQ=OFF \
       -DDIR_ETC=%{_sysconfdir}

%make_build


%install
%make_install -C %{_arch}

rm -rf %{buildroot}%{_datadir}/zsh/

## below is the dkms module

mv %{buildroot}/usr/src/sysdig* %{buildroot}%{_usrsrc}/%{oname}-%{version}-%{release}


%post -n dkms-%{oname}
dkms add -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms build -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms install -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade --force
true
/sbin/modprobe %{oname}-probe

%preun -n dkms-%{oname}
dkms remove --binary -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade --all
true
/sbin/modprobe -r %{oname}-probe || :

%files
%{_bindir}/*%{oname}*
%{_datadir}/%{oname}
%{_mandir}/man8/*sysdig*
%{_sysconfdir}/bash_completion.d/%{oname}

%files -n dkms-%{oname}
%{_usrsrc}/%{oname}-%{version}-%{release}
