# Parallel build with too many cores brings up issues with luajit
%global _smp_ncpus_max 4

%define engine  t-engine

%ifarch aarch64
%bcond_with luajit2
%else
%bcond_without luajit2
%endif

Name:           t-engine4
Version:        1.7.6
Release:        %mkrel 2
Summary:        T-Engine4 is a graphical roguelike and tactical RPG engine
Group:          Games/Adventure
License:        GPLv3+
URL:            https://te4.org
# Tarball stripped of the files provided in the "tome" SRPM (part of it being nonfree)
Source0:        %{name}-%{version}.tar.xz
# Use this script to split the tarballs automatically
Source10:       split-tarballs.sh
Patch0:         t-engine4-1.3.1-mga-include-sdl2.patch
Patch1:         t-engine4-1.4.1-mga-no-stripping.patch
Patch2:         t-engine4-missing-include.patch

BuildRequires:  premake
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  zip
Recommends:     tome
Provides:       te4 = %{version}-%{release}

%description
T-Engine4 (TE4 for short) is a roguelike game engine operating in Lua and
available for all major platforms. It was primarily developed as the engine
for the Tales of Maj'Eyal game (see package "tome"), but other
games and mods are based on T-Engine4. See te4.org for more information.

%prep
%autosetup -p1

%build
export CFLAGS='%{optflags} -Wno-incompatible-pointer-types'
premake4 --lua=%{!?with_luajit2:default}%{?with_luajit2:jit2} gmake
# Parallel build not supported https://github.com/premake/premake-core/issues/286
echo '.NOTPARALLEL:' >> build/buildvm.make
echo '.NOTPARALLEL:' >> build/luajit2.make
%make_build config=release CC=gcc CXX=g++

%install
# Generate and install the launcher script.
cat << EOF > %{engine}-script
#!/bin/sh
pushd %{_gamesdatadir}/%{name}
./%{engine}
popd
EOF

# Install the engine executable, launcher script.
# Since the executable searches for the data in its directory, I put it in the datadir (Akien)
install -D -m755 %{engine} %{buildroot}%{_gamesdatadir}/%{name}/%{engine}
install -D -m755 %{engine}-script %{buildroot}%{_gamesbindir}/%{engine}

# Install the common game data.
install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -r bootstrap game %{buildroot}%{_gamesdatadir}/%{name}/

# Extract and install the icon. (AUR)
unzip -oj -qq game/engines/te4-%{version}.teae \
              data/gfx/te4-icon.png -d .
install -D -m644 te4-icon.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/%{name}.png

%files
%doc CONTRIBUTING COPYING-MEDIA CREDITS
%{_gamesbindir}/%{engine}
%{_gamesdatadir}/%{name}/
%{_iconsdir}/hicolor/64x64/apps/%{name}.png
