Summary:	A GNU file archiving program
Name:		tar
Version:	1.35
Release:	%mkrel 2
License:	GPLv3
Group:		Archiving/Backup
URL:		https://www.gnu.org/software/tar/tar.html
Source0:	https://ftp.gnu.org/gnu/tar/%{name}-%{version}.tar.xz
Source1:	https://ftp.gnu.org/gnu/tar/%{name}-%{version}.tar.xz.sig
Source2:	%{name}-help2man.bz2
Patch0:		tar-1.30-fix-buffer-overflow.patch
Patch1:		tar-1.35-lzma.patch
Patch10:	tar-1.33-fix-capabilities-test.patch
Patch11:	fix-CVE-2022-48303.patch
Patch12:	tar-1.35-add-forgotten-tests-from-upstream.patch
Patch13:	tar-1.35-revert-fix-savannah-bug-633567.patch
BuildRequires:	bison
BuildRequires:	xz
BuildRequires:	texinfo
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(libacl)

# Required for the checks
BuildRequires:	attr
BuildRequires:	acl
BuildRequires:	policycoreutils


%description
The GNU tar program saves many files together into one archive and
can restore individual files (or all of the files) from the archive.
Tar can also be used to add supplemental files to an archive and to
update or list files in the archive.

Tar includes multivolume support, automatic archive compression/
decompression, the ability to perform remote archives and the
ability to perform incremental and full backups.

If you want to use Tar for remote backups, you'll also need to
install the rmt package.

You should install the tar package, because you'll find its
compression and decompression utilities essential for working
with files.

%prep
%autosetup -p1

bzcat %{SOURCE2} > ./help2man
chmod +x ./help2man

xz ChangeLog

# (misc, 02-11-2010, sigpipe test do not pass on iurt )
sed -i 's/.*sigpipe.at.*//' tests/testsuite.at

# (kekepower, 2019-01-04, dirrem01 and dirrem02 fails on iurt)
sed -i 's/.*dirrem01.*//' tests/testsuite.at
sed -i 's/.*dirrem02.*//' tests/testsuite.at

# skip trick time test for i586 and arm
# (see https://lists.gnu.org/r/bug-tar/2021-10/msg00006.html)
%ifarch %ix86 %arm
sed -i 's/.*time01.*//' tests/testsuite.at
%endif

rm -f tests/testsuite

%build
autoreconf -vfi
%configure \
	--enable-backup-scripts \
	--with-lzma="xz --format=lzma" \
	DEFAULT_RMT_DIR=%{_sbindir} \
	--disable-rpath \
	RSH=/usr/bin/ssh

%make_build

# thanks to diffutils Makefile rule
(echo '[NAME]' && sed 's@/\* *@@; s/-/\\-/; q' src/tar.c) | (./help2man -i - -S '%{name} %{version}' src/tar ) | sed 's/^\.B info .*/.B info %{name}/' > %{name}.1

%check
%__make check

%install
%make_install

ln -sf tar %{buildroot}%{_bindir}/gtar

install -D -m 644 tar.1 %{buildroot}%{_mandir}/man1/tar.1

# conflicts with coda-debug-backup
mv %{buildroot}%{_sbindir}/backup %{buildroot}%{_sbindir}/tar-backup
mv %{buildroot}%{_sbindir}/restore %{buildroot}%{_sbindir}/tar-restore

# rmt is provided by rmt ...
mv %{buildroot}%{_sbindir}/rmt %{buildroot}%{_sbindir}/rmt-tar
mv %{buildroot}%{_mandir}/man8/rmt.8 %{buildroot}%{_mandir}/man8/rmt-tar.8

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS ChangeLog.xz NEWS README THANKS TODO
%{_bindir}/*
%{_libexecdir}/backup.sh
%{_libexecdir}/dump-remind
%{_sbindir}/*
%{_infodir}/*.info*
%{_mandir}/man?/*
