%define major		12
%define libname		%mklibname %{name} %{major}

%define mallocmajor	2
%define malloclib	%mklibname %{name}malloc %{mallocmajor}
%define mallocproxylib	%mklibname %{name}malloc-proxy %{mallocmajor}

%define bindmajor	3
%define bindlib		%mklibname %{name}bind2.5_ %{bindmajor}

%define irmlmajor	1
%define irmllib		%mklibname irml %{irmlmajor}

%define devname		%mklibname %{name} -d

Summary:	Library to abstract low-level threading details
Name:		tbb
Version:	2022.0.0
Release:	%mkrel 2
License:	Apache-2.0 AND BSD-3-Clause
Group:		Development/C++
URL:		https://uxlfoundation.github.io/oneTBB/

Source0:	https://github.com/oneapi-src/oneTBB/archive/v%{version}/%{name}-%{version}.tar.gz
# These two are downstream sources.
Source7:	tbbmalloc.pc
Source8:	tbbmalloc_proxy.pc

BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	gcc-c++
BuildRequires:	hwloc
BuildRequires:	hwloc-devel
BuildRequires:	libgomp-devel
BuildRequires:	python3-devel
BuildRequires:	%{py3_dist setuptools}
BuildRequires:	%{py3_dist sphinx}
BuildRequires:	%{py3_dist sphinx-rtd-theme}
BuildRequires:	swig

%description
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.

TBB requires fewer lines of code to achieve parallelism than other
threading models.  The applications you write are portable across
platforms.  Since the library is also inherently scalable, no code
maintenance is required as more processor cores become available.


%package -n %{libname}
Summary:	Library to abstract low-level threading details
Group:		System/Libraries

%description -n %{libname}
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.

TBB requires fewer lines of code to achieve parallelism than other
threading models.  The applications you write are portable across
platforms.  Since the library is also inherently scalable, no code
maintenance is required as more processor cores become available.


%package -n %{malloclib}
Summary:	Library to abstract low-level threading details
Group:		System/Libraries

Conflicts:	%{_lib}tbb2 < 2020.3-5

%description -n %{malloclib}
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.


%package -n %{mallocproxylib}
Summary:	Library to abstract low-level threading details
Group:		System/Libraries

Conflicts:	%{_lib}tbb2 < 2020.3-5

%description -n %{mallocproxylib}
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.


%package -n %{bindlib}
Summary:	Threading Building Blocks (TBB) NUMA support library
Group:		System/Libraries

%description -n %{bindlib}
Threading Building Blocks (TBB) NUMA support library.


%package -n %{irmllib}
Summary:	Library to abstract low-level threading details
Group:		System/Libraries

%description -n %{irmllib}
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.

TBB requires fewer lines of code to achieve parallelism than other
threading models.  The applications you write are portable across
platforms.  Since the library is also inherently scalable, no code
maintenance is required as more processor cores become available.


%package -n %{devname}
Summary:	The Threading Building Blocks C++ headers and shared development libraries
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Requires:	%{malloclib} = %{version}-%{release}
Requires:	%{mallocproxylib} = %{version}-%{release}
Requires:	%{bindlib} = %{version}-%{release}
Requires:	%{irmllib} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{devname}
Header files and shared object symlinks for the Threading Building
Blocks (TBB) C++ libraries.


%package doc
Summary:	The Threading Building Blocks documentation
Group:		Documentation

%description doc
PDF documentation for the user of the Threading Building Block (TBB)
C++ library.


%package -n python3-%{name}
Summary:	Python 3 TBB module
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Python 3 TBB module.


%prep
%autosetup -p1 -n oneTBB-%{version}

# Fix intersphinx mapping for Sphinx 8.x
sed -e "s|'\(https://docs\.python\.org\)/': None|'python': ('\1/3', None)|" \
    -i doc/GSG/conf.py doc/main/conf.py

%generate_buildrequires
cd python
%pyproject_buildrequires

%build
export TBBROOT=$PWD
export PYTHONPATH=$(sed "s,%{_prefix},$PWD/%{_vpath_builddir}/python/build," <<< %{python3_sitearch})
%cmake \
    -DCMAKE_CXX_STANDARD=17 \
    -DTBB4PY_BUILD:BOOL=ON \
    -DTBB_STRICT:BOOL=OFF
%cmake_build

# The python package is not built the Fedora way.  Do it over.
unset PYTHONPATH
export LD_LIBRARY_PATH=$(ls -1d $PWD/%{_vpath_builddir}/*relwithdebinfo)
export LDFLAGS="-L $LD_LIBRARY_PATH %{build_ldflags}"
cd python
%pyproject_wheel
cd -

# Build documentation
export BUILD_TYPE=oneapi
sphinx-build doc/GSG getting-started
sphinx-build doc/main html

%install
%cmake_install

# The python package is not installed the Fedora way.  Do it over.
rm -fr %{buildroot}%{python3_sitearch}
cd python
%pyproject_install
cd -

mkdir -p %{buildroot}%{_libdir}/pkgconfig
for file in %{SOURCE7} %{SOURCE8}; do
    target=%{buildroot}%{_libdir}/pkgconfig/$(basename ${file})
    sed 's/_FEDORA_VERSION/%{version}/' $file > $target
    touch -r $file $target
done

# Upstream installs tbb32.pc on 32-bit but it's already in a separate directory
# because %%_libdir is different for 32-bit and 64-bit, so rename it to tbb.pc.
if [ -f %{buildroot}%{_libdir}/pkgconfig/%{name}32.pc ]; then
    mv %{buildroot}%{_libdir}/pkgconfig/%{name}32.pc %{buildroot}%{_libdir}/pkgconfig/%{name}.pc
fi

rm -fr %{buildroot}%{_datadir}/doc

%check
# Running the tests in parallel often leads to resource exhaustion.
ctest --output-on-failure --force-new-ctest-process

%files -n %{libname}
%doc RELEASE_NOTES.md README.md
%license LICENSE.txt
%{_libdir}/libtbb.so.%{major}{,.*}

%files -n %{malloclib}
%license LICENSE.txt
%{_libdir}/libtbbmalloc.so.%{mallocmajor}{,.*}

%files -n %{mallocproxylib}
%license LICENSE.txt
%{_libdir}/libtbbmalloc_proxy.so.%{mallocmajor}{,.*}

%files -n %{bindlib}
%license LICENSE.txt
%{_libdir}/libtbbbind_2_5.so.%{bindmajor}{,.*}

%files -n %{irmllib}
%license LICENSE.txt
%{_libdir}/libirml.so.%{irmlmajor}

%files -n %{devname}
%doc cmake/README.md
%{_includedir}/oneapi/
%{_includedir}/tbb/
%{_libdir}/cmake/TBB/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%doc getting-started
%doc html

%files -n python3-%{name}
%doc python/README.md
%{python3_sitearch}/TBB*
%{python3_sitearch}/tbb/
%{python3_sitearch}/tbb-*.dist-info/
%{python3_sitearch}/__pycache__/TBB*
