%define set_tcbver 0.7

%define major   0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define libpamname %mklibname pam 0

Summary:        Libraries and tools implementing the tcb password shadowing scheme
Name:           tcb
Version:        1.2
Release:        %mkrel 4
License:        BSD or GPL+
Group:          System/Libraries
URL:            https://www.openwall.com/tcb/
Source0:        https://www.openwall.com/tcb/%{name}-%{version}.tar.gz
Source1:        https://www.openwall.com/tcb/%{name}-%{version}.tar.gz.sign
Source2:        set_tcb-%{set_tcbver}.tar.bz2
Patch0:         tcb-1.0.2-assume_shadow.patch
Patch1:		tcb-1.1-libtirpc.patch
Patch2:         set_tcb-0.7-nofork.patch
# Fix handling of negative fields in /etc/shadow on x86_64 with recent glibc (#52330)
Patch3:         tcb-1.0.3-warn.patch

BuildRequires:  pkgconfig(libcrypt) >= 4.1.1-2
BuildRequires:  pkgconfig(libnsl)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pam-devel
Requires:       %{libname} >= %{version}
Requires:       pam_tcb = %{version}
Requires:       nss_tcb = %{version}
Requires:       shadow-utils >= 4.0.12-10


%description
The tcb package consists of three components: pam_tcb, libnss_tcb, and
libtcb.  pam_tcb is a PAM module which supersedes pam_unix and pam_pwdb.
It also implements the tcb password shadowing scheme (see tcb(5) for
details).  The tcb scheme allows many core system utilities (passwd(1)
being the primary example) to operate with little privilege.  libnss_tcb
is the accompanying NSS module.  libtcb contains code shared by the
PAM and NSS modules and is also used by programs from the shadow-utils
package.


%package -n %{libname}
Summary:        Libraries and tools implementing the tcb password shadowing scheme
Group:          System/Libraries
Requires:       %{_lib}xcrypt1 >= 4.1.1-2
Requires(pre):  setup 

%description -n %{libname}
libtcb contains code shared by the PAM and NSS modules and is also used
by programs from the shadow-utils package.


%package -n pam_tcb
Summary:        PAM module for TCB
Group:          System/Libraries
Requires:       %{libname} >= %{version}

%description -n pam_tcb
pam_tcb is a PAM module which supersedes pam_unix and pam_pwdb.
It also implements the tcb password shadowing scheme (see tcb(5) for
details).  The tcb scheme allows many core system utilities (passwd(1)
being the primary example) to operate with little privilege.


%package -n nss_tcb
Summary:        NSS library for TCB
Group:          System/Libraries
Requires(post): rpm-helper
Requires(postun): rpm-helper
Requires:       %{libname} = %{version}

%description -n nss_tcb
libnss_tcb is the accompanying NSS module for pam_tcb.


%package -n %{develname}
Summary:        Libraries and header files for building tcb-aware applications
Group:          Development/Other
Requires:       %{libname} >= %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains static libraries and header files needed for
building tcb-aware applications.

%prep
%setup -q -a2
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p0
%patch -P 3 -p1

cat Make.defs | sed -e "s|LIBEXECDIR = /usr/libexec|LIBEXECDIR = %{_libdir}|" >Make.defs.new
cat Make.defs.new | sed -e "s|/lib$|/%{_lib}|g" >Make.defs
# Fix upstream perm bug #3053
chmod 644 LICENSE

%build
%serverbuild
CFLAGS="%{optflags} -DENABLE_SETFSUGID -I/usr/include/tirpc" %make_build

%install
make install-non-root install-pam_pwdb \
    DESTDIR=%{buildroot} \
    MANDIR=%{_mandir} \
    LIBDIR=%{_libdir} \
    LIBEXECDIR=%{_libdir} \
    SLIBDIR=/%{_lib}

mkdir -p %{buildroot}%{_sbindir}
install -m 0750 set_tcb-%{set_tcbver}/set_tcb %{buildroot}%{_sbindir}/
install -m 0644 set_tcb-%{set_tcbver}/set_tcb.8 %{buildroot}%{_mandir}/man8/

%post -n nss_tcb
if [ -f %{_initrddir}/nscd ]; then
    %_post_service nscd
fi

%postun -n nss_tcb
if [ -f %{_initrddir}/nscd ]; then
    %_preun_service nscd
fi

%files
%doc LICENSE
/sbin/tcb_convert
/sbin/tcb_unconvert
%{_sbindir}/set_tcb
%{_mandir}/man8/tcb_convert.8*
%{_mandir}/man8/tcb_unconvert.8*
%{_mandir}/man8/set_tcb.8*

%files -n %{libname}
/%{_lib}/libtcb.so.%{major}*
%attr(0755,root,chkpwd) %verify(not mode group) %dir %{_libdir}/chkpwd
%attr(2755,root,shadow) %verify(not mode group) %{_libdir}/chkpwd/tcb_chkpwd
%{_mandir}/man5/tcb.5*

%files -n nss_tcb
/%{_lib}/libnss_tcb.so.2

%files -n pam_tcb
/%{_lib}/security/pam_pwdb.so
/%{_lib}/security/pam_tcb.so
%{_mandir}/man8/pam_pwdb.8*
%{_mandir}/man8/pam_tcb.8*

%files -n %{develname}
%{_includedir}/tcb.h
%{_libdir}/libtcb.a
%{_libdir}/libtcb.so
