%{!?tcl_version: %define tcl_version %(echo 'puts $tcl_version' | tclsh)}
%{!?tcl_sitelib: %define tcl_sitelib %{_datadir}/tcl%{tcl_version}}
%{!?tcl_sitearch: %define tcl_sitearch %{_libdir}/tcl%{tcl_version}}

Summary: TclDOM is a package that provides a DOM binding for the Tcl scripting language
Name: tcldom
Version: 3.1
Release: %mkrel 7
License: BSD
Group: System/Libraries
URL:   https://tclxml.sourceforge.net/
Source0: https://downloads.sourceforge.net/tclxml/tcldom-3.1.tar.gz
Source1: pkgIndex.tcl.in.gui
Patch0: tcldom.patch
Patch1: tcldom-3.1-pkgprovides.patch
Patch2: tcldom-3.1-cversion.patch
BuildRequires: tcl-devel 
BuildRequires: libxml2-devel 
BuildRequires: tclxml-devel 
BuildRequires: expat-devel
Requires: tcl-tclxml tcl-tcllib

%description
This package provides a DOM binding for Tcl.  It provides one of the following
implementations:
    *     A Tcl-only implementation (slow, but no compilation required),
    *     A wrapper for the Gnome libxml2 library [http://xmlsoft.org/]
          (also fast and compatable with TclXSLT/libxslt
          [https://tclxml.sourceforge.net/tclxslt.html]).

%package expat
Summary: The Tcl dom parser built with the expat xml parser
Group: System/Libraries
Requires: %{name} = %{version}-%{release} tcl-tclxml
%description expat
This package provides an optimized Tcl dom parser built with the expat
xml parser.

%package libxml2
Summary: The Tcl dom parser built with the libxml2 xml parser
Group: System/Libraries
Requires: %{name} = %{version}-%{release} tcl-tclxml
%description libxml2
This package provides an optimized Tcl dom parser built with the libxml2
xml parser.

%package gui
Summary: UI widgets for manipulating a DOM tree
Group: System/Libraries
# actually tcldom is provided by another package (tcl-tclxml)
Requires: %{name} >= %{version}
%description gui
This package provides some useful widgets for manipulating a DOM tree.

%package devel
Summary: The Tcl dom parser development files
Group: System/Libraries
Requires: %{name} = %{version}-%{release} tclxml-devel
Requires: %{name}-libxml2 = %{version}-%{release} tclxml-devel
%description devel
Development headers and libraries needed to link new applications against
tcldom.

%prep
%setup -q
touch -r src/configure.in src/configure.in.stamp
touch -r src-libxml2/configure.in src-libxml2/configure.in.stamp
%patch -P 0 -p1
%patch -P 1
%patch -P 2
touch -r src/configure.in.stamp src/configure.in
touch -r src-libxml2/configure.in.stamp src-libxml2/configure.in
%{__sed} -i 's/\r//' examples/tkxmllint.tcl

%build
pushd src
%configure --enable-threads
%make
popd
pushd src-libxml2
%configure --enable-threads
%make
popd

%install
# We have to hand-install the base Tcl files since the configure script
# doesn't take care of that.
mkdir -p $RPM_BUILD_ROOT/%{tcl_sitelib}/%{name}%{version}
install -m 0644 library/*.tcl $RPM_BUILD_ROOT/%{tcl_sitelib}/%{name}%{version}
sed -e 's/@VERSION@/%{version}/' < library/pkgIndex.tcl.in > $RPM_BUILD_ROOT/%{tcl_sitelib}/%{name}%{version}/pkgIndex.tcl

pushd src-libxml2
mkdir -p $RPM_BUILD_ROOT%{tcl_sitearch}
make install DESTDIR=$RPM_BUILD_ROOT
mv $RPM_BUILD_ROOT%{_libdir}/tcldom_libxml23.1 $RPM_BUILD_ROOT%{tcl_sitearch}/%{name}_libxml2-%{version}
popd

pushd src
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{tcl_sitearch}
mv $RPM_BUILD_ROOT%{_libdir}/tcldom3.1 $RPM_BUILD_ROOT%{tcl_sitearch}/%{name}_expat-%{version}
popd

# Install the examples in a -gui subpackage
install -d $RPM_BUILD_ROOT%{tcl_sitelib}/%{name}-gui%{version}
sed -e 's/@VERSION@/%{version}/' < %{SOURCE1} > $RPM_BUILD_ROOT/%{tcl_sitelib}/%{name}-gui%{version}/pkgIndex.tcl
install -p -m 0644 examples/domtree.tcl \
        examples/domtree-treectrl.tcl \
        examples/domtext.tcl \
        examples/cgi2dom.tcl \
        $RPM_BUILD_ROOT%{tcl_sitelib}/%{name}-gui%{version}/

%files
%{tcl_sitelib}/%{name}%{version}
%doc ChangeLog README MANIFEST RELNOTES LICENSE
%doc docs/* examples/*

%files expat
%dir %{tcl_sitearch}/%{name}_expat-%{version}
%{tcl_sitearch}/%{name}_expat-%{version}/*.tcl
%{tcl_sitearch}/%{name}_expat-%{version}/*.so

%files libxml2
%dir %{tcl_sitearch}/%{name}_libxml2-%{version}
%{tcl_sitearch}/%{name}_libxml2-%{version}/*.tcl
%{tcl_sitearch}/%{name}_libxml2-%{version}/*.so

%files gui
%dir %{tcl_sitelib}/%{name}-gui%{version}
%{tcl_sitelib}/%{name}-gui%{version}/*.tcl

%files devel
%{_includedir}/*
%{_libdir}/%{name}libxml2Config.sh
%{tcl_sitearch}/%{name}_libxml2-%{version}/*.a
