%define major     0
%define libname   %mklibname thrift %{major}
%define develname %mklibname thrift -d

%{?perl_default_filter}
# we don't want to provide private python extension libs
%global __provides_exclude_from %{python3_sitearch}/.*\\.so

%global _disable_ld_no_undefined 1

%global have_mongrel 0
%global have_jsx 0

# We should be able to enable this in the future
%global want_d 0

# Can't do anything with java with all the build deps in modules
%global want_java 0

%if 0%{?want_java} == 0
%global java_configure --without-java
%else
%global java_configure --with-java
%endif

# Thrift's Ruby support depends on Mongrel.  Since Mongrel is
# deprecated in Fedora, we can't support Ruby bindings for Thrift
# unless and until Thrift is patched to use a different HTTP server.
%if 0%{?have_mongrel} == 0
%global ruby_configure --without-ruby
%global with_ruby 0
%else
%global ruby_configure --with-ruby
%global want_ruby 1
%endif

# Thrift's Erlang support depends on the JSX library, which is not
# currently available in Fedora.

%if 0%{?have_jsx} == 0
%global erlang_configure --without-erlang
%global want_erlang 0
%else
%global erlang_configure --with-erlang
%global want_erlang 1
%endif

# Thrift's GO support doesn't build under Fedora
%global want_golang 0
%global golang_configure --without-go

# Thrift's Lua support has not yet been worked on
%global want_lua 0
%global lua_configure --without-lua

# NOTE: thrift versions their libraries by package version, so each version
# change is a SONAME change and dependencies need to be rebuilt

Summary:	Software framework for cross-language services development
Name:		thrift
Version:	0.20.0
Release:	%mkrel 2
Group:		Development/Java
# Parts of the source are used under the BSD and zlib licenses, but
# these are OK for inclusion in an Apache 2.0-licensed whole:
# https://www.apache.org/legal/3party.html
# Here's the breakdown:
# ./lib/py/compat/win32/stdint.h is 2-clause BSD
# ./compiler/cpp/src/md5.[ch] are zlib
License:	ASL 2.0 and BSD and zlib
URL:		https://thrift.apache.org/
Source0:	https://archive.apache.org/dist/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:	https://repo1.maven.org/maven2/org/apache/thrift/lib%{name}/%{version}/lib%{name}-%{version}.pom
Source2:	https://raw.github.com/apache/%{name}/%{version}/bootstrap.sh

# fix configure.ac insistence on using /usr/local/lib for JAVA_PREFIX
Patch2: configure-java-prefix.patch
# stop linking against nonexistent static library
Patch6: thrift-0.20.0-mga-unittest-link.patch

# BuildRequires for language-specific bindings are listed under these
# subpackages, to facilitate enabling or disabling individual language
# bindings in the future
BuildRequires:	libstdc++-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
%ifarch %{mono_arches}
BuildRequires:	mono-devel
%endif
BuildRequires:	texlive
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	bison
BuildRequires:	boost-devel
BuildRequires:	boost-devel-static
BuildRequires:	flex
BuildRequires:	glib2-devel
BuildRequires:	libevent-devel
%if 0%{?want_java} > 0
BuildRequires:	ant
%endif
BuildRequires:	mawk

%ifarch %{mono_arches}
Requires:	mono-core
%endif
%if 0%{?want_golang} > 0
BuildRequires:	golang
Requires:	golang
%endif
Requires:	%{libname} >= %{version}-%{release}

%description
The Apache Thrift software framework for cross-language services
development combines a software stack with a code generation engine to
build services that work efficiently and seamlessly between C++, Java,
Python, %{?php_langname}and other languages.

%package -n	%{libname}
Summary:	General-purpose scalable concurrent malloc implementation
Group:		System/Libraries
# shared libs moved from thrift-0.9.1
Conflicts:	thrift < 0.9.3

%description -n	%{libname}
The Apache Thrift software framework for cross-language services
development combines a software stack with a code generation engine to
build services that work efficiently and seamlessly between C++, Java,
Python, %{?php_langname}and other languages.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} >= %{version}-%{release}
Obsoletes:	thrift-devel
Provides:	thrift-devel = %{version}-%{release}
Requires:	boost-devel

%description -n %{develname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n	python3-%{name}
Summary:	Python 3 support for %{name}
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
Requires:	%{name} >= %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
The python3-%{name} package contains Python bindings for %{name}.

%package -n	perl-%{name}
Summary:	Perl support for %{name}
Group:		Development/Perl
Provides:	perl(Thrift) = %{version}-%{release}
BuildRequires:	perl(Bit::Vector)
BuildRequires:	perl(Class::Accessor)
BuildRequires:	perl(ExtUtils::MakeMaker)
# thrift improperly packages some components in files with names different
# than the package they contain
Provides:	perl(Thrift::Exception)
Provides:	perl(Thrift::MessageType)
Provides:	perl(Thrift::Type)
BuildArch:	noarch

%description -n perl-%{name}
The perl-%{name} package contains Perl bindings for %{name}.

%if %{?want_d}
%package -n	d-%{name}
Summary:	D support for %{name}
Group:		Development/Other
BuildRequires:	ldc
Requires:	%{libname} >= %{version}-%{release}

%description -n d-%{name}
The d-%{name} package contains D bindings for %{name}.
%endif

%if 0%{?want_java} > 0
%package -n	lib%{name}-javadoc
Summary:	API documentation for java-%{name}
Group:		Documentation
Requires:	lib%{name}-java = %{version}-%{release}
BuildArch:	noarch

%description -n lib%{name}-javadoc
The lib%{name}-javadoc package contains API documentation for the
Java bindings for %{name}.

%package -n	lib%{name}-java
Summary:	Java support for %{name}
Group:		Development/Java
BuildRequires:	apache-commons-codec
BuildRequires:	apache-commons-lang
BuildRequires:	apache-commons-logging
BuildRequires:	httpcomponents-client
BuildRequires:	httpcomponents-core
BuildRequires:	java-devel
BuildRequires:	javapackages-tools
BuildRequires:	javapackages-local
BuildRequires:	junit
BuildRequires:	log4j
BuildRequires:	slf4j
# javax.servlet-api 3.1.0 is provided by glassfish-servlet-api
BuildRequires:	mvn(javax.servlet:javax.servlet-api) = 3.1.0
Requires:	java-headless >= 1:1.6.0
Requires:	javapackages-tools
Requires:	mvn(org.slf4j:slf4j-api)
Requires:	mvn(commons-lang:commons-lang)
Requires:	mvn(org.apache.httpcomponents:httpclient)
Requires:	mvn(org.apache.httpcomponents:httpcore)
BuildArch:	noarch

%description -n lib%{name}-java
The lib%{name}-java package contains Java bindings for %{name}.
%endif

%if 0%{?want_ruby} > 0
%package -n	ruby-%{name}
Summary:	Ruby support for %{name}
Group:		Development/Ruby
Requires:	ruby(release)
BuildRequires:	ruby-devel
Requires:	%{name} >= %{version}-%{release}

%description -n ruby-%{name}
The ruby-%{name} package contains Ruby bindings for %{name}.
%endif

%if 0%{?want_erlang} > 0
%package -n	erlang-%{name}
Summary:	Erlang support for %{name}
Group:		Development/Erlang
Requires:	erlang
Requires:	erlang-jsx
BuildRequires:	erlang
BuildRequires:	erlang-rebar

%description -n erlang-%{name}
The erlang-%{name} package contains Erlang bindings for %{name}.
%endif

%prep
%autosetup -p1

# avoid spurious executable permissions in debuginfo package
find . -name \*.cpp -or -name \*.cc -or -name \*.h | xargs -r chmod 644

cp -p %{SOURCE2} bootstrap.sh

# work around linking issues
echo 'libthrift_c_glib_la_LIBADD = $(GLIB_LIBS) $(GOBJECT_LIBS) -L../cpp/.libs ' >> lib/c_glib/Makefile.am
echo 'libthriftqt5_la_LIBADD = $(QT_LIBS) -lthrift -L.libs' >> lib/cpp/Makefile.am
echo 'libthriftz_la_LIBADD = $(ZLIB_LIBS) -lthrift -L.libs' >> lib/cpp/Makefile.am
echo 'EXTRA_libthriftqt5_la_DEPENDENCIES = libthrift.la' >> lib/cpp/Makefile.am
echo 'EXTRA_libthriftz_la_DEPENDENCIES = libthrift.la' >> lib/cpp/Makefile.am

# fix broken upstream check for ant version; we enforce this with BuildRequires, so no need to check here
sed -i 's|ANT_VALID=.*|ANT_VALID=1|' aclocal/ax_javac_and_java.m4

# explicitly set python3
shopt -s globstar
sed -i -E 's@^(#!.*/env) *python *$@\1 python3@' **/*.py

# make autoreconf more happy
sed -i -e 's/\(^AM_INIT_AUTOMAKE.*\)\s\+/\1 foreign /g' configure.ac

%build
export PY_PREFIX=%{_prefix}
export PERL_PREFIX=%{_prefix}
export JAVA_PREFIX=%{_javadir}
export RUBY_PREFIX=%{_prefix}
export GLIB_LIBS=$(pkg-config --libs glib-2.0)
export GLIB_CFLAGS=$(pkg-config --cflags glib-2.0)
export GOBJECT_LIBS=$(pkg-config --libs gobject-2.0)
export GOBJECT_CFLAGS=$(pkg-config --cflags gobject-2.0)

find %{_builddir} -name rebar -exec rm -f '{}' \;
find . -name Makefile\* -exec sed -i -e 's/[.][/]rebar/rebar/g' {} \;

# install javadocs in proper places
sed -i 's|-Dinstall.javadoc.path=$(DESTDIR)$(docdir)/java|-Dinstall.javadoc.path=$(DESTDIR)%{_javadocdir}/%{name}|' lib/java/Makefile.*

# build a jar without a version number
#sed -i 's|${thrift.artifactid}-${version}|${thrift.artifactid}|' lib/java/build.xml

# Proper permissions for Erlang files
sed -i 's|$(INSTALL) $$p|$(INSTALL) --mode 644 $$p|g' lib/erl/Makefile.am

sh ./bootstrap.sh
autoreconf -fi

export CXXFLAGS="%{optflags} -DBOOST_TEST_DYN_LINK=1"

# use unversioned doc dirs where appropriate (via _pkgdocdir macro)
export PYTHON=%{__python3}
%configure \
    --disable-dependency-tracking \
    --disable-static \
    --with-boost=/usr %{java_configure} %{ruby_configure} %{erlang_configure} %{golang_configure} %{lua_configure} \
    --docdir=%{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}} \
    --with-qt4=no --with-qt5=yes

# eliminate unused direct shlib dependencies
sed -i -e 's/ -shared / -Wl,--as-needed\0/g' libtool

%make_build

%install

%make_install

find %{buildroot} -name fastbinary.so | xargs -r chmod 755
find %{buildroot} -name \*.erl -or -name \*.hrl -or -name \*.app | xargs -r chmod 644

%if 0%{?want_java} > 0
# Remove javadocs jar
find %{buildroot}/%{_javadir} -name lib%{name}-javadoc.jar -exec rm -f '{}' \;

# Add POM file and depmap
mkdir -p %{buildroot}%{_mavenpomdir}

install -pm 644 %{SOURCE1} %{buildroot}%{_mavenpomdir}/JPP-libthrift.pom

%add_maven_depmap JPP-libthrift.pom libthrift.jar

# Remove bundled jar files
find %{buildroot} -name \*.jar -a \! -name \*thrift\* -exec rm -f '{}' \;
%endif

# Move perl files into appropriate places
find %{buildroot} -name \*.pod -exec rm -f '{}' \;
find %{buildroot} -name .packlist -exec rm -f '{}' \;
find %{buildroot}/usr/lib/perl5 -type d -empty -delete
mkdir -p %{buildroot}/%{perl_vendorlib}/
mv %{buildroot}/usr/lib/perl5/Thrift* %{buildroot}/%{perl_vendorlib}

# Fix permissions on Thread.h
find %{buildroot} -name Thread.h -exec chmod a-x '{}' \;

# Ensure all python scripts are executable
find %{buildroot} -name \*.py -exec grep -q /usr/bin/env {} \; -print | xargs -r chmod 755

%files
%{_bindir}/thrift

%files -n %{libname}
%doc LICENSE NOTICE
%{_libdir}/libthrift_c_glib.so.%{major}{,.*}
%{_libdir}/libthrift-%{version}.so
%{_libdir}/libthriftnb-%{version}.so
%{_libdir}/libthriftqt5-%{version}.so
%{_libdir}/libthriftz-%{version}.so

%files -n %{develname}
%{_includedir}/thrift
%{_libdir}/libthrift_c_glib.so
%{_libdir}/libthrift.so
%{_libdir}/libthriftnb.so
%{_libdir}/libthriftqt5.so
%{_libdir}/libthriftz.so
%{_libdir}/pkgconfig/thrift-z.pc
%{_libdir}/pkgconfig/thrift-nb.pc
%{_libdir}/pkgconfig/thrift.pc
%{_libdir}/pkgconfig/thrift_c_glib.pc
%{_libdir}/pkgconfig/thrift-qt5.pc

%files -n perl-%{name}
%doc LICENSE NOTICE
%{perl_vendorlib}/Thrift
%{perl_vendorlib}/Thrift.pm

%if %{?want_erlang} > 0
%files -n erlang-%{name}
%{_libdir}/erlang/lib/%{name}-%{version}/
%endif

%files -n python3-%{name}
%{python3_sitearch}/%{name}
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info

%if 0%{?want_java} > 0
%files -n lib%{name}-javadoc
%{_javadocdir}/%{name}/

%files -n lib%{name}-java -f .mfiles
%endif
