%define oname TiMidity++

# Stick to /usr/lib/timidity on any platform
# XXX probably better in /usr/share/timidity for arch independent data
# but it's not worth splitting that much
%define timiditydir	%{_prefix}/lib/timidity

#
# When big change is involved (e.g. timidity.cfg change location),
# so that new timidity binray and old patch RPM won't work together,
# increment this number by 1 for all timidity related RPMs
#
%define patch_pkg_version 2

#
# NOTE: When updating config for midia patch set, please refresh both
# config file included here and the one in patch pkg
#

Summary:	MIDI to WAVE converter and player
Name:		timidity++
Version:	2.15.0
Release:	%mkrel 4
URL:		https://timidity.sourceforge.net/
License:	GPLv2+
Group:		Sound/Midi
Source0:	https://download.sourceforge.net/timidity/%{oname}-%{version}.tar.xz
Source1:	https://www.timidity.jp/dist/cfg/timidity.cfg
Source2:	timidity-emacs-mode.el
Source3:	timidity.README.mga
# (Abel) change default config path to /etc/timidity/timidity.cfg
Patch0:		timidity-2.13.2-default-config-path.patch
Patch2:		timidity-2.14.0-opensuse-zero-division-fix.patch
Patch3:		timidity-2.14.0-opensuse-out-of-bound-access-fix.patch
Patch4:		timidity++-configure-c99.patch
Requires:	timidity-instruments = %{patch_pkg_version}
BuildRequires:	pkgconfig(alsa)
BuildRequires:	autoconf
BuildRequires:	emacs-bin
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(jack)
BuildRequires:	motif-devel
BuildRequires:	pkgconfig(ao)
BuildRequires:	pkgconfig(flac) >= 1.1.3
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(portaudio-2.0)
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(slang)
BuildRequires:	imagemagick
BuildConflicts:	Xaw3d-devel

Provides:	TiMidity++ = %{version}-%{release}

%description
TiMidity is a MIDI to WAVE converter and player that uses Gravis
Ultrasound(tm) or SoundFont(tm) patch files to generate digital audio data
from general MIDI files. The audio data can be played through any
sound device or stored on disk.

%package	interfaces-extra
Summary:	Extra GUI/text mode interfaces for TiMidity
Group:		Sound/Midi
Requires:	%{name} = %{version}-%{release}
Requires:	emacs-bin

%description	interfaces-extra
TiMidity is a MIDI to WAVE converter and player that uses Gravis
Ultrasound(tm) or SoundFont(tm) patch files to generate digital audio data
from general MIDI files. The audio data can be played through any
sound device or stored on disk.

Install this if you want to use TiMidity under other interfaces, such as
Motif(or Lesstif), Tcl/Tk, emacs etc.

%prep
%autosetup -p1 -n %{oname}-%{version}

%build
# FIXME:
# Workaround GCC 14 build error
%global optflags %{optflags} -Wno-implicit-function-declaration -Wno-incompatible-pointer-types
# fix build on aarch64
autoreconf -vfi

# little ugly trick to force install of tclIndex, running wish requires
# X display
touch interface/tclIndex

export SHLDFLAGS="%(echo %{build_ldflags}|sed -e 's/-Wl,--no-undefined//')"
export EXTRADEFS="-DUSE_INTERP_RESULT"
%configure \
	--enable-audio=oss,alsa,portaudio,jack,ao,vorbis,flac,speex \
	--enable-dynamic=dynamic,ncurses,slang,motif,tcltk,emacs,xaw,xskin,gtk \
	--enable-interface=alsaseq \
	--enable-network \
	--enable-server \
	--with-ao-libraries=%{_libdir} \
	--with-ogg-libraries=%{_libdir} \
	--with-vorbis-libraries=%{_libdir} \
	--with-libFLAC-libraries=%{_libdir}
%make_build

%install
%make_install
install -d %{buildroot}%{_datadir}/timidity
install -m644 %{SOURCE1} -D %{buildroot}%{_sysconfdir}/timidity/timidity-custom.cfg
install -d %{buildroot}%{_datadir}/applications
cat <<EOF > %{buildroot}%{_datadir}/applications/%{oname}.desktop
[Desktop Entry]
Name=TiMidity++
GenericName=MIDI file player
GenericName[ar]=مشغل ملفات MIDI
GenericName[az]=MIDI fayl çalğıcısı
GenericName[bg]=MIDI плеър
GenericName[bn]=মিডি ফাইল বাদক
GenericName[br]=Ur soner a restr MIDI
GenericName[bs]=Svirač MIDI datoteka
GenericName[ca]=Reproductor de fitxers MIDI
GenericName[cs]=Přehrávač hudebních souborů MIDI
GenericName[cy]=Chwaraewr ffeil MIDI
GenericName[da]=MIDI-musikafspiller
GenericName[de]=MIDI Dateienspieler
GenericName[el]=Πρόγραμμα αναπαραγωγής MIDI
GenericName[es]=Reproductor de archivos MIDI
GenericName[et]=MIDI failide mängija
GenericName[eu]=MIDI fitxategi-erreproduzigailua
GenericName[fa]=پخشگر پرونده MIDI
GenericName[fi]=MIDI-soitin
GenericName[fr]=Lecteur de fichiers MIDI
GenericName[gl]=Reproductor de ficheiros MIDI
GenericName[he]=נגן קבצי מידי
GenericName[hi]=मीडी फ़ाइल प्लेयर
GenericName[hu]=MIDI-fájllejátszó
GenericName[id]=Pemutar file MIDI
GenericName[is]=MIDI skráa spilari
GenericName[it]=Riproduttore di file MIDI
GenericName[ja]=MIDI プレーヤー
GenericName[ky]=MIDI файлын ойноткучу
GenericName[mk]=Плеер на „MIDI“ датотеки
GenericName[mt]=Programm biex iddoqq mużika MIDI
GenericName[nb]=MIDI-fil avspiller
GenericName[nl]=MIDI bestandsspeler
GenericName[nn]=MIDI-filspelar
GenericName[pl]=Odtwarzacz plików MIDI
GenericName[pt]=Leitor de ficheiros MIDI
GenericName[pt_BR]=Player de arquivos MIDI
GenericName[ro]=Lector de fișiere MIDI
GenericName[ru]=Проигрыватель MIDI-файлов
GenericName[sc]=Sonadori de file MIDI
GenericName[sk]=Prehrávač MIDI hudby
GenericName[sl]=Predvajalnik MIDI datotek
GenericName[sq]=Lexues skedaresh MIDI
GenericName[sv]=Spelar MIDI-filer
GenericName[tg]=Бозигари MIDI файл
GenericName[th]=โปรแกรมเล่นไฟล์ MIDI
GenericName[tl]=Tagapagpatugtog ng MIDI file
GenericName[tr]=MIDI dosya çalıcı
GenericName[uk]=Програвач файлів MIDI
GenericName[uz]=MIDI fayl pleyer
GenericName[uz@cyrillic]=MIDI файл плейер
GenericName[vi]=Trình chơi tập tin MIDI
GenericName[wa]=Djouweu di fitchîs MIDI
GenericName[zh_CN]=MIDI 文件播放机
GenericName[zh_TW]=MIDI 音樂播放程式
Comment=A midi to wav converter and midi file player
Comment[de]=Ein Midi-zu-Wav-Konverter und Midi-Player
Comment[ru]=Плейер MIDI-файлов и конвертор в WAV
Exec=timidity -ig
Icon=%{oname}
Terminal=false
Type=Application
StartupNotify=true
Categories=Audio;Midi;
EOF

mkdir -p %{buildroot}%{_iconsdir}/hicolor/48x48/apps
convert interface/pixmaps/timidity.xpm %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{oname}.png

# emacs mode
install -m644 %{SOURCE2} -D %{buildroot}%{_sysconfdir}/emacs/site-start.d/timidity.el

# japanese manpages
install -m644 doc/ja_JP.eucJP/timidity.1 -D %{buildroot}%{_mandir}/ja/man1/timidity.1
install -m644 doc/ja_JP.eucJP/timidity.cfg.5 %{buildroot}%{_mandir}/ja/man1/timidity.cfg.5

%postun
if [ "$1" = "0" ]; then
%{_sbindir}/update-alternatives --remove timidity.cfg %{_sysconfdir}/timidity/timidity-custom.cfg
fi

%triggerpostun -- %{oname} <= 2.13.2-22
%{_sbindir}/update-alternatives --install %{_sysconfdir}/timidity/timidity.cfg timidity.cfg %{_sysconfdir}/timidity/timidity-custom.cfg 10

%files
%doc AUTHORS ChangeLog NEWS README doc/C/FAQ
%doc doc/C/README.{alsaseq,dl,sf,m2m,mts}
%config(noreplace) %{_sysconfdir}/timidity
%{_bindir}/timidity
%{_mandir}/man?/timidity*
%lang(ja) %{_mandir}/ja/man?/*
%{_datadir}/timidity
%dir %{timiditydir}
%{timiditydir}/if_gtk.so
%{timiditydir}/if_ncurses.so
%{_datadir}/applications/%{oname}.desktop
%{_iconsdir}/hicolor/*/apps/%{oname}.png

%files interfaces-extra
%doc doc/C/README.{tk,xaw,xskin}
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*.el
%{timiditydir}/if_emacs.so
%{timiditydir}/if_motif.so
%{timiditydir}/if_slang.so
%{timiditydir}/if_tcltk.so
%{timiditydir}/if_xaw.so
%{timiditydir}/if_xskin.so
%{_datadir}/emacs/site-lisp/*.el
%{timiditydir}/*.tcl
%{timiditydir}/tclIndex
