Name:           tkimg
Version:        1.4.16
Release:        %mkrel 1
Summary:        Image support library for Tk
Group:          System/Libraries
License:        BSD
URL:            https://sourceforge.net/projects/tkimg
Source0:        https://downloads.sourceforge.net/tkimg/Img-%{version}-Source.tar.gz
# CVE-2023-6277
# https://gitlab.com/libtiff/libtiff/-/issues/614
# https://gitlab.com/libtiff/libtiff/-/merge_requests/545
Patch0:         tkimg-libtiff-CVE-2023-6277.patch

BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(tk)
BuildRequires:  tcl-tcllib
Requires:       tcl

# tkimg builds its own bundled copies of the zlib, libjpeg, libpng,
# and libtiff libraries. From the README:
#  Note that you have to build these libraries to
#  support the named formats, even if your system already has shared
#  libraries for these formats. This is because the libraries here are
#  built such that they can be loaded as packages by the Tcl/Tk core,
#  making the handling of the various dependencies much easier. An
#  earlier version, 1.2.4, used a modified copy of Tcl's functions for
#  loading of shared libraries to load the support libraries at runtime.
#  These have been abandoned in favor of the new approach.

Provides:       bundled(zlib) = 1.2.13
Provides:       bundled(libjpeg) = 9e
Provides:       bundled(libpng) = 1.6.38
Provides:       bundled(libtiff) = 4.4.0

%description
This package contains a collection of image format handlers for the Tk
photo image type, and a new image type, pixmaps.
The provided format handlers include bmp, gif, ico, jpeg, pcx, png,
ppm, ps, sgi, sun, tga, tiff, xbm, and xpm.

%package devel
Summary:        Libraries, includes, etc. used to develop an application with %{name}
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig(tcl)
Requires:       pkgconfig(tk)

%description devel
This are the header files needed to develop a %{name} application.

%prep
%setup -q -n Img-%{version}
%patch -P 0 -p1 -b .CVE-2023-6277

%build
export CFLAGS="%{build_cflags} -lm"
%configure --with-tcl=%{tcl_sitearch} --with-tk=%{_libdir} --libdir=%{tcl_sitearch} --enable-64bit
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

# Fixing some permissions
find %{buildroot}/%{tcl_sitearch} -name "*.sh" |xargs chmod 644
find %{buildroot}/%{tcl_sitearch} -name "*.tcl" |xargs chmod 644
find %{buildroot}/%{tcl_sitearch} -name "*.a" |xargs chmod 644
find %{buildroot}/%{tcl_sitearch} -name "*.so" |xargs chmod 755

# Make library links
%{__mv} %{buildroot}/%{tcl_sitearch}/*.sh %{buildroot}/%{_libdir}
for tcllibs in %{buildroot}/%{tcl_sitearch}/Img%{version}/*tcl*.so; do
btcllibs=`basename $tcllibs`
%{__ln_s} tcl%{tcl_version}/Img%{version}/$btcllibs %{buildroot}/%{_libdir}/$btcllibs
done

%files
%doc README
%license license.terms
%{_libdir}/*.so
%{tcl_sitearch}/Img%{version}
%exclude %{tcl_sitearch}/Img*/*.a
%{_mandir}/mann/img*

%files devel
%doc README
%{_includedir}/*
%{_libdir}/*.sh
%{tcl_sitearch}/Img%{version}/*.a
