%define toruser		toruser
%define torgroup	toruser

#comment out if not rc
#define prel rc

%define rel 1

Name:		tor
#
# https://gitlab.torproject.org/tpo/core/team/-/wikis/NetworkTeam/CoreTorReleases#calendar
#
Version:	0.4.8.16
Release:	%mkrel %{?prel:%prel.}%{rel}
Summary:	Anonymizing overlay network for TCP (The onion router)
URL:		https://www.torproject.org/
Group:		Networking/Other
License:	BSD-like
Source0:	https://www.torproject.org/dist/%{name}-%{version}%{?prel:-%prel}.tar.gz
Source2:	tor.logrotate
Source3:	tor.defaults-torrc
Source4:	tor.tmpfiles.d
Source10:	tor.service
Source11:	tor@.service
Source12:	tor-master.service
Source20:	README

# Patch from Fedora:
Patch0:		tor-0.4.8.4-torrc-ControlSocket-and-CookieAuthFile.patch

BuildRequires:	pkgconfig(openssl) >= 1.0.1
BuildRequires:	pkgconfig(libevent) >= 2.0.10
BuildRequires:	pkgconfig(zlib) >= 1.2
BuildRequires:	autoconf
BuildRequires:	asciidoc
BuildRequires:	pkgconfig(libsystemd)
Requires(post):	systemd >= %{systemd_required_version}
Requires(post):	rpm-helper >= 0.24.8-1
Requires(preun):rpm-helper >= 0.24.8-1
Requires:	openssl >= 0.9.8
Requires:	tsocks

%description
The Tor network is a group of volunteer-operated servers that allows people to
improve their privacy and security on the Internet. Tor's users employ this
network by connecting through a series of virtual tunnels rather than making a
direct connection, thus allowing both organizations and individuals to share
information over public networks without compromising their privacy. Along the
same line, Tor is an effective censorship circumvention tool, allowing its
users to reach otherwise blocked destinations or content. Tor can also be used
as a building block for software developers to create new communication tools
with built-in privacy features.

This package contains the Tor software that can act as either a server on the
Tor network, or as a client to connect to the Tor network.

%prep
%autosetup -n %{name}-%{version}%{?prel:-%prel} -p1

%build
%configure \
	--with-tor-user=%{toruser} \
	--with-tor-group=%{torgroup} \
	--enable-systemd
%make_build

%install
%make_install

# config file
install -D -p -m 644 %{SOURCE3} %{buildroot}%{_datadir}/tor/defaults-torrc
mv %{buildroot}%{_sysconfdir}/%{name}/torrc.sample \
	%{buildroot}%{_sysconfdir}/%{name}/torrc

# README
install -D -p -m 644 %{SOURCE20} %{buildroot}%{_sysconfdir}/tor/README

# logrotate config
install -D -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/tor

# needed directories
mkdir -p -m 750 %{buildroot}%{_localstatedir}/lib/tor
mkdir -p -m 750 %{buildroot}%{_logdir}/tor

# Bash completion
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
echo 'complete -F _command $filenames torify' > %{buildroot}%{_sysconfdir}/bash_completion.d/tor

# Systemd support
install -D -p -m 644 %{SOURCE10} %{buildroot}%_unitdir/tor.service
install -D -p -m 644 %{SOURCE11} %{buildroot}%_unitdir/tor@.service
install -D -p -m 644 %{SOURCE12} %{buildroot}%_unitdir/tor-master.service
install -D -p -m 644 %{SOURCE4}  %{buildroot}%{_tmpfilesdir}/tor.conf

# Some mga specific changes
sed \
	-i %{buildroot}%{_sysconfdir}/tor/README \
	-i %{buildroot}%{_datadir}/tor/defaults-torrc \
	-i %{buildroot}%{_sysconfdir}/logrotate.d/tor \
	-i %{buildroot}%{_tmpfilesdir}/tor.conf \
	-e 's|toranon|%{toruser}|g'

# Handle docs in files section
rm -rf %{buildroot}%{_docdir}/

%pre
%_pre_useradd %{toruser} %{_localstatedir}/lib/%{name} /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}
%_preun_service %{name}-master

if [ $1 -eq 0 ]; then
	rm -fR %{_localstatedir}/lib/%{name}/*
fi

%postun
if [ $1 -ge 1 ]; then
    # Use restart instead of try-restart, as tor-master may be "inactive" even
    # when there are tor.service and tor@.service instances running.
    systemctl restart tor-master.service >/dev/null 2>&1 || :
fi

%files
%doc ChangeLog ReleaseNotes doc/HACKING
%license LICENSE
%{_bindir}/tor
%{_bindir}/tor-gencert
%{_bindir}/tor-print-ed-signing-cert
%{_bindir}/tor-resolve
%{_bindir}/torify
%{_mandir}/man1/tor.1*
%{_mandir}/man1/tor-gencert.1*
%{_mandir}/man1/tor-print-ed-signing-cert.1*
%{_mandir}/man1/tor-resolve.1*
%{_mandir}/man1/torify.1*
%dir %{_datadir}/tor
%{_datadir}/tor/defaults-torrc
%{_datadir}/tor/geoip
%{_datadir}/tor/geoip6
%{_tmpfilesdir}/tor.conf
%{_unitdir}/tor.service
%{_unitdir}/tor@.service
%{_unitdir}/tor-master.service

%dir %{_sysconfdir}/tor
%{_sysconfdir}/tor/README
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/tor/torrc
%config(noreplace) %{_sysconfdir}/logrotate.d/tor

%attr(0750,%{toruser},root) %dir %dir %{_localstatedir}/lib/tor
%attr(0750,%{toruser},%{torgroup}) %dir %{_logdir}/tor

%{_sysconfdir}/bash_completion.d/tor
