# Fedora package release versions are committed as versions in upstream
%global origrel 1

Name:		tracer
Version:	1.1
Release:	%mkrel 3
Summary:	Finds outdated running applications in your system

BuildArch:	noarch
Group:		System/Packaging
License:	GPLv2+
URL:		https://tracer-package.com/

Source0:	https://github.com/FrostyX/tracer/archive/%{name}-%{version}-%{origrel}.tar.gz


BuildRequires:	asciidoc
BuildRequires:	gettext

Requires:	python3-%{name} = %{version}-%{release}

%package common
Summary:	Common data files for %{name}
Group:		System/Packaging

%description common
This package contains common data files for %{name}.

%package -n python3-%{name}
Summary:	%{summary}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}
BuildRequires:	python3-devel
BuildRequires:	python3-sphinx
BuildRequires:	python3-sphinx_rtd_theme
Recommends:	python3-argcomplete
Requires:	%{name}-common = %{version}-%{release}

%global _description \
Tracer determines which applications use outdated files and prints them.\
For special kind of applications such as services or daemons, it suggests\
a standard command to restart it. Detecting whether file is outdated or\
not is based on a simple idea. If application has loaded in memory any\
version of a file which is provided by any package updated since system\
was booted up, tracer consider this application as outdated.

%description
%{_description}

%description -n python3-%{name}
%{_description}


%prep
%setup -q -n %{name}-%{name}-%{version}-%{origrel}


%generate_buildrequires
%pyproject_buildrequires

%build
sed -i -e '1s|^#!.*$|#!%{__python3}|' bin/%{name}.py
%pyproject_wheel
%make_build man SPHINXBUILD="sphinx-build-3"


%install
# Data files
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -a data/* %{buildroot}%{_datadir}/%{name}/

# Python module code
mkdir -p %{buildroot}%{python3_sitelib}/%{name}
cp -ar %{name}/* tests %{buildroot}%{python3_sitelib}/%{name}/

# Main executable and man page
install -Dpm0755 bin/%{name}.py %{buildroot}%{_bindir}/%{name}
install -Dpm0644 doc/build/man/%{name}.8 %{buildroot}%{_mandir}/man8/%{name}.8

# Bash completion
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
install -pm 644 scripts/%{name}.bash_completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}

# Translations
make DESTDIR=%{buildroot}%{_datadir} mo
%find_lang %{name}


%files common -f %{name}.lang
%doc README.md
%license LICENSE
%{_datadir}/tracer/

%files -n python3-%{name}
%license LICENSE
%{python3_sitelib}/%{name}/

%files
%{_bindir}/tracer
%{_mandir}/man8/tracer.8*
%{_datadir}/bash-completion/completions/%{name}
