%define commit      653bd0400b4413db96b80c807f0f7524f9248adb
%define shortcommit %(c=%{commit}; echo ${c:0:7})
%define commitdate  20241113

Name:           tvheadend
Summary:        TV streaming server
Version:        4.3
Release:        %mkrel 8.git%{commitdate}.1
License:        GPL-3.0-or-later and CC-BY-2.5 and Apache-2.0
URL:            https://tvheadend.org/
Group:          Video/Television
Source0:        https://github.com/tvheadend/tvheadend/archive/%{shortcommit}/%{name}-%{shortcommit}.tar.gz
Source2:        %{name}.png
Source4:        %{name}.conf
Source5:        README.install.urpmi
# Use system queue.h header
Patch0:         %{name}-4.3-use_system_queue.patch
# Fix build with hdhomerun
Patch1:         %{name}-4.3-hdhomerun.patch
# Python 3 fixes for Python bindings
Patch2:         %{name}-4.3-python3.patch
# Fix systemd service and configuration:
# - Fix daemon group (use video to access DVB devices)
# - Add -C option to allow UI access without login at first run
Patch3:         %{name}-4.3-service.patch
# Enforcing system crypto policies, see
# https://fedoraproject.org/wiki/Packaging:CryptoPolicies
Patch5:         %{name}-4.3-crypto_policies.patch
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(liburiparser)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-drm)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  hdhomerun-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  bzip2
BuildRequires:  gzip

Requires(post): pwgen
Requires(pre):  rpm-helper
Requires(post): systemd
Requires(preun): systemd

%description
Tvheadend is a TV streaming server for Linux supporting DVB-S, DVB-S2, DVB-C,
DVB-T, ATSC, IPTV, HDHomeRun, and Analog video (V4L) as input sources.

Tvheadend offers the HTTP (VLC, MPlayer), HTSP (Kodi, Movian) and SAT>IP
streaming.

Multiple EPG sources are supported (over-the-air DVB and ATSC including OpenTV
DVB extensions, XMLTV, PyXML).

The Analog video (V4L) is supported directly up to version 3.4. In recent
version, the pipe:// source (in IPTV network) might be used to obtain the
MPEG-TS stream generated by ffmpeg/libav from a V4L device.

%prep
%autosetup -p0 -n %{name}-%{commit}

%build
%configure \
    --release \
    --disable-dvbscan \
    --disable-tvhcsa \
    --disable-libx264 \
    --disable-libx265 \
    --disable-libfdkaac_static \
    --disable-ffmpeg_static \
    --disable-hdhomerun_static \
    --disable-libfdkaac_static \
    --disable-libopus_static \
    --disable-libtheora_static \
    --disable-libvorbis_static \
    --disable-libvpx_static \
    --disable-libx264_static \
    --disable-libx265_static \
    --enable-libfdkaac \
    --enable-hdhomerun_client \
    --enable-libsystemd_daemon \
    --python=%{python3}

%make_build

%install
%make_install

cp -v %{SOURCE5} .

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
cp -v %{SOURCE4} %{buildroot}%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1

mkdir -p %{buildroot}%{_iconsdir}
cp -v %{SOURCE2} %{buildroot}%{_iconsdir}/%{name}.png

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Tvheadend
Comment=TV streaming server
Exec=%{_bindir}/xdg-open http://localhost:9981/
Icon=%{_iconsdir}/%{name}
Type=Application
Categories=AudioVideo;Video;TV;Recorder;X-Mageia-CrossDesktop;
EOF

install -Dpm 0644 rpm/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -Dpm 0644 rpm/%{name}.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/%{name}

chmod +x %{buildroot}%{_bindir}/%name

%pre
# create a user "tvheadend" with a home directory /var/lib/tvheadend
# with no login shell and make him a member of the video group
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /sbin/nologin
gpasswd -a %{name} video >/dev/null

%post
chown %{name}:root %{_localstatedir}/lib/%{name} 
cd %{_localstatedir}/lib/%{name}
chown -R %{name}:video .hts*

# check if the access control file still has the initial dummy password, and
# replace the dummy password by a random, 12-character pwgen-generated password
if  grep -q '"password": "dummypassword"' %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1; then
  sed -i "s,\"password\": \"dummypassword\",\"password\": \"$(pwgen -s 12 1)\"," %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1
fi

%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc CONTRIBUTING.md README.md
%doc README.install.urpmi
%license LICENSE.md licenses/gpl-3.0.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/%name
%{_bindir}/tv_meta_tmdb.py
%{_bindir}/tv_meta_tvdb.py
%{_bindir}/tvhmeta
%{_unitdir}/%{name}.service
%{_mandir}/man1/%name.1*
%{_iconsdir}/%name.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/

#home directory and config file 
%dir %attr(-,tvheadend,root) %{_localstatedir}/lib/%{name}
%dir %attr(-,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
%attr(0600,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1

