Name:		u-boot
Epoch:		1
Version:	2024.10
Release:	%mkrel 2
Summary:	U-Boot Universal Boot Loader
License:	GPLv2
Group:		System/Kernel and hardware
Url:		https://www.denx.de/wiki/U-Boot
Source0:	https://github.com/u-boot/u-boot/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(tinfo)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	bc
# Tools needed for some boards
BuildRequires:	swig
BuildRequires:	pkgconfig(python)
BuildRequires:	dtc
%ifarch aarch64
BuildRequires:	arm-trusted-firmware-armv8
%endif

%define build_boards 0

%ifarch armv5tl armv7hl
%define build_boards 1
%define boards rpi_0_w rpi rpi_2 rpi_3_32b rpi_4_32b Bananapro
%endif
%ifarch aarch64
%define build_boards 1
%define boards rpi_3 rpi_3_b_plus rpi_arm64 rpi_4 pine64_plus
%endif

BuildRequires:  flex bison

%description
Das U-Boot (or just "U-Boot" for short)
is an Open Source Firmware for Embedded PowerPC, ARM, MIPS and x86 processors.

%package tools
Summary:	Tools for the U-Boot Boot Loader
Group:		Development/Other

%description tools
Das U-Boot (or just "U-Boot" for short)
is an Open Source Firmware for Embedded PowerPC, ARM, MIPS and x86 processors.
This package contains:
mkimage a tool that creates kernel bootable images for u-boot.

%package doc
Summary:	Documentation for the U-Boot Boot Loader
Group:		Development/Other
Obsoletes:	u-boot-tools-doc < 20130723-7

%description doc
Das U-Boot (or just "U-Boot" for short) is an Open Source Firmware
for Embedded PowerPC, ARM, MIPS and x86 processors.
This package contains documentation for u-boot firmware

%prep
%setup -q
%autopatch -p1

# Fix build with SWIG >= 4.3.0
sed -i -e 's/SWIG_Python_AppendOutput/SWIG_AppendOutput/g' $(grep -rl SWIG_Python_AppendOutput scripts/dtc)

%build
%if %{build_boards}
for board in %{boards}; do
    if [ $board == "pine64_plus" ]; then
	export BL31=%{_datadir}/arm-trusted-firmware/sun50i_a64/bl31.bin
	export SCP=/dev/null
    else
	unset BL31
    fi
    %make_build O=builds/$board ${board}_defconfig V=1 CONFIG_TOOLS_DEBUG=1
    %make_build O=builds/$board V=1 CONFIG_TOOLS_DEBUG=1
    scripts/get_default_envs.sh ./builds/${board}/ > ./builds/${board}/default_env.txt
done
%endif

make defconfig
%make_build tools-all V=1 CONFIG_TOOLS_DEBUG=1

%install
%if %{build_boards}
for board in %{boards}; do
    install -D -m 0755 builds/$board/{*.bin,default_env.txt} -t %{buildroot}%{_prefix}/lib/%{name}/$board
done
%endif

for tool in asn1_compiler dumpimage env/fw_printenv jtagconsole kwboot netconsole mkenvimage mkimage mksunxiboot sunxi-spl-image-builder; do
	install -D -m 0755 tools/$tool %{buildroot}%{_bindir}/$(basename $tool)
done
ln -s fw_printenv %{buildroot}%{_bindir}/fw_setenv
for man in doc/*.1; do
	install -D -m 0644 $man %{buildroot}%{_mandir}/man1/$(basename $man)
done

%if %{build_boards}
%files
%{_prefix}/lib/%{name}
%endif

%files tools
%{_bindir}/*
%{_mandir}/man1/*.1.*
%doc README

%files doc
%doc doc/README.*
