# Copyright (c) 2008, 2009 David Sugar, Tycho Softworks.
# This file is free software; as a special exception the author gives
# unlimited permission to copy and/or distribute it, with or without
# modifications, as long as this notice is preserved.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE.

Name:           ucommon
Summary:        Portable C++ framework for threads and sockets
Version:        7.0.1
Release:        %mkrel 1
License:        LGPLv3+
Group:          Development/C++
URL:            https://www.gnu.org/software/commoncpp/
# https://ftp.gnu.org/gnu/commoncpp/%%{name}-%%{version}.tar.gz
Source0:        https://git.savannah.gnu.org/cgit/commoncpp.git/snapshot/commoncpp-%{version}.tar.gz
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  gnutls-devel
BuildRequires:  cmake


%description
GNU uCommon C++ is a lightweight library to facilitate using C++ design
patterns even for very deeply embedded applications, such as for systems using
uClibc along with POSIX threading support. For this reason, uCommon disables
language features that consume memory or introduce runtime overhead. uCommon
introduces some design patterns from Objective-C, such as reference counted
objects, memory pools, and smart pointers.  uCommon introduces some new
concepts for handling of thread locking and synchronization.

#------------------------------------------------------------------------------

%define ucommon_major 8
%define libucommon %mklibname ucommon %{ucommon_major}

%package -n     %libucommon
Summary:        Runtime library for %{name}
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %libucommon
GNU uCommon C++ is a lightweight library to facilitate using C++ design
patterns even for very deeply embedded applications.

This package provides the runtime library.

%files -n %libucommon
%doc AUTHORS README COPYING COPYING.LESSER COPYRIGHT NEWS SUPPORT ChangeLog
%{_libdir}/libucommon.so.%{ucommon_major}{,.*}
%{_libdir}/libusecure.so.%{ucommon_major}{,.*}
%{_libdir}/libcommoncpp.so.%{ucommon_major}{,.*}

#------------------------------------------------------------------------------

%package        bin
Group:          Development/Tools
Summary:        ucommon system and support applications
Requires:       %{libucommon} = %{version}-%{release}

%description    bin
This is a collection of command line tools that use various aspects of the
ucommon library.  Some may be needed to prepare files or for development of
applications.

%files bin
%{_bindir}/args
%{_mandir}/man1/args.*
%{_bindir}/car
%{_mandir}/man1/car.*
%{_bindir}/mdsum
%{_mandir}/man1/mdsum.*
%{_bindir}/scrub-files
%{_mandir}/man1/scrub-files.*
%{_bindir}/sockaddr
%{_mandir}/man1/sockaddr.*
%{_bindir}/zerofill
%{_mandir}/man1/zerofill.*
%{_bindir}/pdetach
%{_mandir}/man1/pdetach.*
%{_bindir}/keywait
%{_mandir}/man1/keywait.1.*
%{_bindir}/urlout
%{_mandir}/man1/urlout.1.*

#------------------------------------------------------------------------------

%define ucommondevel %mklibname ucommon -d

%package -n     %ucommondevel
Group:          Development/C++
Summary:        Headers for building uCommon applications
Requires:       %{libucommon} = %{version}-%{release}
Requires:       %{name}-bin = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %ucommondevel
This package provides header and support files needed for building
applications that use the uCommon library and frameworks.

%files -n %ucommondevel
%{_libdir}/*.so
%{_includedir}/ucommon/
%{_includedir}/commoncpp/
%{_libdir}/pkgconfig/*.pc
%{_bindir}/ucommon-config
%{_bindir}/commoncpp-config
%{_mandir}/man1/ucommon-config.*
%{_mandir}/man1/commoncpp-config.*
%dir %{_datadir}/ucommon
%dir %{_datadir}/ucommon/cmake
%{_datadir}/ucommon/cmake/Cape*.cmake

#------------------------------------------------------------------------------

%package        doc
Group:          Documentation
Summary:        Generated class documentation for uCommon
BuildArch:      noarch

%description    doc
Generated class documentation for GNU uCommon library from header files,
html browsable.

%files doc
%doc build/doc/html

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n commoncpp-%{version}

%build
%cmake \
  -DCMAKE_CXX_STANDARD=14 \
  -DCRYPTO_OPENSSL=OFF
%cmake_build
%cmake_build -t doc

%install
%cmake_install

%{__chmod} 0755 %{buildroot}%{_bindir}/ucommon-config
%{__chmod} 0755 %{buildroot}%{_bindir}/commoncpp-config
