%define oname ufdbGuard

Summary:        ufdbGuard is a URL filter for Squid
Name:           ufdbguard
Version:        1.35.8
Release:        %mkrel 1
License:        GPLv2
Group:          System/Servers
URL:            https://www.urlfilterdb.com/
Source0:        https://downloads.sourceforge.net/ufdbguard/%{oname}-%{version}.tar.gz
Source1:        https://www.urlfilterdb.com/files/downloads/ReferenceManual.pdf
Patch0:         ufdbGuard-1.35.7-fix-make_install.patch
Patch2:         ufdbGuard-1.35.7-do-not-phone-home.patch
Patch3:         ufdbGuard-1.33-listen-locally.patch
Patch4:         ufdbGuard-1.35.4-categories.patch
BuildRequires:  perl
BuildRequires:  wget
BuildRequires:  gdb
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  squid
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  systemd

Requires:       wget
Requires:       squid
Requires:       rootcerts

Requires(post):   rpm-helper
Requires(postun): rpm-helper
Requires(pre):    rpm-helper
Requires(preun):  rpm-helper

Obsoletes:      squidguard < 1.4-22

%description
ufdbGuard is a free URL filter for Squid with additional features like
SafeSearch enforcement for a large number of search engines, safer HTTPS 
visits and dynamic detection of proxies (URL filter circumventors).

ufdbGuard supports free and commercial URL databases that can be
downloaded from various sites and vendors.
You can even make your own URL database for ufdbGuard.

%package cgi
Summary:        Perl-based CGI for generating responses to blocked requests
Group:          System/Servers
Requires:       %{name} = %{version}-%{release}
Requires:       webserver-base

%description cgi
This is the Perl-based CGI for ufdbGuard to generate responses to requests
that are blocked by the filtering software.  This can used with a web server
that supports CGIs as an alternative to the one built in to ufdbhttpd.


%prep
%setup -q -n %{oname}-%{version}
%patch -P 0 -p1
%patch -P 2 -p1
%patch -P 3 -p0
#patch -P 4 -p1

perl -pi -e 's|$root = .*;|$root = %{_datadir}/%{oname};|g' samples/URLblocked.cgi

# use local redirector instead of external one
perl -pi -e 's|cgibin.urlfilterdb.com|localhost:8080|g' src/ufdbGuard.conf.in
# default HTTPS redirections to localhost:443 instead of upstream site
# this can be overridden at runtime with the redirect-https configuration parameter
# e.g., redirect-https blockedhttps.urlfilterdb.com:443, in ufdbGuard.conf
perl -pi -e 's|blockedhttps.urlfilterdb.com|localhost|g' src/ufdb.h.in

cp %{SOURCE1} .

# ufdbGuard handles log rotation internally, a logrotate config is not needed.
# if you can disable internal rotation, perhaps we should add one.

%build
install -d %{buildroot}%{_sysconfdir}/sysconfig # needed by configure

%configure \
        --with-ufdb-bindir=%{_bindir} \
        --with-ufdb-piddir=%{_rundir}/ufdb \
        --with-ufdb-mandir=%{_mandir} \
        --with-ufdb-samplesdir=%{_datadir}/%{oname}/samples \
        --with-ufdb-config=%{_sysconfdir}/ufdb \
        --with-ufdb-logdir=%{_logdir}/ufdb \
        --with-ufdb-dbhome=%{_datadir}/%{oname}/db \
        --with-ufdb-imagesdir=%{_datadir}/%{oname}/images \
        --with-ufdb-user=squid
%make_build

%install
install -d %{buildroot}%{_logdir}/ufdb
install -d %{buildroot}%{_sysconfdir}/ufdb
install -d %{buildroot}%{_datadir}/%{oname}/db
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -d %{buildroot}%{_var}/www/cgi-bin

%make_install logdir=%{_logdir}/ufdb cfgdir=%{_sysconfdir}/ufdb dbhome=%{_datadir}/%{oname}/db images_dir=%{_datadir}/%{oname}/images

install -m 0644 src/mtserver/ufdbguard.service %{buildroot}%{_unitdir}/ufdb.service
cp -a src/mtserver/sysconfig.ufdbguard %{buildroot}%{_sysconfdir}/sysconfig/%{name}
cp -a samples/URLblocked.cgi %{buildroot}%{_var}/www/cgi-bin/URLblocked.cgi

touch %{buildroot}%{_logdir}/ufdb/{ufdbguardd,ufdbgclient,ufdbhttpd,ufdbsignal}.log

cp -a test/blacklist/{entertainment,ipv6,known,proxies,security} %{buildroot}%{_datadir}/%{oname}/db/
rm -f %{buildroot}%{_datadir}/%{oname}/db/security/cacerts
ln -s /etc/pki/tls/certs/ca-bundle.crt %{buildroot}%{_datadir}/%{oname}/db/security/cacerts

# what are the other files in test/blacklist/ for?  installing in samples...
for file in domains emptyuserlist erruserlist expression-error expressions httpsgoogle.expressions httpsipblock.expressions license-status privuserlist urls; do
  cp -a test/blacklist/$file %{buildroot}%{_datadir}/%{oname}/samples/
done

cat > README.urpmi <<EOF
To enable ufdbGuard usage in Squid, you should add the following lines
to %{_sysconfdir}/squid/squid.conf:
url_rewrite_program %{_bindir}/ufdbgclient -l %{_logdir}/ufdb
url_rewrite_children 64
EOF

mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf <<EOF
d /run/ufdb 0700 squid squid -
EOF

install -d -m 0755 %{buildroot}%{_rundir}/ufdb

%postun
if [ "$1" = "0" ]; then
   rm -rf %{_datadir}/%{oname}
fi

%post
%_tmpfilescreate %{name}
%_post_service ufdb
systemctl -q try-restart squid.service ||:

%preun
%_preun_service ufdb

if [ "$1" = "0" ]; then
   rm -f %{_logdir}/ufdb/*
fi

%files
%doc CREDITS README.urpmi doc/README ReferenceManual.pdf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_sysconfdir}/ufdb
%config(noreplace) %{_sysconfdir}/ufdb/%{oname}.conf
%{_bindir}/ufdbAnalyse
%{_bindir}/ufdbDLstatus
%{_bindir}/ufdb_analyse_urls
%{_bindir}/ufdb_analyse_users
%{_bindir}/ufdbConvertDB
%{_bindir}/ufdbgclient
%{_bindir}/ufdbGenTable
%{_bindir}/ufdbguardd
%{_bindir}/ufdbhttpd
%{_bindir}/ufdb-pstack
%attr(4755,squid,squid) %{_bindir}/ufdbsignal
%{_bindir}/ufdb_top_urls
%{_bindir}/ufdb_top_users
%{_bindir}/ufdbUpdate
%dir %{_datadir}/%{oname}
%dir %{_datadir}/%{oname}/db
%{_datadir}/%{oname}/db/*
%dir %{_datadir}/%{oname}/samples
%{_datadir}/%{oname}/samples/*
%dir %{_datadir}/%{oname}/images
%{_datadir}/%{oname}/images/*
%attr(-,squid,squid) %dir %{_logdir}/ufdb
%attr(0640,squid,squid) %{_logdir}/ufdb/*
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/ufdb.service
%dir %ghost %attr(0700, squid, squid) %{_rundir}/ufdb
%ghost %attr(0660, -, -) %{_rundir}/ufdb/ufdb.pid

%files cgi
%attr(0755,apache,apache) %{_var}/www/cgi-bin/URLblocked.cgi
