Name:           ugene
Summary:        Integrated bioinformatics toolkit
Version:        52.0
Release:        %mkrel 1
License:        GPLv2+
Group:          Sciences/Biology
URL:            https://ugene.net/
Source0:        https://github.com/ugeneunipro/ugene/archive/%{version}/%{name}-%{version}.tar.gz
Source10:       ugene.wrapper

# Non-SSE2 x86 support dropped in 37.0:
# https://github.com/ugeneunipro/ugene/commit/f47fdf48c0a177dea5b5fada0ab51ff3a37e0f33
ExclusiveArch:  x86_64

BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5NetworkAuth)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  procps-devel
BuildRequires:  qttools5
BuildRequires:  libstdc++-static-devel

Provides:       bundled(samtools) = 1.19.2

%description
Unipro UGENE is a cross-platform visual environment for DNA and protein
sequence analysis. UGENE integrates the most important bioinformatics
computational algorithms and provides an easy-to-use GUI for performing
complex analysis of the genomic data. One of the main features of UGENE
is a designer for custom bioinformatics workflows.


%prep
%autosetup -p1

%build
%qmake_qt5 -r \
        INSTALL_BINDIR=%{_bindir} \
        INSTALL_LIBDIR=%{_libdir} \
        INSTALL_DATADIR=%{_datadir} \
        INSTALL_MANDIR=%{_mandir} \
        UGENE_USE_SYSTEM_SQLITE=1 \
        UGENE_USE_BUNDLED_ZLIB=0 \
        UGENE_WITHOUT_NON_FREE=1 \
        UGENE_EXCLUDE_LIST_ENABLED=1
%make_build

%install
LIBAPPDIR=%{_libdir}/%{name}
make install \
    INSTALL="install -p"

# Some needed files are not installed.....
mkdir -p %{buildroot}$LIBAPPDIR
cp -a src/_release/* %{buildroot}$LIBAPPDIR
cp -a dist/%{name}-%{version}/* %{buildroot}$LIBAPPDIR/
rm -f %{buildroot}$LIBAPPDIR/*.a

# 1. manually move files...
pushd %{buildroot}
rm -f ./$LIBAPPDIR/LICENSE*

#  bindir
mkdir -p ./%{_bindir}
install -cpm 0755 %{SOURCE10} ./%{_bindir}/%{name}

#  data files
mkdir -p ./%{_datadir}/%{name}/
mv ./$LIBAPPDIR/data ./%{_datadir}/%{name}
ln -sf ../../../%{_datadir}/%{name} ./$LIBAPPDIR/data

#  hicolor
mkdir -p ./%{_datadir}/icons/hicolor/32x32/mimetypes/
mv ./$LIBAPPDIR/application-x-ugene-ext.png ./%{_datadir}/icons/hicolor/32x32/mimetypes/

#  mime
mkdir -p ./%{_datadir}/mime/packages
mv ./$LIBAPPDIR/application-x-ugene.xml ./%{_datadir}/mime/packages

#  man file
mkdir -p ./%{_mandir}/man1
mv ./$LIBAPPDIR/%{name}.1* ./%{_mandir}/man1

# desktop files
mkdir -p ./%{_datadir}/applications/
mv ./$LIBAPPDIR/%{name}.desktop ./%{_datadir}/applications/

#  icons
mkdir -p ./%{_datadir}/pixmaps
mv ./$LIBAPPDIR/%{name}.{png,xpm} ./%{_datadir}/pixmaps
popd

%files
%license	LICENSE.txt
%license	LICENSE.3rd_party.txt

%{_bindir}/%{name}
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/lib*.so
%dir %{_libdir}/%{name}/plugins/
%{_libdir}/%{name}/plugins/*.license
%{_libdir}/%{name}/plugins/*.plugin
%{_libdir}/%{name}/plugins/lib*.so
%{_libdir}/%{name}/ugene
%{_libdir}/%{name}/ugenecl
%{_libdir}/%{name}/ugenem
%{_libdir}/%{name}/ugeneui
%{_libdir}/%{name}/plugins_checker	
%{_libdir}/%{name}/transl_ru.qm
%{_libdir}/%{name}/transl_tr.qm
%dir	%{_datadir}/%{name}/
%{_datadir}/%{name}/data/
%{_libdir}/%{name}/data
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/ugene.*
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-ugene-ext.png
%{_datadir}/mime/packages/*.xml
%{_mandir}/man1/%{name}.1*
