%define         majornum       8
%define         libname        %mklibname %{name} %{majornum}
%define         develname      %mklibname %{name} -d

%bcond_without  dnstap
%bcond_without  doh
%bcond_without  redis

Name:           unbound
Version:        1.22.0
Release:        %mkrel 2
Summary:        A validating, recursive, and caching DNS resolver

License:        BSD
Group:          Networking/Other
Url:            https://unbound.net

Source0:        https://nlnetlabs.nl/downloads/unbound/%{name}-%{version}.tar.gz
Source1:        %{name}-tmpfiles.conf
Source2:        %{name}.service
Source3:        %{name}_mga.conf
Source4:        README.urpmi


BuildRequires:  bison
BuildRequires:  doxygen
BuildRequires:  flex
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(nss)
%if %{with redis}
BuildRequires:  pkgconfig(hiredis)
%endif
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libmnl)
%if %{with doh}
BuildRequires:	pkgconfig(libnghttp2)
%endif
%if %{with dnstap}
BuildRequires:	pkgconfig(libprotobuf-c)
%endif
#
# For Python bindings
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig

Requires(pre):    rpm-helper >= %{rpmhelper_required_version}
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}

%description
Unbound is a validating, recursive, and caching DNS resolver. The C
implementation of Unbound is developed and maintained by NLnet
Labs. It is based on ideas and algorithms taken from a java prototype
developed by Verisign labs, Nominet, Kirei and ep.net. Unbound is
designed as a set of modular components, so that also DNSSEC (secure
DNS) validation and stub-resolvers (that do not run as a server, but
are linked into an application) are easily possible.


%package -n %{libname}
Summary:        Shared libraries for Unbound  
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}
Provides:       lib%{name}%{?_isa} = %{version}-%{release}

%description -n %{libname}
%{summary}.


%package -n %{develname}
Summary:        Development headers and libraries for Unbound
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
%{summary}.

%package -n python3-unbound
Summary:        Python 3 modules and extensions for unbound
Group:          Development/Python
%{?python_provide:%python_provide python3-unbound}
Requires:       lib%{name}%{?_isa} = %{version}-%{release}

%description -n python3-unbound
Python 3 modules and extensions for unbound


%prep
%autosetup -p1 -n %{name}-%{version}

%build
export PYTHON=%__python3
%configure \
	--disable-rpath \
	--disable-static \
	--with-libevent \
	--enable-event-api \
	--with-pythonmodule \
	--with-pyunbound \
	--with-pidfile=%{_rundir}/unbound.pid \
	--enable-ipset \
%if %{with dnstap}
	--enable-dnstap \
%endif
%if %{with doh}
	--with-libnghttp2 \
%endif
%if %{with redis}
	--enable-cachedb \
	--with-libhiredis \
%endif
	--enable-tfo-client \
	--enable-tfo-server
	
%make_build

%install
%make_install

%{__install} -m644 %{SOURCE4} README.urpmi
 
%{__install} -D -p -m 0644  %{buildroot}%{_sysconfdir}/%{name}/unbound.conf %{buildroot}%{_docdir}/%{name}/unbound.conf
%{__install} -D -p -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
%{__install} -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

find %{buildroot}%{_libdir} -name '*.la' -delete

%pre
%_pre_useradd %{name} /dev/null /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files
%doc README README.urpmi
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%{_sbindir}/%{name}*
%{_docdir}/%{name}/unbound.conf
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}*.5*
%{_mandir}/man8/%{name}*.8*

%files -n %{libname}
%license doc/LICENSE
%{_libdir}/lib%{name}.so.%{majornum}{,.*}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3.*

%files -n python3-unbound
%license pythonmod/LICENSE
%{python3_sitearch}/*
%doc libunbound/python/examples/*
%doc pythonmod/examples/*
