%global src_dir src/%{name}

Name:		unetbootin
Version:	702
Release:	%mkrel 3
Summary:	Create bootable Live USB drives for a variety of Linux distributions
Group:		File tools
License:	GPLv2+
URL:		https://unetbootin.github.io
Source0:	https://github.com/%{name}/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	net.sourceforge.%{name}.policy
# Syslinux is only available on x86 architectures
ExclusiveArch:	%{ix86} x86_64

BuildRequires:	desktop-file-utils
BuildRequires:	qttools5
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Widgets)

# Not picked up automatically, required for operation
Requires:	extlinux
Requires:	p7zip
Requires:	syslinux
Requires:	polkit

%description
UNetbootin allows you to create bootable Live USB drives for a variety of
Linux distributions from Windows or Linux, without requiring you to burn a CD.
You can either let it download one of the many distributions supported
out-of-the-box for you, or supply your own Linux .iso file if you've already
downloaded one or your preferred distribution isn't on the list.


%prep
%setup -q
cd %{src_dir}

# fix for "libpng warning: iCCP: known incorrect sRGB profile"
find . -type f -name "*.png" -exec convert {} -strip {} \;

%build
cd %{src_dir}
mv unetbootin.desktop mageia-unetbootin.desktop
%{_qt5_bindir}/lupdate unetbootin.pro
%{_qt5_bindir}/lrelease unetbootin.pro
%qmake_qt5

%make_build

%install
cd %{src_dir}
install -D -p -m 0755 %{name} %{buildroot}%{_libexecdir}/%{name}

# Install desktop file
desktop-file-install --vendor="" \
	--remove-key=Version \
	--remove-key=Name[en_US] \
	--remove-key=GenericName[en_US] \
	--remove-key=Comment[en_US] \
	--remove-category=Application \
	--set-key=Exec --set-value=%{name} \
	--dir=%{buildroot}%{_datadir}/applications \
	mageia-unetbootin.desktop

# Install localization files
install -d %{buildroot}%{_datadir}/unetbootin
install -c -p -m 644 unetbootin_*.qm %{buildroot}%{_datadir}/unetbootin/

# Install icons
install -D -c -p -m 644 unetbootin_16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_22.png %{buildroot}%{_datadir}/icons/hicolor/22x22/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_24.png %{buildroot}%{_datadir}/icons/hicolor/24x24/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_64.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_192.png %{buildroot}%{_datadir}/icons/hicolor/192x192/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_256.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/unetbootin.png

# Policy Kit support for nice root access
%__mkdir_p %{buildroot}%{_bindir}
cat >%{buildroot}%{_bindir}/%{name} <<EOF
#!/bin/sh
if  [[ "\$UID" != "0" ]] ; then
    %{_bindir}/pkexec %{_libexecdir}/%{name} "\$@"
    exit \$?
fi
exec %{_libexecdir}/%{name} "\$@"
EOF
%__install -m 0644 %{SOURCE1} -D %{buildroot}%{_datadir}/polkit-1/actions/net.sourceforge.%{name}.policy


%files
%doc %{src_dir}/readme.md
%attr(0755,root,root) %{_bindir}/%{name}
%{_libexecdir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/applications/mageia-%{name}.desktop
%{_iconsdir}/hicolor/*/apps/unetbootin.png
