%define major            0
%define libasrclient     %mklibname asrclient %{major}
%define libunimrcpclient %mklibname unimrcpclient %{major}
%define libunimrcpserver %mklibname unimrcpserver %{major}
%define devel            %mklibname %{name} -d

# filter out lib requires provided by bundled libs from unimrcp-deps
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}lib(apr(|util)-1|sofia-sip-ua)\.so\.[0-9]\+

Name:           unimrcp
Version:        1.7.0
Release:        %mkrel 2
Summary:        Media Resource Control Protocol Stack
License:        Apache
Group:          System/Servers
Url:            https://unimrcp.org/
Source0:        https://unimrcp.org/project/component-view/%{name}-1-7-0-tar-gz/download#/%{name}-%{version}.tar.gz
Source1:        %{name}server.service

BuildRequires:  libunimrcp-deps-devel
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(pocketsphinx)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(sphinxbase)

Requires:       libunimrcp-deps

%description
Media Resource Control Protocol (MRCP) allows to control media processing
resources over the network using distributed client/server architecture.

Media processing resources include:
- Speech Synthesizer (TTS)
- Speech Recognizer (ASR)
- Speaker Verifier (SV)
- Speech Recorder (SR)

MRCP is not a stand alone protocol and it relies on various VoIP protocols
such as:
- SIP (MRCPv2), RTSP (MRCPv1) session management
- SDP offer/answer model
- RTP media streaming

UniMRCP is an open source cross-platform MRCP implementation, which provides
everything required for MRCP client and server side deployment.
UniMRCP encapsulates SIP/MRCPv2, RTSP, SDP and RTP stacks inside and provides
MRCP version independent user level interface for the integration.

#----------------------------------------------------------------------------

%package -n     %{libasrclient}
Summary:        Media Resource Control Protocol Stack shared library
Group:          System/Libraries

%description -n %{libasrclient}
Media Resource Control Protocol Stack shared library.

#----------------------------------------------------------------------------

%package -n     %{libunimrcpclient}
Summary:        Media Resource Control Protocol Stack shared library
Group:          System/Libraries

%description -n %{libunimrcpclient}
Media Resource Control Protocol Stack shared library.

#----------------------------------------------------------------------------

%package -n     %{libunimrcpserver}
Summary:        Media Resource Control Protocol Stack shared library
Group:          System/Libraries

%description -n %{libunimrcpserver}
Media Resource Control Protocol Stack shared library.

#----------------------------------------------------------------------------

%package -n     %{devel}
Summary:        Media Resource Control Protocol Stack development
Group:          Development/C
Requires:       %{libasrclient} = %{version}-%{release}
Requires:       %{libunimrcpclient} = %{version}-%{release}
Requires:       %{libunimrcpserver} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{devel}
UniMRCP is an open source cross-platform MRCP implementation, which provides
everything required for MRCP client and server side deployment.
UniMRCP encapsulates SIP/MRCPv2, RTSP, SDP and RTP stacks inside and provides
MRCP version independent user level interface for the integration.
This package contains development part of UniMRCP.

%prep
%setup -q

%build
# fix build on aarch64
autoreconf -vfi -Ibuild/acmacros

export PKG_CONFIG_PATH="%{_libdir}/unimrcp-deps/lib/pkgconfig${PKG_CONFIG_PATH}"
export PATH=%{_libdir}/unimrcp-deps/bin/${PATH:+:${PATH}}
export LDFLAGS="%{build_ldflags} -Wl,-rpath -Wl,%{_libdir}/unimrcp-deps/lib"
%configure \
    --sysconfdir=%{_sysconfdir}/%{name} \
    --with-sofia-sip=%{_libdir}/unimrcp-deps \
    --disable-silent-rules \
    --disable-static

%make_build

%install
%make_install

mv -f %{buildroot}/usr/share %{buildroot}%{_sysconfdir}/%{name}/
mv -f %{buildroot}/usr/log %{buildroot}%{_sysconfdir}/%{name}/
mv -f %{buildroot}/usr/plugin %{buildroot}%{_sysconfdir}/%{name}/

install -D -m0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}server.service

# we don't want these
find %{buildroot} -name '*.la' -delete

%files
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/client-profiles
%dir %{_sysconfdir}/%{name}/umc-scenarios
%config(noreplace) %{_sysconfdir}/%{name}/*.xml
%config(noreplace) %{_sysconfdir}/%{name}/*.xsd
%config(noreplace) %{_sysconfdir}/%{name}/client-profiles/*.xml
%config(noreplace) %{_sysconfdir}/%{name}/umc-scenarios/*.xml
%{_bindir}/*
%{_sysconfdir}/%{name}/plugin
%{_sysconfdir}/%{name}/share
%{_sysconfdir}/%{name}/log
%attr(0644,root,root) %{_unitdir}/%{name}server.service

%files -n %{libasrclient}
%{_libdir}/libasrclient.so.%{major}{,.*}

%files -n %{libunimrcpclient}
%{_libdir}/libunimrcpclient.so.%{major}{,.*}

%files -n %{libunimrcpserver}
%{_libdir}/libunimrcpserver.so.%{major}{,.*}

%files -n %{devel}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
