# local RH-friendly definition of %%mkrel, so we can assume it works and drop
# other release hacking macros
%{?!mkrel: %define mkrel(c:) %{-c: 0.%{-c*}.}%{1}%{?distsuffix:.%distsuffix}%{?distversion}}
%{?!makeinstall_std: %define makeinstall_std() make DESTDIR=%{?buildroot:%{buildroot}} install}


%define compat_perl_vendorlib %(perl -MConfig -e 'print "%{?perl_vendorlib:1}" ? "%{perl_vendorlib}" : "$Config{installvendorlib}"')
%global allow_gurpmi %(perl -e 'print "%_vendor" =~ /\\bmag/i ? 1 : 0')
%define req_webfetch %(perl -e 'print "%_vendor" =~ /\\bmag/i ? "webfetch" : "curl wget"')

%global __requires_exclude perl\\(standalone\\)

Name:		urpmi
Version:	8.133
Release:	%mkrel 1
Group:		System/Packaging
License:	GPLv2+
Source0:	https://gitweb.mageia.org/software/rpm/urpmi/snapshot/%{name}-v%{version}.tar.xz
# NO PATCH ALLOWED, USE GIT INSTEAD
# (tmb) first step of handling renamed kernels...
#       could be better to detect and trigger on: Provides: installonlypkg(kernel)
#       like dnf does as inst.list is tagged config(noreplace)
Patch001:	urpmi-v8.125-add-kernels-to-inst.list.patch
Summary:	Command-line software installation tools
VCS:		https://gitweb.mageia.org/software/rpm/urpmi/
URL:		https://metacpan.org/release/urpmi
Requires:	%{req_webfetch}
Requires:	eject
Requires(post):	perl-Locale-gettext
Requires(post):	perl-URPM
Requires:	perl-URPM >= 5.13-4
# gzip is used in perl-URPM for synthesis and hdlist
Requires(post):	gzip
Requires:	genhdlist2
Requires:	meta-task
Requires:	perl-Filesys-Df
Requires:	perl-Time-ZoneInfo
Obsoletes:	urpmi-dudf
Recommends:	aria2
Recommends:	deltarpm
BuildRequires:	bzip2-devel
BuildRequires:	gettext
BuildRequires:	glibc-devel
BuildRequires:	intltool
BuildRequires:	perl
BuildRequires:  perl_checker
BuildRequires:	perl-Locale-gettext
BuildRequires:	perl-MDV-Distribconf
BuildRequires:	perl(Net::LDAP)
BuildRequires:	perl-URPM
# for make test:
#BuildRequires:  glibc-static-devel
BuildRequires:	mdv-distrib-tools
BuildRequires:	perl-File-Slurp
BuildRequires:  perl-Net-Server
BuildRequires:	perl-Test-Pod
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl-XML-LibXML
BuildRequires:	mozilla-nss
# for genhdlist in make test:
BuildRequires:  perl-Expect
BuildRequires:  rpmtools
BuildArch:	noarch
Requires:	perl-XML-LibXML >= 2.12.900-4.mga7

%description
urpmi is a console-based software installation tool. You can
use it to install software from the console in the same way as you use the
graphical Install Software tool (rpmdrake) to install software from the
desktop. urpmi will follow package dependencies -- in other words, it will
install all the other software required by the software you ask it to
install -- and it's capable of obtaining packages from a variety of media,
including the installation CD-ROMs and DVDs, your local hard disk,
and remote sources such as web or FTP sites.

%if %{allow_gurpmi}
%package -n gurpmi
Summary:	User mode rpm GUI install
Group:		System/Packaging
Requires:	urpmi >= %{version}-%{release}
Requires:	polkit
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

%description -n gurpmi
gurpmi is a graphical front-end to urpmi.
%endif

%package -n urpmi-parallel-ka-run
Summary:	Parallel extensions to urpmi using ka-run
Requires:	urpmi >= %{version}-%{release}
Requires:	parallel-tools
Group:		System/Packaging

%description -n urpmi-parallel-ka-run
urpmi-parallel-ka-run is an extension module to urpmi for handling
distributed installation using ka-run or Taktuk tools.

%package -n urpmi-parallel-ssh
Summary:	Parallel extensions to urpmi using ssh and scp
Requires:	urpmi >= %{version}-%{release} openssh-clients
Group:		System/Packaging

%description -n urpmi-parallel-ssh
urpmi-parallel-ssh is an extension module to urpmi for handling
distributed installation using ssh and scp tools.

%package -n urpmi-ldap
Summary:	Extension to urpmi to specify media configuration via LDAP
Requires:	urpmi >= %{version}-%{release}
Requires:	openldap-clients
Group:		System/Packaging

%description -n urpmi-ldap
urpmi-ldap is an extension module to urpmi to allow to specify
urpmi configuration (notably media) in an LDAP directory.

%prep
%autosetup -p1 -n %name-v%version

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor \
%if %{allow_gurpmi}
    --install-gui \
%endif
    --install-polkit \
    --install-po
%{__make}

%check
%{__make} test

%install
%make_install

# bash completion
install -d -m 755 %{buildroot}%{_sysconfdir}/bash_completion.d
install -m 644 %{name}.bash-completion %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

# rpm-find-leaves is invoked by this name in rpmdrake
ln -sf rpm-find-leaves %{buildroot}%{_bindir}/urpmi_rpm-find-leaves

# (cg) provide a urpmi.update in the path because users like to use it without
# mgaapplet installed (me included).
# If bin and sbin ever merge, real files will likely be favoured over symlinks
# and this should still operate properly (albeit with a bit of an upgrade glitch)
ln -sf %{_libexecdir}/urpmi.update %{buildroot}%{_sbindir}/urpmi.update

# Don't install READMEs twice
rm -f %{buildroot}%{compat_perl_vendorlib}/urpm/README*

# Desktop entry (only used to register new MIME type handler, so no icon etc.)
%if %{allow_gurpmi}
mkdir -p %buildroot%_datadir/applications
cp -a gurpmi.desktop %buildroot%_datadir/applications/gurpmi.desktop

mkdir -p %buildroot%_datadir/mime/packages
cat > %buildroot%_datadir/mime/packages/gurpmi.xml << EOF
<?xml version="1.0"?>
<mime-info xmlns="https://www.freedesktop.org/standards/shared-mime-info">
  <mime-type type="application/x-urpmi">
    <comment>urpmi file</comment>
    <glob pattern="*.urpmi"/>
  </mime-type>
</mime-info>
EOF
%endif

%find_lang %{name}

%preun
if [ "$1" = "0" ]; then
  cd /var/lib/urpmi
  rm -f compss provides depslist* descriptions.* *.cache hdlist.* synthesis.hdlist.* list.*
  cd /var/cache/urpmi
  rm -rf partial/* headers/* rpms/*
fi
exit 0

%files -f %{name}.lang
%dir /etc/urpmi
%dir /var/lib/urpmi
%dir /var/cache/urpmi
%dir /var/cache/urpmi/partial
%dir /var/cache/urpmi/headers
%dir /var/cache/urpmi/rpms
%config(noreplace) /etc/urpmi/skip.list
%config(noreplace) /etc/urpmi/inst.list
%{_sysconfdir}/bash_completion.d/%{name}
%{_bindir}/urpmi_rpm-find-leaves
%{_bindir}/rpm-find-leaves
%{_bindir}/urpmf
%{_bindir}/urpmq
%{_sbindir}/urpmi
%{_sbindir}/rurpmi
%{_sbindir}/rurpme
%{_sbindir}/urpme
%{_sbindir}/urpmi.addmedia
%{_sbindir}/urpmi.removemedia
%{_sbindir}/urpmi.update
%{_libexecdir}/urpmi.update
%{_mandir}/man3/*urpm*
%{_mandir}/man5/urpm*
%{_mandir}/man5/proxy*
%{_mandir}/man8/rurpm*
%{_mandir}/man8/urpme*
%{_mandir}/man8/urpmf*
%{_mandir}/man8/urpmq*
%{_mandir}/man8/urpmi.8*
%{_mandir}/man8/urpmi.addmedia*
%{_mandir}/man8/urpmi.removemedia*
%{_mandir}/man8/urpmi.update*
%{_mandir}/man8/urpmihowto*
%dir %{compat_perl_vendorlib}/urpm
%{compat_perl_vendorlib}/urpm.pm
%{compat_perl_vendorlib}/urpmi.pm
%{compat_perl_vendorlib}/urpm/args.pm
%{compat_perl_vendorlib}/urpm/bug_report.pm
%{compat_perl_vendorlib}/urpm/cfg.pm
%{compat_perl_vendorlib}/urpm/cdrom.pm
%{compat_perl_vendorlib}/urpm/download.pm
%{compat_perl_vendorlib}/urpm/get_pkgs.pm
%{compat_perl_vendorlib}/urpm/install.pm
%{compat_perl_vendorlib}/urpm/lock.pm
%{compat_perl_vendorlib}/urpm/main_loop.pm
%{compat_perl_vendorlib}/urpm/md5sum.pm
%{compat_perl_vendorlib}/urpm/media.pm
%{compat_perl_vendorlib}/urpm/mirrors.pm
%{compat_perl_vendorlib}/urpm/msg.pm
%{compat_perl_vendorlib}/urpm/orphans.pm
%{compat_perl_vendorlib}/urpm/parallel.pm
%{compat_perl_vendorlib}/urpm/prompt.pm
%{compat_perl_vendorlib}/urpm/removable.pm
%{compat_perl_vendorlib}/urpm/select.pm
%{compat_perl_vendorlib}/urpm/signature.pm
%{compat_perl_vendorlib}/urpm/sys.pm
%{compat_perl_vendorlib}/urpm/util.pm
%{compat_perl_vendorlib}/urpm/xml_info.pm
%{compat_perl_vendorlib}/urpm/xml_info_pkg.pm
%doc Changes README.zeroconf urpmi-repository-http.service

%if %{allow_gurpmi}
%files -n gurpmi
%{_bindir}/gurpmi
%{_bindir}/gurpmi2
%{_libexecdir}/gurpmi2
%{_datadir}/polkit-1/actions/org.mageia.gurpmi2.policy
%{_datadir}/applications/gurpmi.desktop
%{_datadir}/mime/packages/gurpmi.xml
%{compat_perl_vendorlib}/gurpmi.pm
%{compat_perl_vendorlib}/gurpm/RPMProgressDialog.pm
%endif

%files -n urpmi-parallel-ka-run
%doc urpm/README.ka-run
%dir %{compat_perl_vendorlib}/urpm
%{compat_perl_vendorlib}/urpm/parallel_ka_run.pm

%files -n urpmi-parallel-ssh
%doc urpm/README.ssh
%dir %{compat_perl_vendorlib}/urpm
%{compat_perl_vendorlib}/urpm/parallel_ssh.pm

%files -n urpmi-ldap
%doc urpmi.schema
%{compat_perl_vendorlib}/urpm/ldap.pm
