%define major     0
%define api       69
%define libname   %mklibname %{name} %{api}
%define libscript %mklibname %{name}-script %{major}
%define devname   %mklibname %{name} -d

Name:           vapoursynth
Version:        R69
Release:        %mkrel 2
Summary:        A video processing framework with the future in mind
License:        LGPLv2
Group:          Video/Utilities
Url:            https://www.vapoursynth.com/
Source0:        https://github.com/vapoursynth/vapoursynth/archive/%{version}/%{name}-%{version}.tar.gz
Patch1:         vapoursynth-version.patch

BuildRequires:  libtool
BuildRequires:  nasm
BuildRequires:  shared-mime-info
BuildRequires:  yasm
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(sphinx)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(tesseract)
BuildRequires:  pkgconfig(zimg)
# Optional
BuildRequires:  pkgconfig(Magick++) >= 7.0

Requires:       ffmpeg
Requires:       tesseract

%description
VapourSynth is an application for video manipulation. Or a plugin. Or a
library. It’s hard to tell because it has a core library written in C++
and a Python module to allow video scripts to be created. It came to be
when I started thinking about alternative designs for Avisynth and most
of it was written over a 3 month period.

The software has been heavily inspired by Avisynth and aims to be a 21st
century rewrite, taking advantage of the advancements computers have made
since the late 90s.

The main features compared to Avisynth are:

* Multithreaded
  - Frame level multithreading that scales well
* Generalized Colorspaces
  - New colorspaces can be specified at runtime
* Per Frame Properties
  - Additional metadata can be attached to frames
* Python Based
  - The scripting part is implemented as a Python module so you don’t have
    to learn a special language
* Support for video with format changes
  - Some video just can’t stick to one format or frame size.
* Compatible with a large number of already existing Avisynth plugins

%files
%doc ChangeLog
%{_bindir}/*

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n %{libname}
Shared library for %{name}.

%files -n %{libname}
%doc ChangeLog
%{_libdir}/libvapoursynth-%{api}.so

#----------------------------------------------------------------------------

%package -n %{libscript}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n %{libscript}
Shared library for %{name}.

%files -n %{libscript}
%doc ChangeLog
%{_libdir}/libvapoursynth-script.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libscript} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files and headers for %{name}.

%files -n %{devname}
%doc ChangeLog
%{_includedir}/%{name}/
%{_libdir}/libvapoursynth.so
%{_libdir}/libvapoursynth-script.so
%{_libdir}/pkgconfig/*.pc

#----------------------------------------------------------------------------

%package -n python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)

%description -n python3-%{name}
Python 3 bindings for %{name}.

%files -n python3-%{name}
%doc ChangeLog
%{python3_sitearch}/vapoursynth.so
%{python3_sitearch}/VapourSynth-%{api}-py*.*.egg-info

#----------------------------------------------------------------------------

%package doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description doc
This package contains documentation for %{name}.

%files doc
%doc doc/

#----------------------------------------------------------------------------

%prep
%autosetup -p1 %{name}-%{version}

%build
autoreconf -vif
%configure \
    --disable-static \
    --enable-x86-asm \
    --enable-core \
    --enable-vsscript \
    --enable-vspipe \
    --enable-python-module

%make_build

%install
%py3_install
%make_install
