%define major		3
%define libname		%mklibname varnish %{major}
%define develname	%mklibname varnish -d

%define __brp_python_bytecompile %{nil}

Summary:	Varnish is a high-performance HTTP accelerator
Name:		varnish
Version:	7.3.2
Release:	%mkrel 1
License:	BSD
Group:		System/Servers
URL:		https://www.varnish-cache.org/
Source0:	https://varnish-cache.org/_downloads/%{name}-%{version}.tgz
Source1:        varnish.service
Source3:        varnishncsa.service
Source4:        varnishlog.service
Source5:	varnish.logrotate
Source6:	default.vcl

#
# Security patches
# P100 -> ...
#

BuildRequires:	groff
BuildRequires:	libxslt-proc
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(libunwind)
BuildRequires:	pkgconfig(jemalloc)
BuildRequires:	python3dist(docutils)
BuildRequires:	python3dist(sphinx)
BuildRequires:	pkgconfig(readline)
# Varnish actually needs gcc installed to work. It uses the C compiler 
# at runtime to compile the VCL configuration files. This is by design.
Requires:	gcc
Requires(post):	systemd >= %{systemd_required_version}
Requires(post):	util-linux

%description
This is the Varnish high-performance HTTP accelerator. Documentation wiki and
additional information about Varnish is available on the following web site:
https://www.varnish-cache.org/

%package -n	%{libname}
Summary:	Shared libraries for varnish
Group:		System/Libraries

%description -n	%{libname}
Varnish is a high-performance HTTP accelerator.

This package provides the shared libraries for varnish.

%package -n	%{develname}
Summary:	Development headers and libraries for varnish
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Varnish is a high-performance HTTP accelerator.

This package provides the development files for varnish.

%prep
%setup -q
%autopatch -p1

# Hack to get 32- and 64-bits tests run concurrently on the same build machine
case `uname -m` in
	ppc64 | s390x | x86_64 | sparc64 )
		sed -i '
			s,9001,9011,g;
			s,9080,9090,g;
			s,9081,9091,g;
			s,9082,9092,g;
			s,9180,9190,g;
		' bin/varnishtest/*.c bin/varnishtest/tests/*vtc
		;;
	*)
		;;
esac

mkdir examples
cp etc/*.vcl examples

mkdir -p Mageia
cp %{SOURCE5} Mageia/varnish.logrotate
cp %{SOURCE6} Mageia/default.vcl

%build
%configure \
    --disable-static \
    --localstatedir=%{_var}/lib

%make_build

%install

%make_install INSTALL="install -p"

install -d %{buildroot}%{_sysconfdir}/varnish
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}%{_var}/lib/varnish
install -d %{buildroot}%{_var}/log/varnish

mkdir -p %{buildroot}%{_unitdir}
install -D -m 0644 %SOURCE1 %{buildroot}%{_unitdir}/varnish.service
install -D -m 0644 %SOURCE3 %{buildroot}%{_unitdir}/varnishncsa.service
install -D -m 0644 %SOURCE4 %{buildroot}%{_unitdir}/varnishlog.service
install -m0644 Mageia/varnish.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/varnish
install -m0644 Mageia/default.vcl %{buildroot}%{_sysconfdir}/varnish/default.vcl

rm -f %{buildroot}%{_datadir}/varnish/vcl/devicedetect.vcl

# cleanup
find %{buildroot} -name '*.la' -delete

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/varnish 0755 varnish varnish
EOF

# Use the new ld.so.conf.d
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
pushd %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/varnish" > %name.conf
popd

%pre
getent group varnish >/dev/null || groupadd -r varnish
getent passwd varnish >/dev/null || \
	useradd -r -g varnish -d /var/lib/varnish -s /sbin/nologin \
		-c "Varnish http accelerator user" varnish
exit 0

%post
if [ ! -f %{_sysconfdir}/%{name}/secret ]; then
	uuidgen > %{_sysconfdir}/%{name}/secret
	chown %{name}:adm %{_sysconfdir}/%{name}/secret
	chmod 0660 %{_sysconfdir}/%{name}/secret

	# While not strictly related, we also need to fix storage permissions from
	# older versions and the lack of a secret file is a good indicator
	find /var/lib/%{name}/ -uid 0 -exec chown %{name}:%{name} {} \;
fi
%_tmpfilescreate %{name}
%_post_service %{name} %{name} varnishlog varnishncsa

%preun
%_preun_service %{name} %{name} varnishlog varnishncsa

%files
%doc README.rst ChangeLog examples/*.vcl
%config(noreplace) %{_sysconfdir}/logrotate.d/varnish
%dir %{_sysconfdir}/varnish
%config(noreplace) %{_sysconfdir}/varnish/default.vcl
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/*
%{_unitdir}/varnish.service
%{_unitdir}/varnishncsa.service
%{_unitdir}/varnishlog.service
%{_tmpfilesdir}/%{name}.conf
%{_sbindir}/*
%{_bindir}/*
%attr(0755,varnish,varnish) %dir %{_var}/lib/varnish
%attr(0755,varnish,varnish) %dir %{_var}/log/varnish
%{_mandir}/man1/*.1*
%{_mandir}/man7/*.7*
%{_libdir}/varnish/vmods/
%{_mandir}/man3/vmod_{blob,cookie,directors,h2,purge,std,vtc,proxy,unix}.3*

%files -n %{libname}
%doc LICENSE
%{_libdir}/lib*.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/lib*.so
%{_datadir}/aclocal/varnish*.m4
%{_datadir}/varnish/vmodtool.py
%{_datadir}/varnish/vsctool.py
%dir %{_includedir}/varnish
%dir %{_includedir}/varnish/{cache,common,tbl,vapi,waiter}
%{_includedir}/varnish/*.h
%{_includedir}/varnish/{cache,common,tbl,vapi,waiter}/*.h
%{_libdir}/pkgconfig/*.pc
