%define gitdate 20191102
%define rel	7
%define plugin	sc

%define dkmsname dvb-ttpci-sc_patched

%ifarch %ix86 %arm
%define parallel PARALLEL=PARALLEL_32_INT
%endif

%ifarch aarch64
%define parallel PARALLEL=PARALLEL_64_LONG
%endif

Summary:	VDR plugin: A software emulated CAM
Name:		vdr-plugin-%plugin
Version:	1.0.0
Release:	%mkrel %{?gitdate:1.git%gitdate.}%{rel}
Group:		Video/Utilities
License:	GPLv2+
URL:		https://github.com/3PO/vdr-plugin-sc
Source:		%{name}-%{gitdate}.tar.xz
BuildRequires:	vdr-devel >= 1.6.0-7
BuildRequires:	openssl-devel
BuildRequires:	pcsc-lite-devel
BuildRequires:	bzip2-devel
BuildRequires:	gettext
Requires:	vdr-abi = %vdr_abi

%description
This VDR plugin provides a software emulated CAM. Software
decryption with ffdecsa for budget cards is also available. With
this plugin you can, for example, use your pay-tv subscription with
a smart card reader/programmer without expensive CI and CAM devices.

If you use this plugin with an FF card, you will also need to use a
special version of the firmware available from the plugin home page.

This package is in tainted section because it contains algorithms
that may be covered by software patents and because its decryption
capabilities (while requiring appropriate keys) may be considered
breaking DRM.

%if 0
# Does not work, but does not seem to be needed; is doc wrong?
%package -n	dkms-%dkmsname
Summary:	DVB FF card driver patched to support vdr-sc
Group:		Video/Utilities
Requires:	dkms
Requires:	kernel-source
Requires(post):	dkms
Requires(preun):	dkms
# in non-free:
#Requires:	dvb-firmware-ttpci-sc_patched

%description -n	dkms-%dkmsname
The dvb-ttpci module which is patched to support vdr-sc. You may
need this package if you use VDR sc plugin with an FF card.

You also need the patched ttpci firmware from the package
dvb-firmware-ttpci-sc_patched.

Note that this dkms package does not work with
kernel-source-stripped packages.

This package is in PLF because it is useless without the
vdr-plugin-sc package.
%endif

%prep
%autosetup -n %{name}-%{gitdate} -p1

perl -pi -e 's,-march=,,' Makefile
%vdr_plugin_prep

%if 0
cat > patched_dvb-ttpci.sh <<EOF
#!/bin/sh -ex
KERNELDIR="\$1"
mkdir ttpci
cp \$KERNELDIR/drivers/media/dvb/ttpci/{*.[ch],Makefile} ttpci
patch -p4 -i dvb-cwidx.diff
make -C \$KERNELDIR M=\$(pwd)/ttpci modules
EOF
%endif

%vdr_plugin_params_begin %plugin
# See README for more information.
#
# forces DVB device N to budget mode (using FFdecsa)
var=FORCE_BUDGET
param=--budget=MULTIPLE_PARAMS
# external key update script
var=EXTERNAL_AU
param="-E EXTERNAL_AU"
%vdr_plugin_params_end

cat > README.0.9.0.upgrade.urpmi <<EOF
As of vdr-sc 0.9.0, the plugin expects the configuration files to
reside in the /plugins/sc subdirectory instead of /plugins. If you
are using the default configuration directory location of
/var/lib/vdr/config, you must move any SC config files from
/var/lib/vdr/config/plugins to /var/lib/vdr/config/plugins/sc.
If you do not use any configuration files with sc, you do not have
to take any action.
EOF

cat > README.0.9.2.upgrade.urpmi <<EOF
As of vdr-sc 0.9.2, smart card reader configuration has been moved
to cardslot.conf. If you have a smart card reader activated in
/etc/sysconfig/vdr-sc, you need to remove those settings and
configure the reader in /var/lib/vdr/config/plugins/sc/cardslot.conf
instead. See the example file in
/var/lib/vdr/config/plugins/sc/cardslot.conf.example.
EOF

%build
# TODO: export MAXCAID in vdr header
VDR_PLUGIN_EXTRA_FLAGS="-I%{_includedir}/PCSC -Wno-narrowing"
%vdr_plugin_build CSAFLAGS="%{vdr_plugin_flags}" %{?parallel} CPUOPT="" MAXCAID=64 HASLOCALE=1 WITH_PCSC=1 HAVE_SD=1 HAVE_HD=1 -j1

%install
%vdr_plugin_install

install -d -m755 %{buildroot}%{_vdr_plugin_cfgdir}/%{plugin}

# install some examples in-place
install -m644 examples/*.conf.example %{buildroot}%{_vdr_plugin_cfgdir}/%{plugin}

%if 0
install -d -m755 %{buildroot}/usr/src/%dkmsname-%{version}-%{release}
install -m755 patched_dvb-ttpci.sh %{buildroot}/usr/src/%dkmsname-%{version}-%{release}
install -m644 patches/dvb-cwidx.diff %{buildroot}/usr/src/%dkmsname-%{version}-%{release}

cat > %{buildroot}/usr/src/%dkmsname-%{version}-%{release}/dkms.conf <<EOF
PACKAGE_NAME="%dkmsname"
PACKAGE_VERSION="%{version}-%{release}"
MAKE[0]="./patched_dvb-ttpci.sh \$kernel_source_dir"
CLEAN="rm -rf ttpci"
AUTOINSTALL=yes
BUILT_MODULE_NAME[0]="dvb-ttpci"
BUILT_MODULE_LOCATION[0]="ttpci"
DEST_MODULE_LOCATION[0]="/kernel/drivers/media/dvb/ttpci"
EOF
%endif

%if 0
%post -n dkms-%{dkmsname}
dkms add     -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms build   -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms install -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade
true

%preun -n dkms-%{dkmsname}
dkms remove  -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade --all
true
%endif

%files -f %plugin.vdr
%doc README* HISTORY COPYING examples
%{_vdr_plugin_dir}/libsc-*.so.%vdr_apiversion
%attr(-,vdr,vdr) %dir %{_vdr_plugin_cfgdir}/%{plugin}
%{_vdr_plugin_cfgdir}/%{plugin}/*.conf.example

%if 0
%files -n dkms-%dkmsname
/usr/src/%dkmsname-%{version}-%{release}
%endif

