%define srcname Vega-Strike-Engine-Source

# comment out if not pre rel
#define prel	beta3

# rel for bumping
%define rel	1

%bcond_with	ffmpeg
%bcond_with	ogre

Name:		vegastrike
Version:	0.9.0
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	3D OpenGL spaceflight simulator
License:	GPL-2.0-or-later
Group:		Games/Simulation
URL:		https://www.vega-strike.org/
Source0:	https://github.com/vegastrike/%{srcname}/archive/v%{version}%{?prel:-%prel}/%{srcname}-%{version}%{?prel:-%prel}.tar.gz
Source5:	vegastrike.png
Patch0:		vegastrike-add-mageia-distri-rpm-config.patch
# https://github.com/vegastrike/Vega-Strike-Engine-Source/pull/445
Patch1:		0001-cmake-Install-man-pages-into-matching-sub-directory.patch

BuildRequires:	cmake
BuildRequires:	boost-devel
%if %{with ffmpeg}
BuildRequires:	ffmpeg-devel
%endif
%if %{with ogre}
BuildRequires:	cmake(ogre)
%endif
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(glut)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(opengl)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(zlib)

Requires:	xdg-utils
Requires:	%{name}-data >= %{version}
Recommends:	%{name}-sounds = %{version}

%description
Vega Strike is a GPL 3D OpenGL Action RPG space sim that
allows a player to trade and bounty hunt in the spirit
of Elite. You start in an old beat up Wayfarer
cargo ship, with endless possibility before you and just
enough cash to scrape together a life. Yet danger lurks in
the space beyond.

%prep
%autosetup -p1 -n %{srcname}-%{version}%{?prel:-%prel}

sed -i 's|Vega Strike Version: \${VEGASTRIKE_VERSION_LONG_STR}|Vega Strike Version: \${VEGASTRIKE_VERSION_LONG_STR}%{?prel:%prel}|' engine/CMakeLists.txt

%build
%global _vpath_srcdir engine
%cmake \
	-DCMAKE_INSTALL_BINDIR=%{_gamesbindir} \
	-DDATADIR=%{_gamesdatadir}/%{name} \
	-DUSE_SYSTEM_BOOST:BOOL=ON \
	-DBUILD_STATIC_LIBS:BOOL=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DENABLE_PIE:BOOL=ON \
	-DUSE_GTEST:BOOL=OFF \
	-DINSTALL_GTEST:BOOL=OFF \
	%{?with_ffmpeg:-DDISABLE_FFMPEG:BOOL=OFF} \
	%{?with_ogre:-DDISABLE_OGRE:BOOL=OFF}
%cmake_build

%install
%cmake_install

# We let RPM install it correctly itself
rm -rfv %{buildroot}%{_datadir}/doc/Vega_Strike

# icons and desktop are already provided upstream in vegastrike-data
%if 0
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Vega Strike
Comment=3D OpenGL spaceflight simulator
Comment[cs]=Hraj 3D vesmírnou simulaci
Comment[es]=Simulador de vuelo espacial 3D/OpenGL
GenericName=vegastrike
GenericName[en_US]=vegastrike
Exec=%{_gamesbindir}/vegastrike
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
EOF

install -D -m0644 %{S:5} %{buildroot}%{_iconsdir}/hicolor/64x64/apps/%{name}.png
%endif

mkdir -p %{buildroot}%{_gamesdatadir}/%{name}

%files
%doc AUTHORS README.md
%license LICENSE
%{_gamesbindir}/vega*
%{_gamesbindir}/vs*
%dir %{_gamesdatadir}/%{name}
%{_mandir}/man1/*
