Name:           veusz
Version:        3.6.2
Release:        %mkrel 4
Summary:        GUI scientific plotting package

Group:          Sciences/Mathematics
# The entire source code is GPLv2+ except helpers/src/_nc_cntr.c which is Python
License:        GPLv2+ and Python
URL:            https://veusz.github.io/
Source0:        https://github.com/veusz/veusz/releases/download/veusz-%{version}/veusz-%{version}.tar.gz
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-sip6
BuildRequires:  python3-pyqt5-sip
BuildRequires:  python3-tomli

Requires:       python3dist(astropy) >= 0.2.3

%{?_python3_sip_api:Requires: sip-api(%{_python3_sip_api_major}) >= %{_python3_sip_api}}
Requires:       python3dist(numpy)
Requires:       python3dist(h5py)
Requires:       python3-qt5-core
Requires:       python3-qt5-gui
Requires:       python3-qt5-printsupport
Requires:       python3-qt5-svg
Requires:       python3-qt5-widgets
Requires:       python3-pkg-resources
Requires:       /usr/bin/env
Provides:       python3-veusz = %{version}

# we don't want to provide private python extension libs
%{?filter_setup:
%filter_provides_in %{python3_sitearch}/veusz/helpers/.*\.so$
%filter_setup
}

%description
Veusz is a 2D and 3D scientific plotting package, designed to create
publication-ready vector PDF and SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with error bars, keys, labels, stacked plots,
ternary plots, vector plots, contours, images, shapes and fitting
data. 3D point, surface, volume and function plots are also supported.

%prep
%autosetup -p1 -n veusz-%{version}

find -name \*~ | xargs rm -f

# remove shebangs from scripts which aren't installed
# (veusz allows these to be executed if app isn't installed properly)
sed -i '/^#!/d' veusz/veusz_main.py
sed -i '/^#!/d' veusz/veusz_listen.py

%build
%py3_build

%install
# veusz-resource-dir: put data files in location given

%py3_install -- --veusz-resource-dir=%{buildroot}%{_datadir}/veusz --disable-install-examples

# tell veusz where its resource directory is in _datadir
ln -s %{_datadir}/veusz \
    %{buildroot}%{python3_sitearch}/veusz/resources

# tell it where to look for examples and COPYING
ln -s  %{_defaultdocdir}/%{name}/examples \
    %{buildroot}%{_datadir}/veusz

# install desktop file
desktop-file-install  \
    --dir %{buildroot}%{_datadir}/applications \
    support/veusz.desktop

# file to register .vsz mimetype
mkdir -p %{buildroot}%{_datadir}/mime/packages/
install -p support/veusz.xml -m 0644 %{buildroot}%{_datadir}/mime/packages/

# appdata file
mkdir -p %{buildroot}%{_datadir}/appdata/
install -p support/veusz.appdata.xml -m 0644 %{buildroot}%{_datadir}/appdata/

# symlink main veusz icon into pixmaps (for desktop file)
mkdir %{buildroot}%{_datadir}/pixmaps
ln -s ../veusz/icons/veusz_48.png %{buildroot}%{_datadir}/pixmaps/veusz.png

# also link in hicolor icons
for size in 16 32 48 64 128; do
    odir=%{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps
    mkdir -p $odir
    ln -s %{_datadir}/veusz/icons/veusz_${size}.png ${odir}/veusz.png
done
odir=%{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mkdir -p $odir
ln -s %{_datadir}/veusz/icons/veusz.svg $odir

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -p Documents/man-page/veusz.1 -m 0644 \
    %{buildroot}%{_mandir}/man1

%check
%define enable_tests 0
%if %{enable_tests}
# as the data directory hasn't got the same absolute path we have
# to define VEUSZ_RESOURCE_DIR
PYTHONPATH=%{buildroot}%{python3_sitearch} \
    VEUSZ_RESOURCE_DIR=%{buildroot}%{_datadir}/veusz \
    QT_QPA_PLATFORM=minimal \
    %{__python3} tests/runselftest.py
%endif

%files
%doc README.md AUTHORS
%doc examples
%doc Documents/manual/html
%license COPYING
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/mime/packages/*
%{_datadir}/appdata/*
%{_datadir}/pixmaps/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/veusz/
%{python3_sitearch}/veusz-*.egg-info
%{python3_sitearch}/veusz
