%define	italcgrp veyon

Name:		veyon
# version used by GlobalConfig.xml
Version:	4.9.4
Release:	%mkrel 1
Summary:	Computer monitoring and classroom management
Group:		Networking/Remote access
License:	GPLv2+
URL:		https://veyon.io/
Source0:	https://github.com/veyon/veyon/releases/download/v%{version}/veyon-%{version}-src.tar.bz2
Source1:	veyon.desktop
Source3:	ica-autostart.desktop
Source4:	ica-start
# Upstream 4.9 branch patches
#
BuildRequires:	cmake
BuildRequires:	cmake(Qt6LinguistTools)
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6HttpServer)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6QuickControls2)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qca-qt6)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(libfakekey)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libproc2)
BuildRequires:	pkgconfig(libsasl2)
BuildRequires:	pkgconfig(libvncclient)
BuildRequires:	pkgconfig(libvncserver)
BuildRequires:	pkgconfig(lzo2)
BuildRequires:	pkgconfig(polkit-agent-1)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xkbcommon)
BuildRequires:	pkgconfig(xkbcommon-x11)
BuildRequires:	pkgconfig(xtst)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pam-devel
BuildRequires:	desktop-file-utils
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	openldap2-devel

Requires:	qca-qt6
Provides:	italc = %{version}-%{release}
Obsoletes:	italc < 4.7.4

%description
Veyon is a free and open source software for monitoring and controlling
computers across multiple platforms. Veyon supports you in teaching in digital
learning environments, performing virtual trainings or giving remote support.

The following features are available in Veyon:

    Overview: monitor all computers in one or multiple locations or classrooms
    Remote access: view or control computers to watch and support users
    Demo: broadcast the teacher's screen in realtime (fullscreen/window)
    Screen lock: draw attention to what matters right now
    Communication: send text messages to students
    Start and end lessons: log in and log out users all at once
    Screenshots: record learning progress and document infringements
    Programs & websites: launch programs and open website URLs remotely
    Teaching material: distribute and open documents, images and videos easily
    Administration: power on/off and reboot computers remotely


%package client
Summary:	Software for iTALC-clients
Group:		Networking/Remote access
Requires:	%{name} = %{version}
Obsoletes:	italc-client < 4.7.4
Provides:	italc-client = %{version}-%{release}

%description client
This package contains the software, needed by veyon-clients.

%package client-autostart
Summary:	Autostart for veyon-client
Group:		Networking/Remote access
Requires:	%{name} = %{version}
Requires:	veyon-client
Obsoletes:	italc-client-autostart < 4.7.4
Provides:	italc-client-autostart = %{version}-%{release}

%description client-autostart
This package contains autostart for veyon-client.

%package master
Summary:	veyon master software
Group:		Networking/Remote access
Requires:	%{name} = %{version}
Requires:	%{name}-client = %{version}
Obsoletes:	italc-master < 4.7.4
Provides:	italc-master = %{version}-%{release}

%description master
This package contains the actual master-software for accessing clients.

%prep
%autosetup -p1

%build
%cmake  -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
        -DSYSTEMD_SERVICE_INSTALL_DIR:PATH=%{_unitdir} \
        -DCMAKE_VEYON_X11VNC_EXTERNAL:BOOL=ON \
        -DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=ON \
        -DCOTIRE_MINIMUM_NUMBER_OF_TARGET_SOURCES=9999 \
        -DWITH_PCH:BOOL=OFF \
        -DWITH_QT6:BOOL=ON
%cmake_build

%install
%cmake_install

# From Suse
# create the directories containing the auth-keys
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/keys/{private,public}/{teacher,admin,supporter,other}
# create pseudo key files so RPM can own them (ghost files)
for role in admin supporter teacher; do
	touch %{buildroot}%{_sysconfdir}/%{name}/keys/{private,public}/$role/key
done

desktop-file-install --dir=%{buildroot}%{_datadir}/applications/ %{SOURCE1}

install -dm 755 %{buildroot}%{_sysconfdir}/xdg/autostart
install -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/xdg/autostart/
install -dm 755 %{buildroot}%{_bindir}
install -m 755 %{SOURCE4} %{buildroot}%{_bindir}/

%pre client
%{_sbindir}/groupadd -r -f %{italcgrp} 2>/dev/null ||:

%post client
if
    getent group %{italcgrp} >/dev/null
then
    : OK group %{italcgrp} already present
else
    groupadd -r %{italcgrp} 2>/dev/null || :
fi

%post master
if
    getent group %{italcgrp} >/dev/null
then
    : OK group %{italcgrp} already present
else
    groupadd -r %{italcgrp} 2>/dev/null || :
fi


%files
%doc README.md CONTRIBUTORS
%license COPYING
%dir %{_datadir}/veyon
%dir %{_datadir}/veyon/translations
%{_datadir}/veyon/translations/veyon*.qm

%files client
%{_bindir}/veyon-auth-helper
%{_bindir}/veyon-cli
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/keys
%dir %{_sysconfdir}/%{name}/keys/private
%defattr(0440,root,%{italcgrp},0750)
%dir %{_sysconfdir}/%{name}/keys/private/teacher
%dir %{_sysconfdir}/%{name}/keys/private/admin
%dir %{_sysconfdir}/%{name}/keys/private/supporter
%dir %{_sysconfdir}/%{name}/keys/private/other
%ghost %attr(0440,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/private/teacher/key
%ghost %attr(0440,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/private/admin/key
%ghost %attr(0440,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/private/supporter/key
%ghost %attr(0444,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/public/teacher/key
%ghost %attr(0444,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/public/admin/key
%ghost %attr(0444,root,%{italcgrp}) %config(noreplace) %{_sysconfdir}/%{name}/keys/public/supporter/key

%files master
%{_bindir}/veyon-master
%{_bindir}/veyon-configurator
%{_bindir}/veyon-server
%{_bindir}/veyon-service
%{_bindir}/veyon-worker
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-master.desktop
%{_datadir}/applications/%{name}-configurator.desktop
%{_iconsdir}/hicolor/48x48/apps/*.png
%{_iconsdir}/hicolor/scalable/apps/*.svg
%{_datadir}/pixmaps/%{name}-*.xpm
%{_datadir}/polkit-1/actions/io.veyon.veyon-configurator.policy
%{_unitdir}/%{name}.service
%dir %{_libdir}/veyon
%{_libdir}/veyon/authkeys.so
%{_libdir}/veyon/builtin-x11vnc-server.so
%{_libdir}/veyon/builtindirectory.so
%{_libdir}/veyon/demo.so
%{_libdir}/veyon/desktopservices.so
%{_libdir}/veyon/external-vnc-server.so
%{_libdir}/veyon/filetransfer.so
%{_libdir}/veyon/headless-vnc-server.so
%{_libdir}/veyon/ldap.so
%{_libdir}/veyon/libkldap-light.so
%{_libdir}/veyon/libldap-common.so
%{_libdir}/veyon/libveyon-core.so
%{_libdir}/veyon/linux-platform.so
%{_libdir}/veyon/powercontrol.so
%{_libdir}/veyon/remoteaccess.so
%{_libdir}/veyon/screenlock.so
%{_libdir}/veyon/screenshot.so
%{_libdir}/veyon/systemusergroups.so
%{_libdir}/veyon/textmessage.so
%{_libdir}/veyon/usersessioncontrol.so
%{_libdir}/veyon/webapi.so


%files client-autostart
%{_sysconfdir}/xdg/autostart/ica-autostart.desktop
%{_bindir}/ica-start
