
%ifarch aarch64
# Work around gcc bug causing Error: can't resolve value for symbol `.LVU45'
%global optflags %(echo %{optflags} | sed 's/-g /-g1 /')
%endif

%bcond_with ffmpeg

Name:		vice
Version:	3.9
Release:	%mkrel 1
License:	GPLv2+
Summary:	Versatile Commodore Emulator
Group:		Emulators
URL:		https://vice-emu.sourceforge.io/
Source0:	https://downloads.sourceforge.net/project/vice-emu/releases/vice-%{version}.tar.gz
Source1:	vice-normalicons.tar.bz2
Source2:	vice-largeicons.tar.bz2
Source3:	vice-miniicons.tar.bz2
Patch1:		vice-build-flags.patch
BuildRequires:	bdftopcf
BuildRequires:	bison
BuildRequires:	dos2unix
BuildRequires:	flex
BuildRequires:	gettext-devel
BuildRequires:	giflib-devel
BuildRequires:	gtkglext-devel
BuildRequires:	ieee1284-devel
BuildRequires:	liblame-devel
BuildRequires:	mkfontdir
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libevdev)
BuildRequires:	pkgconfig(flac)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-3.0)
%if %{with ffmpeg}
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
%endif
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(xf86vidmodeproto)
BuildRequires:	pkgconfig(xt)
BuildRequires:	readline-devel
BuildRequires:	texinfo
BuildRequires:	texinfo-tex
BuildRequires:	xa

%description
VICE is a set of accurate emulators for the Commodore 64, 128, VIC20,
PET and CBM-II 8-bit computers, all of which run under the X Window
System.

%prep
%autosetup -p1

# use system libs
rm -rf src/lib/{liblame,libx264}

%if %{with ffmpeg} || 1
rm -rf src/lib/{ffmpeg,libffmpeg}
sed -i -e '/src\/lib\/ffmpeg\/Makefile/d' configure.ac
%endif

%build
./autogen.sh
%configure \
%if %{with ffmpeg}
  --enable-external-ffmpeg \
%endif
  --enable-gtk3ui \
  --with-lame \
  --enable-ethernet \
  --with-libieee1284 \
  --without-portaudio \
  --without-oss
  
%make_build

%install
%make_install

#xdg menu
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/vice-x64.desktop << EOF
[Desktop Entry]
Name=C64 Emulator
Comment=Commodore 64 sc Emulator
Exec=%{_bindir}/x64sc %U
Icon=c64icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF

cat > %{buildroot}%{_datadir}/applications/vice-x64dtv.desktop << EOF
[Desktop Entry]
Name=C64dtv Emulator
Comment=Commodore 64 dtv Emulator
Exec=%{_bindir}/x64dtv %U
Icon=c64icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF

cat > %{buildroot}%{_datadir}/applications/vice-x128.desktop << EOF
[Desktop Entry]
Name=C128 Emulator
Comment=Commodore 128 Emulator
Exec=%{_bindir}/x128 %U
Icon=c128icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xpet.desktop << EOF
[Desktop Entry]
Name=PET Emulator
Comment=Commodore PET Emulator
Exec=%{_bindir}/xpet %U
Icon=peticon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xvic.desktop << EOF
[Desktop Entry]
Name=VIC 20 Emulator
Comment=Commodore VIC 20 Emulator
Exec=%{_bindir}/xvic %U
Icon=vic20icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xcbm2.desktop << EOF
[Desktop Entry]
Name=CBM2 Emulator
Comment=Commodore BM 2 Emulator
Exec=%{_bindir}/xcbm2 %U
Icon=c610icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xplus4.desktop << EOF
[Desktop Entry]
Name=CPLUS4 Emulator
Comment=Commodore PLUS4 Emulator
Exec=%{_bindir}/xplus4 %U
Icon=plus4icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-c1541.desktop << EOF
[Desktop Entry]
Name=VICE disk image tool
Comment=C1541 stand alone disk image maintenance program
Exec=%{_bindir}/c1541 %U
Icon=commodore
Terminal=true
Type=Application
StartupNotify=true
Categories=System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-vsid.desktop << EOF
[Desktop Entry]
Name=VSID music player
Comment=VICE SID music player for Commodore tunes
Exec=%{_bindir}/vsid %U
Icon=commodore
Terminal=false
Type=Application
StartupNotify=true
Categories=AudioVideo;Audio;Player;
MimeType=audio/prs.sid
EOF

# Install icons
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,48x48}/apps
tar xjf %{SOURCE1} -C %{buildroot}%{_iconsdir}/hicolor/32x32/apps
tar xjf %{SOURCE2} -C %{buildroot}%{_iconsdir}/hicolor/48x48/apps
tar xjf %{SOURCE3} -C %{buildroot}%{_iconsdir}/hicolor/16x16/apps

%files
%doc README
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/applications/vice-*
%{_iconsdir}/hicolor/*/apps/*.png
