# comment out if not nightly snapshot from
# http://viewvc.org/nightly/
%global nightly	20200516

# rel for bumping
%global rel	3

Name:           viewvc
Version:        1.3.0
Release:        %mkrel %{?nightly:0.dev%nightly.}%{rel}
Summary:        Browser interface for CVS and Subversion version control repositories
License:        BSD
Group:          System/Servers
URL:            https://www.viewvc.org/
Source0:        https://viewvc.org%{!?nightly:/downloads}%{?nightly:/nightly}/viewvc-%{version}%{?nightly:-dev-%nightly}.tar.gz
Patch0:         viewvc-tools.patch
Patch1:         viewvc-1.1.14-fhs.patch
Patch2:         CVE-2023-22464.patch
Patch3:         CVE-2023-22456.patch
BuildArch:      noarch
BuildRequires:  python3
Requires:       apache
Requires:       python3
Requires(post): rpm-helper
Requires(postun): rpm-helper
Recommends:     python3-svn
Recommends:     python3-pygments
Recommends:     python3-chardet

%description
ViewVC is a browser interface for CVS and Subversion version control
repositories. It generates templatized HTML to present navigable
directory, revision, and change log listings. It can display specific
versions of files as well as diffs between those versions. Basically,
ViewVC provides the bulk of the report-like functionality you expect out
of your version control tool, but much more prettily than the average
textual command-line program output.

Here are some of the additional features of ViewVC:

    * Support for filesystem-accessible CVS and Subversion repositories.
    * Individually configurable virtual host support.
    * Line-based annotation/blame display (CVS only).
    * Revision graph capabilities (via integration with CvsGraph) (CVS
      only).
    * Syntax highlighting support (via integration with GNU enscript).
    * Bonsai-like repository query facilities.
    * Template-driven output generation.
    * Colorized, side-by-side differences.
    * Tarball generation (by tag/branch for CVS, by revision for
      Subversion).
    * I18N support based on the Accept-Language request header.
    * Ability to run either as CGI script or as a standalone server.
    * Regexp-based file searching.
    * INI-like configuration file (as opposed to requiring actual code
      tweaks).

%prep
%setup -qn %{name}-%{version}%{?nightly:-dev-%nightly}
%autopatch -p1

%build
#nothing

%install
%{__python3} ./viewvc-install --destdir=%{buildroot} --prefix=%{_datadir}/%{name}

# remove uneeded files
rm -rf %{buildroot}%{_datadir}/%{name}/bin/mod_python/.htaccess

# fix python shebangs
%py_shebang_fix %{buildroot}%{_datadir}/%{name}

# fix conf pathname
perl -pi \
        -e 's|CONF_PATHNAME =.*|CONF_PATHNAME = r"%{_sysconfdir}/%{name}/viewvc.conf"|g;' \
        $(find %{buildroot}%{_datadir}/%{name} -type f)

# fix paths in configuration
perl -pi \
  -e 's|^#template_dir = .*|template_dir = %{_datadir}/%{name}/templates/default|g;' \
  -e 's|^#docroot = .*|docroot = /%{name}/static|;' \
  -e 's|^#cvsgraph_conf = .*|cvsgraph_conf = %{_sysconfdir}/%{name}/cvsgraph.conf|;' \
  -e 's|^#mime_types_files = .*|mime_types_files = %{_sysconfdir}/%{name}/mimetypes.conf, %{_sysconfdir}/httpd/conf/mime.types|;' \
  %{buildroot}%{_datadir}/%{name}/viewvc.conf

# install config to sysconf directory
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
install -p -m 644 %{buildroot}%{_datadir}/%{name}/viewvc.conf %{buildroot}%{_sysconfdir}/%{name}/viewvc.conf
rm -rf %{buildroot}%{_datadir}/%{name}/viewvc.conf
install -p -m 644 %{buildroot}%{_datadir}/%{name}/cvsgraph.conf %{buildroot}%{_sysconfdir}/%{name}/cvsgraph.conf
rm -rf %{buildroot}%{_datadir}/%{name}/cvsgraph.conf
install -p -m 644 %{buildroot}%{_datadir}/%{name}/mimetypes.conf %{buildroot}%{_sysconfdir}/%{name}/mimetypes.conf
rm -rf %{buildroot}%{_datadir}/%{name}/mimetypes.conf

# compile the python files
find %{buildroot}%{_datadir}/%{name}/lib -type f -name "*.pyc" -delete

# apache configuration
mkdir -p %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/%{name}.conf <<EOF
# %{name} configuration

Alias /%{name}/static %{_datadir}/%{name}/templates/docroot

<Directory %{_datadir}/%{name}/templates/docroot>
    Require local granted
    ErrorDocument 403 "Access denied per %{_webappconfdir}/%{name}.conf"
</Directory>

Alias /%{name} %{_datadir}/%{name}/bin/cgi

<Directory %{_datadir}/%{name}/bin/cgi>
    Require local granted
    ErrorDocument 403 "Access denied per %{_webappconfdir}/%{name}.conf"
    DirectoryIndex viewvc.cgi
</Directory>
EOF

# set mode 755 on executable scripts
grep -rl '^#!' %{buildroot}%{_datadir}/%{name} | %{_bindir}/xargs %{__chmod} 755

cat >README.mga <<EOF
Mageia RPM specific notes
=========================

Setup
-----
The setup used here differs from default one in order to achieve better FHS
compliance:

- the configuration file is located at /etc/viewvc/viewvc.conf
- the other files are in /usr/share/viewvc

Post-installation
-----------------
You have manually to create the MySQL database if you want to use query mode.

Additional useful packages
--------------------------
- cvs and rcs provide a web interface for CVS repositories
- python3-svn provides a web interface for SVN repositories
- MySQL-python and a MySQL database are needed for query mode
- apache-mod_python, will be accessible at http://localhost/viewvc-mp (instead
  of the cgi files)
EOF

%files
%license LICENSE
%doc CHANGES COMMITTERS INSTALL README.md README.mga docs/
%config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_webappconfdir}/%{name}.conf
%{_datadir}/%{name}/
