%define major		11
%define libname		%mklibname %{name} %{major}
%define olddevel	%libname-devel
%define libnamedevel	%mklibname %{name} -d
%define tarballver	%(echo %version|sed -e 's/\\./-/g')

Name:		vigra
Version:	1.12.1
Release:	%mkrel 6
Summary:	Generic Programming for Computer Vision
License:	MIT
Group:		Development/C
URL:		https://ukoethe.github.io/vigra/
Source0:	https://github.com/ukoethe/vigra/archive/Version-%{tarballver}/%{name}-%{version}.tar.gz
#Source0:	https://github.com/ukoethe/vigra/releases/download/Version-%%{tarballver}/%%{name}-%%{version}-src.tar.gz
# https://github.com/ukoethe/vigra/issues/588
Patch0:		vigra-cmake-module-dir.patch
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	boost-devel
BuildRequires:	hdf5-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(fftw3) >= 3
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	python3-numpy-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(pytest)
BuildRequires:	python3dist(sphinx)

%description
VIGRA stands for "Vision with Generic Algorithms". It's a novel computer vision
library that puts its main emphasis on customizable algorithms and data
structures. By using template techniques similar to those in the C++ Standard
Template Library, you can easily adapt any VIGRA component to the needs of your
application without thereby giving up execution speed.

%package -n	%{libname}
Summary:	Library of vigra library
Group:		Development/C

%description -n	%{libname}
VIGRA stands for "Vision with Generic Algorithms". It's a novel computer vision
library that puts its main emphasis on customizable algorithms and data
structures. By using template techniques similar to those in the C++ Standard
Template Library, you can easily adapt any VIGRA component to the needs of your
application without thereby giving up execution speed.

%package -n	%{libnamedevel}
Summary:	Development tools for programs which will use the vigra library
Group:		Development/C
Requires:	%{libname} = %{version}
Requires:	python3dist(sphinx)
Requires:	python3-numpy-devel
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{libnamedevel}
The %{libnamedevel} package includes the header files necessary for developing
programs that use the %{name} library.

%package -n	python3-%{name}
Summary:	Python 3 interface for the vigra computer vision library
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}
Requires:	python3dist(numpy)
Provides:	%{name}-python = %{version}-%{release}
Provides:	python-%{name} = %{version}-%{release}

%description -n	python3-%{name}
The python3-%{name} package provides python 3 bindings for %{name}.

%prep
%autosetup -p1 -n %{name}-Version-%{tarballver}

# cleanup
rm -f doc/vigranumpy/.buildinfo

# python shebang
sed -i '1s=^#!/usr/bin/\(python\|env python\)[0-9.]*=#!%{python3}=' config/vigra-config.in

%build
%cmake \
	-DDOCINSTALL=share/doc/%{name} \
	-DPYTHON_VERSION=%{python3_version} \
	-DVIGRANUMPY_INSTALL_DIR=%{python3_sitearch} \
	-DWITH_OPENEXR=ON
%cmake_build -j4

%install
%cmake_install

%files -n %{libname}
%{_libdir}/lib%{name}impex.so.%{major}{,.*}

%files -n %{libnamedevel}
%doc %{_datadir}/doc/%{name}
%{_bindir}/%{name}-config
%{_includedir}/%{name}/
%{_libdir}/lib%{name}impex.so
%{_libdir}/cmake/%{name}/
%{_libdir}/cmake/vigranumpy/

%files -n python3-%{name}
%{python3_sitearch}/%{name}/
