# Please keep this package in sync with FC

# "fix" underlinking:
%define _disable_ld_no_undefined 1

%global major 1
%define libname %mklibname virglrenderer %major
%define devname %mklibname -d virglrenderer

# Define the gitdate below and download the tarball using 
# make-git-snapshot.sh <commit> to retrieve the snapshot version.
#
#global gitdate 20241201
#global gitversion 41f2587c

# To be sure that mass_rebuild script can increase the rel
%define rel 1

# for vulkan (see https://docs.mesa3d.org/drivers/venus.html)
%define enable_venus	1

Name:		virglrenderer
Version:	1.1.0
Release:	%mkrel %{?gitdate:%{rel}.%{gitdate}git%{gitversion}}%{!?gitdate:%rel}

Summary:	The VirGL virtual OpenGL renderer
Group:		Emulators
License:	MIT

%if 0%{?gitdate}
Source0:	virglrenderer-%{gitdate}.tar.xz
%else
Source0:	https://gitlab.freedesktop.org/virgl/virglrenderer/-/archive/%{version}/virglrenderer-%{version}.tar.bz2
%endif
Source1:	make-git-snapshot.sh

BuildRequires:  meson
BuildRequires:	x11-util-macros
BuildRequires:	pkgconfig(epoxy)
BuildRequires:	pkgconfig(gbm)
BuildRequires:	pkgconfig(egl)
BuildRequires:	python3
BuildRequires:	pkgconfig(libdrm)
BuildRequires:	pkgconfig(libva)
%if 0%{?enable_venus}
BuildRequires:	pkgconfig(vulkan)
%endif

%description
The Virgil3D rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

%package -n %libname
Summary: Virgl Rendering library
Group:	Emulators

%description -n %libname
The Virgil3D rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

%package -n %devname
Summary: Virgil3D renderer development files
Group:	Emulators
Provides: %{name}-devel
Requires: %{libname} = %{version}-%{release}

%description -n %devname
Virgil3D renderer development files, used by
qemu to build against.

%package test-server
Summary: Virgil3D renderer testing server
Group:	Emulators
Requires: %{libname} = %{version}-%{release}
%if 0%{?enable_venus}
Requires: %{name}-vulkan = %{version}-%{release}
%endif

%description test-server
Virgil3D renderer testing server is a server
that can be used along with the mesa virgl
driver to test virgl rendering without GL.

%package vulkan
Summary: Virgil3D renderer vulkan files
Group: Emulators

%description vulkan
The Virgil3D rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

This package contains the extra files for the Venus
Virtio-GPU protocol for Vulkan command serialization.


%prep
%if 0%{?gitdate}
%setup -q -n %{name}-%{gitdate}
%else
%setup -q -n %{name}-%{version}
%endif
%autopatch -p1

%build
%meson \
%if 0%{?enable_venus}
	-Dvenus=true \
	-Dvenus-validate=true \
%endif
	-Dvideo=true
%meson_build

%install
%meson_install
find %{buildroot} -type f -name '*.la' | xargs rm -f -- || :



%files -n %libname
%license COPYING
%{_libdir}/lib*.so.*

%files -n %devname
%dir %{_includedir}/virgl/
%{_includedir}/virgl/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files test-server
%{_bindir}/virgl_test_server

%files vulkan
%if 0%{?enable_venus}
%{_libexecdir}/virgl_render_server
%endif
