%define oname   VirtualGL
%define libname %mklibname %{name}

Name:           virtualgl
Summary:        A toolkit for displaying OpenGL applications to thin clients
Group:          Networking/Other
Version:        3.1.1
Release:        %mkrel 1
URL:            https://www.virtualgl.org/
License:        wxWindows
Source0:        https://github.com/VirtualGL/virtualgl/releases/download/%{version}/%{oname}-%{version}.tar.gz
# fix for rhbz#1088475 - Don't install hidden files into /usr/bin
Patch3:         virtualgl-2.4.1-mga-libexec-paths.patch
# fix issue on no-undefined (https://github.com/VirtualGL/virtualgl/issues/62)
# merged from opensuse
Patch4:         virtualgl-link-libs.patch
# Fix default prefix
Patch5:         virtualgl-3.0.2-fix-default-prefix.patch

BuildRequires:  cmake
BuildRequires:  fltk-devel
BuildRequires:  jpeg-devel
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xv)

Requires:       %{libname} = %{version}-%{release}
Requires:       glxspheres = %{version}-%{release}

%description
VirtualGL is a library which allows most Linux OpenGL applications to be
remotely displayed to a thin client without the need to alter the
applications in any way.  VGL inserts itself into an application at run time
and intercepts a handful of GLX calls, which it reroutes to the server's
display (which presumably has a 3D accelerator attached.)  This causes all
3D rendering to occur on the server's display.  As each frame is rendered
by the server, VirtualGL reads back the pixels from the server's framebuffer
and sends them to the client for re-compositing into the appropriate X
Window.

VirtualGL can be used to give hardware-accelerated 3D capabilities to
VNC or other remote display environments that lack GLX support.  In a LAN
environment, it can also be used with its built-in motion-JPEG video delivery
system to remotely display full-screen 3D applications at 20+ frames/second.

%files
%doc %{_docdir}/%{name}/
%{_bindir}/cpustat
%{_bindir}/glreadtest
%{_bindir}/nettest
%{_bindir}/tcbench
%{_bindir}/vgl*
%{_libexecdir}/vglrun.vars%{__isa_bits}

#--------------------------------------------------------------------
%package -n %{libname}
Summary:        Libraries injected by VirtualGL into applications that are ran through it
Group:          System/Libraries

%description -n %{libname}
Libraries injected by VirtualGL into applications that are run through it.
The lib package allow installing 32 and 64 bits libraries at the same time.

%files -n %{libname}
%{_libdir}/libdlfaker.so
%{_libdir}/libgefaker.so
%{_libdir}/libvglfaker.so
%{_libdir}/libvglfaker-nodl.so
%{_libdir}/libvglfaker-opencl.so
%{_libdir}/fakelib/libGL.so

#--------------------------------------------------------------------
%package devel
Summary:        A toolkit for displaying OpenGL applications to thin clients
Group:          Networking/Other
Requires:       %{libname} = %{version}-%{release}

%description devel
Development headers for VirtualGL.

%files devel
%{_includedir}/rrtransport.h
%{_includedir}/rr.h

#--------------------------------------------------------------------
%package -n glxspheres
Summary:        GLX Spheres test application for OpenGL rendering
Group:          Graphics/Utilities
# File moved in 2.6.1-5
Conflicts:      virtualgl < 2.6.1-5

%description -n glxspheres
Test application for OpenGL rendering drawing spheres.

%files -n glxspheres
%{_bindir}/glxspheres
%{_bindir}/eglxspheres
%if 0%{?__isa_bits} == 64
%{_bindir}/glxspheres64
%{_bindir}/eglxspheres64
%endif

#--------------------------------------------------------------------
%prep
%autosetup -p1 -n %{oname}-%{version}

# Fix old /usr/X11R6 path:
sed -e 's|usr/X11R6|usr|g' -i server/{vglgenkey,vglrun.in}
# Fix /etc/opt/VirtualGL path to /var/lib/VirtualGL:
sed -e 's|/etc/opt|/var/lib|g' -i server/{vglgenkey,vglrun.in,vglserver_config} \
                               -i doc/{unixconfig.txt,index.html,advancedopengl.txt}
# Fix documentation to match actual system setup:
sed -e 's|/opt/VirtualGL/bin|/usr/bin|g' -i ChangeLog.md -i doc/*.{txt,html}

%build
# avoid Wl,--as-needed flag otherwise the resulting libvglfaker.so it's
# not linked against libGL.so and libEGL.so. See
# https://github.com/VirtualGL/virtualgl/issues/139
export LDFLAGS="$(echo %ldflags | sed -e 's@-Wl,--as-needed@@g')"
%cmake \
    -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
    -DVGL_BUILDSTATIC=0 \
    -DVGL_SYSTEMFLTK=1 \
    -DVGL_SYSTEMGLX=1 \
    -DVGL_SYSTEMXCB=1 \
    -DVGL_FAKEXCB=1 \
    -DVGL_USEXV=1 \
    -DVGL_USESSL=0 \
    -DVGL_LIBDIR=%{_libdir} \
    -DTJPEG_INCLUDE_DIR=%{_includedir} \
    -DTJPEG_LIBRARY=%{_libdir}/libturbojpeg.so
%cmake_build

%install
%cmake_install

install -d %{buildroot}%{_libexecdir}
mv %{buildroot}%{_bindir}/.vglrun.vars%{__isa_bits} %{buildroot}%{_libexecdir}/vglrun.vars%{__isa_bits}

# Fix fakelib
mkdir -p %{buildroot}%{_libdir}/fakelib
ln -sf ../libvglfaker.so %{buildroot}%{_libdir}/fakelib/libGL.so

%if 0%{?__isa_bits} == 64
ln -s glxspheres64 %{buildroot}%{_bindir}/glxspheres
ln -s eglxspheres64 %{buildroot}%{_bindir}/eglxspheres
%endif

# The command glxinfo provided in this package is a modified version of standard
# glxinfo (see docs/advancedopengl.txt, section Troubleshooting). To avoid conflicts
# with the same version provided in package glxinfo, rename it to something other
mv -f %{buildroot}%{_bindir}/glxinfo %{buildroot}%{_bindir}/vgl-glxinfo
mv -f %{buildroot}%{_bindir}/eglinfo %{buildroot}%{_bindir}/vgl-eglinfo
mv -f %{buildroot}%{_bindir}/eglxinfo %{buildroot}%{_bindir}/vgl-eglxinfo
