# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

%define major   1
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:		vkd3d
Version:	1.14
Release:	%mkrel 1
Summary:	D3D12 to Vulkan translation library
Group:          System/Libraries

License:	LGPLv2+
URL:		https://source.winehq.org/git/vkd3d.git
Source0:	https://dl.winehq.org/vkd3d/source/%{name}-%{version}.tar.xz
Source1:	https://dl.winehq.org/vkd3d/source/%{name}-%{version}.tar.xz.sign

BuildRequires:	make
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gcc
BuildRequires:	pkgconfig(SPIRV-Tools)
BuildRequires:	pkgconfig(vulkan)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	pkgconfig(xcb-keysyms)
BuildRequires:	pkgconfig(xcb-icccm)
BuildRequires:	pkgconfig(xcb-util)
BuildRequires:	spirv-headers

BuildRequires:	mingw32-filesystem >= 95
BuildRequires:	mingw32-gcc
BuildRequires:	mingw32-spirv-headers
BuildRequires:	mingw32-spirv-tools
BuildRequires:	mingw32-vulkan-headers
BuildRequires:	mingw32-vulkan-loader

BuildRequires:	mingw64-filesystem >= 95
BuildRequires:	mingw64-gcc
BuildRequires:	mingw64-spirv-headers
BuildRequires:	mingw64-spirv-tools
BuildRequires:	mingw64-vulkan-headers
BuildRequires:	mingw64-vulkan-loader

%description
The vkd3d project includes libraries, shaders, utilities, and demos for
translating D3D12 to Vulkan.


%package -n %{libname}
Summary:	D3D12 to Vulkan translation library
Group:          System/Libraries
Obsoletes:      %{_lib}vkd3d-utils1 < 1.2-1

%description -n %{libname}
Vkd3d is a 3D graphics library built on top of Vulkan. It has an API very
similar, but not identical, to Direct3D 12.

Vkd3d can be used by projects that target Direct3D 12 as a drop-in replacement
at build-time with some modest source modifications.

%package -n %{devname}
Summary:	Development files for vkd3d
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{_lib}vkd3d-utils-devel < 1.2-1


%description -n %{devname}
Development files for vkd3d.


%package -n mingw32-%{name}
Summary:	%{summary}
BuildArch:	noarch


%description -n mingw32-%{name}
%{summary}.


%package -n mingw64-%{name}
Summary:	%{summary}
BuildArch:	noarch


%description -n mingw64-%{name}
%{summary}.


%{?mingw_debug_package}


%prep
%autosetup
mkdir ../mingw-build
cp -rp . ../mingw-build


%build
%configure
%make_build

pushd ../mingw-build
export SONAME_LIBVULKAN=vulkan-1
%mingw_configure
%mingw_make
popd


%install
%make_install
pushd ../mingw-build
%mingw_make_install
%mingw_debug_install_post
popd

#Remove libtool files and static libraries
find %{buildroot} -regextype egrep -regex '.*\.a$|.*\.la$' ! -iname '*.dll.a' -delete


%files -n %{libname}
%doc AUTHORS INSTALL README
%license COPYING LICENSE
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}-shader.so.%{major}{,.*}
%{_libdir}/lib%{name}-utils.so.%{major}{,.*}


%files -n %{devname}
# (tv) to be split in vkd3d-compiler?
%{_bindir}/%{name}-compiler
%{_bindir}/vkd3d-dxbc
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}-shader.so
%{_libdir}/lib%{name}-utils.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_libdir}/pkgconfig/lib%{name}-shader.pc
%{_libdir}/pkgconfig/lib%{name}-utils.pc



%files -n mingw32-%{name}
%license COPYING LICENSE
%{mingw32_bindir}/libvkd3d-1.dll
%{mingw32_bindir}/libvkd3d-shader-1.dll
%{mingw32_bindir}/libvkd3d-utils-1.dll
%{mingw32_includedir}/%{name}/
%{mingw32_bindir}/vkd3d-compiler.exe
%{mingw32_bindir}/vkd3d-dxbc.exe
%{mingw32_libdir}/pkgconfig/libvkd3d.pc
%{mingw32_libdir}/pkgconfig/libvkd3d-shader.pc
%{mingw32_libdir}/pkgconfig/libvkd3d-utils.pc
%{mingw32_libdir}/libvkd3d.dll.a
%{mingw32_libdir}/libvkd3d-shader.dll.a
%{mingw32_libdir}/libvkd3d-utils.dll.a


%files -n mingw64-%{name}
%license COPYING LICENSE
%{mingw64_bindir}/libvkd3d-1.dll
%{mingw64_bindir}/libvkd3d-shader-1.dll
%{mingw64_bindir}/libvkd3d-utils-1.dll
%{mingw64_bindir}/vkd3d-compiler.exe
%{mingw64_bindir}/vkd3d-dxbc.exe
%{mingw64_includedir}/%{name}/
%{mingw64_libdir}/pkgconfig/libvkd3d.pc
%{mingw64_libdir}/pkgconfig/libvkd3d-shader.pc
%{mingw64_libdir}/pkgconfig/libvkd3d-utils.pc
%{mingw64_libdir}/libvkd3d.dll.a
%{mingw64_libdir}/libvkd3d-shader.dll.a
%{mingw64_libdir}/libvkd3d-utils.dll.a

