%define debug_package %{nil}

%global __requires_exclude perl\\(Exporter\\)|perl\\(XSLoader\\)

%define with_docs 1

Summary:	A framework for configuring, compiling and installing applications
Name:		waf
Version:	2.1.5
Release:	%mkrel 2
License:	BSD and Python
Group:		Development/Tools
Url:		https://waf.io/
# Original tarfile can be found at
# https://waf.io/waf-%%{version}.tar.bz2
# We remove docs/book, as this is under CC-BY-NC-ND, which is not
# allowed in Mageia.
# We remove Waf logos ./docs/gfx/waflogo.svg ./docs/slides/presentation/gfx/waflogo.svg ./docs/sphinx/_images/waf-64x64.png
# - Waf logos, licensed CC BY-NC
Source0:	waf-%{version}.stripped.tar.xz
Source1:        macros.waf
Source3:	repack.sh
Patch0:		waf-1.8.11-libdir.patch
Patch1:		waf-1.6.9-logo.patch
Patch2:		waf-1.8.11-sphinx-no-W.patch
Patch3:		pyext-linking.patch
Patch4:		0001-Fix-linking-order-when-linking-C-and-C.patch
BuildArch:	noarch
BuildRequires:	pkgconfig(python3)
%if %{with_docs}
BuildRequires:	python3dist(sphinx)
BuildRequires:	graphviz
BuildRequires:	imagemagick
Recommends:	%{name}-doc
%endif
BuildConflicts:	waf
Requires:	python(abi) = %{python3_version}
Provides:	waf-python3 = %{version}-%{release}

%description
Waf is a Python-based framework for configuring, compiling and installing
applications. It derives from the concepts of other build tools such as
Scons, Autotools, CMake, and Ant.

%if %{with_docs}
%package -n %{name}-doc
Summary:	Documentation for %{name}
Group:		Documentation

%description -n %{name}-doc
Waf is a Python-based framework for configuring, compiling and
installing applications. It is a replacement for other tools such as
Autotools, Scons, CMake or Ant.
This package contains the HTML documentation for %{name}.
%endif

%prep
%autosetup -p1

%build
extras=
for f in waflib/extras/*.py ; do
	f=$(basename "$f" .py);
	if [ "$f" != "__init__" ]; then
		extras="${extras:+$extras,}$f" ;
	fi
done
%{python3} ./waf-light --make-waf --strip --tools="$extras"

%if %{with_docs}
# build html docs
export WAFDIR=$(pwd)
pushd docs/sphinx
%{python3} ../../waf configure build
popd
%endif

%install
# use waf so it unpacks itself
mkdir -p _temp
pushd _temp
  cp -av ../waf .
  %{python3} ./waf >/dev/null 2>&1
  pushd .waf3-%{version}-*
    find . -name '*.py' -printf '%%P\0' |
	xargs -0 -I{} install -m 0644 -p -D {} %{buildroot}%{_datadir}/waf3/{}
  popd
popd

install -m 0755 -p -D waf-light %{buildroot}%{_bindir}/waf-%{python3_version}

ln -s waf-%{python3_version} %{buildroot}%{_bindir}/waf

# remove shebangs from and fix EOL for all scripts in wafadmin
find %{buildroot}%{_datadir}/ -name '*.py' \
	-exec sed -i -e '1{/^#!/d}' -e 's|\r$||g' {} \;

# fix waf script shebang line
%py3_shebang_fix %{buildroot}%{_bindir}/waf-%{python3_version}

# remove x-bits from everything going to doc
find demos utils -type f -exec chmod 0644 {} \;

# remove hidden file
rm -f docs/sphinx/build/html/.buildinfo

# install waf rpm macro helper
install -Dpm644 %{SOURCE1} %{buildroot}%{_rpmmacrodir}/macros.waf

# do byte compilation
%py_byte_compile %{python3} %{buildroot}%{_datadir}/waf3

%if %{with_docs}
%files -n %{name}-doc
%doc docs/sphinx/build/html
%doc README* ChangeLog demos
%endif

%files
%{_rpmmacrodir}/macros.waf
%{_bindir}/%{name}
%{_bindir}/%{name}-%{python3_version}
%{_datadir}/waf3/
