# comment out if not prerelease
#define prel	rc1

%define rel	1

Summary:	Portable, fast, light and extensible IRC client
Name:		weechat
Version:	4.5.2
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv3
Group:		Networking/IRC
Url:		https://www.weechat.org/
%if 0%{?prel:1}
Source0:	https://github.com/weechat/weechat/archive/v%{version}-%{prel}/%{name}-%{version}-%{prel}.tar.gz
%else
Source0:	https://www.weechat.org/files/src/%{name}-%{version}.tar.xz
%endif
BuildRequires:	asciidoctor
BuildRequires:	cmake
BuildRequires:	ncurses-devel
BuildRequires:	curl-devel
# need for utf8 support
BuildRequires:	ncursesw-devel
BuildRequires:	perl-devel
# Ruby & Python are really needed for the build, tks lbd
BuildRequires:	python3-devel
BuildRequires:	ruby-devel
BuildRequires:	lua-devel
BuildRequires:	aspell-devel
BuildRequires:	enchant2-devel
BuildRequires:	gettext
BuildRequires:	docbook-style-xsl
BuildRequires:	gnutls-devel
BuildRequires:	libgcrypt-devel
BuildRequires:	tcl-devel
BuildRequires:	guile3.0-devel
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(libcjson)
Obsoletes:	%{name}-gtk

%description
WeeChat (Wee Enhanced Environment for Chat) is a fast, light and extensible
chat client designed for many platforms.

Main features are:
- modular: a lightweight core with plugins around
- multi-protocols: IRC and Jabber (other soon)
- extensible: C plugins and scripts (Perl, Python, Ruby, Lua and Tcl)
- free software: released under GPLv3 license
- fully documented: user's guide, API, FAQ,.. translated in many languages

%files -f %{name}.lang
%doc doc/en/*.html
%{_bindir}/%{name}
%{_bindir}/%{name}-curses
%{_bindir}/%{name}-headless
%{_mandir}/man1/%{name}*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_datadir}/applications/%{name}.desktop
%{_libdir}/%{name}/plugins/alias.so
%{_libdir}/%{name}/plugins/buflist.so
%{_libdir}/%{name}/plugins/exec.so
%{_libdir}/%{name}/plugins/fifo.so
%{_libdir}/%{name}/plugins/fset.so
%{_libdir}/%{name}/plugins/irc.so
%{_libdir}/%{name}/plugins/logger.so
%{_libdir}/%{name}/plugins/relay.so
%{_libdir}/%{name}/plugins/script.so
%{_libdir}/%{name}/plugins/trigger.so
%{_libdir}/%{name}/plugins/typing.so
%{_libdir}/%{name}/plugins/xfer.so
%{_iconsdir}/hicolor/*/apps/%{name}.png

#--------------------------------------------------------------------

%package perl
Group:		Networking/IRC
Summary: 	Weechat perl plugins
Requires:	%{name} = %{version}

%description perl
This package allow weechat to use perl scripts

%files perl
%{_libdir}/%{name}/plugins/perl.so

#--------------------------------------------------------------------

%package python
Group:		Networking/IRC
Summary:	Weechat python plugins
Requires:	%{name} = %{version}

%description python
This package allow weechat to use python scripts

%files python
%{_libdir}/%{name}/plugins/python.so

#--------------------------------------------------------------------

%package guile
Group:          Networking/IRC
Summary:        Weechat guile plugins
Requires:       %{name} = %{version}

%description guile
This package allow weechat to use guile scripts

%files guile
%{_libdir}/%{name}/plugins/guile.so

#--------------------------------------------------------------------

%package tcl
Group:		Networking/IRC
Summary:	Weechat tcl plugins
Requires:	%{name} = %{version}

%description tcl
This package allow weechat to use tcl scripts

%files tcl
%{_libdir}/%{name}/plugins/tcl.so

#--------------------------------------------------------------------

%package ruby
Group:		Networking/IRC
Summary:	Weechat ruby plugins
Requires:	%{name} = %{version}

%description ruby
This package allow weechat to use ruby scripts

%files ruby
%{_libdir}/%{name}/plugins/ruby.so

#--------------------------------------------------------------------

%package lua
Group:		Networking/IRC
Summary:	Weechat lua plugins
Requires:	%{name} = %{version}

%description lua
This package allow weechat to use lua scripts

%files lua
%{_libdir}/%{name}/plugins/lua.so

#--------------------------------------------------------------------

%package charset
Group:		Networking/IRC
Summary:	Weechat charset plugins
Requires:	%{name} = %{version}

%description charset
This package allow weechat to use charset

%files charset
%{_libdir}/%{name}/plugins/charset.so

#--------------------------------------------------------------------

%package aspell
Group:		Networking/IRC
Summary:	Weechat spell check plugins
Requires:	%{name} = %{version}

%description aspell
This package allow weechat to use spell checker feature.

%files aspell
%{_libdir}/%{name}/plugins/spell.so

#--------------------------------------------------------------------

%package  devel
Summary:	Development files for weechat
Group:		Development/C
Requires:	%{name} = %{version}-%{release}

%description devel
WeeChat (Wee Enhanced Environment for Chat) is a portable, fast, light and
extensible IRC client. Everything can be done with a keyboard.
It is customizable and extensible with scripts.

This package contains include files and pc file for weechat.

%files devel
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}%{?prel:-%prel}

%build
%cmake \
	-DPREFIX=%{_prefix} \
	-DLIBDIR=%{_libdir} \
	-DENABLE_ENCHANT=ON \
	-DENABLE_MAN=ON \
	-DENABLE_JAVASCRIPT=OFF \
	-DCA_FILE=/etc/pki/tls/certs/ca-bundle.crt \
	-DENABLE_PHP=OFF
%cmake_build

asciidoctor doc/en/*.adoc

%install
%cmake_install

%find_lang %{name} --all-name --with-man
