# This is the timestamp and hash added to the release tarball
%define extra 113634-bbcac864

%define _enable_debug_package %{nil}
%define debug_package %{nil}

Name: wezterm
Version: 20240127
Release: %mkrel 1
Summary: A GPU-accelerated cross-platform terminal emulator and multiplexer
License: MIT and OFL
Group: Terminals
URL: https://wezfurlong.org/wezterm/
Source0: https://github.com/wez/wezterm/releases/download/%{version}-%{extra}/wezterm-%{version}-%{extra}-src.tar.gz
Source1: https://github.com/wez/wezterm/releases/download/%{version}-%{extra}/wezterm-%{version}-%{extra}-src.tar.gz.sha256
# This is packaged vendor and termwiz/vendor
Source2: wezterm-%{version}-vendor.tar.xz

Source4: %{name}.cargo
Source5: termwiz.cargo

# You can use this file to vendor and compress
Source100: pack-cargo-vendor.sh

BuildRequires: cargo
BuildRequires: cargo-rpm-macros
BuildRequires: imagemagick
BuildRequires: ncurses
BuildRequires: libmesaegl-devel
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(xcb)
BuildRequires: pkgconfig(xkbcommon)
BuildRequires: pkgconfig(wayland-server)
BuildRequires: pkgconfig(xcb-util)
BuildRequires: pkgconfig(xcb-keysyms)
BuildRequires: pkgconfig(xcb-image)
BuildRequires: pkgconfig(xcb-ewmh)

Requires: %{name}-terminfo = %{version}-%{release}
Requires: %{name}-gui = %{version}-%{release}

%description
ezTerm is a powerful cross-platform terminal emulator and multiplexer written
by @wez and implemented in Rust.

Features
- Runs on Linux, macOS, Windows 10 and FreeBSD
- Multiplex terminal panes, tabs and windows on local and remote hosts, with
  native mouse and scrollback
- Ligatures, Color Emoji and font fallback, with true color and dynamic color
  schemes.
- Hyperlinks
- And more

%package bash-completion
Summary: bash completion for %{name}
Group: Terminals
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description bash-completion
Bash completion file for %{name}.

%package zsh-completion
Summary: ZSH completion for %{name}
Group: Terminals
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description zsh-completion
ZSH completion file for %{name}.

%package fish-completion
Summary: fish completion for %{name}
Group: Terminals
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description fish-completion
Fish completion file for %{name}.

%package nautilus
Summary: Nautilus integration for %{name}
Group: Terminals
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description nautilus
%{summary}.

%package docs
Summary: Documentation for %{name}
Group: Terminals
BuildArch: noarch

%description docs
%{summary}.

%package terminfo
Summary: Terminfo for %{name}
Group: Terminals
BuildArch: noarch

%description terminfo
%{summary}.

Install this on servers and other computers where you normally don't need
or want to install the full package.

%package mux-server
Summary: Wezterm Multiplex Server for headless systems
Group: Terminals

%description mux-server
Install this package on headless systems and other computers where you
normally don't need or want to install the full package.

%package gui
Summary: Wezterm GUI
Group: Terminals
Requires: %{name} = %{version}-%{release}

%description gui
This is the GUI portion of the terminal

%prep
%autosetup -p1 -n %{name}-%{version}-%{extra} -a 2

%__cp %{S:4} .cargo/config
%__mkdir termwiz/.cargo
%__cp %{S:5} termwiz/.cargo/config

%build
#cargo build --release --features distro-defaults,vendored-fonts
%{cargo_build} --features distro-defaults,vendored-fonts

%install
%__mkdir_p %{buildroot}%{_bindir}
%__cp target/release/%{name} %{buildroot}%{_bindir}/
%__cp target/release/%{name}-gui %{buildroot}%{_bindir}/
%__cp target/release/%{name}-mux-server %{buildroot}%{_bindir}/
%__cp target/release/strip-ansi-escapes %{buildroot}%{_bindir}/

# Icons
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/16x16/apps
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/32x32/apps
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/48x48/apps
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/64x64/apps
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/128x128/apps
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/256x256/apps
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/512x512/apps
%__mkdir_p %{buildroot}%{_iconsdir}/hicolor/scalable/apps

convert assets/icon/wezterm-icon.svg \
	-resize 16x16 %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
convert assets/icon/wezterm-icon.svg \
	-resize 32x32 %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
convert assets/icon/wezterm-icon.svg \
	-resize 48x48 %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png
convert assets/icon/wezterm-icon.svg \
	-resize 64x64 %{buildroot}%{_iconsdir}/hicolor/64x64/apps/%{name}.png
convert assets/icon/wezterm-icon.svg \
	-resize 128x128 %{buildroot}%{_iconsdir}/hicolor/128x128/apps/%{name}.png
convert assets/icon/wezterm-icon.svg \
	-resize 256x256 %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}.png
convert assets/icon/wezterm-icon.svg \
	-resize 512x512 %{buildroot}%{_iconsdir}/hicolor/512x512/apps/%{name}.png
%__cp assets/icon/wezterm-icon.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

# Completions
%__mkdir_p %{buildroot}%{_datadir}/bash-completions/completions
%__mkdir_p %{buildroot}%{_datadir}/zsh/site-functions
%__mkdir_p %{buildroot}%{_datadir}/fish/vendor_completions.d
%__cp assets/shell-completion/bash %{buildroot}%{_datadir}/bash-completions/completions/%{name}
%__cp assets/shell-completion/zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
%__cp assets/shell-completion/fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

# Desktop
%__mkdir_p %{buildroot}%{_datadir}/applications/
%__cp assets/%{name}.desktop %{buildroot}%{_datadir}/applications/
%__mkdir_p %{buildroot}%{_metainfodir}
%__cp assets/wezterm.appdata.xml %{buildroot}%{_metainfodir}/
%__mkdir_p %{buildroot}%{_datadir}/nautilus-python/extensions/
%__cp assets/wezterm-nautilus.py %{buildroot}%{_datadir}/nautilus-python/extensions/
%__mkdir_p %{buildroot}%{_sysconfdir}/profile.d
%__cp assets/shell-integration/wezterm.sh %{buildroot}%{_sysconfdir}/profile.d/
%__mkdir_p %{buildroot}%{_datadir}/terminfo/w
%{_bindir}/tic -x -o %{buildroot}%{_datadir}/terminfo/ termwiz/data/wezterm.terminfo

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}
%{_bindir}/strip-ansi-escapes
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_datadir}/applications/%{name}.desktop
%{_metainfodir}/%{name}.appdata.xml
%{_sysconfdir}/profile.d/%{name}.sh

%files bash-completion
%{_datadir}/bash-completions/completions/%{name}

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{name}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files nautilus
%{_datadir}/nautilus-python/extensions/%{name}-nautilus.py

%files terminfo
%{_datadir}/terminfo/w/%{name}

%files mux-server
%{_bindir}/%{name}-mux-server

%files gui
%{_bindir}/%{name}-gui

%files docs
%doc docs/*
