%global namedreltag -incubating
%global namedversion %{version}%{?namedreltag}
Name:          whirr
Version:       0.6.0
Release:       %mkrel 1
Summary:       Apache Whirr is a set of libraries for running cloud services
Group:         Development/Java
License:       ASL 2.0
Url:           https://whirr.apache.org/
Source0:       https://archive.apache.org/dist/incubator/whirr/whirr-%{namedversion}/whirr-%{namedversion}-src.tar.gz
Source1:       whirr-0.6.0-incubating-depmap

Patch0:        whirr-0.6.0-incubating-build-fix.patch

BuildRequires: java-devel
BuildRequires: jpackage-utils

BuildRequires: apache-cassandra
BuildRequires: apache-commons-codec
BuildRequires: apache-commons-configuration
BuildRequires: apache-commons-io
BuildRequires: apache-hbase
BuildRequires: apache-zookeeper
BuildRequires: dnsjava >= 2.0.8
BuildRequires: hadoop
BuildRequires: hama
BuildRequires: hamcrest
BuildRequires: httpcomponents-client
BuildRequires: httpcomponents-core
BuildRequires: guava
BuildRequires: jackson
BuildRequires: jclouds
BuildRequires: jdom
BuildRequires: jopt-simple >= 3.2
BuildRequires: jsch
BuildRequires: junit4
BuildRequires: liblog4j-java
BuildRequires: libthrift-java
BuildRequires: mockito
BuildRequires: not-yet-commons-ssl
BuildRequires: protobuf-java
BuildRequires: slf4j
BuildRequires: voldemort-java

BuildRequires: apache-rat-plugin
BuildRequires: maven-assembly-plugin
BuildRequires: maven-checkstyle-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-dependency-plugin
BuildRequires: maven-doxia
BuildRequires: maven-enforcer-plugin
BuildRequires: maven-failsafe-plugin
BuildRequires: maven-gpg-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-pdf-plugin
BuildRequires: maven-project-info-reports-plugin
BuildRequires: maven-remote-resources-plugin
BuildRequires: maven-site-plugin
BuildRequires: maven-source-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: maven-wagon

Requires:      apache-cassandra
Requires:      apache-commons-codec
Requires:      apache-commons-configuration
Requires:      apache-commons-io
Requires:      apache-hbase
Requires:      apache-zookeeper
Requires:      dnsjava
Requires:      guava
Requires:      hadoop
Requires:      hama
Requires:      hamcrest
Requires:      httpcomponents-client
Requires:      httpcomponents-core
Requires:      jclouds
Requires:      jdom
Requires:      jopt-simple
Requires:      jsch
Requires:      junit4
Requires:      liblog4j-java
Requires:      libthrift-java
Requires:      mockito
Requires:      not-yet-commons-ssl
Requires:      protobuf-java
Requires:      slf4j
Requires:      voldemort-java

Requires:      jpackage-utils
Requires:      java
BuildArch:     noarch

%description
Apache Whirr is a set of libraries for running cloud services.

Whirr provides:

* A cloud-neutral way to run services. You don't have to worry about the
  idiosyncrasies of each provider.
* A common service API. The details of provisioning are particular to the
  service.
* Smart defaults for services. You can get a properly configured system running quickly,
  while still being able to override settings as needed.


%package javadoc
Summary:       Javadocs for %{name}
Group:         Development/Java
Requires:      jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n whirr-%{namedversion}-src
find -name '*.class' -exec rm -f '{}' \;
find -name '*.jar' -exec rm -f '{}' \;

%patch -P 0 -p1

rm core/src/test/java/org/apache/whirr/ClusterTest.java \
  core/src/test/java/org/apache/whirr/util/integration/BlobCacheTest.java \
  core/src/test/java/org/apache/whirr/service/integration/BlobClusterStateStoreTest.java
 
rm services/cassandra/src/test/java/org/apache/whirr/service/cassandra/integration/CassandraServiceTest.java

rm services/hadoop/src/test/java/org/apache/whirr/service/hadoop/integration/benchmark/HadoopServiceTestDFSIOBenchmark.java \
  services/hadoop/src/test/java/org/apache/whirr/service/hadoop/integration/benchmark/HadoopBenchmarkSuite.java

rm services/hbase/src/test/java/org/apache/whirr/service/hbase/integration/*.java

rm services/cdh/src/test/java/org/apache/whirr/service/cdh/integration/*.java

rm services/elasticsearch/src/test/java/org/apache/whirr/service/elasticsearch/ElasticSearchConfigurationBuilderTest.java

rm cli/src/test/java/org/apache/whirr/cli/command/RunScriptCommandTest.java \
  cli/src/test/java/org/apache/whirr/cli/command/DestroyInstanceCommandTest.java

%build

mvn-rpmbuild -Dmaven.local.depmap.file=%{SOURCE1} install javadoc:aggregate

%install

mkdir -p %{buildroot}%{_javadir}/%{name}

mkdir -p %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-%{name}.pom
%add_maven_depmap JPP.%{name}-%{name}.pom

for m in build-tools \
  core \
  cli \
  examples ; do

  install -m 644 ${m}/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-${m}.pom
  install -m 644 ${m}/target/%{name}-${m}-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}/${m}.jar
  %add_maven_depmap JPP.%{name}-${m}.pom %{name}/${m}.jar
done

for services in cassandra \
  cdh \
  elasticsearch \
  hadoop \
  hama \
  hbase \
  voldemort \
  zookeeper ; do

  install -m 644 services/${services}/pom.xml %{buildroot}%{_mavenpomdir}/JPP.%{name}-${services}.pom
  install -m 644 services/${services}/target/%{name}-${services}-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}/${services}.jar
  %add_maven_depmap JPP.%{name}-${services}.pom %{name}/${services}.jar
done

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}

%files
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/build-tools.jar
%{_javadir}/%{name}/cassandra.jar
%{_javadir}/%{name}/cdh.jar
%{_javadir}/%{name}/cli.jar
%{_javadir}/%{name}/core.jar
%{_javadir}/%{name}/elasticsearch.jar
%{_javadir}/%{name}/examples.jar
%{_javadir}/%{name}/hadoop.jar
%{_javadir}/%{name}/hama.jar
%{_javadir}/%{name}/hbase.jar
%{_javadir}/%{name}/voldemort.jar
%{_javadir}/%{name}/zookeeper.jar
%{_mavenpomdir}/JPP.%{name}-*.pom
%{_mavendepmapfragdir}/%{name}
%doc CHANGES.txt DISCLAIMER.txt LICENSE.txt NOTICE.txt README.txt

%files javadoc
%{_javadocdir}/%{name}
%doc LICENSE.txt
