%bcond_without qt

Summary:	Linux WPA Supplicant (IEEE 802.1X, WPA, WPA2, RSN, IEEE 802.11i)
Name:		wpa_supplicant
Version:	2.11
Release:	%mkrel 3
License:	GPLv2+
Group:		Communications/Mobile
URL:		https://w1.fi/wpa_supplicant/
Source0:	https://w1.fi/releases/%{name}-%{version}.tar.gz
Source1:	wpa_supplicant.service
Source2:	wpa_supplicant.sysconfig
Source3:	wpa_supplicant.logrotate
Source4:	wpa_supplicant.tmpfiles
Source5:	wpa_supplicant.mgaconf
Patch1:		wpa_supplicant-2.11-mga-defconfig.patch
Patch2:		wpa_supplicant-1.0-mga-dbus-service-file-args.patch

# fedora patches
# quiet an annoying and frequent syslog message
Patch51:	wpa_supplicant-2.2-quiet-scan-results-message.patch
# distro specific customization for Qt4 build tools, not suitable for upstream
Patch52:	wpa_supplicant-gui-qt4.patch
# Allow legacy renegotiation with openssl 3.0 to fix connection to
# PEAP/Radius servers that don't support secure renegotiation:
# https://bugzilla.redhat.com/show_bug.cgi?id=2072070
Patch53:	wpa_supplicant-allow-legacy-renegotiation.patch
# Move signal strength change messages to debug to drastically reduce logging spew
# see https://bugzilla.redhat.com/2309148
# From: https://w1.fi/cgit/hostap/commit/?id=c330b5820eefa8e703dbce7278c2a62d9c69166a
Patch54:	wpa_supplicant-Send-signal-change-as-debug-msg.patch 
#
# security patches
Patch100:	CVE-2025-24912.patch

BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	doxygen
%if %{with qt}
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5Widgets)
%endif
BuildRequires:	pkgconfig(libnl-3.0)
Requires(post):	systemd >= %{systemd_required_version}

%description
wpa_supplicant is a WPA Supplicant for Linux, BSD and Windows with
support for WPA and WPA2 (IEEE 802.11i / RSN). Supplicant is the IEEE
802.1X/WPA component that is used in the client stations. It
implements key negotiation with a WPA Authenticator and it controls
the roaming and IEEE 802.11 authentication/association of the wlan
driver.

wpa_supplicant is designed to be a "daemon" program that runs in the
background and acts as the back-end component controlling the wireless
connection. wpa_supplicant supports separate frontend programs and an
example text-based frontend, wpa_cli, is included with wpa_supplicant.

Supported WPA/IEEE 802.11i features:
    * WPA-PSK ("WPA-Personal")
    * WPA with EAP (e.g., with RADIUS authentication server)
      ("WPA-Enterprise")
    * key management for CCMP, TKIP, WEP104, WEP40
    * WPA and full IEEE 802.11i/RSN/WPA2
    * RSN: PMKSA caching, pre-authentication

See the project web site or the eap_testing.txt file for a complete
list of supported EAP methods (IEEE 802.1X Supplicant), supported
drivers and interoperability testing.

%package gui
Summary:	Graphical tool for wpa_supplicant
Group:		System/Networking

%description gui
wpa_gui is a QT frontend for wpa_supplicant.
wpa_supplicant is a WPA Supplicant for Linux, BSD and Windows with
support for WPA and WPA2 (IEEE 802.11i / RSN).

%prep
%autosetup -p1

pushd wpa_supplicant
# (blino) comment all "network = { }" blocks
perl -pi -e '$_ = "# $_" if /^\s*network\s*=\s*{/ .. /^\s*}/' wpa_supplicant.conf
cp defconfig .config
popd

%build
%set_build_flags

pushd wpa_supplicant
# yes, BINDIR=_sbindir
export BINDIR="%{_sbindir}"
export LIBDIR="%{_libdir}"
%make_build
%make_build eapol_test

%if %{with qt}
pushd wpa_gui-qt4
 %qmake_qt5
 %make_build
popd
%endif

popd

%install
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -D -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

pushd wpa_supplicant

# binaries
install -d %{buildroot}%{_sbindir}
install -m 755 wpa_supplicant %{buildroot}%{_sbindir}
install -m 755 wpa_cli %{buildroot}%{_sbindir}
install -m 755 wpa_passphrase %{buildroot}%{_sbindir}
install -m 755 eapol_test %{buildroot}%{_sbindir}

%if %{with qt}
# gui
install -d %{buildroot}%{_bindir}
install -m 755 wpa_gui-qt4/wpa_gui %{buildroot}%{_bindir}
%endif

# default mga config (mga#32160)
install -d -m 755 %{buildroot}%{_sysconfdir}
install -m 600 %{SOURCE5} %{buildroot}%{_sysconfdir}/wpa_supplicant.conf

# example config
install -d -m 755 %{buildroot}%{_docdir}/%{name}
install -m 644 wpa_supplicant.conf %{buildroot}%{_docdir}/%{name}/wpa_supplicant.conf.sample

# dbus
install -d %{buildroot}%{_sysconfdir}/dbus-1/system.d
install -d %{buildroot}%{_datadir}/dbus-1/system-services
install -m 644 dbus/dbus-wpa_supplicant.conf \
    %{buildroot}%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
install -m 0644 dbus/fi.w1.wpa_supplicant1.service \
     %{buildroot}%{_datadir}/dbus-1/system-services

# man pages
install -d -m 755 %{buildroot}%{_mandir}/man{5,8}
install -m 644 doc/docbook/*.8 %{buildroot}%{_mandir}/man8
install -m 644 doc/docbook/*.5 %{buildroot}%{_mandir}/man5

popd

%post
%_tmpfilescreate %{name}

%files
%license COPYING
%doc wpa_supplicant/ChangeLog wpa_supplicant/README
%doc wpa_supplicant/eap_testing.txt wpa_supplicant/todo.txt
%doc wpa_supplicant/examples/*.conf wpa_supplicant.conf.sample
%attr(0600,root,daemon) %config(noreplace) %{_sysconfdir}/wpa_supplicant.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/wpa_supplicant
%config(noreplace) %{_sysconfdir}/sysconfig/wpa_supplicant
%{_unitdir}/wpa_supplicant.service
%dir %ghost %attr(0775, root, root) %{_rundir}/wpa_supplicant
%ghost %attr(0660, -, -) %{_rundir}/wpa_supplicant/wpa_supplicant.pid
%{_tmpfilesdir}/wpa_supplicant.conf
%{_sbindir}/wpa_cli
%{_sbindir}/wpa_passphrase
%{_sbindir}/wpa_supplicant
%{_sbindir}/eapol_test
%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
# Uncomment after it is enabled
%{_datadir}/dbus-1/system-services/fi.w1.wpa_supplicant1.service
%{_mandir}/man8/*
%{_mandir}/man5/*

%if %{with qt}
%exclude %{_mandir}/man8/wpa_gui.8.*

%files gui
%{_bindir}/wpa_gui
%{_mandir}/man8/wpa_gui.8.*
%endif

