Name: x11-driver-input-synaptics
Version: 1.9.2
Release: %mkrel 1
Summary: X.org input driver for Synaptics touchpad devices
Group: System/X11
URL: https://xorg.freedesktop.org
Source0: https://xorg.freedesktop.org/releases/individual/driver/xf86-input-synaptics-%{version}.tar.xz
Source3:        70-synaptics.conf
Source4:        70-touchpad-quirks.rules
# Fedora patches:
# Mageia patches:
Patch11:	0001-Always-enable-tapping-and-vertical-edge-scroll.patch
Patch12:	0002-When-appling-changes-via-property-mode-apply-to-all.patch

License: MIT

BuildRequires: pkgconfig(libevdev)
BuildRequires: x11-proto-devel
BuildRequires: pkgconfig(xorg-server) >= 1.9.0
BuildRequires: x11-util-macros >= 1.3.0
BuildRequires: pkgconfig(xi)
BuildRequires: pkgconfig(xtst)
BuildRequires: pkgconfig(mtdev)
Provides: synaptics = %{version}-%{release}
Obsoletes: synaptics < %{version}-%{release}

Requires: x11-server-common %(xserver-sdk-abi-requires xinput)

%description
This is the Synaptics touchpad driver for the X.Org X server. The following
touchpad models are supported:
* Synaptics
* appletouch (Post February 2005 and October 2005 Apple Aluminium Powerbooks)
* Elantech (EeePC)
* bcm5974 (Macbook Air (Jan 2008), Macbook Pro Penryn (Feb 2008), iPhone
  (2007), iPod Touch (2008)

Note that support for appletouch, elantech and bcm5974 requires the respective
kernel module.
A touchpad by default operates in compatibility mode by emulating a standard
mouse. However, by using a dedicated driver, more advanced features of the
touchpad become available.

Features:

    * Movement with adjustable, non-linear acceleration and speed.
    * Button events through short touching of the touchpad ("tapping").
    * Double-Button events through double short touching of the touchpad.
    * Dragging through short touching and holding down the finger on the
      touchpad.
    * Middle and right button events on the upper and lower corner of the
      touchpad.
    * Vertical scrolling (button four and five events) through moving the
      finger on the right side of the touchpad.
    * The up/down button sends button four/five events.
    * Horizontal scrolling (button six and seven events) through moving the
      finger on the lower side of the touchpad.
    * The multi-buttons send button four/five events, and six/seven events for
      horizontal scrolling.
    * Adjustable finger detection.
      Multifinger taps: two finger for middle button and three finger for
      right button events. (Needs hardware support. Not all models implement
      this feature.)
    * Run-time configuration using shared memory. This means you can change
      parameter settings without restarting the X server.

%package devel
Summary:        Development files for programming with the xorg synaptics driver
Group:          Development/C

%description devel
Development files for programming with the xorg synaptics driver


%prep
%setup -q -n xf86-input-synaptics-%{version}
%autopatch -p1

%build
autoreconf -v --install --force || exit 1
%configure --with-udev-rules-dir=%{_udevrulesdir}
%make_build

%install
%make_install

# FIXME: Remove all libtool archives (*.la) from modules directory.  This
# should be fixed in upstream Makefile.am or whatever.
find $RPM_BUILD_ROOT -regex ".*\.la$" | xargs rm -f --

# Remove upstream synaptics.conf as we've several special fixes in ours
rm $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d/70-synaptics.conf

install -d $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_datadir}/X11/xorg.conf.d/70-synaptics.conf

install -d $RPM_BUILD_ROOT%{_udevrulesdir}
install -m 0644 %{SOURCE4} $RPM_BUILD_ROOT%{_udevrulesdir}/70-touchpad-quirks.rules

%files
%doc README.md
%license COPYING
%{_datadir}/X11/xorg.conf.d/70-synaptics.conf
%{_libdir}/xorg/modules/input/synaptics_drv.so
%{_bindir}/synclient
%{_bindir}/syndaemon
%{_mandir}/man4/synaptics.4*
%{_mandir}/man1/synclient.1*
%{_mandir}/man1/syndaemon.1*
%{_udevrulesdir}/70-touchpad-quirks.rules

%files devel
%license COPYING
%{_libdir}/pkgconfig/xorg-synaptics.pc
%{_includedir}/xorg/synaptics-properties.h


