%global tarball xf86-video-qxl
%global moduledir %(pkg-config xorg-server --variable=moduledir )
%global driverdir %{moduledir}/drivers

%define rel 3

# Xspice is x86_64 and ARM only since spice-server is x86_64 / ARM only
%ifarch %{ix86} x86_64 %{arm} aarch64
%define with_xspice 1
%else
%define with_xspice 0
%endif

%ifarch %{ix86} x86_64
%define with_spiceccid 1
%else
%define with_spiceccid 0
%endif

#global gitdate 20160929
#global gitversion e13d28ee

%if 0%{?gitdate}

%define gver .%{gitdate}git%{gitversion}
%endif

Name:    x11-driver-video-qxl
Version: 0.1.6
Release: %mkrel %{rel}%{?gver}
Summary: X.org driver for QEMU QXL paravirt video
Group:   System/X11
URL:     https://www.x.org/
Source0: https://xorg.freedesktop.org/releases/individual/driver/%{tarball}-%{version}.tar.xz
License: MIT

# upstream patches (from https://gitlab.freedesktop.org/xorg/driver/xf86-video-qxl)

BuildRequires: make
BuildRequires: pkgconfig
BuildRequires: git-core
BuildRequires: x11-util-macros
BuildRequires: pkgconfig(xorg-server) >= 1.1.0-1
BuildRequires: spice-protocol >= 0.12.1
BuildRequires: pkgconfig(libdrm) >= 2.4.46-1
%if %{with_xspice}
BuildRequires: spice-server-devel >= 0.8.0
%if %{with_spiceccid}
BuildRequires: pkgconfig(libcacard)
BuildRequires: pkgconfig(libpcsclite)
%endif
%endif
BuildRequires: glib2-devel
BuildRequires: libtool
BuildRequires: pkgconfig(libudev)
BuildRequires: pkgconfig(xfont2)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xv)

Requires:	x11-server-common %(xserver-sdk-abi-requires ansic)
Requires:	x11-server-common %(xserver-sdk-abi-requires videodrv)

%description
X.org driver for QEMU QXL paravirt video.

%if %{with_xspice}
%package -n    x11-server-xspice
Summary:       XSpice is an X server that can be accessed by a Spice client
Requires:	x11-server-common %(xserver-sdk-abi-requires ansic)
Requires:	x11-server-common %(xserver-sdk-abi-requires videodrv)
Requires:      x11-server-xorg
Requires:      python3

%description -n x11-server-xspice
XSpice is both an X and a Spice server.
%endif

%prep
%autosetup -S git_am -n %{tarball}-%{?gitdate:%{gitdate}}%{!?gitdate:%{version}}

# python shebangs
%py3_shebang_fix scripts/Xspice

%build
autoreconf -ivf
%if %{with_xspice}
%define enable_xspice --enable-xspice
%endif
%if %{with_spiceccid}
%define enable_spiceccid --enable-ccid
%endif
%configure --disable-static %{?enable_xspice} %{?enable_spiceccid}
%make_build

%install
%make_install

# FIXME: Remove all libtool archives (*.la) from modules directory.  This
# should be fixed in upstream Makefile.am or whatever.
find $RPM_BUILD_ROOT -regex ".*\.la$" | xargs rm -f --

%if %{with_xspice}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/X11
install -p -m 644 examples/spiceqxl.xorg.conf.example \
    $RPM_BUILD_ROOT%{_sysconfdir}/X11/spiceqxl.xorg.conf
# FIXME: upstream installs this file by default, we install it elsewhere.
# upstream should just not install it and let dist package deal with
# doc/examples.
rm -f $RPM_BUILD_ROOT/usr/share/doc/xf86-video-qxl/spiceqxl.xorg.conf.example
%if !%{with_xspice}
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/X11/spiceqxl.xorg.conf
%endif
%endif

%files
%doc COPYING
%{driverdir}/qxl_drv.so


%if %{with_xspice}
%files -n x11-server-xspice
%doc COPYING README.xspice examples/spiceqxl.xorg.conf.example
%config(noreplace) %{_sysconfdir}/X11/spiceqxl.xorg.conf
%{_bindir}/Xspice
%{driverdir}/spiceqxl_drv.so
%if %{with_spiceccid}
%dir %{_libdir}/pcsc
%dir %{_libdir}/pcsc/drivers
%dir %{_libdir}/pcsc/drivers/serial
%{_libdir}/pcsc/drivers/serial/libspiceccid.so*
%endif
%endif
