# remove bogus auto-requires
%global __requires_exclude pear\\(xapian.*\\)

%define with_php 0

%global _default_patch_fuzz 2

%ifarch %mips %arm
%define build_java 0
%else
%define build_java 1
%endif
%ifarch %mips
%define build_mono 0
%else
%define build_mono 1
%endif

Summary:	Bindings for the Xapian
Name:		xapian-bindings
Version:	1.4.27
Release:	%mkrel 1
License:	GPLv2+
Group:		Development/Other
URL:		https://www.xapian.org/
Source0:	https://www.oligarchy.co.uk/xapian/%{version}/%{name}-%{version}.tar.xz
Patch0:		xapian-bindings-check-lua.patch
BuildRequires:	pkgconfig(xapian-core) >= %{version}
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(setuptools)
%if %with_php
BuildRequires:	php-devel
BuildRequires:	php-cli
%endif
BuildRequires:	pkgconfig(tcl)
%if %build_java
BuildRequires:	java-devel
BuildRequires:	javapackages-tools
BuildRequires:	javapackages-local
%endif
BuildRequires:	pkgconfig(ruby)
BuildRequires:	pkgconfig(lua)
%if %build_mono
BuildRequires:	pkgconfig(mono)
%endif
BuildRequires:	libtool
BuildRequires:	autoconf

%description
SWIG and JNI bindings allowing Xapian to be used from various
other programming languages.

%if %build_java
%package java
Summary:	Files needed for developing Java applications which use Xapian
Group:		Development/Java
Requires:	xapian >= %{version}
Requires:	java

%description java
This package provides the files needed for developing Java applications which
use Xapian.
%endif

%package lua
Summary:	Files needed for developing lua scripts which use Xapian
Group:		Development/PHP
Requires:	xapian >= %{version}
Requires:	lua%{lua_version}

%description lua
This package provides the files needed for developing
lua scripts which use Xapian.

%if %build_mono
%package mono
Summary:	Files needed for developing C# applications which use Xapian
Group:		Development/C#
Requires:	xapian >= %{version}
Requires:	mono-core

%description mono
This package provides the files needed for developing
C# applications which use Xapian.
%endif

%if %with_php
%package php
Summary:	Files needed for developing PHP scripts which use Xapian
Group:		Development/PHP
Requires:	xapian >= %{version}
Requires:	php

%description php
This package provides the files needed for developing
PHP scripts which use Xapian.
%endif

%package -n python3-%{name}
Summary:	Files needed for developing Python 3 scripts which use Xapian
Group:		Development/Python
Requires:	xapian >= %{version}
Requires:	python3
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package provides the files needed for developing
Python 3 scripts which use Xapian.

%package ruby
Summary:	Files needed for developing Ruby applications which use Xapian
Group:		Development/Ruby
Requires:	xapian >= %{version}
Requires:	ruby

%description ruby
This package provides the files needed for developing
Ruby applications which use Xapian.

%package tcl
Summary:	Files needed for developing TCL scripts which use Xapian
Group:		Development/Other
Requires:	xapian >= %{version}
Requires:	tcl

%description tcl
This package provides the files needed for developing
TCL scripts which use Xapian.

%prep
%autosetup -p1

# There is no sphinx.main in Sphinx 2
sed -i 's/sphinx\.main/sphinx.cmd.build.main/g' $(grep -r 'sphinx\.main' -l)
sed -i 's/import sphinx/import sphinx.cmd.build/g' $(grep -r 'import sphinx' -l)

%build
# (tpg) do not check for this, to much effort to provide a patch
%define Werror_cflags %nil

# We want to avoid using jni.h from libgcj-devel, so we force
# the includedir instead of using ./configure detection, which would
# default to libgcj jni.h:
# - Anssi (12/2007)
export CPPFLAGS="%{optflags} -I%{java_home}/include"
export JDK_HOME=%{java_home}
export TCL_LIB=%{tcl_sitearch}
export LUA_INC=%{_includedir}
export LUA_LIB=%{lua_libdir}
export RUBY_LIB=%{ruby_vendorlibdir}
export RUBY_LIB_ARCH=%{ruby_vendorarchdir}

autoreconf -fiv

%configure \
%if %build_mono
	--with-csharp \
%endif
	--with-lua \
%if %with_php
	--with-php7 \
%endif
	--with-python3 \
	--with-ruby \
	--with-tcl \
%if %build_java
	--with-java
%endif


%make_build

%install
%make_install jnidir=%{_libdir}

%if %build_java
# Install the needed jar file as well
install -d -m755 %{buildroot}%{_jnidir}
install -m644 java/built/xapian.jar %{buildroot}%{_jnidir}
%endif

%if %build_java
%files java
%doc %{_docdir}/xapian-bindings/java
%{_libdir}/libxapian_jni.so
%{_jnidir}/xapian.jar
%endif

%files lua
%doc %{_docdir}/xapian-bindings/lua
%{lua_libdir}/xapian.so

%if %build_mono
%files mono
%doc %{_docdir}/xapian-bindings/csharp
%{_libdir}/_XapianSharp.so
%{_libdir}/mono/XapianSharp/XapianSharp.dll
%{_libdir}/mono/gac/XapianSharp/%{version}*/XapianSharp.dll
%endif

%if %with_php
%files php
%doc %{_docdir}/xapian-bindings/php
%{_libdir}/php/extensions/xapian.so
%{_datadir}/php/xapian.php
%endif

%files -n python3-%{name}
%doc %{_docdir}/xapian-bindings/python3
%dir %{python3_sitearch}/xapian
%{python3_sitearch}/xapian/*.py*
%{python3_sitearch}/xapian/*.so
%{python3_sitearch}/xapian/__pycache__/*

%files ruby
%doc %{_docdir}/xapian-bindings/ruby
%{ruby_vendorarchdir}/_xapian.so
%{ruby_vendorlibdir}/xapian.rb

%files tcl
%doc %{_docdir}/xapian-bindings/tcl8
%{tcl_sitearch}/xapian%{version}/

