%define	major		3
%define libname		%mklibname %{name} %{major}

%define major_pp	9
%define libname_pp	%mklibname %{name}++ %{major_pp}

%define major_util	4
%define libname_util	%mklibname xmlrpc-util %{major_util}

%define develname	%mklibname %{name} -d

#define advanced_branch	1

# Upstream libxml2 back-end is completely broken since 2015
# https://sourceforge.net/p/xmlrpc-c/patches/49/
%bcond_without libxml2

Name:		xmlrpc-c
Summary:	Programming library for writing an XML-RPC server or client in C or C++
Version:	1.59.03
Release:	%mkrel 2
Group:		System/Libraries
# See doc/COPYING for details.
# The Python 1.5.2 license used by a few files is just BSD.
License:        BSD and MIT
URL:            https://xmlrpc-c.sourceforge.io/
Source0:        https://dl.sourceforge.net/sourceforge/xmlrpc-c/xmlrpc-c-%{version}.tgz

# Upstreamable patches
Patch102:       0002-Use-proper-datatypes-for-long-long.patch
Patch103:       0003-allow-30x-redirections.patch

Source2004:      0004-Add-missing-validation-of-encoding-CVE-2022-25235.patch

BuildRequires:  git-core
BuildRequires:  gcc
BuildRequires:  gcc-c++
%if %{with libxml2}
BuildRequires:  pkgconfig(libxml-2.0)
%else
# upstream has its own fork of expat
Provides:       bundled(expat)
%endif
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(ncurses)

%description
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for C and C++.

%files
%doc doc/COPYING doc/CREDITS doc/DEVELOPING
%doc doc/HISTORY doc/SECURITY doc/TESTING doc/TODO
%{_bindir}/xmlrpc
%{_bindir}/xmlrpc_dumpserver
%{_bindir}/xmlrpc_parsecall
%{_bindir}/xmlrpc_pstream
%{_bindir}/xmlrpc_transport
%{_bindir}/xml-rpc-api2cpp
%{_bindir}/xml-rpc-api2txt
%{_bindir}/xmlrpc_cpp_proxy
%{_mandir}/man1/xml-rpc-api2cpp.1*
%{_mandir}/man1/xml-rpc-api2txt.1*

#--------------------------------------------------------------------

%package -n %{libname}
Summary:	Programming library for writing an XML-RPC server or client in C
Group:		System/Libraries

%description -n %{libname}
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for C.

%files -n %{libname}
%{_libdir}/lib*.so.%{major}{,.*}

#--------------------------------------------------------------------

%package -n %{libname_pp}
Summary:	Programming library for writing an XML-RPC server or client in C++
Group:		System/Libraries

Conflicts:	%{_lib}xmlrpc-c3 < 1.51.08-2

%description -n %{libname_pp}
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for C++.

%files -n %{libname_pp}
%{_libdir}/lib*.so.%{major_pp}{,.*}

#--------------------------------------------------------------------

%package -n %{libname_util}
Summary:	Programming library for writing an XML-RPC server or client in extra C
Group:		System/Libraries

Conflicts:	%{_lib}xmlrpc-c3 < 1.51.08-2

%description -n %{libname_util}
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for extra C runtime libraries.

%files -n %{libname_util}
%{_libdir}/libxmlrpc_util.so.%{major_util}{,.*}

#--------------------------------------------------------------------

%package -n %{develname}
Summary:        Programming library for writing an XML-RPC server or client in C or C++
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname_pp} = %{version}-%{release}
Requires:       %{libname_util} = %{version}-%{release}
Requires:       %{name} >= %{version}
%if %{with libxml2}
Requires:       pkgconfig(libxml-2.0)
%endif
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for C and C++.

This package contains the development files.

%files -n %{develname}
%{_bindir}/xmlrpc-c-config
%{_includedir}/*.h
%{_includedir}/%{name}/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

#--------------------------------------------------------------------

%prep
%autosetup -Sgit

%build
%configure --enable-libxml2-backend
%make_build

%install
%make_install
%make_install -C tools

rm -f %{buildroot}%{_libdir}/libxmlrpc*.a

%check
unset PKG_CONFIG_PATH
export PKG_CONFIG_LIBDIR=%{buildroot}%{_libdir}/pkgconfig:%{_libdir}/pkgconfig:%{_datadir}/pkgconfig
PATH=%{buildroot}%{_bindir}:$PATH

_e() {
     echo "\$ $@"
     "$@"
}

set +x
_e xmlrpc-c-config --help
for comp in cgi-server server-util abyss-server client libwww-client; do
	for opt in '--version' '--libs'; do
		_e xmlrpc-c-config "$comp" $opt
	done
done
set -x
