%define major       5
%define lname       lzma
%define libname     %mklibname %{lname} %{major}
%define libdev      %mklibname -d %{lname}

# Extra documentation is installed by xz,
# these definitions are for where they exist/go
%define xz_pkgdocdir   %{_datadir}/doc/%{name}
%define dev_pkgdocdir  %{_datadir}/doc/%{libdev}

Summary:          XZ utils
Name:             xz
Version:          5.8.1
Release:          %mkrel 1
# Scripts xz{grep,diff,less,more} and symlinks (copied from gzip) are
# GPLv2+, binaries are Public Domain (linked against LGPL getopt_long but its
# OK), documentation is Public Domain.
License:          GPLv2+ and Public Domain
Group:            Archiving/Compression
URL:              https://tukaani.org/xz/
Source0:          https://github.com/tukaani-project/xz/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source2:          https://github.com/tukaani-project/xz/releases/download/v%{version}/%{name}-%{version}.tar.xz.sig
Source1:          xzme
Requires:         %{libname} = %{version}-%{release}
# add special tuning for text files, parameter: '--text':
Patch0:           xz-5.8.1-text-tune.patch

%rename           lzma
BuildRequires:    pkgconfig(zlib)
BuildRequires:    diffutils

%description
XZ provides very high compression ratio and fast decompression. The
core of the XZ utils is Igor Pavlov's LZMA SDK containing the actual
LZMA encoder/decoder. LZMA utils add a few scripts which provide
gzip-like command line interface and a couple of other XZ related
tools. Also provides:

- Average compression ratio 30% better than that of gzip and 15%
  better than that of bzip2.

- Decompression speed is only little slower than that of gzip, being
  two to five times faster than bzip2.

- In fast mode, compresses faster than bzip2 with a comparable
  compression ratio.

- Achieving the best compression ratios takes four to even twelve
  times longer than with bzip2. However, this doesn't affect
  decompressing speed.

- Very similar command line interface than what gzip and bzip2 have.

%package -n       %{libname}
Summary:          Libraries for decoding XZ/LZMA compression
Group:            System/Libraries
Requires(pre):    filesystem >= 2.1.9-18
Conflicts:        %{name} < %{version}-%{release}

%description -n   %{libname}
Libraries for decoding LZMA compression.

%package -n       %{libdev}
Summary:          Devel libraries & headers for liblzma
Group:            Development/C
Requires(pre):    filesystem >= 2.1.9-18
Requires:         %{libname} = %{version}
Provides:         %{lname}-devel = %{version}-%{release}
Provides:         lib%{lname}-devel = %{version}-%{release}
Provides:         xz-devel

%description -n %{libdev}
Devel libraries & headers for liblzma.

%prep
%setup -q
%autopatch -p1

%build
CFLAGS="%{optflags} -O3 -funroll-loops" \
%configure
%make_build

%install
%make_install
install -m755 %{SOURCE1} -D %{buildroot}%{_bindir}/xzme

rm -f %{buildroot}%{_libdir}/*.la
%find_lang %{name} --with-man --all-name

# Move examples to devel subpackage
mkdir -p %{buildroot}%{dev_pkgdocdir}
mv %{buildroot}%{xz_pkgdocdir}/examples* %{buildroot}%{dev_pkgdocdir}

%check
%__make check

%files -f %{name}.lang
%doc %{xz_pkgdocdir}
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%doc COPYING
%{_libdir}/liblzma.so.%{major}
%{_libdir}/liblzma.so.%{version}

%files -n %{libdev}
%doc COPYING
%doc %{dev_pkgdocdir}/examples*
%{_includedir}/%{lname}.h
%dir %{_includedir}/%{lname}
%{_includedir}/%{lname}/*.h
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/lib%{lname}.pc
