%define oname YafaRay

# NOTE: Please update the version and rebuild this package if blender is updated:
%define blender_addons %{_datadir}/blender/4.1/scripts/addons/
%define addon_name %{name}_v3

# Disable automatic compilation of Python files in extra directories
%global _python_bytecompile_extra 0

%define __provides_exclude_from ^%{python3_sitearch}/.*\\.so|%{_libdir}/%{name}-plugins/.*\\.so

Name:           yafaray
Version:        3.5.1
Release:        %mkrel 17
Summary:        A free open-source ray tracing render engine
Group:          Graphics/3D
License:        LGPLv2+
URL:            http://www.yafaray.org
Source0:        https://github.com/YafaRay/libYafaRay/archive/v%{version}/libYafaRay-%{version}.tar.gz
Source1:        https://github.com/YafaRay/Blender-Exporter/archive/v%{version}/Blender-Exporter-%{version}.tar.gz
Source2:        %{name}-blender.metainfo.xml
Patch1:         yafaray-openexr3.patch
# Add missing includes needed by gcc 13
Patch2:         YafaRay-include.patch
ExclusiveArch:  x86_64
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(opencv)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  swig

# Name was changed in 2014
Provides:       yafray = %{version}

# libyafarayqt.so moved from Blender subpackage to main package
Conflicts:      yafaray-blender < 3.3.0-8

%description
YafaRay is a free open-source ray tracing render engine.

Ray tracing is a rendering technique for generating realistic images by
tracing the path of light through a 3D scene. A render engine consists of
a "faceless" computer program that interacts with a host 3D application
to provide very specific ray tracing capabilities "on demand". Blender 3D
is the host application of YafaRay.

%package blender
Summary:        Blender integration scripts
Group:          Graphics/3D
License:        GPLv2+

Requires:       %{name} >= %{version}-%{release}
Requires:       blender

%description blender
YafRay uses a python-coded settings interface to set lighting and rendering
parameters. This settings interface is launched by an entry automatically
added to the Blender Render menu.

%prep
%autosetup -p1 -a 1 -n libYafaRay-%{version}

# TODO: Patch to use LIB_SUFFIX and PR upstream
sed -i -e 's|set(YAF_LIB_DIR lib)|set(YAF_LIB_DIR %{_lib})|g' CMakeLists.txt
sed -i -e 's|set(YAF_TARGET_TYPE ARCHIVE DESTINATION ${CMAKE_INSTALL_PREFIX}/lib RUNTIME)|\
    set(YAF_TARGET_TYPE ARCHIVE DESTINATION ${CMAKE_INSTALL_PREFIX}/%{_lib} RUNTIME)|g' CMakeLists.txt

mv Blender-Exporter-%{version} %{addon_name}

# Fix setup for standalone + Blender install
sed -i -e "s|PLUGIN_PATH =.*|PLUGIN_PATH = os.path.join('%{_prefix}', '%{_lib}', '%{name}-plugins')|" %{addon_name}/__init__.py
sed -i -e "s|@YAFARAY_BLENDER_EXPORTER_VERSION@|%{version}|g" %{addon_name}/__init__.py

mv %{addon_name}/tests %{addon_name}_tests

%build
%cmake \
    -DCMAKE_POSITION_INDEPENDENT_CODE=ON \
    -DUSER_RELEASE_OPTIMIZATION_FLAGS="%{optflags} -O3 -ffast-math -pthread" \
    -DWITH_QT=ON \
    -DREQUIRED_PYTHON_VERSION=%{python3_version} \
    -DYAF_BINDINGS_PY_DIR=%{python3_sitearch} \
    -DYAF_PY_VERSION=%{python3_version}

%cmake_build

%install
%cmake_install

install -d %{buildroot}%{blender_addons}
cp -pr %{addon_name} %{buildroot}%{blender_addons}

# FIXME workaround for: https://github.com/K-3D/k3d/issues/15
ln -s %{_bindir}/%{name}-xml %{buildroot}%{_bindir}/yafray

install -D -m644 %{_sourcedir}/%{name}-blender.metainfo.xml \
    %{buildroot}%{_datadir}/metainfo/%{name}-blender.metainfo.xml

# Let RPM pick docs in the file section
rm -rf %{buildroot}%{_docdir}/%{name}

# We don't ship those for now, it doesn't seem built to be used
# as a shared library.
rm -fr %{buildroot}%{_includedir}/%{name}

# Manually invoke the python byte compile macro for each path that needs byte
# compilation.
%py_byte_compile %{__python3} %{buildroot}%{_datadir}/blender/

%files
%license LICENSES
%doc AUTHORS.md CODING.md CHANGELOG.md README.md
%doc tests/*
%{_bindir}/yafray
%{_bindir}/%{name}-xml
%{_datadir}/%{name}/
%{_libdir}/%{name}-plugins/
%{_libdir}/libyafaray_v3_core.so
%{_libdir}/libyafaray_v3_plugin.so
%{_libdir}/libyafarayqt.so

%files blender
%doc %{addon_name}_tests/*
%{blender_addons}/%{addon_name}/
%{_datadir}/metainfo/%{name}-blender.metainfo.xml
%{python3_sitearch}/_yaf*.so
%{python3_sitearch}/yaf*.py*
%{python3_sitearch}/__pycache__/*
