%define url_ver		%(echo %{version} | cut -d. -f1,2)

%define enable_fts	0

%define api_version	2.0
%define gir_major       2.0
%define lib_major	0
%define lib_name        %mklibname %{name} %{api_version} %{lib_major}
%define libnamedev      %mklibname -d %{name} %{api_version}
%define gir_name        %mklibname %{name}-gir %{gir_major}

# Turn off the brp-python-bytecompile script
%define __brp_python_bytecompile %{nil}

Summary:	Event logging framework for the desktop
Name:		zeitgeist
Version:	1.0.4
Release:	%mkrel 5
License:	LGPLv3
Group:		System/Libraries
URL:		https://launchpad.net/zeitgeist
Source0:	https://launchpad.net/%{name}/%{url_ver}/%{version}/+download/%{name}-%{version}.tar.xz
# https://bugzilla.redhat.com/show_bug.cgi?id=1779103
# https://gitlab.freedesktop.org/zeitgeist/zeitgeist/issues/19
Patch1:         %{name}-1.0.4-0001-datahub-Fix-wrong-parameter-for-Event.full-ctor.patch
BuildRequires:	pkgconfig(python3)
%if %{enable_fts}
BuildRequires:	xapian-devel
%endif
BuildRequires:  make
BuildRequires:	raptor2
BuildRequires:	python3-rdflib
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(telepathy-glib)
BuildRequires:	vala-devel
Requires:	python3-dbus
Requires:	python3-pyxdg

%description
Zeitgeist is an "Event Logging Framework" that provides cross
application awareness of the desktop's activities.

You worked on a file, but you cannot remember where you saved it? You
visited a web page about basketball three days ago, but you cannot
find the URL in your browser's history? No problem, this is where
Zeitgeist enters the scene. It knows a lot about your activities and
has a feature rich D-Bus API which allows GUI applications like
gnome-zeitgeist, zeitgeistfs and others to present you your
activities in a readable way.

%package -n	%{lib_name}
Summary: 	Libraries for %{name}
Group:		System/Libraries

%description -n	%{lib_name}
This package contains the libraries for %{name}.

%package -n	%{gir_name}
Summary: 	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{lib_name} = %{version}-%{release}

%description -n	%{gir_name}
GObject Introspection interface description for %{name}.

%package -n	%{libnamedev}
Summary: 	Development libraries and header files of %{name}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Requires:	%{gir_name} = %{version}-%{release}

%description -n	%{libnamedev}
This package contains the header and pkg-config files for developing
with %{name}.

%prep
%autosetup -p1

# Regenerate C source from vala source
find -name '*.vala' -exec touch {} \; 

%build
export PYTHON=%{python3}

%configure \
%if %{enable_fts}
	--enable-fts \
%endif
	--disable-rpath
%make_build

%install
%make_install

# handle docs in files section
rm -rf %{buildroot}%{_docdir}

# fix systemd unit file
%if %{enable_fts}
sed -i -e 's,@libexecdir@,%{_libexecdir},g' %{buildroot}%{_userunitdir}/%{name}-fts.service
%endif

# remove unpackaged files
find %{buildroot} -name '*.la' -delete

%files
%doc AUTHORS NEWS
%{_bindir}/%{name}-daemon
%{_bindir}/%{name}-datahub
%{_datadir}/%{name}/
%{_datadir}/dbus-1/services/org.gnome.zeitgeist.Engine.service
%{_userunitdir}/zeitgeist.service
%{_mandir}/man1/%{name}-daemon.1*
%{_mandir}/man1/%{name}-datahub.1*
%{python3_sitelib}/%{name}/
%{_sysconfdir}/xdg/autostart/%{name}-datahub.desktop
%{_datadir}/bash-completion/completions/%{name}-daemon
#Zeitgeist full-text search (fts) indexer
%if %{enable_fts}
%{_userunitdir}/%{name}-fts.service
%dir %{_libexecdir}/%{name}/
%{_libexecdir}/%{name}/%{name}-fts
%{_datadir}/dbus-1/services/org.gnome.zeitgeist.SimpleIndexer.service
%endif

%files -n %{lib_name}
%{_libdir}/lib%{name}-%{api_version}.so.%{lib_major}
%{_libdir}/lib%{name}-%{api_version}.so.%{lib_major}.*

%files -n %{gir_name}
%{_libdir}/girepository-1.0/*-%{gir_major}.typelib

%files -n %{libnamedev}
%dir %{_includedir}/%{name}-%{api_version}
%{_includedir}/%{name}-%{api_version}/*.h
%{_libdir}/lib%{name}-%{api_version}.so
%{_libdir}/pkgconfig/%{name}-%{api_version}.pc
%{_datadir}/gir-1.0/*-%{gir_major}.gir
%{_datadir}/vala/vapi/*.vapi
%{_datadir}/vala/vapi/*.deps
