%define major	%(echo %{version} | cut -d. -f1,2)

%define libname  %mklibname %{name} %{major}
%define devname  %mklibname %{name} -d
%define qlibname %mklibname q%{name} %{major}
%define qdevname %mklibname q%{name} -d

Name:		zint
Version:	2.13.0
Release:	%mkrel 1
Summary:	Barcode generator
License:	GPLv3+
Group:		Graphics/Scanning
URL:		https://www.zint.org.uk/
Source0:	https://downloads.sourceforge.net/%{name}/%{name}-%{version}-src.tar.gz
Patch0:		zint-rpath.patch
Patch1:		zint-install-location.patch
BuildRequires:	cmake
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(zlib)
# Qt6
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6UiTools)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Svg)

BuildRequires:	desktop-file-utils

%description
Zint is a C library for encoding data in several barcode variants. The
bundled command-line utility provides a simple interface to the library.
Features of the library:
- Over 50 symbologies including all ISO/IEC standards, like QR codes.
- Unicode translation for symbologies which support Latin-1 and
  Kanji character sets.
- Full GS1 support including data verification and automated insertion of
  FNC1 characters.
- Support for encoding binary data including NULL (ASCII 0) characters.
- Health Industry Barcode (HIBC) encoding capabilities.
- Output in PNG, EPS and SVG formats with user adjustable sizes and colors.
- Verification stage for SBN, ISBN and ISBN-13 data.

%package -n %{libname}
Summary:	C library for encoding data in several barcode variants
Group:		System/Libraries
License:	BSD

%description -n %{libname}
Zint is a C library for encoding data in several barcode variants.

Features of the library:
- Over 50 symbologies including all ISO/IEC standards, like QR codes.
- Unicode translation for symbologies which support Latin-1 and
  Kanji character sets.
- Full GS1 support including data verification and automated insertion of
  FNC1 characters.
- Support for encoding binary data including NULL (ASCII 0) characters.
- Health Industry Barcode (HIBC) encoding capabilities.
- Output in PNG, EPS and SVG formats with user adjustable sizes and colors.
- Verification stage for SBN, ISBN and ISBN-13 data.

%package -n %{devname}
Summary:	Library and header files for %{name}
Group:		Development/C
License:	BSD
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
C library and header files needed to develop applications that use
the Zint library. The API documentation can be found on the project website:
https://www.zint.org.uk/zintSite/Manual.aspx

%package qt
Summary:	Zint Barcode Studio
Group:		Graphics/Scanning

%description qt
Zint Barcode Studio is a Qt-based GUI which allows desktop users to generate
barcodes which can then be embedded in documents or HTML pages.

%package -n %{qlibname}
Summary:	libQZint shared libraries
Group:		System/Libraries

%description -n %{qlibname}
libQZint shared libraries.

%package -n %{qdevname}
Summary:	Library and header files for %{name}-qt
Group:		Development/C
Requires:	%{qlibname} = %{version}-%{release}
Provides:	q%{name}-devel = %{version}-%{release}
Provides:	libq%{name}-devel = %{version}-%{release}

%description -n %{qdevname}
C library and header files needed to develop applications that use libQZint.

%prep
%autosetup -n %{name}-%{version}-src -p1

# remove BSD-licensed file required for Windows only (just to ensure that this package is plain GPLv3+)
rm -f backend/ms_stdint.h

# remove bundled getopt sources (we use the corresponding mga package instead)
rm -f frontend/getopt*

# build shared libs
sed -i -e '/add_library/s/STATIC/SHARED/g' backend_qt/CMakeLists.txt

%build
%cmake -DZINT_QT6:BOOL=ON
%cmake_build

%install
%cmake_install

#we don't need this(?)
rm -rf %{buildroot}%{_datadir}/apps

#icon
install -D -p -m 644 zint-qt.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/zint-qt.png
install -D -p -m 644 frontend_qt/images/scalable/zint-qt.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/zint-qt.svg

#.desktop file
install -D -p -m 644 %{name}-qt.desktop %{buildroot}%{_datadir}/applications/zint-qt.desktop

%files
%doc docs/manual.txt README TODO
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%files -n %{libname}
%license LICENSE
%{_libdir}/libzint.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/zint.h
%{_libdir}/libzint.so

%files qt
%doc README
%license frontend_qt/COPYING
%{_bindir}/zint-qt
%{_datadir}/applications/zint-qt.desktop
%{_iconsdir}/hicolor/*/apps/zint-qt.{png,svg}

%files -n %{qlibname}
%license backend_qt/COPYING
%{_libdir}/libQZint.so.%{major}{,.*}

%files -n %{qdevname}
%{_includedir}/qzint.h
%{_libdir}/libQZint.so
%{_libdir}/cmake/zint/
