%define _disable_ld_no_undefined 1

%global __requires_exclude_from %{_docdir}

# The version flow of zsh: N - N-dev-1 - ... - (N+1)-prel-1 ... (N+1)
#define dev  0
#define prel 0
%define zshversion 5.9

# rel to bump
%define rel 4

%if %{?dev:1}%{!?dev:0} && %{?prel:1}%{!?prel:0}
%{error:Both %%prel and %%dev defined}
%endif

%if %{?dev:1}%{!?dev:0} || %{?prel:1}%{!?prel:0}
%define devdir development/
%endif

%define srcversion %{zshversion}%{?prel:-prel-%{prel}}%{?dev:-dev-%{dev}}

Summary:	A shell with lots of features
Name:		zsh
Epoch: 		1
Version:	%zshversion%{?dev:.dev%{dev}}
Release:	%mkrel %{?prel:0.prel%{prel}.}%{rel}
Url:		https://www.zsh.org/
License:	MIT
Group:		Shells
Source0:	https://sourceforge.net/projects/zsh/files/zsh/%{version}/%{?devdir}%{name}-%{srcversion}.tar.xz
Source1:	https://sourceforge.net/projects/zsh/files/zsh-doc/%{version}/%{?devdir}%{name}-%{srcversion}-doc.tar.xz
Source2:	zcfg-mga.tar.bz2
Source3:	https://zsh.sourceforge.net/Guide/zshguide_html.tar.gz#/zshguide_html-%{srcversion}.tar.gz
Source4:	zsh.urpmi_comp

# do not use egrep in tests to make them pass again
Patch1: 0001-zsh-5.9-do-not-use-egrep-in-tests.patch
# Upstream commit ab4d62eb975a4c4c51dd35822665050e2ddc6918
Patch2: 0002-zsh-Use-int-main-in-test-c-codes.patch
# upstream commit a84fdd7c8f77935ecce99ff2b0bdba738821ed79
Patch3: 0003-zsh-fix-module-loading-problem-with-full-RELRO.patch
# upstream commit 1b421e4978440234fb73117c8505dad1ccc68d46
Patch4: 0004-zsh-enable-PCRE-locale-switching.patch
# upstream commit b62e911341c8ec7446378b477c47da4256053dc0 and 10bdbd8b5b0b43445aff23dcd412f25cf6aa328a
Patch5: 0005-zsh-port-to-pcre2.patch
# upstream commit ecd3f9c9506c7720dc6c0833dc5d5eb00e4459c4
Patch6: 0006-zsh-support-texinfo-7.0.patch
# upstream commit 4c89849c98172c951a9def3690e8647dae76308f
Patch7: 0007-zsh-configure-c99.patch
# upstream commit d3edf318306e37d2d96c4e4ea442d10207722e94
Patch8: 0008-zsh-deletefilelist-segfault.patch

# from debian
Patch10:	fix-typos-in-man-pages.patch
Patch11:	example-shebang.patch
Patch12:	further-mitigate-test-suite-hangs.patch

BuildRequires:	gdbm-devel
BuildRequires:	groff
BuildRequires:	libtermcap-devel >= 2.0
BuildRequires:	locales-ja
BuildRequires:	man-db
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(libpcre2-posix)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	rpm-helper >= 0.18.5
BuildRequires:	texi2html
BuildRequires:	texinfo
BuildRequires:	yodl
Requires(postun): rpm-helper
Requires(post): rpm-helper

%description
Zsh is a UNIX command interpreter (shell) usable as an
interactive login shell and as a shell script command
processor. Of the standard shells, zsh most closely resembles
ksh but includes many enhancements. Zsh has command-line editing,
built-in spelling correction, programmable command completion,
shell functions (with autoloading), a history mechanism, and a
lots of other features

Install the zsh package if you'd like to try out a different shell.

%package doc
Summary:	The doc package of zsh
Group:		Documentation
BuildArch:	noarch

%description doc
Zsh is a UNIX command interpreter (shell) usable as an
interactive login shell and as a shell script command
processor. Of the standard shells, zsh most closely resembles
ksh but includes many enhancements. Zsh has command-line editing,
built-in spelling correction, programmable command completion,
shell functions (with autoloading), a history mechanism, and a
lots of other features

This package include doc guid examples and manual for zsh.

%prep
%setup -q -a 2 -a 1 -n %{name}-%{srcversion}
%autopatch -p1

mv %{name}-%{srcversion}/Doc/* Doc/

mv -f Completion/Mandriva Completion/%{_vendor}
perl -i -lp -e 's@Completion/Mandriva/@Completion/%{_vendor}/@g' Src/Zle/complete.mdd

install -m 0644 %{SOURCE4}  Completion/%{_vendor}/Command/_urpmi

# remove temporary files
find | grep '~$' | xargs rm -f
perl -pi -e 's|/usr/local/bin/|%{_bindir}/|' Functions/Misc/{run-help,checkmail,zcalc}

%build
autoreconf -fi
# check for tcsetpgrp fails with "configure: error: no controlling tty" when
# building by bot; force tcsetpgrp
%configure \
	--enable-etcdir=%{_sysconfdir} \
	--enable-function-subdirs \
	--enable-pcre \
	--enable-maildir-support \
	--with-tcsetpgrp
%make_build all html

%install
%make_install install.info

# copy Mageia Configuration files.
mkdir -p %{buildroot}/{bin,etc}
cp -a zcfg/etc/z* %{buildroot}%{_sysconfdir}
cp -a zcfg/share/zshrc_default %{buildroot}%{_datadir}/%{name}/%{srcversion}/zshrc_default

# this prevents RPM helper from adding dependency on /usr/bin/zsh
find %{buildroot}%{_datadir}/%{name}/%{srcversion} -type f -exec chmod 0644 '{}' \;

# Backward compatibilie should be removed in the others times.
pushd %{buildroot}/bin && {
    mv ..%{_bindir}/%{name} ./%{name}
} && popd

# zshall.1 includes all other man pages which does not work with compressed
# files. Generate full contents here
pushd %{buildroot}%{_mandir} && {
    /usr/bin/soelim man1/zshall.1 > zshall-full
    mv zshall-full man1/zshall.1
    popd
}

rm -f %{buildroot}%{_bindir}/%{name}-%{srcversion}

# Copy documentation.
rm -rf docroot
mkdir -p docroot/{Info_html,Examples,Documentation}/

cp -a README docroot/
cp -a Functions/Misc/* Misc/* Util/* docroot/Examples/
cp -a INSTALL ChangeLog* docroot/Documentation
cp -a StartupFiles docroot/
cp -a Etc/* docroot/Documentation
cp -a Doc/*html docroot/Info_html/

mkdir -p docroot/Zsh_Guide
tar xzf %SOURCE3 -C docroot/Zsh_Guide
mv docroot/Zsh_Guide/zshguide/*html docroot/Zsh_Guide/
rm -Rf docroot/Zsh_Guide/zshguide/

# Doc
rm -f docroot/{StartupFiles/.distfiles,Examples/{Makefile*,*.yo},Documentation/{Makefile*,*.yo}}
find docroot/ -name 'Makefile*' -o -name '.yo'|xargs rm -f
find docroot/ -type f|xargs perl -pi -e 's@^#!%{_prefix}/local/bin/(perl|zsh)@#!%{_bindir}/\1@'
mv docroot/Examples/compctl-examples docroot/StartupFiles

%check
# avoid unnecessary failure of the test-suite in case ${RPS1} is set
unset RPS1

# run the test-suite
# seems there are problems in creating wtmp or utmp 
# files in the BS (in mock this works, in iurt doesn't),
# so skip C02cond and V14system tests for now.
mkdir -p Test/skip
mv -f Test/C02cond.ztst Test/skip/
mv -f Test/V14system.ztst Test/skip/
ZTST_verbose=0 make check
# rerun C02cond and V14system tests without aborting on error
mv -f Test/skip/C02cond.ztst Test/
mv -f Test/skip/V14system.ztst Test/
ZTST_continue=1 ZTST_verbose=2 make TESTNUM=C02 check || :
ZTST_continue=1 ZTST_verbose=2 make TESTNUM=V14 check || :

%post
%_post_shelladd /bin/zsh

%postun
%{_rpm_helper_dir}/del-shell %{name} $1 /bin/zsh

%files
%doc docroot/README NEWS
%doc %{_datadir}/%{name}/%{srcversion}/help
%config(noreplace) %{_sysconfdir}/z*
/bin/%{name}
%{_mandir}/man1/*.1*
%{_infodir}/*.info*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{srcversion}/
%{_datadir}/%{name}/%{srcversion}/functions
%{_datadir}/%{name}/%{srcversion}/scripts
%{_datadir}/%{name}/%{srcversion}/zshrc_default
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/%{srcversion}/
%{_datadir}/%{name}/site-functions/

%files doc
%doc docroot/Documentation/ docroot/Examples/ docroot/Info_html/
%doc docroot/StartupFiles/ docroot/Zsh_Guide ChangeLog* LICENCE
