%define fversion %(echo %version | tr -d .)
%define dversion %(echo %version | sed s/\\\\./_/)

Name:           zsnes
Epoch:          1
Version:        1.51
Release:        %mkrel 15
Summary:        Nintendo Super NES / Super Famicom Emulator
Group:          Emulators
License:        GPLv2+
URL:            https://zsnes.sourceforge.net/
Source0:        https://downloads.sourceforge.net/zsnes/%{name}%{fversion}src.tar.bz2
Source1:        %{name}-icons.tar.bz2
Patch0:         zsnes150-desktop.patch
Patch1:         zsnes-1.51-libao.patch
Patch2:         zsnes-1.51-gcc43.patch
Patch3:         zsnes-1.51-libpng15.patch
Patch4:         zsnes-1.51-gcc4.7.patch
Patch5:         zsnes-1.51-hat-events.patch
Patch6:         zsnes-1.51-matrix-init.patch
Patch7:         zsnes-1.51-no-strip.patch
Patch8:         zsnes-1.51-gcc10.patch

BuildRequires:  nasm
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(zlib)
# Does not build currently on x86_64
ExclusiveArch:  %ix86

%description
This is an emulator for Nintendo's 16 bit console, called Super Nintendo
Entertainment System or Super Famicom. It features a pretty accurate emulation
of that system's graphic and sound capabilities.
The GUI enables the user to select games, change options, enable cheat codes
and to save the game state, even network play is possible.

%prep
%setup -q -a1 -n %{name}_%{dversion}
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p0
%patch -P 3 -p0
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1

# Use -std=gnu++14 for CXX source for now, this is not ready for C++17
sed -i src/configure.in -e '\@CXXFLAGS=@s|CFLAGS|CFLAGS -std=gnu++14 |'

%build
pushd src
autoreconf -fiv
# zsnes do not work with fortify patch, and i frankly do not want to mess with the mix of asm and C source code
# (misc)
export CFLAGS="-O2 -g -pipe -fexceptions -fomit-frame-pointer -fasynchronous-unwind-tables"
export LDFLAGS="-lpthread"
%configure --enable-libao --disable-cpucheck force_arch=i586
make

%install
install -D -m755 src/zsnes %{buildroot}%{_bindir}/%{name}
install -D -m644 src/linux/zsnes.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -D -m644 src/linux/zsnes.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

for size in 16x16 32x32 48x48; do
  install -D -m644 %{name}-${size}.png %{buildroot}%{_iconsdir}/hicolor/${size}/apps/%{name}.png
done

%files
%doc docs/*
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*
