%define realname        zstd
%define libmajor        1
%define libname         %mklibname %{realname} %{libmajor}
%define libname_devel   %mklibname %{realname} -d

# enable pzstd support by default
%bcond_without pzstd

# Something is broken with how Iurt sets up the environment
# for the test suite's run...
%bcond_without check

Name:           zstd
Version:        1.5.7
Release:        %mkrel 1
Summary:        Zstd compression library
Group:          Archiving/Compression
License:        BSD and GPLv2
URL:            http://www.zstd.net/
Source0:        https://github.com/facebook/zstd/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(liblzma)

%description
Zstd, short for Zstandard, is a fast lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

%package -n %{libname}
Summary:        Zstd shared library
Group:          System/Libraries

%description -n %{libname}
Zstandard compression shared library.

%package -n %{libname_devel}
Summary:        Header files for Zstd library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{libname_devel}
Header files for Zstd library.


%prep
%setup -q
find -name .gitignore -delete

%build
%global _vpath_srcdir build/cmake/
%define _vpath_builddir build-%{_target}

%cmake -GNinja \
  -DZSTD_PROGRAMS_LINK_SHARED:BOOL=ON \
  -DZSTD_BUILD_STATIC:BOOL=OFF \
  -DZSTD_BUILD_SHARED:BOOL=ON \
  -DZSTD_BUILD_CONTRIB:BOOL=%{?with_pzstd:ON}%{?!with_pzstd:OFF} \
  -DZSTD_BUILD_TESTS:BOOL=OFF
%cmake_build

# for tests
%if %{with check}
%define _vpath_builddir build-%{_target}-check
%cmake -GNinja \
  -DZSTD_PROGRAMS_LINK_SHARED:BOOL=ON \
  -DZSTD_BUILD_STATIC:BOOL=ON \
  -DZSTD_BUILD_SHARED:BOOL=ON \
  -DZSTD_BUILD_CONTRIB:BOOL=%{?with_pzstd:ON}%{?!with_pzstd:OFF} \
  -DZSTD_BUILD_TESTS:BOOL=ON
%cmake_build

%check
%define _vpath_builddir build-%{_target}-check
export LD_LIBRARY_PATH=$(pwd)/%{_vpath_builddir}/lib
%ctest
%endif

%install
%define _vpath_builddir build-%{_target}
%cmake_install

%if %{with pzstd}
ln -s %{name}.1 %{buildroot}%{_mandir}/man1/pzstd.1
%endif

%files
%license LICENSE
%doc CHANGELOG README.md
%{_bindir}/zstd
%if %{with pzstd}
%doc %{_vpath_builddir}/contrib/gen_html/zstd_manual.html
%{_bindir}/pzstd
%{_mandir}/man1/pzstd.1*
%endif
%{_bindir}/zstdmt
%{_bindir}/unzstd
%{_bindir}/zstdcat
%{_bindir}/zstdgrep
%{_bindir}/zstdless
%{_mandir}/man1/zstd.1*
%{_mandir}/man1/unzstd.1*
%{_mandir}/man1/zstdcat.1*
%{_mandir}/man1/zstdgrep.1*
%{_mandir}/man1/zstdless.1*

%files -n %{libname}
%license LICENSE
%{_libdir}/libzstd.so.%{libmajor}{,.*}

%files -n %{libname_devel}
%{_includedir}/zdict.h
%{_includedir}/zstd.h
%{_includedir}/zstd_errors.h
%{_libdir}/pkgconfig/libzstd.pc
%{_libdir}/cmake/zstd/
%{_libdir}/libzstd.so
