%define srcname		zuluCrypt

%define major		1.2.0
%define pm_major	1.0.0
%define libname		%mklibname %{name} %{major}
%define libname_exe	%mklibname %{name}-exe %{major}
%define libname_pm	%mklibname %{name}pluginmanager %{pm_major}
%define devname		%mklibname %{name} -d

%bcond_with	bundle_lxqtwallet

Name:		zulucrypt
Version:	7.1.0
Release:	%mkrel 1
Summary:	Qt GUI front end to cryptsetup
# major license is GPLv3+ (but GPLv2+ for some source files)
# BSD for lxqt_wallet and tcplay (both bundled)
# Public Domain for bundled md5-openssl
License:	GPLv3+ and GPLv2+ and BSD and Public Domain
Group:		File tools
URL:		https://mhogomchungu.github.io/zuluCrypt
Source0:	https://github.com/mhogomchungu/zuluCrypt/releases/download/%{version}/%{srcname}-%{version}.tar.xz
# polkit policy stolen from debian, https://github.com/marciosouza20/zulucrypt
Source10:	zulucrypt-gui.policy
Source11:	zulumount-gui.policy

BuildRequires:	gcc
BuildRequires:	gcc-c++

BuildRequires:	kf6-rpm-macros
BuildRequires:	cmake(KF6Wallet)
BuildRequires:	cmake(KF6Notifications)

BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Widgets)

BuildRequires:	pkgconfig(libsecret-1)
BuildRequires:	pkgconfig(devmapper)
BuildRequires:	pkgconfig(blkid)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(ossp-uuid)
BuildRequires:	pkgconfig(pwquality)
BuildRequires:	pkgconfig(libcryptsetup)
BuildRequires:	pkgconfig(libgcrypt)
%if %{with bundle_lxqtwallet}
# Version 6.2.0 bundles lxqt-wallet 3.2.2
Provides:	bundled(lxqt-wallet) = 3.2.0
%else
BuildRequires:	pkgconfig(lxqt-wallet) >= 4.0.0
%endif

Requires:	%{name}-console = %{version}-%{release}

# ownership of top folders we place files in
Requires:	polkit
Requires:	shared-mime-info

# upstream: 'extended my "personal" copy of the library in incompatible ways'
Provides:	bundled(tcplay) = 3.3

%description
zuluCrypt is a front end to cryptsetup.
It makes it easier to use cryptsetup by providing
a Qt-based GUI and a simpler to use CLI frontend
to cryptsetup.
It does the same thing truecrypt does but without
licensing problems or requiring a user to setup
sudo for it or presenting root's password.
This package contains the applications.

#-----------------------------------------------

%package	console
Summary:	Console tools of %{name}
Group:		File tools

%description	console
This package contains the console (CLI) frontends of
zuluCrypt. Those got split into an own subpackage to
provide possible independence from Qt as some minimum.

#-----------------------------------------------

%package -n	%{libname}
Summary:	Shared library for %{name}
Group:		System/Libraries

%description -n	%{libname}
This package contains libraries that provide higher
level access to cryptsetup API and provide
mounting/unmounting API to easy opening and closing
of volume.

#-----------------------------------------------

%package -n	%{libname_exe}
Summary:	Shared library for %{name}
Group:		System/Libraries

%description -n	%{libname_exe}
This package contains libraries that provide higher
level access to cryptsetup API and provide
mounting/unmounting API to easy opening and closing
of volume..

#-----------------------------------------------

%package -n	%{libname_pm}
Summary:	Shared library for %{name}
Group:		System/Libraries

%description -n	%{libname_pm}
This package contains libraries that provide higher
level access to cryptsetup API and provide
mounting/unmounting API to easy opening and closing
of volume..

#-----------------------------------------------

%package -n	%{devname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} >= %{version}-%{release}
Requires:	%{libname_exe} >= %{version}-%{release}
Requires:	%{libname_pm} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
This package contains development files and libraries
necessary to build programs around zuluCrypt.

#-----------------------------------------------

%prep
%autosetup -p1 -n %{srcname}-%{version}

# documentation later with %%doc
mv 'ABOUT ME' AUTHORS
sed -i /docs/d CMakeLists.txt

# handle zuluSafe as a GUI application, binary needs Qt
sed -i -r 's:(zuluSafe)-cli:\1:g' CMakeLists.txt zuluSafe/CMakeLists.txt zuluSafe-cli.1
mv zuluSafe-cli.1 zuluSafe.1

# remove bundled libraries
%if %{without bundle_lxqtwallet}
rm -rf external_libraries/lxqt_wallet
%endif

# fix desktop file categories
sed -i 's|X-MandrivaLinux|X-MageiaLinux|' zuluCrypt-gui/CMakeLists.txt
sed -i 's|X-MandrivaLinux|X-MageiaLinux|' zuluMount-gui/CMakeLists.txt

%build
%cmake_kf6 \
	-DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
	-DCMAKE_SKIP_INSTALL_RPATH=ON \
	-DLIB_SUFFIX=%{_lib} \
	-DREUSEMOUNTPOINT=false \
	-DUDEVSUPPORT=true \
	-DNOGUI=false \
	-DBUILD_WITH_QT6=true \
	-DHOMEMOUNTPREFIX=false \
	-DNOGNOME=false \
	-DNOKDE=false \
	-DUSE_POLKIT=true

%cmake_build

%install
%cmake_install

%find_lang %{name} --with-qt --all-name

install -p -m0644 -t %{buildroot}%{_datadir}/polkit-1/actions -D %{SOURCE10} %{SOURCE11}

chmod 0644 %{buildroot}%{_datadir}/applications/zulu*.desktop

%files -f %{name}.lang
%doc docs/*.pdf
%doc docs/README docs/*.jpg images/*.png
%license COPYING GPLv* LICENSE
%{_bindir}/zuluCrypt-gui
%{_bindir}/zuluMount-gui
%{_bindir}/zuluPolkit
%{_bindir}/zuluSafe
# specific GUI plugins stored to libdir, need Qt
%{_libdir}/%{srcname}/
%{_datadir}/applications/zulu*.desktop
%{_iconsdir}/hicolor/*/apps/zulu*.png
%{_iconsdir}/zulu*.png
%{_datadir}/pixmaps/zulu*.png
%{_mandir}/man1/zulu*-gui.1*
%{_mandir}/man1/zuluSafe.1*
%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/mime/packages/*.xml
# find_lang does not care about subfolders
%dir %{_datadir}/%{srcname}
%dir %{_datadir}/%{srcname}/translations
%dir %{_datadir}/%{srcname}/translations/zulu*-gui

%files console
%{_bindir}/zuluCrypt-cli
%{_bindir}/zuluMount-cli
%{_mandir}/man1/zulu*-cli.1*

%files -n %{libname}
%doc AUTHORS *README* TODO changelog
%license COPYING GPLv* LICENSE
%{_libdir}/lib%{srcname}.so.%{major}{,.*}

%files -n %{libname_exe}
%doc AUTHORS *README* TODO changelog
%license COPYING GPLv* LICENSE
%{_libdir}/lib%{srcname}-exe.so.%{major}{,.*}

%files -n %{libname_pm}
%doc AUTHORS *README* TODO changelog
%license COPYING GPLv* LICENSE
%{_libdir}/lib%{srcname}PluginManager.so.%{pm_major}{,.*}

%files -n %{devname}
%{_includedir}/%{srcname}/
%{_libdir}/lib%{srcname}*.so
%{_libdir}/pkgconfig/libzulu*.pc
