%define major		0
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%bcond_with llvm

Name:		lightspark
Version:	0.9.0
Release:	%mkrel 1
Summary:	An alternative Flash Player implementation
Group:		Networking/WWW
License:	LGPLv3+
URL:		https://lightspark.github.io/
Source0:	https://github.com/lightspark/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
## Upstream patches

# Mageia patches
Patch50:	lightspark-mga-fix-desktop-categories.patch

ExclusiveArch:	%{ix86} x86_64

BuildRequires:	cmake
BuildRequires:	nasm
BuildRequires:	boost-devel
BuildRequires:	ffmpeg-devel
%if %{with llvm}
BuildRequires:	llvm-devel >= 3.9.1
%endif
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(ftgl)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(SDL2_mixer)
BuildRequires:	pkgconfig(gtkglext-1.0)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libxml++-2.6)
BuildRequires:	pkgconfig(librtmp)
BuildRequires:	pkgconfig(liblzma)

Requires:	fonts-ttf-liberation
Obsoletes:	lightspark-pulse < 0.7.2-23

%description
Lightspark is a modern, free, open-source flash player implementation.

Lightspark features:

* JIT compilation of Actionscript to native x86 bytecode using LLVM
* Hardware accelerated rendering using OpenGL Shaders (GLSL)
* Very good and robust support for current-generation Actionscript 3
* A new, clean, code base exploiting Multi-Threading and optimized for
  modern hardware. Designed from scratch after the official Flash
  documentation was released.

%package -n	%{libname}
Summary:	%{name} libraries
Group:		System/Libraries

%description -n	%{libname}
This is the libraries used by %{name}.

%package -n	%{develname}
Summary:	Development libraries for %{name}
Group:		Development/C++
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n	%{develname}
Development files for the %{name} libraries.

%package	mozilla-plugin
Summary:	Mozilla compatible plugin for %{name}
Group:		Networking/WWW
Conflicts:	gnash-firefox-plugin

%description	mozilla-plugin
This is the Mozilla compatible plugin for %{name}.

%package	ppapi-plugin
Summary:	PPAPI compatible plugin for %{name}
Group:		Networking/WWW

%description	ppapi-plugin
This is the PPAPI compatible plugin for %{name}.


%prep
%autosetup -p1

# Fix ASM dialect
sed -i -e '/ENABLE_LANGUAGE/s/ASM-NASM/ASM_NASM/g' CMakeLists.txt
sed -i -e '/ASM_DIALECT/s/-NASM/_NASM/g' conf/*.cmake

%build
%cmake \
%if %{with llvm}
	-DENABLE_LLVM=TRUE \
%endif
	-DPPAPI_PLUGIN_DIRECTORY=%{_libdir}/%{name}/PepperFlash
%cmake_build

%install
%cmake_install

#(eandry) tell lightspark where the libs are
install -d -m 0755  %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/lightspark" > %{buildroot}%{_sysconfdir}/ld.so.conf.d/lightspark-%{__isa_bits}.conf

%files
%doc ChangeLog CONTRIBUTING CONTRIBUTORS README.md
%license COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/xdg/lightspark.conf
%{_bindir}/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libCore.so
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man1/%{name}.1.*

%files -n %{libname}
%config %{_sysconfdir}/ld.so.conf.d/lightspark-%{__isa_bits}.conf
%{_libdir}/%{name}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/%{name}/lib%{name}.so

%files mozilla-plugin
%{_libdir}/mozilla/plugins/lib%{name}plugin.so

%files ppapi-plugin
%{_libdir}/%{name}/PepperFlash/
