%define pypi_name networkx

%bcond_with docs

Name:		python-%{pypi_name}
Version:	3.4.2
Release:	%mkrel 2
Summary:	Python package for the study of complex networks
License:	BSD
Group:		Development/Python
Url:		https://networkx.org/
Source0:	%{pypi_source}
Source1:	https://github.com/networkx/documentation/blob/gh-pages/%{pypi_name}-%{version}/_downloads/networkx_reference.pdf
Source2:	https://github.com/networkx/documentation/blob/gh-pages/%{pypi_name}-%{version}/_downloads/networkx_tutorial.pdf
Source3:	https://github.com/networkx/documentation/blob/gh-pages/%{pypi_name}-%{version}/_downloads/networkx-documentation.zip
# The football example requires network access, so expect it to fail.
# The parallel betweenness example hangs when executed, possibly due to a
# function that cannot be pickled.  In any case, skip it.
Patch0:		0001-networkx-3.1-doc.patch
BuildArch:	noarch

BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(docutils)
BuildRequires:	xdg-utils

%if %{with docs}
# Documentation
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(sphinx-gallery)
BuildRequires:	python3dist(sphinx-rtd-theme)
BuildRequires:	python3dist(texext)
BuildRequires:	latex
BuildRequires:	zip
%endif

%description
NetworkX (NX) is a Python package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.

Features:
* Includes standard graph-theoretic and statistical physics functions
* Easy exchange of network algorithms between applications, disciplines,
  and platforms
* Includes many classic graphs and synthetic networks
* Nodes and edges can be "anything" (e.g. time-series, text, images,
  XML records)
* Exploits existing code from high-quality legacy software in C, C++,
  Fortran, etc.
* Open source (encourages community input)
* Unit-tested

%if %{with docs}
%package	doc
Summary:	Documentation for networkx
Group:		Documentation
Requires:	python3-%{pypi_name} >= %{version}-%{release}
Provides:	bundled(js-bootstrap)

%description	doc
Documentation for networkx.
%endif

%package -n	python3-%{pypi_name}
Summary:	Python 3 package for the study of complex networks
Group:		Development/Python

Recommends:	xdg-utils

%description -n	python3-networkx
NetworkX is a Python 3 package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.

%pyproject_extras_subpkg -n python3-networkx extra

%generate_buildrequires
%pyproject_buildrequires

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Do not use env
for f in $(grep -FRl %{_bindir}/env .); do
  sed -e 's,%{_bindir}/env python[[:digit:]]*,%{__python3},' \
      -e 's,%{_bindir}/env ,%{_bindir},' \
      -i.orig $f
  touch -r $f.orig $f
  rm $f.orig
done

# Use local objects.inv for intersphinx
sed -e 's|\("https://docs\.python\.org/3/": \)None|\1"%{_docdir}/python3-docs/html/objects.inv"|' \
    -e 's|\("https://numpy\.org/doc/stable/": \)None|\1"%{_docdir}/python3-numpy-doc/objects.inv"|' \
    -i doc/conf.py

%build
%pyproject_wheel

%if %{with docs}
# Build the documentation
PYTHONPATH=$PWD/build/lib make -C doc html
%endif
rst2html --no-datestamp README.rst README.html

%install
%pyproject_install
%pyproject_save_files networkx

# Repack uncompressed zip archives
for fil in $(find doc/build -name \*.zip); do
  mkdir zip
  cd zip
  unzip ../$fil
  zip -9r ../$fil .
  cd ..
  rm -fr zip
done

%check
%define enable_tests 0
%if %{enable_tests}
%pytest -v
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.html
%license LICENSE.txt

%if %{with docs}
%files doc
%doc doc/build/html/*
%endif
